(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   4345886,     119377]*)
(*NotebookOutlinePosition[   4346639,     119403]*)
(*  CellTagsIndexPosition[   4346595,     119399]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Discrete Fourier Transform (DFT) examples", "Title"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " definitions"
}], "Section"],

Cell[CellGroupData[{

Cell["Load needed packages for this notebook", "Subsection"],

Cell[BoxData[{
    \(\(<< Graphics`Colors`;\)\), "\[IndentingNewLine]", 
    \(\(<< Calculus`FourierTransform`;\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Set up defaults", "Subsection"],

Cell[CellGroupData[{

Cell["Turn off annoying warning messages", "Subsubsection"],

Cell[BoxData[{
    \(\(Off[General::spell];\)\), "\[IndentingNewLine]", 
    \(\(Off[General::spell1];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Set default options for specific functions", "Subsubsection"],

Cell[BoxData[{
    \(\(SetOptions[Plot, Frame \[Rule] True];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[ListPlot, Frame \[Rule] True, \ PlotJoined \[Rule] True, \ 
        Axes \[Rule] {True, False}];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[Fourier, 
        FourierParameters \[Rule] {1, \(-1\)}];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[InverseFourier, 
        FourierParameters \[Rule] {1, \(-1\)}];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[FourierTransform, \ 
        FourierParameters \[Rule] {0, \(-2\) \[Pi]}];\)\), "\
\[IndentingNewLine]", 
    \(\(SetOptions[FourierTransform, \ 
        FourierParameters \[Rule] {0, \(-2\) \[Pi]}];\)\), "\
\[IndentingNewLine]", 
    \(\(SetOptions[InverseFourierTransform, \ 
        FourierParameters \[Rule] {0, \(-2\) \[Pi]}];\)\)}], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Visualization functions", "Subsection"],

Cell[CellGroupData[{

Cell["Fix time variable for sampled signals", "Subsubsection"],

Cell[BoxData[
    \(\(FixTime[signal_, 
          sampleRate_] := \[IndentingNewLine]Module[{time, 
            data}, \[IndentingNewLine]time = 
            Table[i/sampleRate, {i, 1, 
                Length[signal]}]; \[IndentingNewLine]data\  = \ {time, 
                signal} // Transpose\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Generate periodic waveform from one period", "Subsubsection"],

Cell["\<\
PeriodicSignal[f, {dmin, dmax}, {t, min, max}] generates a periodic \
waveform for the interval [min, max]. It is assumed that one period of the \
function f(t) is defined over the interval [dmin, dmax].\
\>", "Text"],

Cell[BoxData[
    \(\(PeriodicSignal[
          f_, {dmin_, dmax_}, {t_, min_, 
            max_}] := \[IndentingNewLine]Module[{T, imin, 
            imax}, \[IndentingNewLine]T\  = \ 
            dmax\  - \ dmin; \[IndentingNewLine]imin = 
            Floor[\((min - dmin)\)/T]; \[IndentingNewLine]imax = 
            Ceiling[\((max - dmax)\)/T]; \ \[IndentingNewLine]Sum[
            f[t - i\ T]\ \((UnitStep[t - dmin - i\ T]\  - \ 
                  UnitStep[t - dmax - i\ T])\), {i, imin, 
              imax}]\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot periodic waveforms", "Subsubsection"],

Cell[TextData[{
  "PeriodicPlot[f, {dmin, dmax}, {t, min, max}, opts] plots a a periodic \
waveform for the interval [min, max]. It is assumed that one period of the \
function f(t) is defined over the interval [dmin, dmax]. The 'opts' argument \
passed plotting options to the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function Plot[ ]."
}], "Text"],

Cell[BoxData[
    \(\(PeriodicPlot[f_, {dmin_, dmax_}, {t_, min_, max_}, 
          opts___] := \[IndentingNewLine]Module[{fnc}, \[IndentingNewLine]fnc \
= PeriodicSignal[f, {dmin, dmax}, {t, min, max}]; \[IndentingNewLine]Plot[
            fnc, {t, min, max}, opts]\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot discrete-time signal as sequence of amplitude lines", \
"Subsubsection"],

Cell[BoxData[
    \(\(DiscreteListPlot[signal_, color_:  Black, 
          opts___] := \[IndentingNewLine]Module[{data, g1, 
            g2}, \[IndentingNewLine]If[
            Length[signal[\([1]\)]]\  \[Equal] \ 2, \[IndentingNewLine]data = 
              signal, \[IndentingNewLine]data = 
              FixTime[signal, 
                1]\[IndentingNewLine]]; \[IndentingNewLine]g1 = \
\(Line[{{#[\([1]\)], 0}, {#[\([1]\)], #[\([2]\)]}}] &\)\  /@ \ 
              data; \[IndentingNewLine]g2 = \({PointSize[ .015], 
                  Point[#]} &\)\  /@ \ data; \[IndentingNewLine]Show[
            Graphics[{color, g1, g2}], 
            opts]\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot discrete-time signal as sequence of amplitude lines", \
"Subsubsection"],

Cell[BoxData[
    \(\(DiscreteListPlot2[signal_, color_:  Black, 
          opts___] := \[IndentingNewLine]Module[{data, g1, 
            g2}, \[IndentingNewLine]If[
            Length[signal[\([1]\)]]\  \[Equal] \ 2, \[IndentingNewLine]data = 
              signal, \[IndentingNewLine]data = 
              FixTime[signal, 
                1]\[IndentingNewLine]]; \[IndentingNewLine]g1 = \
\(Line[{{#[\([1]\)], 0}, {#[\([1]\)], #[\([2]\)]}}] &\)\  /@ \ 
              data; \[IndentingNewLine]g2 = \({PointSize[ .005], 
                  Point[#]} &\)\  /@ \ data; \[IndentingNewLine]Show[
            Graphics[{color, g1, g2}], 
            opts]\[IndentingNewLine]];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Fourier rearrange", "Subsection"],

Cell[TextData[{
  "FourierRearrange[fft] rearranges the result of an FFT (",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function Fourier[ ]), to a easier to visualize the spectrum represented \
by 'fft'. The length of the list 'fft' is assumed to be even; if it is not, \
the last term in 'fft' is dropped. "
}], "Text"],

Cell[BoxData[
    \(\(FourierRearrange[fft_, \ 
          samplingRate_] := \[IndentingNewLine]Module[{fft2, n, 
            n2}, \[IndentingNewLine]If[EvenQ[Length[fft]], \ 
            fft2\  = \ fft, \ 
            fft2\  = \ Drop[fft, \(-1\)]]; \ \[IndentingNewLine]n = 
            Length[fft]; 
          n2 = n/2; \[IndentingNewLine]{Table[\ 
                samplingRate\ i/n, {i, \(-n2\) + 1, n2}], 
              Take[fft2, {n2 + 2, n2*2}]~Join~Take[fft2, {1, n2 + 1}]} // 
            Transpose\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Short-cut functions", "Subsection"],

Cell[CellGroupData[{

Cell["Dirac delta function", "Subsubsection"],

Cell[BoxData[
    \(\(\[Delta][t_] := DiracDelta[t];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Unit step function", "Subsubsection"],

Cell[BoxData[
    \(\(u[t_] := UnitStep[t];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Pulse of width ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(p[t_, w_] := u[t + w/2] - u[t - w/2];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Hack to plot ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta](t)\)]]
}], "Subsection"],

Cell[BoxData[
    \(PlotConvert[X_, 
        w_] := \[IndentingNewLine]X\  /. \ {\[Delta][a_] \[Rule] 
            p[a, w]}\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Sampler (CT to DT converter)", "Subsection"],

Cell[BoxData[
    \(\(sampler[xc_, fs_, 
          range_: {0, 5}] := \[IndentingNewLine]Table[{n, xc[n/fs]}, {n, 
            range[\([1]\)]*fs, range[\([2]\)]*fs}];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Sampled frequency spectrum", "Subsection"],

Cell[BoxData[
    \(\(SampledSpectrum[X_, f_, fs_, n_:  5] := \[IndentingNewLine]Sum[
          X[f - k\ fs], {k, \(-n\), n}];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Definition of DTFT", "Subsection"],

Cell[BoxData[
    \(\(DTFT[
          xd_, \[Theta]_] := \[IndentingNewLine]Module[{n, xn, n1, 
            n2}, \[IndentingNewLine]{n, xn}\  = \ 
            xd\  // \ Transpose; \[IndentingNewLine]n1\  = \ First[n]; \ 
          n2\  = \ Last[n]; \[IndentingNewLine]Sum[
            xn[\([k - n1 + 1]\)]\ Exp[\(-I\)\ k\ \[Theta]], {k, n1, 
              n2}]\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Definition of DFT", "Subsection"],

Cell[BoxData[
    \(\(DFT[
          x_] := \[IndentingNewLine]Module[{x2, \ k}, \[IndentingNewLine]If[
            Length[First[x]]\  > \ 1, \ x2\  = \ Last\  /@ \ x, \ 
            x2\  = \ x]; \[IndentingNewLine]{Table[
                k, {k, 0, Length[x2] - 1}], Fourier[x2]}\  // \ 
            Transpose];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["DTFT vs. DFT: Example #1: 1Hz cosine wave", "Section"],

Cell[CellGroupData[{

Cell["Sampled sequence", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(x[t_] := Cos[2  \[Pi]\ t];\)\), "\n", 
    \(\(xd = \ sampler[x, fs = 10, {0, 3}];\)\), "\[IndentingNewLine]", 
    \(\(If[OddQ[Length[xd]], \ xd\  = \ Drop[xd, \(-1\)]];\)\), "\n", 
    \(\(gx\  = \ 
        DiscreteListPlot2[xd, \ Blue, \ Frame \[Rule] True, 
          Axes \[Rule] {True, False}, \ ImageSize \[Rule] 504, \ 
          AspectRatio \[Rule] 1/3];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
%%ImageSize: 504 168 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0328407 0.166667 0.15873 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18801 -0.0125 -3 -9 ]
[.18801 -0.0125 3 0 ]
[.35222 -0.0125 -6 -9 ]
[.35222 -0.0125 6 0 ]
[.51642 -0.0125 -6 -9 ]
[.51642 -0.0125 6 0 ]
[.68062 -0.0125 -6 -9 ]
[.68062 -0.0125 6 0 ]
[.84483 -0.0125 -6 -9 ]
[.84483 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00794 -12 -4.5 ]
[-0.0125 .00794 0 4.5 ]
[-0.0125 .0873 -24 -4.5 ]
[-0.0125 .0873 0 4.5 ]
[-0.0125 .16667 -6 -4.5 ]
[-0.0125 .16667 0 4.5 ]
[-0.0125 .24603 -18 -4.5 ]
[-0.0125 .24603 0 4.5 ]
[-0.0125 .3254 -6 -4.5 ]
[-0.0125 .3254 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18801 0 m
.18801 .00625 L
s
[(5)] .18801 -0.0125 0 1 Mshowa
.35222 0 m
.35222 .00625 L
s
[(10)] .35222 -0.0125 0 1 Mshowa
.51642 0 m
.51642 .00625 L
s
[(15)] .51642 -0.0125 0 1 Mshowa
.68062 0 m
.68062 .00625 L
s
[(20)] .68062 -0.0125 0 1 Mshowa
.84483 0 m
.84483 .00625 L
s
[(25)] .84483 -0.0125 0 1 Mshowa
.125 Mabswid
.05665 0 m
.05665 .00375 L
s
.08949 0 m
.08949 .00375 L
s
.12233 0 m
.12233 .00375 L
s
.15517 0 m
.15517 .00375 L
s
.22085 0 m
.22085 .00375 L
s
.25369 0 m
.25369 .00375 L
s
.28654 0 m
.28654 .00375 L
s
.31938 0 m
.31938 .00375 L
s
.38506 0 m
.38506 .00375 L
s
.4179 0 m
.4179 .00375 L
s
.45074 0 m
.45074 .00375 L
s
.48358 0 m
.48358 .00375 L
s
.54926 0 m
.54926 .00375 L
s
.5821 0 m
.5821 .00375 L
s
.61494 0 m
.61494 .00375 L
s
.64778 0 m
.64778 .00375 L
s
.71346 0 m
.71346 .00375 L
s
.74631 0 m
.74631 .00375 L
s
.77915 0 m
.77915 .00375 L
s
.81199 0 m
.81199 .00375 L
s
.87767 0 m
.87767 .00375 L
s
.91051 0 m
.91051 .00375 L
s
.94335 0 m
.94335 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00794 m
.00625 .00794 L
s
[(-1)] -0.0125 .00794 1 0 Mshowa
0 .0873 m
.00625 .0873 L
s
[(-0.5)] -0.0125 .0873 1 0 Mshowa
0 .16667 m
.00625 .16667 L
s
[(0)] -0.0125 .16667 1 0 Mshowa
0 .24603 m
.00625 .24603 L
s
[(0.5)] -0.0125 .24603 1 0 Mshowa
0 .3254 m
.00625 .3254 L
s
[(1)] -0.0125 .3254 1 0 Mshowa
.125 Mabswid
0 .02381 m
.00375 .02381 L
s
0 .03968 m
.00375 .03968 L
s
0 .05556 m
.00375 .05556 L
s
0 .07143 m
.00375 .07143 L
s
0 .10317 m
.00375 .10317 L
s
0 .11905 m
.00375 .11905 L
s
0 .13492 m
.00375 .13492 L
s
0 .15079 m
.00375 .15079 L
s
0 .18254 m
.00375 .18254 L
s
0 .19841 m
.00375 .19841 L
s
0 .21429 m
.00375 .21429 L
s
0 .23016 m
.00375 .23016 L
s
0 .2619 m
.00375 .2619 L
s
0 .27778 m
.00375 .27778 L
s
0 .29365 m
.00375 .29365 L
s
0 .30952 m
.00375 .30952 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.02381 .32708 m
.02381 .33333 L
s
.18801 .32708 m
.18801 .33333 L
s
.35222 .32708 m
.35222 .33333 L
s
.51642 .32708 m
.51642 .33333 L
s
.68062 .32708 m
.68062 .33333 L
s
.84483 .32708 m
.84483 .33333 L
s
.125 Mabswid
.05665 .32958 m
.05665 .33333 L
s
.08949 .32958 m
.08949 .33333 L
s
.12233 .32958 m
.12233 .33333 L
s
.15517 .32958 m
.15517 .33333 L
s
.22085 .32958 m
.22085 .33333 L
s
.25369 .32958 m
.25369 .33333 L
s
.28654 .32958 m
.28654 .33333 L
s
.31938 .32958 m
.31938 .33333 L
s
.38506 .32958 m
.38506 .33333 L
s
.4179 .32958 m
.4179 .33333 L
s
.45074 .32958 m
.45074 .33333 L
s
.48358 .32958 m
.48358 .33333 L
s
.54926 .32958 m
.54926 .33333 L
s
.5821 .32958 m
.5821 .33333 L
s
.61494 .32958 m
.61494 .33333 L
s
.64778 .32958 m
.64778 .33333 L
s
.71346 .32958 m
.71346 .33333 L
s
.74631 .32958 m
.74631 .33333 L
s
.77915 .32958 m
.77915 .33333 L
s
.81199 .32958 m
.81199 .33333 L
s
.87767 .32958 m
.87767 .33333 L
s
.91051 .32958 m
.91051 .33333 L
s
.94335 .32958 m
.94335 .33333 L
s
.97619 .32958 m
.97619 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .00794 m
1 .00794 L
s
.99375 .0873 m
1 .0873 L
s
.99375 .16667 m
1 .16667 L
s
.99375 .24603 m
1 .24603 L
s
.99375 .3254 m
1 .3254 L
s
.125 Mabswid
.99625 .02381 m
1 .02381 L
s
.99625 .03968 m
1 .03968 L
s
.99625 .05556 m
1 .05556 L
s
.99625 .07143 m
1 .07143 L
s
.99625 .10317 m
1 .10317 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .13492 m
1 .13492 L
s
.99625 .15079 m
1 .15079 L
s
.99625 .18254 m
1 .18254 L
s
.99625 .19841 m
1 .19841 L
s
.99625 .21429 m
1 .21429 L
s
.99625 .23016 m
1 .23016 L
s
.99625 .2619 m
1 .2619 L
s
.99625 .27778 m
1 .27778 L
s
.99625 .29365 m
1 .29365 L
s
.99625 .30952 m
1 .30952 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
0 .16667 m
1 .16667 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .16667 m
.02381 .3254 L
s
.05665 .16667 m
.05665 .29508 L
s
.08949 .16667 m
.08949 .21572 L
s
.12233 .16667 m
.12233 .11762 L
s
.15517 .16667 m
.15517 .03825 L
s
.18801 .16667 m
.18801 .00794 L
s
.22085 .16667 m
.22085 .03825 L
s
.25369 .16667 m
.25369 .11762 L
s
.28654 .16667 m
.28654 .21572 L
s
.31938 .16667 m
.31938 .29508 L
s
.35222 .16667 m
.35222 .3254 L
s
.38506 .16667 m
.38506 .29508 L
s
.4179 .16667 m
.4179 .21572 L
s
.45074 .16667 m
.45074 .11762 L
s
.48358 .16667 m
.48358 .03825 L
s
.51642 .16667 m
.51642 .00794 L
s
.54926 .16667 m
.54926 .03825 L
s
.5821 .16667 m
.5821 .11762 L
s
.61494 .16667 m
.61494 .21572 L
s
.64778 .16667 m
.64778 .29508 L
s
.68062 .16667 m
.68062 .3254 L
s
.71346 .16667 m
.71346 .29508 L
s
.74631 .16667 m
.74631 .21572 L
s
.77915 .16667 m
.77915 .11762 L
s
.81199 .16667 m
.81199 .03825 L
s
.84483 .16667 m
.84483 .00794 L
s
.87767 .16667 m
.87767 .03825 L
s
.91051 .16667 m
.91051 .11762 L
s
.94335 .16667 m
.94335 .21572 L
s
.97619 .16667 m
.97619 .29508 L
s
.005 w
.02381 .3254 Mdot
.05665 .29508 Mdot
.08949 .21572 Mdot
.12233 .11762 Mdot
.15517 .03825 Mdot
.18801 .00794 Mdot
.22085 .03825 Mdot
.25369 .11762 Mdot
.28654 .21572 Mdot
.31938 .29508 Mdot
.35222 .3254 Mdot
.38506 .29508 Mdot
.4179 .21572 Mdot
.45074 .11762 Mdot
.48358 .03825 Mdot
.51642 .00794 Mdot
.54926 .03825 Mdot
.5821 .11762 Mdot
.61494 .21572 Mdot
.64778 .29508 Mdot
.68062 .3254 Mdot
.71346 .29508 Mdot
.74631 .21572 Mdot
.77915 .11762 Mdot
.81199 .03825 Mdot
.84483 .00794 Mdot
.87767 .03825 Mdot
.91051 .11762 Mdot
.94335 .21572 Mdot
.97619 .29508 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 168},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000Z2000`400?l00000o`00003ooooooooi
ooooo`00<?ooool2o`0004Sooooo0ol00015ooooo`?o00001?ooool2o`00047ooooo0ol00003oooo
o`?o0000@Oooool5o`0000?ooooo0_l00010ooooo`Go00000_ooool3o`0004kooooo000_ooooo`04
o`000?ooooooooooo`0004Kooooo00Go0000ooooooooooooooooo`000015ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo0000@Oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool0?oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
043ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo04_ooooo000_
ooooo`04o`000?ooooooooooo`0004[ooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`00047ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`10ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000@Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo04_ooooo000_ooooo`04o`000?ooooooooooo`0004[o
oooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
047ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`11ooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0Boooool002oooooo00Co0000oooooooooooo0000A_ooool4o`0004Kooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00011ooooo`04o`000?ooooooooooooooo`Co0000
@Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000?oooool01_l0
003ooooooooooooooooo0000ooooo`Co0000C_ooool002oooooo00Co0000oooooooooooo0000A_oo
ool00ol0003oooooooooo`16ooooo`;o00001?ooool01?l0003oooooooooool00010ooooo`;o0000
0oooool00ol0003oooooooooo`12ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool0000oooooo`07o`000?ooooooooooooooool0003oooooo`00001Aooooo`00<?ooool2
o`0004Oooooo1Ol00015ooooo`03o`000?oooooooooo00?ooooo0_l00012ooooo`04o`000?oooooo
ooooooooo`Go0000@Oooool3o`0000Cooooo0_l00011ooooo`?o00000_ooool5o`0004gooooo003o
ooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003o
ooooooWooooo003oooooooWooooo000Woooooooo0000b?l0000:ooooo`007?ooool3o`0000Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`007Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool001Gooooo1Ol00003
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`17
ooooo`;o003oB_ooool00ol0003oooooooooo`17ooooo`;o003oBOooool00ol0003oooooooooo`17
ooooo`;o003oAOooool00ol0003oooooooooo`08ooooo`007Oooool00ol0003oooooooooo`07oooo
o`?o0000DOooool2o`00oiCooooo0_l00?nCooooo`;o003o@_ooool4o`0000[ooooo000Mooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0D_ooool00ol00?ooooooooooo`2Booooo`03
o`00oooooooooooo09;ooooo00?o003oooooooooool0A?ooool00ol0003oooooooooo`08ooooo`00
7?ooool2o`0000Wooooo00?o0000ooooooooool0D_ooool00ol00?ooooooooooo`2Booooo`03o`00
oooooooooooo09;ooooo00?o003oooooooooool0A?ooool00ol0003oooooooooo`08ooooo`007Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05;ooooo00?o003oooooooooool0T_oo
ool00ol00?ooooooooooo`2Booooo`03o`00oooooooooooo04Cooooo00?o0000ooooooooool02?oo
ool002Oooooo00?o0000ooooooooool0D_ooool00ol00?ooooooooooo`2Booooo`03o`00oooooooo
oooo09;ooooo00?o003oooooooooool0A?ooool00ol0003oooooooooo`08ooooo`009oooool00ol0
003oooooooooo`1Booooo`03o`00oooooooooooo09;ooooo00?o003oooooooooool0T_ooool00ol0
0?ooooooooooo`14ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo05;o
oooo00?o003oooooooooool0T_ooool00ol00?ooooooooooo`2Booooo`03o`00oooooooooooo04Co
oooo00?o0000ooooooooool02?ooool002Oooooo0_l0001Cooooo`03o`00oooooooooooo09;ooooo
00?o003oooooooooool0T_ooool00ol00?ooooooooooo`12ooooo`?o00002_ooool002Oooooo00?o
0000ooooooooool0D_ooool00ol00?ooooooooooo`2Booooo`03o`00oooooooooooo09;ooooo00?o
003oooooooooool0A?ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`1B
ooooo`03o`00oooooooooooo09;ooooo00?o003oooooooooool0T_ooool00ol00?ooooooooooo`14
ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo05;ooooo00?o003ooooo
ooooool0T_ooool00ol00?ooooooooooo`2Booooo`03o`00oooooooooooo04Cooooo00?o0000oooo
ooooool02?ooool002Oooooo00?o0000ooooooooool0D_ooool00ol00?ooooooooooo`2Booooo`03
o`00oooooooooooo09;ooooo00?o003oooooooooool0A?ooool00ol0003oooooooooo`08ooooo`00
9oooool00ol0003oooooooooo`1Booooo`03o`00oooooooooooo09;ooooo00?o003oooooooooool0
T_ooool00ol00?ooooooooooo`14ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oo
oooooooo04?ooooo0_l00?l=ooooo`03o`00oooooooooooo00_ooooo0_l00?mfooooo`;o003o3Ooo
ool00ol00?ooooooooooo`0<ooooo`;o003oMOooool2o`00o`gooooo00?o003oooooooooool03?oo
ool2o`00ocKooooo00?o0000ooooooooool02?ooool002Oooooo0_l00014ooooo`;o003o3Oooool0
0ol00?ooooooooooo`0;ooooo`;o003oM_ooool2o`00o`gooooo00?o003oooooooooool03?ooool2
o`00ogGooooo0_l00?l=ooooo`03o`00oooooooooooo00cooooo0_l00?ldooooo`?o00002_ooool0
02Oooooo00?o0000ooooooooool0@oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool0M?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool0MOooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool0=Oooool00ol0003oooooooooo`08ooooo`009oooool00ol0003o
ooooooooo`13ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`1dooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`1eooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0eooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo04?ooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo07Cooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo07Gooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Gooooo
00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0@oooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0M?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0MOooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0=Oooool00ol0003ooooooooo
o`08ooooo`009oooool00ol0003oooooooooo`13ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`1dooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`1eooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0eooooo`03o`000?oooooooooo00Sooooo000Woooo
o`03o`000?oooooooooo04?ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo07Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo07Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo03Gooooo00?o0000ooooooooool02?ooool002Oooooo0_l00014ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1dooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1eooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0cooooo`?o
00002_ooool002Oooooo00?o0000ooooooooool0@oooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool0M?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool0MOooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool0=Oooool00ol0003oooooooooo`08ooooo`009ooo
ool00ol0003oooooooooo`13ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`1dooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`1eooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0eooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooo
oooo04?ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo07Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo07Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo03Gooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0@oooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0M?ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0MOooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0=Oooool00ol0
003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`13ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1dooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1eooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0eooooo`03o`000?oooooooooo00So
oooo000Wooooo`03o`000?oooooooooo04?ooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo07Cooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo07Gooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo03Gooooo00?o0000ooooooooool02?ooool002Oooooo00?o
0000ooooooooool0@oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0M?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0MOooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0=Oooool00ol0003oooooooooo`08ooooo`009oooool2o`0004Cooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo07Cooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo07Gooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03?ooooo0ol0000:
ooooo`009oooool00ol0003oooooooooo`13ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`1dooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`1eooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0eooooo`03o`000?oooooooooo00Sooooo000Wooooo`03
o`000?oooooooooo04?ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo07Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo07Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo03Gooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0
@oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
M?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
MOooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
=Oooool00ol0003oooooooooo`08ooooo`004Oooool2o`0000Cooooo00?o0000ooooooooool00_oo
ool3o`0000Sooooo00?o0000ooooooooool0@oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool0M?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool0MOooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool0=Oooool00ol0003oooooooooo`08ooooo`004?ooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
ooooo`13ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`1dooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`1eooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0eooooo`03o`000?oooooooooo00Sooooo0009ooooo`Go00000_ooool01?l0003ooooooooo
ool0000;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0@oooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0M?ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0MOooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0=Oooool00ol0003ooooo
ooooo`08ooooo`004?ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00Gooooo
0ol00013ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`1dooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`1eooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0booooo`Co00002_ooool0013ooooo00Co0000oooooooooooo00001oooool4o`0000Sooooo
00?o0000ooooooooool0@oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool0M?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool0MOooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool0=Oooool00ol0003oooooooooo`08ooooo`004?ooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0@oooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0M?ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0MOooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0=Oooool00ol0003ooooo
ooooo`08ooooo`004Oooool2o`0000Sooooo1Ol00007ooooo`03o`000?oooooooooo04?ooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo07Cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo07Gooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Gooooo00?o
0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0@oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0M?ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0MOooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0=Oooool00ol0003oooooooooo`08
ooooo`009oooool00ol0003oooooooooo`13ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`1dooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`1eooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0eooooo`03o`000?oooooooooo00Sooooo000Wooooo`03
o`000?oooooooooo04?ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo07Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo07Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo03Gooooo00?o0000ooooooooool02?ooool002Oooooo0_l00014ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1dooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1eooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0cooooo`?o0000
2_ooool002Oooooo00?o0000ooooooooool0@oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool0M?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool0MOooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool0=Oooool00ol0003oooooooooo`08ooooo`009oooool0
0ol0003oooooooooo`13ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`1dooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`1eooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0eooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo
04?ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
07Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
07Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
03Gooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0@oooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0M?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0MOooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0=Oooool00ol0003o
ooooooooo`08ooooo`009oooool00ol0003oooooooooo`13ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`1dooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`1eooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0eooooo`03o`000?oooooooooo00Sooooo
000Wooooo`03o`000?oooooooooo03Cooooo0_l00?l=ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`;o003oF?ooool2o`00o`gooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00_ooooo0_l0
0?mHooooo`;o003o3_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool2o`00obOooooo00?o0000ooooooooool02?ooool002Oooooo0_l0000e
ooooo`;o003o3Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool02oooool2o`00oeSooooo0_l00?l=ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`;o003oF?ooool2o`00o`kooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo0_l00?lU
ooooo`?o00002_ooool002Oooooo00?o0000ooooooooool0=?ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo05Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Goooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool09_ooool00ol0003oooooooooo`08oooo
o`009oooool00ol0003oooooooooo`0dooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool0E_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Oooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`00
0?oooooooooo03Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Fooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool0Eoooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo02Kooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0=?oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`1Gooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool09_oo
ool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`0dooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo05Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Vooooo`03o`000?oooooo
oooo00Sooooo000Wooooo`03o`000?oooooooooo03Cooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`1Fooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0Eoooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo02Kooooo00?o0000ooooooooool02?ooool002Oo
oooo0_l0000eooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0E_ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo05Oooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0Tooooo`?o00002_ooool002Oooooo00?o0000ooooooooool0=?ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`1Gooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool09_ooool00ol0003ooooo
ooooo`08ooooo`009oooool00ol0003oooooooooo`0dooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0E_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Oooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo000W
ooooo`03o`000?oooooooooo03Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1F
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0Eoooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo02Kooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000oooo
ooooool0=?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Kooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`1Gooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool09_ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`0dooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo05Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Vooooo`03
o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo03Cooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
Eoooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo02Kooooo00?o0000ooooooooool0
2?ooool002Oooooo00?o0000ooooooooool0=?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo05Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Gooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool09_ooool00ol0003oooooooooo`08ooooo`009oooool2
o`0003Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool0Eoooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo02Cooooo0ol0000:ooooo`009oooool00ol0003oooooooooo`0dooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
05Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Vooooo`03o`000?oooooooooo
00Sooooo000Wooooo`03o`000?oooooooooo03Cooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`1Fooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0Eoooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo02Kooooo00?o0000ooooooooool02?ooool002Oooooo
00?o0000ooooooooool0=?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Kooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Gooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool09_ooool00ol0003oooooooooo`08ooooo`007Oooool2o`0000Sooooo00?o
0000ooooooooool0=?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Kooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`1Gooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool09_ooool00ol0003oooooooooo`08ooooo`007?ooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo03Cooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`1Fooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0Eoooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo02Kooooo00?o0000ooooooooool02?ooool001cooooo00Co0000
oooooooooooo00001oooool00ol0003oooooooooo`0dooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0E_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Oooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo000L
ooooo`04o`000?ooooooooooo`0000Oooooo2_l000000ol00?oo0000o`00000<o`000003o`00ool0
003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000o`00000<o`000003o`00ool0
003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000o`00000<o`000003o`00ool0
003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000o`00000<o`000003o`00ool0
003o000000co000000?o003oo`000?l000002ol000000ol00?oo0000o`00000<o`000003o`00ool0
003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000o`00000<o`000003o`00ool0
003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000o`00000<o`000003o`00ool0
003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000o`00000<o`000003o`00ool0
003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000o`00000;o`000003o`00ool0
003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000o`00000<o`000003o`00ool0
003o000000co000000?o003oo`000?l000002Ol0000:ooooo`007?ooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo05Oooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`1Gooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0E_ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02?ooool001cooooo00Co0000
oooooooooooo00001oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`1Gooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool0Eoooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Kooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000M
ooooo`;o00002?ooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`1Gooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool0Eoooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Kooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000Woooo
o`03o`000?oooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo05Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`1Goooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000oooooooo
ool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool0Eoooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo05Oooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`07ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Gooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool0Eoooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo05Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo000Wooooo`;o00002?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool0Eoooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo05Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Fooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool01_ooool3o`0000[ooooo000Wooooo`03o`000?oooooo
oooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo05Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`1Gooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00Sooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool01oooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0Eoooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo05Oooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`1Fooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02?ooool00ol0
003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Gooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool0Eoooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Ko
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00So
oooo000Wooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo05Oooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`1Gooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0E_ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02?ooool002Oooooo00?o
0000ooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0Eoooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo05Oooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool02?ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`07
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1G
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0Eoooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo000Wooooo`;o00002?ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool0Eoooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo05Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Foooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool3o`0000[ooooo000Wooooo`03
o`000?oooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo05Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`1Gooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00Sooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0
1oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
Eoooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo05Oooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`07ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Gooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool0Eoooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo05Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo000Wooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Oooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02oooool0
0ol00?ooooooooooo`1Gooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0E_ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02?ooool0
02Oooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool0Eoooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
05Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003o
ooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`1Gooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0Eoooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo00Oooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Oooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`1Gooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool0E_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Sooooo
00?o0000ooooooooool02?ooool002Oooooo0_l00008ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool2o`00oeOooooo0_l00?l>ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`;o003oEoooool2o`00o`kooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00_ooooo0_l0
0?mHooooo`;o003o3Oooool00ol00?ooooooooooo`06ooooo`?o00002_ooool002Oooooo00?o0000
ooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo0_l00?mG
ooooo`;o003o3_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool02oooool2o`00oeOooooo0_l00?l>ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`;o003oF?ooool2o`00o`gooooo00?o003o
ooooooooool02?ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`07oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool0MOooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool0M?ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool0M?ooool00ol00?ooooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo00Oooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`1eooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`1dooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`1dooooo`03o`00oooooooooooo00Sooooo00?o0000oooooooo
ool02?ooool002Oooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo07Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo07Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo07Cooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`08ooooo`009ooo
ool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0MOoo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0M?oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0M?oo
ool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooo
oooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1eooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1dooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1dooooo`03o`00oooooooo
oooo00Sooooo00?o0000ooooooooool02?ooool002Oooooo0_l00008ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool0MOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool0M?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool0M?ooool00ol00?ooooooooooo`06ooooo`?o00002_ooool002Oo
oooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo07Go
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo07Co
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo07Co
oooo00?o003oooooooooool02?ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003ooooo
ooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0MOooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0M?ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0M?ooool00ol00?oooooo
ooooo`08ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo00Oooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`1eooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`1dooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`1dooooo`03o`00oooooooooooo00Sooooo00?o
0000ooooooooool02?ooool0017ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00008
ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1e
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1d
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1d
ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02?ooool0013ooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool01ooo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo07Gooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo07Cooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo07Cooooo00?o003oooooooooool02?oo
ool00ol0003oooooooooo`08ooooo`004?ooool01?l0003oooooooooool0000;ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo07Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo07Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo07Cooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`08ooooo`004?ooool0
1?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00Gooooo0ol00007ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool0MOooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool0M?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool0M?ooool00ol00?ooooooooooo`05ooooo`Co00002_oo
ool0013ooooo00Co0000oooooooooooo00001oooool4o`0000Sooooo00?o0000ooooooooool01ooo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo07Gooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo07Cooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo07Cooooo00?o003oooooooooool02?oo
ool00ol0003oooooooooo`08ooooo`004?ooool01?l0003oooooooooool00007ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo07Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo07Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo07Cooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`08ooooo`004Oooool2
o`0000Sooooo1Ol00007ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`1eooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`1dooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`1dooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02?ooool0
02Oooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
07Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
07Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
07Cooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003o
ooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0MOooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0M?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0M?ooool00ol00?oo
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo00Oooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`1eooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`1dooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`1dooooo`03o`00oooooooooooo00Sooooo
00?o0000ooooooooool02?ooool002Oooooo0_l00008ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0MOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0M?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0M?ooool00ol00?ooooooooooo`06ooooo`?o00002_ooool002Oooooo00?o0000
ooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo07Gooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo07Cooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo07Cooooo00?o003o
ooooooooool02?ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`07oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool0MOooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool0M?ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool0M?ooool00ol00?ooooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo00Oooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`1eooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`1dooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`1dooooo`03o`00oooooooooooo00Sooooo00?o0000oooooooo
ool02?ooool002Oooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo07Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo07Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo07Cooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`08ooooo`009ooo
ool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0MOoo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0M?oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0M?oo
ool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooo
oooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1eooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1dooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1dooooo`03o`00oooooooo
oooo00Sooooo00?o0000ooooooooool02?ooool002Oooooo0_l00008ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool0MOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool0M?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool0M?ooool00ol00?ooooooooooo`06ooooo`?o00002_ooool002Oo
oooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo07Go
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo07Co
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo07Co
oooo00?o003oooooooooool02?ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003ooooo
ooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0MOooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0M?ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0M?ooool00ol00?oooooo
ooooo`08ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo00Oooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`1eooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`1dooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`1dooooo`03o`00oooooooooooo00Sooooo00?o
0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo07Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo07Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo07Cooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`08
ooooo`009oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool0MOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool0M?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool0M?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03
o`000?oooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1eooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1dooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1dooooo`03
o`00oooooooooooo00Sooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0
1oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo07Gooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo07Cooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo07Cooooo00?o003oooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`009oooool2o`0000Sooooo00?o003oooooooooool03?oo
ool2o`00ogGooooo0_l00?l>ooooo`03o`00oooooooooooo00_ooooo0_l00?meooooo`;o003o3_oo
ool00ol00?ooooooooooo`0;ooooo`;o003oMOooool2o`00o`Sooooo0ol0000:ooooo`009oooool0
0ol0003oooooooooo`07ooooo`03o`00oooooooooooo00cooooo0_l00?meooooo`;o003o3_ooool0
0ol00?ooooooooooo`0;ooooo`;o003oMOooool2o`00o`kooooo00?o003oooooooooool02oooool2
o`00ogGooooo0_l00?l:ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo
00Oooooo00?o003oooooooooool0Toooool00ol00?ooooooooooo`2Booooo`03o`00oooooooooooo
08kooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool01oooool00ol00?oo
ooooooooo`2Cooooo`03o`00oooooooooooo09;ooooo00?o003oooooooooool0S_ooool00ol0003o
ooooooooo`08ooooo`009oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo09?ooooo
00?o003oooooooooool0T_ooool00ol00?ooooooooooo`2>ooooo`03o`000?oooooooooo00Sooooo
000Wooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool0Toooool00ol00?oooooooooo
o`2Booooo`03o`00oooooooooooo08kooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000
ooooooooool01oooool00ol00?ooooooooooo`2Cooooo`03o`00oooooooooooo09;ooooo00?o003o
ooooooooool0S_ooool00ol0003oooooooooo`08ooooo`009oooool2o`0000Sooooo00?o003ooooo
ooooool0Toooool00ol00?ooooooooooo`2Booooo`03o`00oooooooooooo08cooooo0ol0000:oooo
o`009oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo09?ooooo00?o003ooooooooo
ool0T_ooool00ol00?ooooooooooo`2>ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`00
0?oooooooooo00Oooooo00?o003oooooooooool0Toooool00ol00?ooooooooooo`2Booooo`03o`00
oooooooooooo08kooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool01ooo
ool00ol00?ooooooooooo`2Cooooo`03o`00oooooooooooo09;ooooo00?o003oooooooooool0S_oo
ool00ol0003oooooooooo`08ooooo`007?ooool3o`0000Sooooo00?o0000ooooooooool01oooool0
0ol00?ooooooooooo`2Cooooo`03o`00oooooooooooo09;ooooo00?o003oooooooooool0S_ooool0
0ol0003oooooooooo`08ooooo`007Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o003oooooooooool0Toooool00ol00?ooooooooooo`2Booooo`03o`00oooooooooooo
08kooooo00?o0000ooooooooool02?ooool001gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`00oooooooooooo09?ooooo00?o003oooooooooool0T_ooool00ol00?oo
ooooooooo`2>ooooo`03o`000?oooooooooo00Sooooo000Mooooo`03o`000?oooooooooo00Oooooo
0ol00007ooooo`;o003oToooool2o`00oi?ooooo0_l00?n=ooooo`Co00002_ooool001gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`;o003oBOooool00ol0003ooooooooo
o`17ooooo`;o003oBOooool00ol0003oooooooooo`17ooooo`;o003oBOooool00ol0003ooooooooo
o`14ooooo`03o`000?oooooooooo00Sooooo000Looooo`;o00002Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo000Mooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`009oooooooo`000<So00002_ooool00001\
\>"],
  ImageRangeCache->{{{0, 503}, {167, 0}} -> {-3.34862, -1.25358, 0.0670304, \
0.0138684}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Magnitude plot of DTFT as a function of frequency", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(X\[Theta]\  = DTFT[xd, \[Theta]]\  // \ Simplify; 
    g1 = Plot[
        Abs[X\[Theta]\  /. \ \[Theta] \[Rule] \ 2  \[Pi]\ f/fs], {f, \(-fs\)/
            2, fs/2}, \ PlotStyle \[Rule] {Blue, \ Dashing[{ .01}]}, \ 
        PlotRange \[Rule] All, PlotPoints \[Rule] 200];\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.0147151 0.0391184 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09295 -6 -4.5 ]
[-0.0125 .09295 0 4.5 ]
[-0.0125 .17119 -6 -4.5 ]
[-0.0125 .17119 0 4.5 ]
[-0.0125 .24943 -6 -4.5 ]
[-0.0125 .24943 0 4.5 ]
[-0.0125 .32766 -6 -4.5 ]
[-0.0125 .32766 0 4.5 ]
[-0.0125 .4059 -12 -4.5 ]
[-0.0125 .4059 0 4.5 ]
[-0.0125 .48414 -12 -4.5 ]
[-0.0125 .48414 0 4.5 ]
[-0.0125 .56237 -12 -4.5 ]
[-0.0125 .56237 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09295 m
.00625 .09295 L
s
[(2)] -0.0125 .09295 1 0 Mshowa
0 .17119 m
.00625 .17119 L
s
[(4)] -0.0125 .17119 1 0 Mshowa
0 .24943 m
.00625 .24943 L
s
[(6)] -0.0125 .24943 1 0 Mshowa
0 .32766 m
.00625 .32766 L
s
[(8)] -0.0125 .32766 1 0 Mshowa
0 .4059 m
.00625 .4059 L
s
[(10)] -0.0125 .4059 1 0 Mshowa
0 .48414 m
.00625 .48414 L
s
[(12)] -0.0125 .48414 1 0 Mshowa
0 .56237 m
.00625 .56237 L
s
[(14)] -0.0125 .56237 1 0 Mshowa
.125 Mabswid
0 .03427 m
.00375 .03427 L
s
0 .05383 m
.00375 .05383 L
s
0 .07339 m
.00375 .07339 L
s
0 .11251 m
.00375 .11251 L
s
0 .13207 m
.00375 .13207 L
s
0 .15163 m
.00375 .15163 L
s
0 .19075 m
.00375 .19075 L
s
0 .21031 m
.00375 .21031 L
s
0 .22987 m
.00375 .22987 L
s
0 .26898 m
.00375 .26898 L
s
0 .28854 m
.00375 .28854 L
s
0 .3081 m
.00375 .3081 L
s
0 .34722 m
.00375 .34722 L
s
0 .36678 m
.00375 .36678 L
s
0 .38634 m
.00375 .38634 L
s
0 .42546 m
.00375 .42546 L
s
0 .44502 m
.00375 .44502 L
s
0 .46458 m
.00375 .46458 L
s
0 .5037 m
.00375 .5037 L
s
0 .52325 m
.00375 .52325 L
s
0 .54281 m
.00375 .54281 L
s
0 .58193 m
.00375 .58193 L
s
0 .60149 m
.00375 .60149 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09295 m
1 .09295 L
s
.99375 .17119 m
1 .17119 L
s
.99375 .24943 m
1 .24943 L
s
.99375 .32766 m
1 .32766 L
s
.99375 .4059 m
1 .4059 L
s
.99375 .48414 m
1 .48414 L
s
.99375 .56237 m
1 .56237 L
s
.125 Mabswid
.99625 .03427 m
1 .03427 L
s
.99625 .05383 m
1 .05383 L
s
.99625 .07339 m
1 .07339 L
s
.99625 .11251 m
1 .11251 L
s
.99625 .13207 m
1 .13207 L
s
.99625 .15163 m
1 .15163 L
s
.99625 .19075 m
1 .19075 L
s
.99625 .21031 m
1 .21031 L
s
.99625 .22987 m
1 .22987 L
s
.99625 .26898 m
1 .26898 L
s
.99625 .28854 m
1 .28854 L
s
.99625 .3081 m
1 .3081 L
s
.99625 .34722 m
1 .34722 L
s
.99625 .36678 m
1 .36678 L
s
.99625 .38634 m
1 .38634 L
s
.99625 .42546 m
1 .42546 L
s
.99625 .44502 m
1 .44502 L
s
.99625 .46458 m
1 .46458 L
s
.99625 .5037 m
1 .5037 L
s
.99625 .52325 m
1 .52325 L
s
.99625 .54281 m
1 .54281 L
s
.99625 .58193 m
1 .58193 L
s
.99625 .60149 m
1 .60149 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .01472 m
.02847 .03212 L
.03089 .03996 L
.03218 .04355 L
.03355 .04687 L
.03484 .04946 L
.03602 .05133 L
.03659 .05205 L
.0372 .05271 L
.03779 .0532 L
.03832 .05353 L
.03862 .05367 L
.03888 .05377 L
.03903 .05381 L
.03919 .05385 L
.03935 .05387 L
.03949 .05389 L
.03963 .0539 L
.03977 .0539 L
.03989 .05389 L
.04002 .05388 L
.04016 .05386 L
.04031 .05383 L
.04058 .05375 L
.04088 .05364 L
.04119 .05347 L
.04177 .05309 L
.04245 .05246 L
.04307 .05175 L
.04426 .04998 L
.04537 .0479 L
.04787 .04177 L
.05032 .03419 L
.05261 .02602 L
.05368 .02199 L
.0548 .01765 L
.05509 .01655 L
.05539 .01536 L
.05548 .01501 L
.05556 .01475 L
.05572 .01537 L
.05603 .01658 L
.05716 .02096 L
.0618 .03761 L
.06415 .04444 L
.0654 .04745 L
.06674 .05013 L
.06802 .05211 L
.06919 .05341 L
.06976 .05385 L
Mistroke
.07005 .05403 L
.07037 .05419 L
.07053 .05425 L
.07068 .0543 L
.07082 .05434 L
.07095 .05438 L
.07108 .0544 L
.07121 .05442 L
.07134 .05443 L
.07149 .05443 L
.07165 .05443 L
.07179 .05442 L
.07187 .05441 L
.07195 .05439 L
.07212 .05436 L
.07227 .05432 L
.07243 .05426 L
.07272 .05414 L
.07331 .05379 L
.07385 .05336 L
.07508 .05196 L
.07637 .04989 L
.07876 .04459 L
.08097 .03815 L
.08324 .0304 L
.08569 .0211 L
.08634 .01853 L
.0867 .01711 L
.08703 .01579 L
.08718 .01521 L
.08732 .01477 L
.08747 .0154 L
.08762 .01598 L
.08827 .01855 L
.0907 .02802 L
.09532 .04357 L
.0977 .04949 L
.0989 .05178 L
.09955 .05279 L
.10023 .0537 L
.10081 .05433 L
.10145 .05487 L
.10173 .05506 L
.10203 .05522 L
.10231 .05535 L
.10256 .05544 L
.10272 .05548 L
.10289 .05551 L
.10297 .05552 L
.10306 .05553 L
Mistroke
.10314 .05554 L
.10324 .05554 L
.10332 .05554 L
.10341 .05554 L
.1035 .05553 L
.10357 .05553 L
.10372 .0555 L
.10388 .05547 L
.10404 .05543 L
.1042 .05537 L
.10451 .05524 L
.10508 .0549 L
.10567 .05441 L
.10622 .05383 L
.10748 .05206 L
.10871 .04978 L
.11002 .04676 L
.11502 .0308 L
.11623 .02614 L
.11751 .021 L
.11804 .01884 L
.11861 .01651 L
.11877 .01586 L
.11886 .0155 L
.11894 .01517 L
.11908 .01485 L
.11924 .01549 L
.11982 .01791 L
.12445 .03607 L
.12671 .04364 L
.12916 .05026 L
.1305 .05304 L
.13174 .05501 L
.13235 .05577 L
.13292 .05635 L
.13351 .05681 L
.13383 .05699 L
.13401 .05708 L
.13417 .05714 L
.13431 .0572 L
.13447 .05724 L
.13456 .05726 L
.13464 .05728 L
.1348 .0573 L
.13494 .05731 L
.13509 .05732 L
.13524 .05731 L
.13539 .0573 L
.13547 .05729 L
.13556 .05727 L
Mistroke
.13573 .05723 L
.13603 .05713 L
.13639 .05696 L
.13672 .05676 L
.13728 .05631 L
.1379 .05567 L
.13915 .05391 L
.14037 .0516 L
.14149 .049 L
.144 .04163 L
.14649 .03267 L
.14879 .0233 L
.14934 .02096 L
.14994 .01841 L
.15021 .01723 L
.1505 .01598 L
.15062 .01546 L
.15075 .01491 L
.15089 .01513 L
.15102 .0157 L
.15227 .02109 L
.1534 .02593 L
.15579 .03567 L
.15838 .04504 L
.16088 .05225 L
.16207 .05493 L
.16319 .05695 L
.16427 .05843 L
.16488 .05905 L
.16544 .05947 L
.16574 .05964 L
.16602 .05976 L
.16617 .05982 L
.16632 .05986 L
.1664 .05988 L
.16649 .0599 L
.16665 .05992 L
.1668 .05993 L
.16689 .05993 L
.16697 .05993 L
.16706 .05993 L
.16713 .05992 L
.16722 .05991 L
.16731 .05989 L
.16746 .05986 L
.1676 .05982 L
.16792 .0597 L
.16824 .05953 L
.16854 .05933 L
.1692 .05875 L
Mistroke
.16978 .05808 L
.1704 .05722 L
.17265 .05274 L
.17379 .0497 L
.17502 .04592 L
.17723 .03794 L
.17962 .02797 L
.18088 .02233 L
.18158 .01917 L
.18191 .01762 L
.18222 .01618 L
.18237 .01551 L
.1825 .01489 L
.18264 .01519 L
.1828 .0159 L
.18341 .01877 L
.18472 .02483 L
.18703 .03512 L
.1893 .0443 L
.19175 .05268 L
.19309 .05639 L
.19433 .05919 L
.19551 .06126 L
.1961 .06206 L
.19676 .06277 L
.19706 .06302 L
.19739 .06325 L
.1977 .06342 L
.19785 .06349 L
.19798 .06354 L
.19812 .06359 L
.19824 .06362 L
.19838 .06364 L
.19853 .06366 L
.19866 .06367 L
.19881 .06366 L
.19896 .06365 L
.19911 .06363 L
.19926 .06359 L
.19943 .06354 L
.19974 .06341 L
.20005 .06324 L
.20032 .06304 L
.20096 .06245 L
.20163 .06163 L
.20276 .05975 L
.20398 .05708 L
.20619 .05067 L
.20857 .04175 L
.21116 .03018 L
Mistroke
.21237 .02435 L
.21303 .02108 L
.21365 .01795 L
.21393 .01652 L
.21408 .01574 L
.21423 .01501 L
.21438 .01522 L
.21447 .01564 L
.21456 .01609 L
.21486 .01762 L
.21595 .0232 L
.22094 .04686 L
.22344 .0564 L
.22454 .05988 L
.22575 .06312 L
.22691 .06559 L
.22799 .06733 L
.22859 .06803 L
.22914 .06851 L
.22942 .0687 L
.22974 .06886 L
.2299 .06892 L
.23007 .06897 L
.23015 .06899 L
.23023 .069 L
.23037 .06902 L
.23051 .06903 L
.23066 .06903 L
.2308 .06901 L
.23093 .06899 L
.23108 .06895 L
.23125 .0689 L
.23155 .06876 L
.23186 .06857 L
.23219 .06831 L
.23279 .06769 L
.23339 .06688 L
.23396 .06594 L
.23501 .06375 L
.23744 .05666 L
.23967 .04788 L
.24214 .0361 L
.24334 .02975 L
.24444 .02373 L
.24498 .02067 L
.24527 .01904 L
.24558 .01731 L
.24584 .01579 L
.24599 .01493 L
.24614 .01532 L
Mistroke
.24627 .01606 L
.24639 .01674 L
.24665 .01828 L
.24903 .03182 L
.25151 .04526 L
.25381 .05637 L
.25618 .06577 L
.25734 .06946 L
.25841 .07226 L
.2596 .07463 L
.26023 .07555 L
.26055 .07594 L
.26089 .07629 L
.26118 .07653 L
.26144 .0767 L
.26157 .07677 L
.26171 .07684 L
.26183 .07689 L
.26196 .07693 L
.2621 .07696 L
.26225 .07698 L
.2624 .07699 L
.26249 .07699 L
.26257 .07698 L
.2627 .07696 L
.26284 .07693 L
.26299 .07689 L
.26313 .07683 L
.26345 .07666 L
.26374 .07645 L
.2644 .07578 L
.26498 .07497 L
.2656 .07389 L
.26666 .07149 L
.26784 .06808 L
.27018 .05904 L
.2727 .0464 L
.27508 .03231 L
.27634 .02426 L
.27702 .01973 L
.27736 .01749 L
.27751 .0165 L
.27759 .01597 L
.27767 .01541 L
.27783 .01508 L
.27798 .01606 L
.2783 .01823 L
.27898 .02279 L
.28016 .03074 L
.28247 .04585 L
Mistroke
.28486 .06022 L
.28746 .0734 L
.28867 .07841 L
.28996 .0828 L
.29106 .08574 L
.29163 .08696 L
.29227 .08804 L
.29286 .08881 L
.29318 .08912 L
.29349 .08934 L
.29363 .08942 L
.29377 .08948 L
.29389 .08953 L
.29403 .08957 L
.29417 .08959 L
.29433 .08961 L
.29446 .0896 L
.2946 .08958 L
.29468 .08956 L
.29477 .08954 L
.29493 .08948 L
.29509 .08941 L
.29523 .08932 L
.29556 .08907 L
.2959 .08872 L
.29654 .08783 L
.29712 .08678 L
.29833 .08377 L
.29945 .08007 L
.30196 .06865 L
.30424 .055 L
.30673 .03714 L
.30795 .02763 L
.30854 .02281 L
.30909 .01829 L
.30925 .01698 L
.3094 .01574 L
.30956 .01498 L
.30964 .01566 L
.30973 .0164 L
.31041 .02217 L
.31162 .03231 L
.31659 .07217 L
.31907 .08872 L
.32028 .09548 L
.32138 .10074 L
.32245 .10501 L
.32361 .10857 L
.32424 .11004 L
.32483 .11108 L
Mistroke
.32512 .11147 L
.32539 .11177 L
.32567 .11202 L
.32582 .11211 L
.32598 .1122 L
.32613 .11225 L
.32621 .11227 L
.32629 .11228 L
.32645 .11229 L
.32654 .11229 L
.32662 .11228 L
.32676 .11225 L
.32691 .11219 L
.32706 .11211 L
.32721 .11201 L
.32755 .11171 L
.32785 .11133 L
.32854 .11016 L
.32914 .10877 L
.32979 .10687 L
.33097 .10238 L
.33211 .09677 L
.33337 .08922 L
.3359 .06985 L
.33845 .04569 L
.33965 .0329 L
.34077 .02044 L
.34091 .01888 L
.34106 .01717 L
.3412 .01556 L
.34133 .01536 L
.34148 .01711 L
.34164 .01896 L
.34192 .02224 L
.34317 .03704 L
.34545 .06424 L
.35004 .11522 L
.35259 .13823 L
.35492 .1539 L
.35607 .15942 L
.35673 .1618 L
.35733 .1635 L
.35786 .16458 L
.35816 .16502 L
.35844 .16532 L
.35858 .16543 L
.35873 .16552 L
.35886 .16556 L
.35901 .16559 L
.35916 .16558 L
Mistroke
.35924 .16556 L
.35932 .16553 L
.35947 .16545 L
.35962 .16535 L
.35975 .16521 L
.3599 .16504 L
.36018 .16464 L
.3605 .16401 L
.36079 .16331 L
.36143 .16131 L
.36203 .15884 L
.3631 .15306 L
.36426 .1447 L
.36664 .12079 L
.36917 .08562 L
.37033 .06641 L
.37155 .04416 L
.37205 .0344 L
.37258 .02362 L
.37274 .02037 L
.37289 .01727 L
.37303 .01497 L
.37317 .01804 L
.37372 .02979 L
.37605 .08321 L
.37857 .14597 L
.3835 .27663 L
.38824 .39861 L
.39281 .49801 L
.39515 .53827 L
.39767 .57152 L
.39889 .58355 L
.39953 .58878 L
.40022 .59348 L
.40088 .59714 L
.40148 .59973 L
.40177 .60073 L
.40208 .60163 L
.40237 .6023 L
.40264 .60277 L
.4028 .60297 L
.40294 .60312 L
.40307 .60322 L
.40321 .60329 L
.40336 .60332 L
.40344 .60332 L
.40353 .6033 L
.40368 .60324 L
.40382 .60314 L
.40395 .60301 L
Mistroke
.40409 .60284 L
.40435 .60243 L
.40462 .60185 L
.40492 .60106 L
.40554 .59884 L
.40621 .59564 L
.40741 .58778 L
.40864 .57695 L
.40998 .56221 L
.41241 .52807 L
.41735 .43456 L
.42211 .32492 L
.42668 .21458 L
.43154 .10539 L
.43379 .06128 L
.43497 .04003 L
.43562 .02903 L
.43594 .02381 L
.43623 .01912 L
.43639 .01655 L
.43647 .01527 L
.43656 .01556 L
.43665 .01695 L
.43675 .01844 L
.43692 .02108 L
.43755 .03033 L
.43878 .04697 L
.44121 .07422 L
.44244 .08519 L
.44378 .09493 L
.44504 .10208 L
.4456 .10464 L
.4462 .10698 L
.44681 .1089 L
.44737 .11029 L
.44764 .11083 L
.44793 .11133 L
.4482 .11172 L
.44846 .11201 L
.44862 .11215 L
.44879 .11228 L
.44894 .11237 L
.44908 .11243 L
.44924 .11247 L
.44933 .11248 L
.44941 .11249 L
.44949 .11248 L
.44957 .11247 L
.44966 .11246 L
.44975 .11243 L
Mistroke
.44989 .11238 L
.45005 .11229 L
.45032 .11209 L
.45062 .11179 L
.45095 .11136 L
.45154 .11034 L
.45216 .10894 L
.45328 .10566 L
.45448 .10109 L
.45579 .09503 L
.46068 .06562 L
.46539 .03328 L
.46663 .02506 L
.46728 .02085 L
.46763 .01859 L
.46796 .01651 L
.46811 .01559 L
.46825 .01472 L
.46833 .01519 L
.46842 .01571 L
.46857 .01661 L
.46923 .02054 L
.47039 .02711 L
.47297 .03976 L
.4753 .04872 L
.47647 .05226 L
.47773 .05536 L
.47893 .05757 L
.48002 .05901 L
.48059 .05954 L
.4809 .05977 L
.4812 .05994 L
.48147 .06007 L
.48162 .06012 L
.48177 .06017 L
.4819 .0602 L
.48205 .06023 L
.48218 .06024 L
.4823 .06025 L
.48244 .06025 L
.4826 .06024 L
.48268 .06023 L
.48277 .06022 L
.48292 .06019 L
.48308 .06015 L
.48322 .0601 L
.4835 .05999 L
.48382 .05982 L
.48412 .05962 L
.48479 .05905 L
Mistroke
.48596 .05765 L
.48706 .0559 L
.48955 .05052 L
.49423 .03627 L
.49662 .02765 L
.49788 .0229 L
.49857 .02025 L
.49922 .01775 L
.49949 .01668 L
.49978 .01555 L
.49994 .01496 L
.50002 .01481 L
.5001 .01512 L
.5004 .01626 L
.50171 .0213 L
.50401 .03 L
.50872 .04577 L
.51129 .05252 L
.51247 .05502 L
.51372 .05718 L
.51486 .05869 L
.51551 .05933 L
.51583 .05958 L
.51613 .05979 L
.51639 .05994 L
.51669 .06007 L
.51681 .06011 L
.51695 .06016 L
.51708 .06019 L
.5172 .06021 L
.51735 .06024 L
.51743 .06024 L
.51751 .06025 L
.51765 .06025 L
.5178 .06024 L
.51794 .06023 L
.51808 .0602 L
.51822 .06017 L
.51835 .06013 L
.51863 .06003 L
.51893 .05987 L
.51955 .05943 L
.52012 .05886 L
.52065 .05819 L
.52186 .05619 L
.52316 .05326 L
.52557 .04566 L
.52812 .03476 L
.52936 .02846 L
.53053 .02197 L
Mistroke
.53104 .019 L
.53131 .01733 L
.53158 .01576 L
.53171 .01493 L
.53186 .0154 L
.53194 .01591 L
.53202 .0164 L
.53217 .01733 L
.53271 .02078 L
.53508 .03647 L
.53761 .05392 L
.54222 .08414 L
.54479 .09788 L
.54601 .10308 L
.54713 .10697 L
.5483 .11001 L
.54891 .11115 L
.54922 .11159 L
.54956 .11198 L
.54972 .11212 L
.54986 .11223 L
.54999 .11232 L
.55013 .11239 L
.55029 .11244 L
.55043 .11247 L
.55058 .11249 L
.55067 .11248 L
.55075 .11247 L
.55088 .11244 L
.55103 .11238 L
.55115 .11232 L
.55128 .11223 L
.55158 .11197 L
.55185 .11165 L
.55246 .11063 L
.55281 .10988 L
.55313 .10907 L
.55433 .10496 L
.55542 .09974 L
.55657 .09264 L
.55893 .07283 L
.56114 .04789 L
.5624 .03094 L
.5627 .02661 L
.56302 .02188 L
.5633 .01775 L
.56345 .01536 L
.5636 .01634 L
.56373 .01841 L
.56387 .0206 L
Mistroke
.56411 .02458 L
.56467 .0338 L
.56583 .05427 L
.57043 .14774 L
.57531 .2624 L
.58002 .3754 L
.58502 .48298 L
.58753 .52714 L
.58984 .56004 L
.59209 .58372 L
.59323 .59226 L
.59387 .59603 L
.59447 .5989 L
.59506 .60099 L
.59539 .60188 L
.5957 .60251 L
.59585 .60275 L
.59598 .60294 L
.59611 .60308 L
.59624 .60319 L
.59639 .60327 L
.59652 .60331 L
.59666 .60332 L
.59682 .60328 L
.5969 .60324 L
.59699 .60318 L
.59715 .60304 L
.5973 .60285 L
.59745 .60263 L
.59777 .60199 L
.59812 .60108 L
.5987 .59904 L
.59934 .59603 L
.60056 .5881 L
.60167 .57835 L
.60419 .54805 L
.60647 .51124 L
.60897 .46218 L
.61386 .34592 L
.61858 .22121 L
.62098 .15772 L
.62358 .09202 L
.6248 .06298 L
.62547 .04769 L
.62609 .0338 L
.62663 .02229 L
.62678 .01904 L
.62692 .01598 L
.62705 .01618 L
.6272 .01913 L
Mistroke
.62841 .04327 L
.63099 .08813 L
.63332 .12032 L
.63449 .13329 L
.63576 .14483 L
.63695 .15337 L
.63805 .1592 L
.63862 .16148 L
.63893 .16251 L
.63923 .16335 L
.6395 .16401 L
.6398 .1646 L
.64007 .16501 L
.64032 .16529 L
.64047 .16541 L
.64062 .1655 L
.64077 .16556 L
.6409 .16559 L
.64106 .16558 L
.64114 .16556 L
.64123 .16554 L
.64138 .16546 L
.64146 .16541 L
.64153 .16535 L
.64185 .16501 L
.64203 .16476 L
.6422 .16449 L
.64282 .16312 L
.64338 .16143 L
.64399 .15914 L
.64509 .15387 L
.64758 .13687 L
.65014 .11345 L
.65257 .08731 L
.65476 .0617 L
.65601 .04677 L
.65719 .03277 L
.65775 .02617 L
.65834 .01928 L
.65848 .01756 L
.65864 .01571 L
.65873 .01477 L
.65882 .01573 L
.65898 .01759 L
.65957 .0243 L
.66211 .05128 L
.66461 .07423 L
.66693 .09111 L
.66809 .09785 L
.66918 .10302 L
Mistroke
.67031 .10721 L
.67092 .10893 L
.67156 .11038 L
.67187 .11092 L
.6722 .1114 L
.67251 .11176 L
.67279 .11201 L
.67296 .11212 L
.67312 .1122 L
.6732 .11223 L
.67329 .11226 L
.67338 .11228 L
.67347 .11229 L
.67356 .11229 L
.67363 .11229 L
.67378 .11227 L
.67387 .11225 L
.67394 .11222 L
.67412 .11215 L
.67426 .11207 L
.67441 .11196 L
.67468 .11171 L
.675 .11132 L
.67529 .11089 L
.6759 .10974 L
.67654 .10818 L
.6777 .10449 L
.67893 .09938 L
.68114 .08743 L
.68615 .05088 L
.68737 .04079 L
.68867 .02993 L
.68977 .02064 L
.69007 .0181 L
.69024 .01671 L
.69039 .0154 L
.69054 .01525 L
.6907 .01658 L
.69098 .01888 L
.69562 .05408 L
.698 .06846 L
.69922 .07454 L
.70054 .08001 L
.70176 .08403 L
.7023 .08546 L
.70288 .08678 L
.7034 .08774 L
.70395 .08855 L
.70426 .08889 L
.70454 .08915 L
Mistroke
.70482 .08935 L
.70509 .08949 L
.70522 .08954 L
.70537 .08958 L
.70551 .0896 L
.70564 .08961 L
.70579 .0896 L
.70588 .08959 L
.70596 .08957 L
.7061 .08953 L
.70626 .08947 L
.70642 .08939 L
.70659 .08929 L
.70691 .08904 L
.70749 .08838 L
.70806 .08752 L
.70865 .08638 L
.70972 .08375 L
.71086 .08012 L
.71209 .07537 L
.7143 .06482 L
.71669 .05111 L
.71929 .03441 L
.7205 .02631 L
.72116 .02183 L
.72149 .01964 L
.72179 .01764 L
.72204 .01591 L
.72217 .01504 L
.72232 .01534 L
.72246 .01629 L
.72261 .01731 L
.72288 .01913 L
.7241 .02706 L
.7265 .04185 L
.7291 .05572 L
.73032 .06121 L
.73161 .06621 L
.73282 .07009 L
.73393 .0729 L
.73506 .07504 L
.73569 .07589 L
.73598 .0762 L
.73629 .07647 L
.73658 .07667 L
.73684 .07681 L
.73696 .07687 L
.7371 .07691 L
.73723 .07695 L
.73734 .07697 L
Mistroke
.73748 .07698 L
.73761 .07699 L
.73775 .07698 L
.7379 .07696 L
.73806 .07692 L
.73821 .07687 L
.7385 .07674 L
.73878 .07656 L
.73905 .07634 L
.73966 .07569 L
.74026 .07485 L
.7409 .07371 L
.74206 .07108 L
.74313 .06805 L
.74541 .0597 L
.74791 .04821 L
.75048 .03457 L
.75281 .02135 L
.75338 .01809 L
.75369 .01632 L
.75384 .01545 L
.75398 .01477 L
.75413 .01563 L
.75429 .01656 L
.75464 .01852 L
.75524 .02193 L
.75753 .03437 L
.76002 .04651 L
.76233 .05585 L
.76457 .06273 L
.7657 .06529 L
.76631 .0664 L
.76695 .06736 L
.76753 .06804 L
.76784 .06833 L
.76817 .06859 L
.76847 .06877 L
.76875 .06889 L
.76888 .06894 L
.76902 .06898 L
.76916 .06901 L
.76928 .06902 L
.76943 .06903 L
.76958 .06903 L
.76973 .06901 L
.76986 .06899 L
.77002 .06895 L
.77019 .06889 L
.7705 .06874 L
.77083 .06854 L
Mistroke
.77117 .06826 L
.7718 .0676 L
.77244 .0667 L
.77304 .06569 L
.77438 .0628 L
.77682 .05553 L
.78158 .03542 L
.78281 .02939 L
.78398 .02353 L
.78503 .01821 L
.78531 .01675 L
.78547 .01595 L
.78562 .0152 L
.78574 .01486 L
.78588 .01555 L
.78617 .017 L
.78852 .02867 L
.79104 .04013 L
.79342 .04933 L
.79467 .0534 L
.79601 .05706 L
.79731 .05988 L
.79849 .06178 L
.79906 .06247 L
.79936 .06277 L
.79967 .06304 L
.79995 .06323 L
.80026 .06341 L
.80039 .06347 L
.80053 .06353 L
.80067 .06357 L
.80079 .06361 L
.80087 .06362 L
.80095 .06364 L
.8011 .06366 L
.80118 .06366 L
.80127 .06367 L
.80143 .06366 L
.80157 .06365 L
.80171 .06363 L
.80186 .06359 L
.80202 .06354 L
.80237 .06339 L
.80271 .06319 L
.80335 .06267 L
.80395 .062 L
.80451 .06123 L
.80577 .05899 L
.80803 .05333 L
.81052 .04499 L
Mistroke
.81306 .03474 L
.81538 .02436 L
.81652 .01907 L
.81684 .01761 L
.81717 .01605 L
.81725 .01569 L
.81734 .0153 L
.81749 .01485 L
.81764 .01554 L
.81777 .01617 L
.82005 .02655 L
.82252 .03694 L
.82482 .04537 L
.82703 .05192 L
.82826 .05478 L
.8294 .0569 L
.82998 .05777 L
.83062 .05856 L
.83127 .05918 L
.83162 .05944 L
.83196 .05964 L
.83225 .05977 L
.8324 .05982 L
.83257 .05987 L
.83271 .0599 L
.83285 .05992 L
.833 .05993 L
.83312 .05993 L
.8332 .05993 L
.83329 .05993 L
.83343 .05991 L
.83352 .0599 L
.8336 .05988 L
.83377 .05984 L
.83407 .05973 L
.83438 .05958 L
.83469 .05938 L
.83502 .05913 L
.8356 .05857 L
.83694 .05675 L
.83821 .05435 L
.83936 .05164 L
.8442 .03573 L
.84642 .0267 L
.84768 .02132 L
.84829 .01867 L
.84885 .01624 L
.84899 .01564 L
.84914 .015 L
.84922 .01477 L
Mistroke
.8493 .01513 L
.84945 .01578 L
.85002 .01822 L
.85126 .02353 L
.85381 .0338 L
.85634 .04276 L
.85866 .04937 L
.85984 .05204 L
.86094 .05405 L
.86208 .05565 L
.86269 .05629 L
.863 .05656 L
.86333 .0568 L
.86364 .05698 L
.86398 .05714 L
.86413 .05719 L
.86428 .05724 L
.86443 .05727 L
.86457 .05729 L
.86465 .0573 L
.86474 .05731 L
.8649 .05732 L
.86499 .05732 L
.86507 .05731 L
.86516 .05731 L
.86526 .05729 L
.86534 .05728 L
.86542 .05727 L
.8656 .05722 L
.86591 .05711 L
.86623 .05696 L
.86652 .05679 L
.86717 .05627 L
.86777 .05563 L
.86834 .0549 L
.86951 .05301 L
.87075 .05046 L
.87298 .04459 L
.87754 .02855 L
.87874 .02376 L
.87989 .01911 L
.88051 .01652 L
.88069 .01581 L
.88078 .01542 L
.88087 .01505 L
.88095 .01472 L
.88104 .01509 L
.8812 .01574 L
.8824 .02066 L
.88476 .02997 L
Mistroke
.88735 .03914 L
.88984 .04643 L
.89212 .05138 L
.89333 .05327 L
.89388 .05395 L
.89447 .05454 L
.89477 .05479 L
.8951 .05502 L
.8954 .0552 L
.89568 .05533 L
.89601 .05544 L
.89618 .05548 L
.89626 .0555 L
.89636 .05552 L
.89651 .05553 L
.89666 .05554 L
.89675 .05554 L
.89684 .05554 L
.89699 .05553 L
.89713 .05551 L
.89728 .05548 L
.89742 .05544 L
.89755 .0554 L
.89787 .05528 L
.89817 .05512 L
.89876 .05471 L
.89941 .0541 L
.90056 .05262 L
.90164 .05082 L
.90412 .04513 L
.90636 .03843 L
.90889 .02957 L
.90999 .02538 L
.9112 .02065 L
.91177 .01841 L
.91208 .01717 L
.91238 .01599 L
.91251 .01546 L
.91265 .0149 L
.91281 .01514 L
.91295 .01571 L
.91347 .01778 L
.91586 .02706 L
.92042 .04236 L
.92276 .04818 L
.92408 .05068 L
.92466 .05159 L
.92528 .05243 L
.9259 .05312 L
.92647 .05363 L
Mistroke
.92674 .05383 L
.92703 .05401 L
.92731 .05416 L
.92757 .05426 L
.92787 .05435 L
.92803 .05439 L
.92812 .0544 L
.9282 .05441 L
.92829 .05442 L
.92837 .05443 L
.92845 .05443 L
.92854 .05443 L
.9287 .05443 L
.92879 .05442 L
.92887 .05441 L
.92902 .05438 L
.92917 .05435 L
.92945 .05426 L
.92974 .05414 L
.93007 .05396 L
.9307 .0535 L
.93131 .05292 L
.93243 .05148 L
.93364 .04943 L
.93496 .04664 L
.93989 .03191 L
.94234 .02285 L
.94296 .02049 L
.94354 .01822 L
.94407 .01618 L
.94421 .01562 L
.94437 .01502 L
.94451 .01497 L
.94464 .01548 L
.94684 .02396 L
.94921 .03257 L
.95173 .04064 L
.95404 .04664 L
.95522 .04905 L
.95631 .05089 L
.95745 .05236 L
.95805 .05294 L
.95837 .05319 L
.9587 .05341 L
.959 .05358 L
.95934 .05372 L
.95948 .05377 L
.95964 .05382 L
.95979 .05385 L
.95993 .05387 L
Mistroke
.96001 .05388 L
.96009 .05389 L
.96024 .0539 L
.96033 .0539 L
.96042 .0539 L
.9605 .05389 L
.96058 .05388 L
.96066 .05387 L
.96075 .05386 L
.96094 .05382 L
.96111 .05377 L
.96126 .05372 L
.96158 .05358 L
.96188 .05342 L
.96243 .05303 L
.96304 .05247 L
.96369 .05171 L
.96482 .05004 L
.96607 .04768 L
.9686 .04141 L
.97345 .0252 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<oooool3o`0002kooooo1Ol0000]ooooo`;o0000;_ooool5o`00033ooooo0ol0000Roooo
o`00=?ooool00ol0003oooooooooo`0^ooooo`04o`000?ooooooooooo`0002cooooo00Co0000oooo
oooooooo0000;_ooool01?l0003oooooooooool0000aooooo`03o`000?oooooooooo027ooooo000[
ooooo`Go000000?oooooo`000?l000000ol0000Xooooo`Go00000oooool00ol0003oooooooooo`0/
ooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool0;_ooool5o`0002;ooooo000a
ooooo`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool0:oooool01?l0003ooooooooo
ool0000`ooooo`03o`000?oooooooooo02gooooo00Co0000oooooooooooo00008oooool003;ooooo
00?o0000ooooool00000;oooool01Ol0003ooooooooooooooooo000002cooooo00Co0000oooooooo
oooo0000;Oooool01Ol0003ooooooooooooooooo000002oooooo00?o0000ooooool000008oooool0
03?ooooo0_l0000_ooooo`05o`000?ooooooooooooooool00000;?ooool01?l0003oooooooooool0
000]ooooo`05o`000?ooooooooooooooool00000<?ooool2o`0002?ooooo000dooooo`03o`000?oo
oooooooo02kooooo0ol0000^ooooo`;o0000;oooool3o`0003;ooooo00?o0000ooooooooool08Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0017oooooool0
000=o`0000?ooooo000:ooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo007ooooo0009ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00Oooool0
00Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`23ooooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool3
o`0000Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Nooooo`;o003o<Oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool01Oooool2
o`00o`Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`?o00000oooool0
00Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0<ooooo`;o003o1_ooool2
o`00o`Oooooo00?o003oooooooooool01Oooool2o`00o`Oooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`05ooooo`;o003o6?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`;o003o1oooool0
0ol00?ooooooooooo`05ooooo`;o003o1oooool00ol00?ooooooooooo`05ooooo`;o003o1oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00Oooool0
00Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0<ooooo`;o003o3oooool0
0ol00?ooooooooooo`05ooooo`;o003o1oooool2o`00o`Kooooo0_l00?l7ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`;o003o1oooool0
0ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo0_l00?l?ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Gooooo0_l00?l6ooooo`;o003o1oooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool0
0ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool00Oooool0
00[ooooo0_l00005ooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool00oooool00ol0
0?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Kooooo0_l00?l6ooooo`03o`00oooooooo003o
00Kooooo0_l00?l8ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`06ooooo`;o003o5oooool2o`00o`Oooooo0_l00?l6ooooo`03o`00ool0003ooooo
00Gooooo0_l00?l7ooooo`;o003o3oooool2o`00o`Oooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`04ooooo`;o003o1oooool2o`00o`Kooooo0_l00?l7ooooo`;o003o1_ooool2o`00
o`Sooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool00oooool00ol00?oo
ooooo`00o`06ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool01_ooool2o`00o`So
oooo00?o003oooooooooool01?ooool2o`00o`Kooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Kooooo0_l00?l7ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`06ooooo`03o`00ool0003ooooo00Go
oooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`0>ooooo`;o003o1oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`04ooooo`?o003o1Oooool00ol00?ooooooooooo`06ooooo`;o003o2?ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooooooo`05ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00001_ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooo003o01Kooooo00?o003oooooool00?l01oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Kooooo0_l00?l6ooooo`;o003o4?ooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00cooooo00Co003oooooool0003o003o1Oooool00ol00?oo
ooooooooo`0Gooooo`;o003o3oooool2o`00o`Kooooo00?o003oooooool00?l09oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooooooo`04ooooo`;o00000oooool0017ooooo00?o0000ooooooooool02_ooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Co003ooooooooooooo003o2?ooool00ol00?ooooooooooo`02oooo
o`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool03_ooool00ol00?ooooooo`00o`06
ooooo`;o003o1_ooool2o`00o`Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool00ol0003o003oooooo`0=
ooooo`;o003o4?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Kooooo0_l00?l6
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`08
ooooo`;o003o1?ooool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Cooooo
00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003ooooo
ooooool01Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0:ooooo`05
o`00ooooooooooooooooool00?l03?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003o
oooooooooooo003o1Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Go
oooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Co
oooo0_l00?l6ooooo`03o`00oooooooooooo00kooooo0_l00?l6ooooo`03o`00oooooooo003o00Oo
oooo00?o0000ooooool00?l01_ooool00ol00?ooooooooooo`04ooooo`;o003o3oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooo003o00Kooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`03ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool0
1Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00ko
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01_ooool01Ol00?oooooo
oooooooooooo003o00Cooooo00?o003oooooooooool02Oooool01Ol00?oooooooooooooooooo003o
00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01?l00?ooooooooooool00?l7ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`06ooooo`;o003o5oooool2o`00o`Kooooo00Co003ooooooooooooo
003o0oooool01?l00?ooooooooooool00005ooooo`04o`00ooooooooooooo`00o`Kooooo0_l00?l?
ooooo`;o003o1_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo00?o003o
ooooooooool01Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0>ooooo`;o003o2oooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`07ooooo`04o`00oooooooo003oo`00o`Cooooo00Co003ooooooooo
oooo003o1?ooool01?l00?ooooooooooool00?l8ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool01Oooool01?l00?ooooooooooooooool2o`00o`;ooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l01ooo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00Co003ooooooooooooo003o
0oooool01?l00?ooooooooooool00005ooooo`04o`00ooooooooooooo`00o`Kooooo0_l00?l?oooo
o`;o003o1_ooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool0
1Ol00?oooooooooooooooooo003o00Cooooo0_l00?l00ooooooo003oooooo`04ooooo`04o`00oooo
oooo003oo`00o`Sooooo00?o0000ooooooooool00Oooool0017ooooo0_l00008ooooo`03o`00oooo
oooooooo00Kooooo0_l00?l6ooooo`;o003o5_ooool00ol00?ooooooooooo`06ooooo`05o`00oooo
ooooooooooooool00?l02?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00
o`Oooooo00?o003oooooooooool01?ooool2o`00oa3ooooo00?o003oooooooooool02_ooool01_l0
0?oooooooooooooooooo0000ooooo`;o003o0_ooool00ol00?ooooooooooo`0Hooooo`;o003o2?oo
ool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o2?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`04ooooo`?o003o1Oooool3o`00o`Sooooo0_l00003ooooo`00
4Oooool00ol0003oooooooooo`0Hooooo`;o003o1oooool2o`00o`Kooooo00?o003oooooool00?l0
4Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l5ooooo`03o`00oooooooooooo00Kooooo0_l00?l?ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool00oooool01?l0003oooooooooool00?l<ooooo`;o003o4?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o
1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0;ooooo`?o003o1_ooool3o`00o`Kooooo0_l00?lJooooo`03o`000?oooooooooo007o
oooo000Aooooo`03o`000?oooooooooo02Wooooo0_l00?l6ooooo`?o003o1Oooool01?l00?oooooo
ooooool00?l4ooooo`05o`00ooooooooooooooooool00?l02oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooo003o00Kooooo0_l00?l?ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool00_ooool3o`00o`?ooooo00Go0000ooooooooooooooooo`00o`05ooooo`03o`00oooooooo
oooo00?ooooo0_l00?lGooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool02Oooool0
1Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1Oooool00ol00?oooooo
o`00o`06ooooo`;o003o:oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`0booooo`;o003o1_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool00oooool00ol00?ooooooo`00o`0Gooooo`03o`00oooooooo003o00Cooooo00?o
003oooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooool00?l03oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo003o00Gooooo00?o
003oooooooooool01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01?l00?ooooooo`00ool00?l5ooooo`;o003o=?ooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`0jooooo`;o003o1_ooool00ol00?ooooooooooo`05ooooo`05o`00
ooooooooooooooooool00?l02?ooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00go
oooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Oo
oooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`0?ooooo`;o003o1_ooool00ol00?oo
ooooo`00o`08ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`04ooooo`;o003o??ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0004Gooooo
00?o003oooooooooool00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`03ooooo`;o003o4Oooool00ol00?ooooooooooo`0=ooooo`03
o`000?oooooooooo00Oooooo00?o003oooooooooool05?ooool2o`00o`Sooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`13ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0@oooool2o`00o`Go
oooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo003o
00kooooo00?o003oooooooooool03oooool00ol0003oooooooooo`0Oooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l5ooooo`;o003oAOooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Booooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool01_ooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`08ooooo`07o`00oooooooooooo
ooooool00?ooooooo`00o`0Fooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0D_oo
ool00ol0003oooooooooo`01ooooo`002?ooool5o`0000Cooooo00?o0000ooooooooool0D_ooool0
0ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool03_oo
ool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02?oo
ool01ol00?oooooooooooooooooo003oooooool00?l03oooool00ol00?ooooooooooo`04ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`1Booooo`03o`000?oooooooooo
007ooooo0009ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Boooool3o`00
o`Sooooo00Go003oooooooooooooooooo`00o`0Fooooo`03o`00oooooooo003o00?ooooo00?o003o
ooooooooool02Oooool00ol0003oooooooooo`08ooooo`05o`00ooooooooooooooooool00?l00_oo
ool00ol00?ooooooooooo`0<ooooo`;o003o1Oooool01Ol00?oooooooooooooooooo003o00Sooooo
0ol00?m=ooooo`03o`000?oooooooooo007ooooo000:ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0Boooool2o`00o`Kooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooo003o013ooooo00Go003oooooooooooooooooo`00o`0;ooooo`03o`00
0?oooooooooo00Sooooo00?o003oooooooooool04oooool2o`00o`Wooooo00?o003oooooooooool0
1oooool2o`00odgooooo00?o0000ooooooooool00Oooool000_ooooo00?o0000ooooooooool00ooo
ool3o`0005?ooooo00?o003oooooooooool02_ooool00ol00?ooooooo`00o`0Aooooo`03o`00oooo
oooooooo00cooooo00?o0000ooooooooool07Oooool01?l00?ooooooooooool00?l<ooooo`03o`00
oooooooooooo053ooooo0ol00003ooooo`002?ooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool0Doooool01?l00?ooooooooooool00?l8ooooo`04o`00ooooooooooooo`00
o`gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo
00_ooooo00Go003oooooooooooooooooo`00o`0@ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`1Cooooo`03o`000?oooooooooo007ooooo0008oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1Cooooo`04o`00oooooooo
ooooo`00o`?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0>ooooo`07o`00oooo
ooooooooooooool00?ooooooo`00o`0<ooooo`03o`000?oooooooooo00Wooooo00?o003oooooool0
0?l00oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooo`00o`1Eooooo`03o`000?oooooooooo007ooooo0009ooooo`?o0000
1Oooool00ol0003oooooooooo`1Eooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
4oooool01ol00?oooooooooooooooooo003oooooool00?l03?ooool00ol0003oooooooooo`09oooo
o`03o`00oooooooo003o00?ooooo00?o003oooooooooool02oooool01?l00?ooooooooooool00?l4
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0EOooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`1Eooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0?ooooo`?o003o3?ooool00ol0003oooooooooo`09oooo
o`03o`00oooooooo003o00?ooooo00?o003oooooooooool02oooool01?l00?ooooooooooool00?l4
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0EOooool00ol0003oooooooooo`01
ooooo`004Oooool2o`0005cooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooo
oooo013ooooo00?o003oooooooooool02oooool00ol0003oooooooooo`0Mooooo`04o`00oooooooo
ooooo`00o`Wooooo0_l00?mEooooo`;o00000oooool0017ooooo00?o0000ooooooooool0Goooool0
1?l00?ooooooooooool00?l=ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool03ooo
ool00ol00?ooooooooooo`0>ooooo`05o`00ooooooooooooooooool00?l0GOooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`1Kooooo`05o`00ooooooooooooooooool00?l0
0_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool0
3oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo05_ooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool0Foooool00ol00?ooooooooooo`0Booooo`03o`00oooo
oooooooo013ooooo00?o0000ooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool0Foooool00ol0003oooooooooo`01ooooo`004Oooool0
0ol0003oooooooooo`1Kooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02oooool0
0ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o003oooooooooool02oooool0
1?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo05_ooooo00?o0000ooooooooool00Ooo
ool0017ooooo0_l0001Looooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oooooooooo
o`0Nooooo`03o`000?oooooooooo01gooooo00Co003ooooooooooooo003oH?ooool2o`0000?ooooo
000Aooooo`03o`000?oooooooooo05oooooo00Co003ooooooooooooo003o3Oooool00ol00?oooooo
ooooo`0@ooooo`03o`000?oooooooooo023ooooo00?o003oooooooooool0Goooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`1Oooooo`04o`00ooooooooooooo`00o`gooooo
00?o003oooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo01;ooooo
00?o003oooooooooool0Foooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`1Kooooo`05o`00ooooooooooooooooool00?l04?ooool00ol00?ooooooooooo`0@ooooo`03o`00
0?oooooooooo00oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo05_ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Fooo
ool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool03ooo
ool00ol00?ooooooooooo`0;ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`1Nooooo`03
o`000?oooooooooo007ooooo000Aooooo`;o0000GOooool00ol00?ooooooo`00o`03ooooo`03o`00
oooooooooooo01kooooo00?o0000ooooooooool07Oooool01Ol00?oooooooooooooooooo003o05oo
oooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1Nooooo`05o`00ooooooooooooooooool0
0?l08?ooool00ol0003oooooooooo`0Qooooo`03o`00oooooooooooo05kooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool0G_ooool01Ol00?oooooooooooooooooo003o00go
oooo00?o003oooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo017o
oooo00?o003oooooooooool0G?ooool00ol0003oooooooooo`01ooooo`002_ooool3o`0000Cooooo
00?o0000ooooooooool0G?ooool3o`00oa7ooooo00?o003oooooooooool04?ooool00ol0003ooooo
ooooo`0?ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`1Looooo`03o`000?oooooooooo007ooooo000;ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0GOooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo013ooooo00?o
0000ooooooooool04?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool0GOooool00ol0003oooooooooo`01ooooo`002?ooool5o`0000Cooooo0ol0001R
ooooo`03o`00oooooooooooo01kooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo063ooooo0ol00003ooooo`002?ooool01?l0003oooooooooool00005
ooooo`03o`000?oooooooooo06;ooooo00?o003oooooooooool07_ooool00ol0003oooooooooo`0M
ooooo`03o`00oooooooooooo06;ooooo00?o0000ooooooooool00Oooool000Wooooo00?o0000oooo
ool000001Oooool00ol0003oooooooooo`1Sooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo06oooooo00?o0000oooo
ooooool00Oooool000[ooooo0_l00005ooooo`03o`000?oooooooooo06oooooo00?o003ooooooooo
ool04Oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool0H_ooool00ol0003oooooooooo`01ooooo`002oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo06oooooo00?o003oooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool0H_ooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`1Sooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool04Ooo
ool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0Hooo
ool00ol0003oooooooooo`01ooooo`004Oooool2o`0006Cooooo00?o003oooooooooool07Oooool0
0ol0003oooooooooo`0Looooo`03o`00oooooooooooo06;ooooo0_l00003ooooo`004Oooool00ol0
003oooooooooo`1Sooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool04Oooool00ol0
003oooooooooo`22ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06?o
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo013o
oooo00?o003oooooooooool0Koooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`1_ooooo`03o`00oooooooooooo017ooooo00?o0000ooooooooool04?ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo06?ooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool0Hoooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?o
0000ooooooooool04?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo06?ooooo00?o
0000ooooooooool00Oooool0017ooooo0_l0001Tooooo`03o`00oooooooooooo01gooooo00?o0000
ooooooooool07?ooool00ol00?ooooooooooo`1Rooooo`;o00000oooool0017ooooo00?o0000oooo
ooooool0Hoooool00ol00?ooooooooooo`0Mooooo`03o`000?oooooooooo08;ooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool0Hoooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo017ooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`1_ooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06oooooo00?o003oooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
Hoooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1_ooooo`03o`00oooo
oooooooo017ooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo06?ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001Tooooo`03o`00oooooooo
oooo01gooooo00?o0000ooooooooool07?ooool00ol00?ooooooooooo`1Rooooo`;o00000oooool0
017ooooo00?o0000ooooooooool0Hoooool00ol00?ooooooooooo`0Mooooo`03o`000?oooooooooo
01cooooo00?o003oooooooooool0Hoooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`1Sooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool04Oooool00ol0003o
ooooooooo`0@ooooo`03o`00oooooooooooo06oooooo00?o0000ooooooooool00Oooool000Wooooo
0ol00005ooooo`03o`000?oooooooooo06oooooo00?o003oooooooooool04Oooool00ol0003ooooo
ooooo`0@ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0Hoooool00ol0003ooooo
ooooo`01ooooo`002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
Koooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`1Sooooo`03o`000?oooooooooo007ooooo0008ooooo`05o`000?oo
ooooooooooooool000001?ooool3o`0006?ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`1Qooooo`?o00000oooool000Sooooo1?l00005ooooo`03o`000?oooooooooo06?ooooo00?o
003oooooooooool07Oooool00ol0003oooooooooo`0Looooo`03o`00oooooooooooo06?ooooo00?o
0000ooooooooool00Oooool000Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1S
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool04Oooool00ol0003oooooooooo`0A
ooooo`03o`00oooooooooooo06kooooo00?o0000ooooooooool00Oooool000Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1Sooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo06kooooo00?o0000oooo
ooooool00Oooool000[ooooo0_l00005ooooo`03o`000?oooooooooo06kooooo00?o003ooooooooo
ool04_ooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool0Hoooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Sooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool0Hoooool00ol0003oooooooooo`01ooooo`004Ooo
ool2o`0006Cooooo00?o003oooooooooool07Oooool00ol0003oooooooooo`0Looooo`03o`00oooo
oooooooo06;ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1Tooooo`03o`00oooooooo
oooo01cooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`1Tooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool04_ooool00ol0
003oooooooooo`0Aooooo`03o`00oooooooooooo06kooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool0K_ooool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo017o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`1Sooooo`03o`000?oooooooooo007o
oooo000Aooooo`03o`000?oooooooooo06kooooo00?o003oooooooooool04_ooool00ol0003ooooo
ooooo`0Aooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0Hoooool00ol0003ooooo
ooooo`01ooooo`004Oooool2o`0006Gooooo00?o003oooooooooool07?ooool00ol0003ooooooooo
o`0Kooooo`03o`00oooooooooooo06?ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1T
ooooo`03o`00oooooooooooo01cooooo00?o0000ooooooooool06oooool00ol00?ooooooooooo`1T
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06Cooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o003ooooo
ooooool0K_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1^ooooo`03
o`00oooooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo06Cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
K_ooool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000IOoo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01;ooooo00?o0000ooooooooool04Ooo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo06?ooooo0_l00003ooooo`004Oooool0
0ol0003oooooooooo`1Tooooo`03o`00oooooooooooo01cooooo00?o0000ooooooooool06oooool0
0ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
06Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo
017ooooo00?o003oooooooooool0K_ooool00ol0003oooooooooo`01ooooo`002Oooool3o`0000Go
oooo00?o0000ooooooooool0I?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01;o
oooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`1^ooooo`03o`000?oooooooooo007o
oooo0008ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1^ooooo`03
o`00oooooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo06Cooooo00?o0000ooooooooool00Oooool000Sooooo00Go0000oooooooooooo
ooooo`000004ooooo`?o0000I?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01;o
oooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo06;o
oooo0ol00003ooooo`002Oooool3o`0000Gooooo00?o0000ooooooooool0I?ooool00ol00?oooooo
ooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o003oooooooooool0I?ooool00ol0003ooooo
ooooo`01ooooo`002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
I?ooool00ol00?ooooooooooo`0Looooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0
0Oooool000Sooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo06Cooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo017ooooo
00?o003oooooooooool0K_ooool00ol0003oooooooooo`01ooooo`002Oooool3o`0000Gooooo00?o
0000ooooooooool0K_ooool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo007ooooo000A
ooooo`;o0000Koooool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`1Sooooo`;o00000oooool0017ooooo00?o0000oooo
ooooool0I?ooool00ol00?ooooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o003ooooo
ooooool0I?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Tooooo`03
o`00oooooooooooo01cooooo00?o0000ooooooooool06oooool00ol00?ooooooooooo`1Tooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06Cooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool0
KOooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1]ooooo`03o`00oooo
oooooooo01?ooooo00?o0000ooooooooool04_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo06Cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0KOooool0
0ol00?ooooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000I_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo06?ooooo0_l00003ooooo`004Oooool00ol0003o
ooooooooo`1Uooooo`03o`00oooooooooooo01_ooooo00?o0000ooooooooool06oooool00ol00?oo
ooooooooo`1Tooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06Gooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo
00?o003oooooooooool0KOooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`1Uooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool04oooool00ol0003ooooooooo
o`0Booooo`03o`00oooooooooooo06gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool0KOooool00ol00?ooooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`1Uooooo`03o`000?oooooooooo007ooooo000Aoooo
o`;o0000I_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01?ooooo00?o0000oooo
ooooool04_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo06Cooooo0_l00003oooo
o`004Oooool00ol0003oooooooooo`1Uooooo`03o`00oooooooooooo01_ooooo00?o0000oooooooo
ool06_ooool00ol00?ooooooooooo`1Uooooo`03o`000?oooooooooo007ooooo0003ooooo`?o0000
1?ooool2o`0000Gooooo00?o0000ooooooooool0IOooool00ol00?ooooooooooo`0Kooooo`03o`00
0?oooooooooo08;ooooo00?o0000ooooooooool00Oooool000Cooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo06Gooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool0
KOooool00ol0003oooooooooo`01ooooo`001?ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0KOooool00ol00?ooooooooooo`0Cooooo`03o`00
0?oooooooooo01;ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`1Uooooo`03o`00
0?oooooooooo007ooooo0004ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
1?ooool3o`0006gooooo00?o003oooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool0Hoooool3o`0000?ooooo0004ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Uooooo`03o`00
oooooooooooo01_ooooo00?o0000ooooooooool06_ooool00ol00?ooooooooooo`1Uooooo`03o`00
0?oooooooooo007ooooo0003ooooo`;o00001?ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo06Gooooo00?o003oooooooooool06oooool00ol0003oooooooooo`0Jooooo`03o`00
oooooooooooo06Gooooo00?o0000ooooooooool00Oooool000Cooooo00?o0000ooooooooool00ooo
ool2o`0000Gooooo00?o0000ooooooooool0IOooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo01?ooooo00?o0000ooooooooool04_ooool00ol00?ooooooooooo`1]ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo06gooooo00?o003oooooooooool04oooool0
0ol0003oooooooooo`0Booooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0IOooool0
0ol0003oooooooooo`01ooooo`004Oooool2o`0006kooooo00?o003oooooooooool04oooool00ol0
003oooooooooo`0Cooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0I?ooool2o`00
00?ooooo000Aooooo`03o`000?oooooooooo06Gooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`1Uooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06Gooooo
00?o003oooooooooool06oooool00ol0003oooooooooo`0Jooooo`03o`00oooooooooooo06Gooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0IOooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo01?ooooo00?o0000ooooooooool04oooool00ol00?oooooooooo
o`1/ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06Gooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o003o
ooooooooool0K?ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0006gooooo00?o003ooooo
ooooool05?ooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool0I?ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo06Gooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`1Uooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo06Gooooo00?o003oooooooooool06oooool00ol0003oooooooooo`0Jooooo`03o`00
oooooooooooo06Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0I_oo
ool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0I_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo01Cooooo00?o0000ooooooooool04oooool00ol00?ooooooooooo`1/ooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo06cooooo00?o003oooooooooool05?ooool00ol0
003oooooooooo`0Cooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0IOooool00ol0
003oooooooooo`01ooooo`004Oooool2o`0006gooooo00?o003oooooooooool05?ooool00ol0003o
ooooooooo`0Cooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0I?ooool2o`0000?o
oooo000Aooooo`03o`000?oooooooooo06Kooooo00?o003oooooooooool06_ooool00ol0003ooooo
ooooo`0Iooooo`03o`00oooooooooooo06Kooooo00?o0000ooooooooool00Oooool000?ooooo0ol0
0002ooooo`Go00001?ooool00ol0003oooooooooo`1Vooooo`03o`00oooooooooooo01[ooooo00?o
0000ooooooooool06Oooool00ol00?ooooooooooo`1Vooooo`03o`000?oooooooooo007ooooo0004
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`1Vooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool05?ooool00ol0003ooooooooo
o`0Cooooo`03o`00oooooooooooo06cooooo00?o0000ooooooooool00Oooool000Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06cooooo00?o003o
ooooooooool05?ooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool0I_ooool00ol0003oooooooooo`01ooooo`001?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo0ol0001/ooooo`03o`00oooooooooooo01Cooooo00?o0000oooo
ooooool04oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo06Cooooo0ol00003oooo
o`001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1Vooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool05?ooool00ol0
003oooooooooo`0Cooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0I_ooool00ol0
003oooooooooo`01ooooo`000oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo06Kooooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0Ioooo
o`03o`00oooooooooooo06Kooooo00?o0000ooooooooool00Oooool000Cooooo00?o0000oooooooo
ool00_ooool3o`0000Gooooo00?o0000ooooooooool0I_ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo01Cooooo00?o0000ooooooooool04oooool00ol00?ooooooooooo`1/ooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06Kooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo00?o003oooooooooool0
K?ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0006gooooo00?o003oooooooooool05?oo
ool00ol0003oooooooooo`0Dooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0IOoo
ool2o`0000?ooooo000Aooooo`03o`000?oooooooooo06Kooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0Dooooo`03o`000?oooooooooo01Cooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`1Vooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
06Kooooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo
06Kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0I_ooool00ol00?oo
ooooooooo`0Jooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool00Oooool0017ooooo
00?o0000ooooooooool0I_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Gooooo
00?o0000ooooooooool05?ooool00ol00?ooooooooooo`1[ooooo`03o`000?oooooooooo007ooooo
000Aooooo`;o0000K?ooool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`1Uooooo`;o00000oooool0017ooooo00?o0000
ooooooooool0Joooool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`1Vooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo06Kooooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0Ioooo
o`03o`00oooooooooooo06Kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0I_ooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o003ooooooooo
ool0I_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Wooooo`05o`00
ooooooooooooooooool00?l05oooool00ol0003oooooooooo`0Dooooo`03o`00oooooooooooo06_o
oooo00?o0000ooooooooool00Oooool0017ooooo0_l0001/ooooo`03o`00oooooooooooo01Gooooo
00?o0000ooooooooool05?ooool01Ol00?oooooooooooooooooo003o06Sooooo0_l00003ooooo`00
4Oooool00ol0003oooooooooo`1[ooooo`03o`00oooooooooooo01Gooooo00?o0000ooooooooool0
5?ooool01Ol00?oooooooooooooooooo003o06Wooooo00?o0000ooooooooool00Oooool0017ooooo
00?o0000ooooooooool0Ioooool01Ol00?oooooooooooooooooo003o01Oooooo00?o0000oooooooo
ool05?ooool01Ol00?oooooooooooooooooo003o06Wooooo00?o0000ooooooooool00Oooool000?o
oooo0ol00004ooooo`?o00001?ooool00ol0003oooooooooo`1Wooooo`03o`00oooooooooooo01Wo
oooo00?o0000ooooooooool06?ooool00ol00?ooooooooooo`1Wooooo`03o`000?oooooooooo007o
oooo0004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1Wooooo`05o`00ooooooooooooooooool00?l05oooool00ol0003oooooooooo`0Dooooo`03
o`00oooooooooooo06_ooooo00?o0000ooooooooool00Oooool000Cooooo00Co0000oooooooooooo
oooo1Ol00004ooooo`03o`000?oooooooooo06Oooooo00Go003oooooooooooooooooo`00o`0Goooo
o`03o`000?oooooooooo01Gooooo00?o003oooooooooool0J_ooool00ol0003oooooooooo`01oooo
o`001?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00oooool3o`00
06_ooooo00?o003oooooooooool05Oooool00ol0003oooooooooo`0Eooooo`04o`00oooooooooooo
o`00ofOooooo0ol00003ooooo`001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo0000
00Gooooo00?o0000ooooooooool0Ioooool01Ol00?oooooooooooooooooo003o01Oooooo00?o0000
ooooooooool05Oooool01?l00?ooooooooooool00?mYooooo`03o`000?oooooooooo007ooooo0003
ooooo`;o00001Oooool2o`0000Gooooo00?o0000ooooooooool0Ioooool00ol00?ooooooooooo`0I
ooooo`03o`000?oooooooooo01Sooooo00?o003oooooooooool0Ioooool00ol0003oooooooooo`01
ooooo`001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0Ioooool01?l00?ooooooooooool00?lHooooo`03o`000?oooooooooo08;ooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Ioooool01?l00?ooooooooooool00?lH
ooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool0J_ooool00ol0003oooooooooo`01
ooooo`004Oooool2o`0006_ooooo00?o003oooooooooool05_ooool00ol0003oooooooooo`0Eoooo
o`04o`00ooooooooooooo`00ofSooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1Zoooo
o`03o`00oooooooooooo01Kooooo00?o0000ooooooooool05Oooool01?l00?ooooooooooool00?mY
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06Sooooo00?o003ooooo
ooooool06?ooool00ol0003oooooooooo`0Gooooo`03o`00oooooooooooo06Sooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool0J?ooool00ol00?ooooooooooo`0Hooooo`03
o`000?oooooooooo01Oooooo00?o003oooooooooool0J?ooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`1Xooooo`?o003o6?ooool00ol0003oooooooooo`0Fooooo`03o`00
oooooooooooo06Wooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001Zooooo`03o`00oooo
oooooooo01Oooooo00?o0000ooooooooool05_ooool2o`00ofWooooo0_l00003ooooo`004Oooool0
0ol0003oooooooooo`23ooooo`03o`000?oooooooooo01Kooooo00?o003oooooooooool0JOooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo
08;ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`01ooooo`004Oooooooo`0000go00000oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.95693, -1.55961, \
0.0394232, 0.0959801}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Phase plot of DTFT as a function of index k", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(g2 = 
        Plot[Arg[
            X\[Theta]\  /. \ \[Theta] \[Rule] \ 2  \[Pi]\ f/fs], {f, \(-fs\)/
              2, fs/2}, \ PlotStyle \[Rule] {Blue, \ Dashing[{ .01}]}, \ 
          PlotRange \[Rule] All, PlotPoints \[Rule] 200];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309351 0.0997283 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01017 -12 -4.5 ]
[-0.0125 .01017 0 4.5 ]
[-0.0125 .10989 -12 -4.5 ]
[-0.0125 .10989 0 4.5 ]
[-0.0125 .20962 -12 -4.5 ]
[-0.0125 .20962 0 4.5 ]
[-0.0125 .30935 -6 -4.5 ]
[-0.0125 .30935 0 4.5 ]
[-0.0125 .40908 -6 -4.5 ]
[-0.0125 .40908 0 4.5 ]
[-0.0125 .50881 -6 -4.5 ]
[-0.0125 .50881 0 4.5 ]
[-0.0125 .60854 -6 -4.5 ]
[-0.0125 .60854 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01017 m
.00625 .01017 L
s
[(-3)] -0.0125 .01017 1 0 Mshowa
0 .10989 m
.00625 .10989 L
s
[(-2)] -0.0125 .10989 1 0 Mshowa
0 .20962 m
.00625 .20962 L
s
[(-1)] -0.0125 .20962 1 0 Mshowa
0 .30935 m
.00625 .30935 L
s
[(0)] -0.0125 .30935 1 0 Mshowa
0 .40908 m
.00625 .40908 L
s
[(1)] -0.0125 .40908 1 0 Mshowa
0 .50881 m
.00625 .50881 L
s
[(2)] -0.0125 .50881 1 0 Mshowa
0 .60854 m
.00625 .60854 L
s
[(3)] -0.0125 .60854 1 0 Mshowa
.125 Mabswid
0 .03011 m
.00375 .03011 L
s
0 .05006 m
.00375 .05006 L
s
0 .07 m
.00375 .07 L
s
0 .08995 m
.00375 .08995 L
s
0 .12984 m
.00375 .12984 L
s
0 .14979 m
.00375 .14979 L
s
0 .16973 m
.00375 .16973 L
s
0 .18968 m
.00375 .18968 L
s
0 .22957 m
.00375 .22957 L
s
0 .24951 m
.00375 .24951 L
s
0 .26946 m
.00375 .26946 L
s
0 .28941 m
.00375 .28941 L
s
0 .3293 m
.00375 .3293 L
s
0 .34924 m
.00375 .34924 L
s
0 .36919 m
.00375 .36919 L
s
0 .38913 m
.00375 .38913 L
s
0 .42903 m
.00375 .42903 L
s
0 .44897 m
.00375 .44897 L
s
0 .46892 m
.00375 .46892 L
s
0 .48886 m
.00375 .48886 L
s
0 .52875 m
.00375 .52875 L
s
0 .5487 m
.00375 .5487 L
s
0 .56864 m
.00375 .56864 L
s
0 .58859 m
.00375 .58859 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01017 m
1 .01017 L
s
.99375 .10989 m
1 .10989 L
s
.99375 .20962 m
1 .20962 L
s
.99375 .30935 m
1 .30935 L
s
.99375 .40908 m
1 .40908 L
s
.99375 .50881 m
1 .50881 L
s
.99375 .60854 m
1 .60854 L
s
.125 Mabswid
.99625 .03011 m
1 .03011 L
s
.99625 .05006 m
1 .05006 L
s
.99625 .07 m
1 .07 L
s
.99625 .08995 m
1 .08995 L
s
.99625 .12984 m
1 .12984 L
s
.99625 .14979 m
1 .14979 L
s
.99625 .16973 m
1 .16973 L
s
.99625 .18968 m
1 .18968 L
s
.99625 .22957 m
1 .22957 L
s
.99625 .24951 m
1 .24951 L
s
.99625 .26946 m
1 .26946 L
s
.99625 .28941 m
1 .28941 L
s
.99625 .3293 m
1 .3293 L
s
.99625 .34924 m
1 .34924 L
s
.99625 .36919 m
1 .36919 L
s
.99625 .38913 m
1 .38913 L
s
.99625 .42903 m
1 .42903 L
s
.99625 .44897 m
1 .44897 L
s
.99625 .46892 m
1 .46892 L
s
.99625 .48886 m
1 .48886 L
s
.99625 .52875 m
1 .52875 L
s
.99625 .5487 m
1 .5487 L
s
.99625 .56864 m
1 .56864 L
s
.99625 .58859 m
1 .58859 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30935 m
1 .30935 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .466 m
.02847 .42171 L
.03355 .37341 L
.03832 .32805 L
.04291 .28442 L
.0478 .23798 L
.0525 .19328 L
.05373 .18157 L
.05438 .1754 L
.05474 .17202 L
.05507 .16886 L
.05536 .16611 L
.05544 .16531 L
.05552 .16456 L
.05567 .47645 L
.05575 .4757 L
.05584 .47489 L
.05599 .47344 L
.05633 .47016 L
.0575 .45908 L
.06251 .41141 L
.06735 .36548 L
.072 .32129 L
.07694 .27429 L
.0817 .22903 L
.0841 .20626 L
.08514 .19632 L
.08628 .18551 L
.08659 .18261 L
.08691 .17954 L
.08704 .17828 L
.08719 .17692 L
.08734 .48873 L
.08749 .48733 L
.08864 .47645 L
.09116 .45248 L
.09612 .40532 L
.1009 .35991 L
.10549 .31624 L
.11039 .26975 L
.1151 .225 L
.11633 .21327 L
.11767 .20054 L
.11828 .19471 L
.11862 .19151 L
.11878 .18995 L
.11893 .18853 L
.11907 .50053 L
.1192 .49929 L
.11949 .49656 L
Mistroke
.1201 .49076 L
.12471 .44693 L
.12962 .4003 L
.13435 .3554 L
.13937 .3077 L
.14421 .26173 L
.14643 .24064 L
.14769 .22867 L
.14886 .21751 L
.15003 .20646 L
.15036 .20327 L
.15052 .20171 L
.15068 .20026 L
.15082 .51226 L
.15096 .51087 L
.15127 .50793 L
.15381 .48378 L
.15837 .44048 L
.16323 .39437 L
.1679 .35 L
.17287 .30283 L
.17765 .25739 L
.18006 .23448 L
.18112 .2245 L
.18167 .21925 L
.18197 .21638 L
.18225 .2137 L
.1824 .21231 L
.18256 .52413 L
.18265 .52328 L
.18273 .52248 L
.18289 .52097 L
.18347 .51542 L
.18462 .5045 L
.18715 .4805 L
.19177 .43666 L
.19669 .39001 L
.20142 .3451 L
.20597 .30193 L
.20849 .27796 L
.21081 .25596 L
.21308 .23442 L
.21363 .22919 L
.21394 .22631 L
.21409 .22489 L
.21422 .22359 L
.2143 .53615 L
.21439 .53535 L
.21456 .53368 L
.21487 .53075 L
Mistroke
.21547 .52504 L
.22004 .48173 L
.2249 .43562 L
.22958 .39125 L
.23455 .34408 L
.23934 .29865 L
.24176 .27573 L
.24395 .25496 L
.24454 .24939 L
.24518 .24337 L
.24547 .24061 L
.24563 .2391 L
.24578 .23769 L
.2459 .23648 L
.24604 .5485 L
.24619 .54707 L
.24633 .54577 L
.24886 .52179 L
.25366 .47623 L
.25829 .43241 L
.26321 .3858 L
.26795 .34093 L
.2725 .29781 L
.27503 .27385 L
.27614 .26336 L
.27673 .25781 L
.27705 .25477 L
.27735 .25189 L
.2775 .25053 L
.27765 .24908 L
.27773 .24833 L
.27782 .56081 L
.27797 .55935 L
.27853 .55404 L
.27963 .54367 L
.28202 .52102 L
.28689 .47498 L
.29158 .43067 L
.29656 .38359 L
.30135 .33825 L
.30597 .29466 L
.30719 .28308 L
.30835 .27219 L
.30899 .26616 L
.30916 .2645 L
.30935 .26276 L
.3095 .26127 L
.30959 .57373 L
.30968 .57295 L
.31088 .56159 L
Mistroke
.31558 .51722 L
.32058 .47008 L
.32539 .42469 L
.33002 .38105 L
.33495 .33464 L
.3374 .31159 L
.3386 .30031 L
.33969 .28999 L
.34023 .28493 L
.34052 .28225 L
.34082 .2794 L
.34097 .27799 L
.34111 .27666 L
.34124 .27547 L
.34138 .58748 L
.34151 .58625 L
.34164 .58496 L
.34189 .58263 L
.34426 .5604 L
.34883 .51738 L
.35371 .47161 L
.3584 .42761 L
.36339 .38088 L
.36819 .33592 L
.37039 .31538 L
.37164 .30369 L
.37225 .29797 L
.37252 .29546 L
.37266 .29413 L
.37281 .29272 L
.37296 .2913 L
.3731 .60332 L
.37324 .60203 L
.37337 .6008 L
.37396 .59531 L
.37519 .58376 L
.37773 .56012 L
.38236 .5169 L
.3873 .471 L
.39205 .42688 L
.39662 .38456 L
.40148 .33961 L
.40616 .29647 L
.41114 .25075 L
.41593 .20688 L
.42054 .16486 L
.42545 .12037 L
.43017 .07778 L
.43259 .05614 L
.43385 .04479 L
Mistroke
.43519 .03284 L
.43577 .02767 L
.43609 .02482 L
.43625 .02343 L
.4364 .02213 L
.43648 .0214 L
.43657 .33392 L
.43665 .33313 L
.43675 .33226 L
.43708 .32937 L
.43771 .32372 L
.44003 .30321 L
.44488 .26055 L
.44955 .21997 L
.45452 .17742 L
.4593 .13715 L
.4639 .0992 L
.46627 .08 L
.46696 .07452 L
.4676 .06938 L
.46788 .06713 L
.46803 .06591 L
.46818 .06477 L
.46833 .37684 L
.46841 .37619 L
.4685 .37549 L
.4688 .37311 L
.47378 .33423 L
.47858 .29812 L
.4832 .26471 L
.48811 .23061 L
.49285 .19902 L
.49739 .16947 L
.49853 .16217 L
.49915 .15819 L
.49945 .15625 L
.49972 .15448 L
.49988 .15349 L
.50002 .46585 L
.50018 .46485 L
.50035 .46377 L
.50103 .45937 L
.50224 .45163 L
.50717 .41961 L
.51191 .38791 L
.51648 .35627 L
.52134 .32117 L
.52601 .28602 L
.52839 .26767 L
.52965 .25784 L
Mistroke
.53034 .25242 L
.53099 .24729 L
.53129 .24487 L
.53146 .24355 L
.53161 .24232 L
.53169 .24167 L
.53178 .55429 L
.53188 .55352 L
.53196 .55282 L
.53229 .55023 L
.53347 .54077 L
.53578 .52211 L
.54058 .4825 L
.54521 .44361 L
.55012 .40151 L
.55486 .36039 L
.55941 .32039 L
.56175 .29975 L
.56239 .29407 L
.56274 .29098 L
.56306 .28809 L
.5632 .28682 L
.56334 .28562 L
.56349 .59755 L
.56364 .59629 L
.56426 .59069 L
.5689 .5492 L
.57384 .50476 L
.57859 .46169 L
.58316 .42008 L
.58803 .37558 L
.59271 .33259 L
.59769 .28673 L
.60249 .24242 L
.6071 .1997 L
.61201 .15413 L
.61674 .11017 L
.62176 .06337 L
.62428 .03984 L
.62539 .02952 L
.62597 .02405 L
.62629 .02105 L
.6266 .0182 L
.62674 .01687 L
.62689 .01545 L
.62697 .01472 L
.62706 .32721 L
.62721 .32577 L
.62777 .32055 L
.62886 .31033 L
Mistroke
.63126 .28799 L
.63611 .24254 L
.64078 .19876 L
.64575 .15215 L
.65054 .10722 L
.65514 .06397 L
.65636 .05249 L
.65751 .04168 L
.65815 .03569 L
.65832 .03405 L
.65851 .03232 L
.65867 .03084 L
.65875 .3433 L
.65884 .34252 L
.66004 .3312 L
.66473 .28707 L
.66972 .24012 L
.67452 .19487 L
.67914 .15131 L
.68405 .10494 L
.68649 .08191 L
.68769 .07063 L
.68879 .06027 L
.68985 .05021 L
.69011 .04776 L
.69025 .04642 L
.69039 .04515 L
.69055 .35695 L
.69069 .35558 L
.69097 .35291 L
.69334 .33062 L
.69797 .28682 L
.7029 .24022 L
.70765 .19532 L
.71222 .15214 L
.71708 .10615 L
.71932 .08498 L
.7205 .07379 L
.72115 .06765 L
.72176 .06187 L
.72192 .06034 L
.72209 .05872 L
.72218 .05787 L
.72228 .37024 L
.72237 .3694 L
.72246 .36861 L
.72308 .36265 L
.72431 .35103 L
.72674 .32809 L
.73143 .28364 L
Mistroke
.73642 .23637 L
.74123 .19082 L
.74586 .14699 L
.7482 .12482 L
.75078 .10036 L
.75196 .0892 L
.75258 .08335 L
.75323 .07718 L
.7535 .07456 L
.7538 .07176 L
.75388 .07094 L
.75397 .07015 L
.75412 .382 L
.75427 .38063 L
.75442 .37914 L
.75552 .36875 L
.76046 .32194 L
.76521 .27685 L
.76979 .23349 L
.77465 .18732 L
.77934 .14288 L
.78172 .12026 L
.78298 .10832 L
.78432 .09562 L
.78499 .08923 L
.78533 .08609 L
.78547 .08472 L
.78563 .08322 L
.78577 .39516 L
.78591 .39389 L
.7862 .39112 L
.78681 .3853 L
.78912 .3634 L
.79382 .31878 L
.79882 .27135 L
.80363 .22565 L
.80827 .18168 L
.81061 .15943 L
.81319 .1349 L
.81438 .1237 L
.81564 .11165 L
.81626 .10581 L
.81684 .10027 L
.8171 .09786 L
.81724 .09653 L
.81737 .09529 L
.81752 .40712 L
.81766 .40578 L
.81794 .40316 L
.82259 .35902 L
Mistroke
.82753 .31207 L
.8323 .26685 L
.83687 .22337 L
.84175 .17707 L
.84644 .13251 L
.84767 .12086 L
.84831 .11471 L
.84867 .11134 L
.84884 .10969 L
.849 .10818 L
.84914 .10685 L
.84929 .41875 L
.84944 .41734 L
.8496 .4158 L
.85026 .40952 L
.85143 .39844 L
.85632 .35198 L
.86103 .30725 L
.86603 .25971 L
.87085 .2139 L
.87549 .16983 L
.87784 .1475 L
.87909 .13566 L
.87977 .12914 L
.88011 .12592 L
.88043 .12294 L
.88072 .12012 L
.88081 .11931 L
.88089 .11854 L
.88104 .43042 L
.88112 .42964 L
.88121 .42883 L
.88136 .42736 L
.88171 .42406 L
.88288 .41293 L
.88518 .3911 L
.88976 .34753 L
.89464 .30115 L
.89934 .2565 L
.90434 .20904 L
.90684 .18528 L
.90915 .16332 L
.91139 .14198 L
.91194 .13679 L
.91223 .13407 L
.91253 .13121 L
.9126 .13047 L
.91269 .12968 L
.91278 .44212 L
.91286 .44131 L
Mistroke
.91317 .43838 L
.91378 .43264 L
.91879 .38502 L
.92361 .33913 L
.92826 .29499 L
.9332 .24803 L
.93796 .2028 L
.94035 .18007 L
.94253 .15932 L
.94311 .15383 L
.94374 .14785 L
.94403 .14512 L
.94418 .14362 L
.94433 .14221 L
.94446 .45432 L
.94459 .45303 L
.94488 .45029 L
.9474 .42633 L
.95236 .37921 L
.95714 .33383 L
.96173 .29018 L
.96661 .24373 L
.97132 .19901 L
.97619 .1527 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00=?ooool3o`0002gooooo1Ol0000]ooooo`;o0000;_ooool5o`0002oooooo0ol0000Soooo
o`00=Oooool00ol0003oooooooooo`0]ooooo`04o`000?ooooooooooo`0002cooooo00Co0000oooo
oooooooo0000;_ooool01?l0003oooooooooool0000`ooooo`03o`000?oooooooooo02;ooooo000/
ooooo`Go000000?oooooo`000?l000000ol0000Wooooo`Go00000oooool00ol0003oooooooooo`0/
ooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool0;Oooool5o`0002?ooooo000b
ooooo`04o`000?ooooooooooo`00037ooooo00?o0000ooooooooool0:oooool01?l0003ooooooooo
ool0000`ooooo`03o`000?oooooooooo02cooooo00Co0000oooooooooooo00009?ooool003?ooooo
00?o0000ooooool00000;_ooool01Ol0003ooooooooooooooooo000002cooooo00Co0000oooooooo
oooo0000;Oooool01Ol0003ooooooooooooooooo000002kooooo00?o0000ooooool000009?ooool0
03Cooooo0_l0000^ooooo`05o`000?ooooooooooooooool00000;?ooool01?l0003oooooooooool0
000]ooooo`05o`000?ooooooooooooooool00000;oooool2o`0002Cooooo000eooooo`03o`000?oo
oooooooo02gooooo0ol0000^ooooo`;o0000;oooool3o`00037ooooo00?o0000ooooooooool08_oo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool000_ooooo0ol0
0005oooooooo00002Ol00005ooooo`002_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`001?ooool5o`0000Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo083ooooo00?o0000
ooooooooool00oooool000cooooo0_l00005ooooo`?o0000POooool00ol0003oooooooooo`1ooooo
o`;o00001Oooool000kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`21ooooo`03
o`000?oooooooooo01kooooo00?o003oooooooooool0Goooool00ol0003oooooooooo`03ooooo`00
2_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0L?ooool00ol00?oo
ooooooooo`0>ooooo`03o`000?oooooooooo01kooooo00?o003oooooooooool0Goooool00ol0003o
ooooooooo`03ooooo`002oooool3o`0000Gooooo00?o0000ooooooooool0L?ooool00ol00?oooooo
ooooo`0>ooooo`03o`000?oooooooooo01kooooo00?o003oooooooooool0Goooool00ol0003ooooo
ooooo`03ooooo`004oooool00ol0003oooooooooo`1`ooooo`03o`00oooooooooooo00kooooo00?o
0000ooooooooool07_ooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo00?ooooo000C
ooooo`;o0000LOooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo01kooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`1Fooooo`;o00001Oooool001?ooooo00?o0000oooo
ooooool0L?ooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo01gooooo0_l00?l7oooo
o`03o`00oooooooooooo05Oooooo00?o0000ooooooooool00oooool001?ooooo00?o0000oooooooo
ool0Koooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooooooo01kooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`1Gooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`00
0?oooooooooo06oooooo0_l00?l@ooooo`03o`000?oooooooooo01kooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`1Gooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oo
oooooooo06oooooo0_l00?l@ooooo`03o`000?oooooooooo01gooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04kooooo00?o0000ooooooooool00ooo
ool001?ooooo0_l0001aooooo`03o`00oooooooooooo00kooooo00?o0000ooooooooool07Oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0COooool2
o`0000Gooooo000Cooooo`03o`000?oooooooooo06oooooo00?o003oooooooooool03oooool00ol0
003oooooooooo`0Mooooo`;o003o1oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
04kooooo00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool0Koooool00ol00?oo
ooooooooo`0?ooooo`03o`000?oooooooooo01kooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo04oooooo00?o0000ooooooooool00oooool001?ooooo
00?o0000ooooooooool0Koooool2o`00oa3ooooo00?o0000ooooooooool07_ooool00ol00?oooooo
ooooo`04ooooo`;o003o1oooool2o`00o`Oooooo00?o003oooooooooool0A_ooool00ol0003ooooo
ooooo`03ooooo`004oooool00ol0003oooooooooo`1_ooooo`;o003o1oooool00ol00?oooooooooo
o`06ooooo`03o`000?oooooooooo01gooooo0_l00?l7ooooo`03o`00oooooooooooo00Gooooo0_l0
0?l7ooooo`03o`00oooooooooooo04Kooooo00?o0000ooooooooool00oooool001?ooooo0_l0001a
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`0M
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool2o`00o`Oooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0mooooo`;o00001Oooool001?ooooo00?o0000oooo
ooooool0L?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o0000oooo
ooooool07?ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo03kooooo00?o0000oooo
ooooool00oooool001?ooooo00?o0000ooooooooool0K_ooool00ol00?ooooooooooo`0@ooooo`03
o`000?oooooooooo01cooooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool0?_ooool00ol0003oooooooooo`03ooooo`00
4oooool00ol0003oooooooooo`1^ooooo`03o`00oooooooo003o00Oooooo00?o003oooooooooool0
1_ooool00ol0003oooooooooo`0Nooooo`03o`00oooooooooooo00Cooooo0_l00?l7ooooo`03o`00
oooooooooooo04oooooo00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool0K_oo
ool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool07?oo
ool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00Gooooo0_l00?l6ooooo`;o003o1ooo
ool00ol00?ooooooooooo`0nooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooo
oooo073ooooo00?o003oooooooooool01?ooool2o`00o`Sooooo00?o0000ooooooooool07?ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01_ooool2
o`00o`Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0eooooo`03o`000?oooooo
oooo00?ooooo000Cooooo`;o0000LOooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Kooooo00?o0000ooooooooool07?ooool00ol00?ooooooooooo`06ooooo`;o003o2?ooool00ol0
0?ooooooooooo`04ooooo`;o003o1oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
03Cooooo0_l00005ooooo`004oooool00ol0003oooooooooo`1^ooooo`03o`00oooooooooooo013o
oooo00?o0000ooooooooool07?ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo01Oo
oooo00?o003oooooooooool01Oooool2o`00o`Oooooo00?o003oooooooooool0;Oooool00ol0003o
ooooooooo`03ooooo`002_ooool5o`0000Cooooo00?o0000ooooooooool0K_ooool00ol00?oooooo
o`00o`06ooooo`;o003o2?ooool00ol0003oooooooooo`0Nooooo`03o`00oooooooooooo00?ooooo
00?o003oooooool00?l01_ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool0;Oooool00ol0003oooooooooo`03ooooo`002oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo06gooooo00Co003ooooooooooooo003o1_ooool2o`00o`So
oooo00?o0000ooooooooool07_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooool00?l01_ooool2o`00o`Kooooo00?o003oooooooooool03oooool00ol00?oo
ooooooooo`0]ooooo`03o`000?oooooooooo00?ooooo0004ooooo`Go00000oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo073ooooo00?o003oooooooooool01?ooool2o`00o`Sooooo
00?o0000ooooooooool06oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooool00?l01_ooool2o`00o`Kooooo0_l00?l8ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo
000=ooooo`03o`000?oooooooooo00?ooooo0ol0001`ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01_ooool00ol0003oooooooooo`0Kooooo`03o`00oooooooooooo00Kooooo00?o
003oooooool00?l02?ooool00ol00?ooooooooooo`04ooooo`;o003o1_ooool2o`00o`Oooooo0_l0
0?l7ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool09?ooool2o`0000Gooooo000:
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1]ooooo`03o`00oooo
oooooooo017ooooo00?o0000ooooooooool06oooool01?l00?ooooooooooool00?l5ooooo`03o`00
oooooooooooo00kooooo00?o003oooooooooool01_ooool2o`00o`Oooooo0_l00?l7ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool09Oooool00ol0003oooooooooo`03ooooo`002_oo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0KOooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool07_ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool09Oooool00ol0003ooooo
ooooo`03ooooo`002oooool3o`0000Gooooo00?o0000ooooooooool0KOooool01?l00?oooooooooo
ool00?l5ooooo`03o`00oooooooo003o00Sooooo00?o0000ooooooooool07_ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`0?ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo01cooooo00?o0000ooooooooool00oooool001?ooooo00?o
0000ooooooooool0KOooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Sooooo
00?o0000ooooooooool06oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00?ooooo
00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`06ooooo`;o003o2?ooool00ol00?oo
ooooooooo`04ooooo`;o003o1oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01co
oooo00?o0000ooooooooool00oooool001?ooooo0_l0001aooooo`03o`00oooooooooooo00?ooooo
00?o003oooooool00?l02?ooool00ol0003oooooooooo`0Kooooo`03o`00oooooooooooo00Kooooo
00?o003oooooool00?l02?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Kooooo
0_l00?l6ooooo`03o`00oooooooo003o00Oooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`05ooooo`;o003o1oooool00ol00?ooooooooooo`0Cooooo`;o00001Oooool001?ooooo00?o
0000ooooooooool0KOooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo01_ooooo00Co
003ooooooooooooo003o1Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooool00?l01_ooool2o`00o`Kooooo00?o003oooooool00?l01oooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0Dooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo06gooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo01kooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Oooooo00?o
003oooooool00?l01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo000C
ooooo`03o`000?oooooooooo06cooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooo
oooo003o00Sooooo00?o0000ooooooooool07_ooool00ol00?ooooooooooo`02ooooo`04o`00oooo
ooooooooo`00o`Gooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`0>ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00oooooo00?o003oooooooooool02oooool00ol0003oooooooooo`03ooooo`00
4oooool00ol0003oooooooooo`1/ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?oo
ooooooooool00?l8ooooo`03o`000?oooooooooo01[ooooo00Go003oooooooooooooooooo`00o`07
ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooo003o00Sooooo00?o003oooooooooool01?ooool2o`00o`Kooooo00?o
003oooooooooool01_ooool2o`00o`Oooooo00?o003oooooooooool01Oooool2o`00o`gooooo00?o
0000ooooooooool00oooool001?ooooo0_l0001aooooo`03o`00oooooooooooo00;ooooo00Co003o
oooooooooooo003o2?ooool00ol0003oooooooooo`0Jooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool00oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Go
oooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01Oooool2o`00o`Oooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0;ooooo`;o00001Oooool001?ooooo00?o0000ooooooooool0K?ooool01Ol00?oooooo
oooooooooooo003o00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Jooooo`05
o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00;ooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo
003o00Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool2
o`00oa3ooooo00?o003oooooooooool00oooool00ol0003oooooooooo`03ooooo`004oooool00ol0
003oooooooooo`1/ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02?ooool2o`00
oacooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooool00?l01_ooool2o`00o`Sooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`06
ooooo`;o003o3Oooool00ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`1/oooo
o`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l8ooooo`03o`00oooo
oooooooo01kooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l5ooooo`03o`00
oooooooooooo01Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03_ooool2o`00o`gooooo00?o0000ooooooooool0
0oooool001?ooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`1Mooooo`05o`00oooo
ooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l7ooooo`03o`00ool0003ooooo01_o
oooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l03_oo
ool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`05ooooo`;o003o1oooool00ol00?ooooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo000Cooooo`03o`000?oooooooooo00_ooooo0_l00?mSooooo`03o`00oooooooo
oooo00;ooooo00Co003ooooooooooooo003o1oooool00ol00?oo0000ooooo`0Kooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo
00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`08ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Ko
oooo0_l00?l7ooooo`;o003o1oooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo000Cooooo`;o00003?ooool00ol00?ooooooooooo`1Rooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01Oooool2o`00oa_ooooo00?o003oooooooooool01_ooool01Ol00?oooooo
oooooooooooo003o00Sooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l5oooo
o`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01_ooool2o`00o`oooooo00?o003o
ooooooooool00oooool2o`0000Gooooo000Cooooo`03o`000?oooooooooo00_ooooo0_l00?l7oooo
o`03o`00oooooooooooo05Cooooo00?o003oooooooooool04_ooool2o`00oa_ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o01[ooooo00?o003oooooool00?l01Oooool0
1?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Kooooo0_l00?l8ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Cooooo00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool03?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo05Cooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01kooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool05oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00Kooooo0_l00?l6ooooo`03o`00oooooooooooo00kooooo00?o
003oooooool00?l03Oooool00ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`0;
ooooo`;o003o1oooool00ol00?ooooooooooo`1Dooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool01?l00?ooooooooooool00?l6ooooo`03o`00oooooooo003o01_ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003ooooooooo
ool03oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Kooooo00?o003ooooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`0;ooooo`;o003o
1oooool00ol00?ooooooooooo`1Iooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooo000001_ooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool00oooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l01_ooool2o`00o`Kooooo00?o
003oooooool00?l01_ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo000C
ooooo`;o00003?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo05Wooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o01_ooooo00?o003o
ooooooooool01_ooool01Ol00?oooooooooooooooooo003o00Sooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1Oooool01?l00?oo
ooooooooool00?l7ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooo`00o`06ooooo`;o003o3oooool00ol00?ooooooooooo`03ooooo`;o00001Oooool001?o
oooo00?o0000ooooooooool02oooool2o`00o`Oooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`1<ooooo`03o`00oooooooooooo017ooooo00?o003oooooool00?l06oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l04?ooool01Ol00?oooooooooooooooooo
003o00Cooooo00Co003ooooooooooooo003o1Oooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`Gooooo00?o003oooooool00?l02?ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooo003o00oooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`00
4oooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo0_l00?l7ooooo`03o`00
oooooooooooo04cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo01kooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo01Oo
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo003o01Oo
oooo00?o003oooooool00?l03Oooool00ol0003oooooooooo`03ooooo`002oooool3o`0000Gooooo
00?o0000ooooooooool02oooool2o`00o`Oooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo04?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Nooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01?oo
ool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Gooooo00?o0000ooooooooool00ooo
ool000cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`;o003o1oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0A?ooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`03ooooo`04o`00ooooooooooooo`0001_ooooo00?o003oooooooooool02_ooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Co003ooooooooooooo003o2?ooool00ol00?ooooooooooo`02ooooo`04o`00oooooooo
ooooo`00o`Gooooo00?o003oooooooooool01_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooo
oooo003o00Kooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo0004ooooo`Go00000oooool00ol0003oooooooooo`04ooooo`?o00002_ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0BOooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00oooool01?l00?oooooooooo
ool0000Kooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`06ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`04
o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooo
oooo003o00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`;o00001Ooo
ool000cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`00oooooooo
oooo00Kooooo0_l00?l7ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0jooooo`03o`00oooooooooooo017ooooo00Co003ooooooooooooo003o6_oo
ool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`gooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`02ooooo`04o`00oooooooo
ooooo`00o`Sooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooo
oooooooo00Gooooo00?o0000ooooooooool00oooool000cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo0_l00?l7ooooo`03o`00oooooooo
oooo00Gooooo0_l00?l7ooooo`03o`00oooooooooooo03[ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01kooooo00Co003ooooooooooooo003o2?oo
ool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o2?ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o3Oooool00ol0
003oooooooooo`03ooooo`002oooool2o`0000Kooooo00?o0000ooooooooool03?ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Cooooo0_l00?l7ooooo`;o003o1oooool00ol00?oo
ooooooooo`0jooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o1?ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo01kooooo00Co003ooooooooooooo003o1?ooool0
1Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00kooooo00Co003ooooooooooooo003o3Oooool00ol0003o
ooooooooo`03ooooo`003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo
00?o003oooooool00?l01oooool00ol00?ooooooooooo`04ooooo`;o003o1oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo03[ooooo00?o003oooooooooool00oooool01?l00?oooooo
ooooool00?l4ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo00006_ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00Go003oooooooooooooooooo`00o`04
ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00Kooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool01_ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`Gooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo000Cooooo`;o00002oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo03Sooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`03ooooo`04o`00oooo
ooooooooo`0001[ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01ooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o
1?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01?ooool2o`0000Gooooo000Cooooo`03o`000?oooooooooo00[ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`05ooooo`;o003o2?ooool00ol00?ooooooooooo`04ooooo`;o003o
1oooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l06_ooool00ol00?oo
ooooooooo`03ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool01_ooool01?l0
0?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l>ooooo`03
o`00oooooooooooo00Gooooo00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool0
3?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Kooooo0_l00?l7ooooo`;o003o
1oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0
0oooool00ol00?ooooooo`00o`08ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04oooo
o`04o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`06
ooooo`04o`00ooooooooooooo`00o`gooooo00?o0000ooooooooool00oooool001?ooooo00?o0000
ooooooooool03?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Kooooo0_l00?l7
ooooo`;o003o1oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool0:?ooool00ol00?ooooooooooo`04ooooo`04o`00ooooooooooooo`00o`Cooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooo003o00Gooooo00Co
003ooooooooooooo003o6Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo
00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`0?ooooo`04o`00ooooooooooooo`00
o`gooooo00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool02Oooool01?l00?oo
ooooooooool00?l7ooooo`03o`00oooooooooooo00Cooooo0_l00?l7ooooo`;o003o1_ooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo02Sooooo00?o003oooooooooool01?ooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`000007
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05
ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool02_ooool01Ol00?oooooooooooooooooo003o
00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00?ooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`06ooooo`03o`000?oooooo
oooo00?ooooo000Cooooo`03o`000?oooooooooo00Wooooo00Co003ooooooooooooo003o1Oooool0
0ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`05ooooo`;o003o1oooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooo
003o00Gooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo000000Oooooo00?o
003oooooooooool03oooool00ol00?ooooooooooo`0<ooooo`04o`00ooooooooooooo`00o`Gooooo
00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1Ooo
ool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool0
0oooool001?ooooo0_l0000:ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Cooooo0_l00?l7ooooo`03o`00oooo
oooooooo00Gooooo0_l00?l7ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?oooooo
ooooo`0?ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`06ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01Ol0
0?oooooooooooooooooo003o00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooo
ooooooooo`00o`gooooo00?o003oooooooooool01Oooool2o`0000Gooooo000Cooooo`03o`000?oo
oooooooo00cooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`05ooooo`03o`00oooo
oooo003o00Sooooo00?o003oooooooooool01?ooool2o`00o`Kooooo0_l00?l@ooooo`03o`00oooo
oooooooo023ooooo00?o003oooooooooool04Oooool01Ol00?oooooooooooooooooo003o00Oooooo
00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Sooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`03
ooooo`004oooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Oooooo00?o003ooooo
ooooool01?ooool2o`00o`Oooooo00?o003oooooooooool0:Oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Goooo
o`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o6Oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00Gooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooo
oooooooo00kooooo00Go003oooooooooooooooooo`00o`0=ooooo`03o`000?oooooooooo00?ooooo
000Cooooo`03o`000?oooooooooo00Wooooo00Co003ooooooooooooo003o1oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l01_ooool2o`00o`oooooo
0_l00?l7ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool06?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`04ooooo`03
o`00oooooooooooo00Cooooo0_l00?lAooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooo
oooo003o4?ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l02?ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`04ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool00oooool001?ooooo00?o0000
ooooooooool02Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo
0_l00?l7ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool07oooool00ol00?oooooo
o`00o`05ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol0003oooooooooo`05ooooo`03
o`00oooooooooooo00oooooo00?o003oooooooooool03?ooool00ol00?ooooooo`00o`06ooooo`03
o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`06oooo
o`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool01_ooool00ol0
003oooooooooo`03ooooo`004oooool2o`0000[ooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0Gooooo`03o`00oooooooo003o00Kooooo0_l00?l7ooooo`;o003o1oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool01Oooool01Ol00?oo
oooooooooooooooo003o00Cooooo00?o003oooooooooool01?ooool2o`00oa7ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l01?oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0=ooooo`03
o`00oooooooooooo00Gooooo0_l00005ooooo`004oooool00ol0003oooooooooo`09ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`08oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01_ooool2o`00o`Sooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Sooooo00?o003ooooo
ooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool04?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00kooooo00?o003ooooo
ool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`06ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo00Kooooo00?o0000ooooooooool00oooool001?ooooo00?o0000oooooooo
ool03?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003ooooo
ool00?l01Oooool01?l00?ooooooooooool00?l7ooooo`03o`00oooooooooooo00Cooooo0_l00?lH
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0G
ooooo`;o003o2?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00?ooooo00Co003o
oooooooooooo003o2?ooool01Ol00?oooooooooooooooooo003o00Sooooo00?o003oooooooooool0
2_ooool01Ol00?oooooooooooooooooo003o00gooooo00?o0000ooooooooool00oooool001?ooooo
00?o0000ooooooooool02?ooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003ooooooooo
ool00oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003ooooo
ool00?l03_ooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Cooooo0_l00?lHoooo
o`;o003o1_ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Gooooo00?o003ooooo
ooooool04Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`07ooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo
00Sooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooool00?l01_ooool2o`00o`Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0F
ooooo`;o003o1_ooool01?l00?ooooooooooool00?l5ooooo`03o`000?oooooooooo00Gooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Gooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`04o`00ooooooooooooo`00o`Cooooo
00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooo
oooo003o00Wooooo00?o0000ooooooooool00oooool001?ooooo0_l00009ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
003o00Kooooo0_l00?l6ooooo`03o`00oooooooo003o00Kooooo0_l00?l7ooooo`03o`00oooooooo
oooo00Gooooo0_l00?lHooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o1Ooo
ool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01_oo
ool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o
1Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00Kooooo0_l00005ooooo`004oooool00ol0003oooooooooo`08ooooo`03
o`00oooooooooooo00Kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l8
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01_ooool2o`00o`Sooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo013ooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Oooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`05ooooo`;o003o3oooool2o`00o`Kooooo00?o003o
ooooool00?l01Oooool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Cooooo
00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`06ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo00?o0000oooo
ooooool00oooool001?ooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`02ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool01?l00?ooooooooooool0
0?l7ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l03oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo00kooooo0_l00?l8ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool00oooool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Oo
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`06ooooo`05o`00oooooooooooooooo
ool00?l01oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00_ooooo00?o0000oooo
ooooool00oooool000cooooo0_l00005ooooo`03o`000?oooooooooo00cooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooo
oooooooo003o1oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool01?ooool2o`00o`Oooooo0_l00?l@ooooo`03o`00oooooooooooo00Gooooo0_l00?l6
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`07
ooooo`03o`00oooooooooooo00kooooo0_l00?l6ooooo`03o`00oooooooo003o00Kooooo0_l00?l6
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00_ooooo00?o0000ooooooooool00oooool000_ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`08ooooo`05o`00ooooooooooooooooool00?l01ooo
ool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l0
1oooool00ol00?ooooooooooo`05ooooo`;o003o1oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00Gooooo0_l00?l6ooooo`04o`00ooooooooooooo`00o`Gooooo00?o0000oooooooo
ool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`05ooooo`;o003o1oooool2o`00o`Kooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooo
oooo003o2?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003o
ooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l02Oooool00ol0003ooooo
ooooo`03ooooo`002oooool01?l0003oooooooooool00004ooooo`_o000000?o003oo`000?l00000
1Ol000000ol00?oo0000o`00000?o`000003o`00ool0003o000000Go000000?o003oo`000?l00000
1_l000000ol00?oo0000o`00o`06o`000003o`00ool0003o003o00Go000000?o003oo`000?l00?l0
1ol000000ol00?oo0000o`000005o`0000;o003o1ol000000ol00?oo0000o`00000>o`0000;o003o
1_l000001?l00?oo0000o`000?l00?l=o`000003o`00ool0003o000000Go000000?o003oo`000?l0
00001_l000000ol00?oo0000o`000005o`000003o`00ool0003o000000Go00000_l00?l7o`0000;o
003o1_l000000ol00?oo0000o`00o`05o`000003o`00ool0003o003o00Ko000000?o003oo`000?l0
00001Ol000000ol00?oo0000o`000005o`000003o`00ool0003o000000;o003o1?l000001?l00?oo
0000o`000?l00?l4o`000005o`00ool0003o0000o`000?l00?l01?l000001Ol00?oo0000o`000?l0
003o003o00[o00001Oooool000_ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool01?l00?oooooooooo
ool00?l8ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1Oooool00ol00?oo
ooooo`00o`08ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l01_ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooo003o00Oooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool2o`00o`Ko
oooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`04o`00ooooooooooooo`00
o`Cooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo
00?ooooo000;ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool03?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool0
0?l4ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooo003o00kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0>ooooo`;o003o
1oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
3oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l0
1Oooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooo
oooo003o2?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00_ooooo00?o0000oooo
ooooool00oooool000_ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0<oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooool00?l01Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo
0_l00?l8ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03oooool00ol00?oooooo
ooooo`05ooooo`;o003o4Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00oa7o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo00?o
oooo000<ooooo`;o00001Oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Co
oooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00kooooo00Co003ooooo
oooooooo003o1oooool00ol00?ooooooooooo`04ooooo`;o003o1_ooool00ol00?ooooooo`00o`07
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooo003o00Kooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool0
0?l6ooooo`;o003o1oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo0_l0
0?l7ooooo`;o003o1_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool00oooool00ol00?ooooooo`00o`08ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool00_ooool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`[o
oooo00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool01oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l04?ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o1Oooool01?l00?ooooooooooool00?l5
ooooo`03o`00oooooooo003o00Oooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`06
ooooo`;o003o4?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo003o00Kooooo00?o0000
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`;o003o1oooool00ol00?ooooooooooo`0>
ooooo`;o003o1oooool2o`00o`Kooooo0_l00?l6ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`05ooooo`04o`00ooooooooooooo`00o`Gooooo00Co
003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00
o`[ooooo00?o0000ooooooooool00oooool001?ooooo0_l00008ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00;o
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`04o`00oooooooo
ooooo`00o`Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooo
oooooooo00Kooooo0_l00?l@ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l01_oo
ool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Oooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
1Oooool2o`00o`Kooooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Gooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool01oooool2o`0000Gooooo000Cooooo`03o`00
0?oooooooooo00cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`04o`00oooooooooooo
o`00o`Cooooo00Co003ooooooooooooo003o3_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00oooooo0_l00?l7ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool03ooo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01_oo
ool2o`00o`Kooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooo003o00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0;ooooo`03o`000?oo
oooooooo00?ooooo000Cooooo`03o`000?oooooooooo00cooooo00Co003ooooooooooooo003o1?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00Oooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l5oooo
o`03o`00oooooooooooo00kooooo00?o003oooooool00?l02?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool05oooool01Ol00?oooooooooooooooooo
003o00[ooooo00?o003oooooooooool05oooool2o`00oa3ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00oooool0
1?l00?ooooooooooool00?l@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02ooo
ool00ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`07ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`0=ooooo`04o`00ooooooooooooo`00o`Oooooo00?o003oooooooooool00oooool00ol0
0?ooooooo`00o`06ooooo`03o`00oooooooo003o00oooooo00?o003oooooooooool03_ooool2o`00
o`Oooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Cooooo0_l00?l7
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00_ooooo00Co003ooooooooooooo003o1Oooool01?l00?oooooooooo
ool00?l:ooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo00Oooooo00?o
003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0?ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o
00Kooooo0_l00?lHooooo`;o003o1oooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooool00?l01oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo
00Gooooo0_l00?l6ooooo`03o`00oooooooooooo00Kooooo0_l00?l6ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`05ooooo`04o`00oooooooooooo
o`00o`Gooooo00Co003ooooooooooooo003o2_ooool00ol0003oooooooooo`03ooooo`004oooool2
o`0000Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Gooooo`05o`00oooooooo
ooooooooool00?l01?ooool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o
00Kooooo0_l00?lHooooo`;o003o1oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01Sooooo00?o003o
ooooooooool01Oooool2o`00o`Kooooo0_l00?l7ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`08ooooo`;o00001Oooool001?ooooo00?o0000oooo
ooooool01_ooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Kooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o2?ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03_ooool00ol00?oo
ooooo`00o`06ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool01Oooool01Ol00?oo
oooooooooooooooo003o00_ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Hoooo
o`03o`00oooooooooooo00Gooooo0_l00?l6ooooo`;o003o1oooool2o`00o`Kooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo003o00Gooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo00?ooooo000Cooooo`03
o`000?oooooooooo00cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool06?ooool01Ol00?oooooooooooooooooo003o00Wooooo00?o003ooooooooo
ool0:Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo0_l00?l7ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool02oooool00ol0003oooooooooo`03ooooo`00
4oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`02o`00o`?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0:ooooo`05o`00oooooooooooo
ooooool00?l01oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Gooooo00Co003o
oooooooooooo003o3_ooool00ol00?ooooooooooo`0?ooooo`;o003o1oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`0Yooooo`03o`00
oooooooooooo00oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00cooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`0;ooooo`03
o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0>ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?oo
ooooooooool00?l7ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o1oooool0
0ol00?ooooooooooo`0Fooooo`;o003o1oooool00ol0003oooooooooo`05ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01_ooool2o`00o`Kooooo0_l00?l8ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo
003o00_ooooo00?o0000ooooooooool00oooool001?ooooo0_l00007ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool05oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?oooooo
ooooool00?l7ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o1Oooool00ol0
0?ooooooo`00o`0Hooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooo003o00Kooooo00?o003oooooooooool08?ooool00ol0
0?ooooooooooo`05ooooo`;o003o1oooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool00ol0
0?ooooooo`00o`06ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`08ooooo`;o00001Oooool001?ooooo00?o0000ooooooooool01_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`06ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
003o00Kooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`06ooooo`04o`00oooooooo
ooooo`00o`Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo02Sooooo0_l00?l7ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`06ooooo`;o003o1_ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00Wooooo00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool03?ooool0
0ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooooooooooooooo
o`00o`04ooooo`03o`00oooooooooooo00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0?ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool06?ooool01?l00?ooooooooooool00?l9oooo
o`03o`00oooooooooooo03;ooooo0_l00?l7ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool01_ooool2o`00o`Sooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0;oooo
o`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo00Kooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1Ooo
ool01?l00?ooooooooooool00?l=ooooo`03o`00oooooooooooo01Wooooo00Co003ooooooooooooo
003o1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo03?ooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00_ooooo00?o0000oooooooo
ool00oooool001?ooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l5oooo
o`04o`00ooooooooooooo`00oa7ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l01oooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`Oo
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Iooooo`03o`000?oooooooooo00Go
oooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l6ooooo`03o`00oooooooooooo
037ooooo00?o003oooooooooool01Oooool2o`00o`Sooooo00?o003oooooooooool01?ooool2o`00
o`Kooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`0;ooooo`03o`000?oooooooooo
00?ooooo000Cooooo`;o00001_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o1?oo
ool01?l00?ooooooooooool00?lQooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool0
0_ooool01?l00?ooooooooooool00?l6ooooo`03o`00oooooooooooo037ooooo00?o003ooooooooo
ool01Oooool2o`00o`Kooooo0_l00?l7ooooo`;o003o1_ooool00ol00?ooooooo`00o`06ooooo`03
o`00oooooooo003o00[ooooo0_l00005ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00Kooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool01_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00Gooooo00Co
003ooooooooooooo003o1Oooool00ol00?ooooooooooo`0Iooooo`04o`00ooooooooooooo`00o`Co
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo03;o
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Ko
oooo0_l00?l6ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`004oooool00ol0003oooooooooo`0<ooooo`03o`00oooooooo003o00Gooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo
00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0>ooooo`04o`00ooooooooooooo`00o`Gooooo00?o
003oooooooooool06Oooool01?l00?ooooooooooool00?m7ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`;o003o1oooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00_ooooo00?o0000ooooooooool00oooool000_ooooo0ol0
0005ooooo`03o`000?oooooooooo00cooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`05ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool01Oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0<ooooo`03o`00oooooooooooo
00;ooooo00Co003ooooooooooooo003o2?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo01Wooooo00?o003oooooool00?l02_ooool00ol00?ooooooooooo`13ooooo`03o`00oooooooo
oooo00Gooooo0_l00?l@ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool0
0ol0003oooooooooo`03ooooo`003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo003o
00Gooooo00Co003ooooooooooooo003o1Oooool01?l00?ooooooooooool00?l@ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool00_ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo03[ooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Cooooo0_l00?l7
ooooo`;o003o3?ooool00ol0003oooooooooo`03ooooo`003?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`0@oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
1?ooool01?l00?ooooooooooool00?lQooooo`03o`000?oooooooooo00Gooooo00?o003ooooooooo
ool00_ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo03[ooooo00?o003ooooo
ooooool01Oooool2o`00o`Oooooo0_l00?l6ooooo`;o003o1oooool2o`00o`cooooo00?o0000oooo
ooooool00oooool000cooooo00?o0000ooooooooool01?ooool3o`0000Gooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooo
oooo003o1?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`06ooooo`04o`00ooooooooooooo`00ob7ooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0@_ooool2o`00o`Oo
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Wo
oooo0_l00005ooooo`003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo
0_l00?l6ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`05ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool01_ooool01?l00?oo
ooooooooool00?l8ooooo`03o`00oooooooooooo00oooooo00Co003ooooooooooooo003o1Oooool0
0ol00?ooooooooooo`0Iooooo`03o`00oooooooo003o00gooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`13ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool2
o`00o`Oooooo00?o003oooooooooool02oooool00ol0003oooooooooo`03ooooo`002oooool2o`00
00Kooooo00?o0000ooooooooool03?ooool2o`00o`Kooooo00?o003oooooool00?l01Oooool01?l0
0?ooooooooooool00?l5ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o1?oo
ool01Ol00?oooooooooooooooooo003o013ooooo00Go003oooooooooooooooooo`00o`08ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Iooooo`;o
003o2_ooool00ol00?ooooooooooo`1=ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo000<ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l5ooooo`03
o`00oooooooo003o00Gooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`0<ooooo`03o`00oooooooooooo01[ooooo0_l00?l6
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo05Cooooo0_l00?l7ooooo`03o`00oooooooooooo00_ooooo00?o0000ooooooooool00ooo
ool001?ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o1?oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l08Oooool00ol0003oooooooooo`05ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
04cooooo00?o003oooooooooool01Oooool2o`00o`Oooooo00?o003oooooooooool02oooool00ol0
003oooooooooo`03ooooo`004oooool2o`0000Gooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0Gooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool07oooool2o`00o`Kooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo04cooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00[ooooo0_l00005ooooo`004oooool00ol0003o
ooooooooo`04ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01?ooool2o`00o`Ko
oooo00?o003oooooooooool01_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Go
oooo00?o003oooooooooool01_ooool01?l00?ooooooooooool00?l8ooooo`03o`00oooooooooooo
00kooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo01[ooooo0_l00?l6
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1D
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02oooool00ol0003oooooooooo`03
ooooo`004oooool00ol0003oooooooooo`0<ooooo`;o003o1_ooool2o`00o`Kooooo00?o003ooooo
ool00?l01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo003o00Gooooo00Co003ooooo
oooooooo003o4?ooool00ol00?ooooooooooo`0;ooooo`05o`00ooooooooooooooooool00?l02?oo
ool00ol00?ooooooooooo`0Jooooo`;o003o2_ooool00ol00?ooooooooooo`1Mooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool02oooool00ol0003oooooooooo`03ooooo`004oooool0
0ol0003oooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool2
o`00o`Kooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`05ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool06_ooool2o`00o`Kooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo05Wooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0;ooooo`03
o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo
003o1?ooool00ol00?ooooooooooo`05ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo01oooooo00?o0000ooooooooool01Oooool01?l0
0?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0GOooool0
0ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo000Cooooo`;o00001Oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o1?oo
ool00ol00?ooooooooooo`05ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`05ooooo`04
o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Moooo
o`03o`00oooooooooooo00[ooooo0_l00005ooooo`004oooool00ol0003oooooooooo`04ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Kooooo0_l00?l6ooooo`03o`00oooooooo003o00Gooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Sooooo00?o003ooooo
ooooool01_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00Go003oooooooooooooooooo`00
o`1Pooooo`03o`00oooooooooooo00_ooooo00?o0000ooooooooool00oooool001?ooooo00?o0000
ooooooooool03?ooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool00ol00?ooooooo`00o`06
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l07Oooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo07Gooooo00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool00oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo0_l00?l6ooooo`03o`00oooooooo
003o00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`04o`00oooooooo
ooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00Co
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00Go
oooo00Co003ooooooooooooo003oMoooool00ol0003oooooooooo`03ooooo`004oooool00ol0003o
ooooooooo`03ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool2o`00o`Ko
oooo0_l00?l7ooooo`;o003o4Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Go
oooo00?o003oooooooooool01Oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003ooooo
ooooool01Oooool01Ol00?oooooooooooooooooo003o01gooooo00?o0000ooooooooool01Oooool0
1?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l0K_ooool00ol0003ooooo
ooooo`03ooooo`004oooool2o`0000gooooo00?o003oooooooooool03_ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00oooool00ol00?ooooooo`00
o`06ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool01Oooool01?l00?oooooooooo
ool00?l5ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool07oooool00ol0003o
ooooooooo`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`1]
ooooo`;o00001Oooool001?ooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool2o`00o`Kooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo003o00Gooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?l8ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`0Mooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool0
1Oooool01Ol00?oooooooooooooooooo003o06kooooo00?o0000ooooooooool00oooool001?ooooo
00?o0000ooooooooool03?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo
0_l00?l7ooooo`03o`00oooooooooooo00Gooooo0_l00?l6ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`0Mooooo`03o`000?oooooooooo00Oooooo00?o003ooooooooo
ool0M_ooool00ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`0Dooooo`03o`00
oooooooooooo00Gooooo0_l00?l7ooooo`03o`00oooooooooooo00Gooooo0_l00?l6ooooo`03o`00
oooooooo003o00kooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l5ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool06oooool00ol0003oooooooooo`07ooooo`03
o`00oooooooooooo07Kooooo00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool0
5?ooool00ol00?ooooooooooo`05ooooo`;o003o1oooool00ol00?ooooooooooo`0?ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`05ooooo`04o`00
ooooooooooooo`00o`Gooooo00?o003oooooooooool01Oooool01Ol00?oooooooooooooooooo003o
01gooooo00?o0000ooooooooool01Oooool00ol00?ooooooo`00o`05ooooo`05o`00oooooooooooo
ooooool00?l0K_ooool00ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`0Moooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooo003o00Kooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`05oooo
o`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o1?ooool00ol00?oooooooooo
o`0Oooooo`03o`000?oooooooooo00Gooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooo
oooooooo003o06kooooo00?o0000ooooooooool00oooool001?ooooo0_l0000Vooooo`03o`00oooo
oooooooo00Gooooo0_l00?l6ooooo`03o`00oooooooo003o00Kooooo0_l00?l6ooooo`03o`00oooo
oooo003o00Gooooo00Co003ooooooooooooo003o1Oooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00oakooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`05oooo
o`04o`00ooooooooooooo`00ofkooooo0_l00005ooooo`004oooool00ol0003oooooooooo`0Loooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool2o`00o`Kooooo00?o003ooooo
ooooool01_ooool2o`00o`Sooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`03oooo
o`04o`00ooooooooooooo`00oakooooo00?o0000ooooooooool03Oooool01?l00?ooooooooooool0
0?m_ooooo`03o`000?oooooooooo00?ooooo000:ooooo`Go00001?ooool00ol0003oooooooooo`0L
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool2o`00o`Kooooo0_l00?lA
ooooo`03o`00oooooooooooo00cooooo00?o003oooooool00?l02?ooool00ol00?ooooooooooo`0L
ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool0M_ooool00ol0003oooooooooo`03
ooooo`002oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo01cooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooool00?l01_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01cooooo00?o0000
ooooooooool01Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00ofoooooo00?o
0000ooooooooool00oooool000cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0U
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05
ooooo`;o003o1_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo003o00Kooooo00?o003o
ooooool00?l01Oooool00ol00?ooooooooooo`0Oooooo`03o`000?oooooooooo00Gooooo0_l00?l6
ooooo`04o`00ooooooooooooo`00ofoooooo00?o0000ooooooooool00oooool000gooooo00?o0000
ooooooooool00oooool3o`0002Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05
ooooo`;o003o1oooool2o`00o`Kooooo0_l00?l6ooooo`03o`00oooooooo003o00Kooooo00?o003o
ooooool00?l01Oooool00ol00?ooooooooooo`0Oooooo`03o`000?oooooooooo00Gooooo00?o003o
ooooooooool01Oooool01?l00?ooooooooooool00?m^ooooo`;o00001Oooool000[ooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo02Gooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo0_l00?l7ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?lNooooo`03o`00
0?oooooooooo00Gooooo00?o003oooooooooool01Oooool01?l00?ooooooooooool00?m_ooooo`03
o`000?oooooooooo00?ooooo000:ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`0]ooooo`03o`00oooooooooooo00Gooooo0_l00?l@ooooo`03o`00oooooooooooo00go
oooo00?o003oooooool00?l02?ooool00ol00?ooooooooooo`0Looooo`03o`000?oooooooooo00Ko
oooo00?o003oooooooooool0Moooool00ol0003oooooooooo`03ooooo`002oooool3o`0000Gooooo
00?o0000ooooooooool0;Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01Oooool2o`00o`Kooooo00?o003oooooool00?l01_ooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo01gooooo00?o0000ooooooooool01Oooool2o`00o`Kooooo
00?o003oooooool00?l0L?ooool00ol0003oooooooooo`03ooooo`004oooool00ol0003ooooooooo
o`0fooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?l6ooooo`03o`00oooooooooooo01oooooo00?o
0000ooooooooool01Oooool2o`00o`Kooooo00?o003oooooool00?l0L?ooool00ol0003ooooooooo
o`03ooooo`004oooool2o`0003Kooooo0_l00?l7ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01Oooool00ol00?ooooooo`00o`06ooooo`;o003o1_ooool00ol00?ooooooooooo`0O
ooooo`03o`000?oooooooooo00Gooooo0_l00?l6ooooo`03o`00oooooooo003o06oooooo0_l00005
ooooo`004oooool00ol0003oooooooooo`0eooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool01Oooool2o`00o`Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooo003o01oooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooo003o073ooooo00?o0000ooooooooool00oooool001?ooooo00?o0000oooooooo
ool0=Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o01oooooo00?o0000oooooooo
ool01_ooool00ol00?ooooooooooo`1gooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`00
0?oooooooooo04Kooooo0_l00?l6ooooo`;o003o1oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo01gooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`1hooooo`03o`00
0?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo03kooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`05ooooo`;o003o1oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooo003o01oooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooo003o073ooooo00?o0000ooooooooool00oooool001?ooooo0_l0000oooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01Oooool2o`00o`Oooooo0_l00?l6ooooo`03o`00oooooooo
oooo01oooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
003o06oooooo0_l00005ooooo`004oooool00ol0003oooooooooo`16ooooo`03o`00oooooooooooo
00Gooooo0_l00?l8ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l07oooool00ol0
003oooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l0L?ooool00ol0
003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`16ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`0Oooooo`03o`000?oooooooooo083o
oooo00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool0A_ooool00ol00?oooooo
ooooo`05ooooo`;o003o1oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01kooooo
00?o0000ooooooooool0P?ooool00ol0003oooooooooo`03ooooo`004oooool00ol0003ooooooooo
o`1>ooooo`;o003o1oooool00ol00?ooooooooooo`05ooooo`;o003o8?ooool00ol0003ooooooooo
o`0=ooooo`;o003oLOooool00ol0003oooooooooo`03ooooo`004oooool2o`0004oooooo0_l00?l7
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool07oooool00ol0003oooooooooo`0=
ooooo`;o003oL?ooool2o`0000Gooooo000Cooooo`03o`000?oooooooooo04kooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`05ooooo`;o003o8?ooool00ol0003oooooooooo`0=oooo
o`;o003oLOooool00ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`1Gooooo`03
o`00oooooooooooo00Gooooo0_l00?lPooooo`03o`000?oooooooooo00gooooo0_l00?maooooo`03
o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo05Oooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0Nooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0
0oooool001?ooooo00?o0000ooooooooool0Eoooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo01kooooo00?o0000ooooooooool03Oooool2o`00og7ooooo00?o0000ooooooooool00ooo
ool001?ooooo00?o0000ooooooooool0Eoooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo01oooooo00?o0000ooooooooool03Oooool2o`00og7ooooo00?o0000ooooooooool00oooool0
01?ooooo0_l0001Pooooo`03o`00oooooooooooo01oooooo00?o0000ooooooooool03Oooool00ol0
0?ooooooooooo`1_ooooo`;o00001Oooool001?ooooo00?o0000ooooooooool0Goooool00ol00?oo
ooooooooo`0Oooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool0L?ooool00ol0003o
ooooooooo`03ooooo`002oooool3o`0000Gooooo00?o0000ooooooooool0Goooool00ol00?oooooo
ooooo`0Oooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool00oooool000[ooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo05oooooo00?o003oooooooooool0
7oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo00?ooooo000>ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`20ooooo`03o`000?oo
oooooooo00?ooooo000<ooooo`;o00001Oooool3o`00087ooooo00?o0000ooooooooool0Ooooool2
o`0000Gooooo000>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00oooool000[o
oooo00Go0000ooooooooooooooooo`000004oooooooo00002Ol00005ooooo`002oooool3o`000?oo
oooo4oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-6.02802, -3.57023, \
0.039899, 0.0381025}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Magnitude plot of DFT as a function of frequency", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fft\  = \ DFT[xd];\)\), "\n", 
    \(\(g3 = 
        DiscreteListPlot[\({#[\([1]\)], \ Abs[#[\([2]\)]]} &\)\  /@ \ fft, 
          Red, \ PlotRange \[Rule] All, \ Frame \[Rule] True, \ 
          Axes \[Rule] False];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0328407 0.0147151 0.0392403 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18801 -0.0125 -3 -9 ]
[.18801 -0.0125 3 0 ]
[.35222 -0.0125 -6 -9 ]
[.35222 -0.0125 6 0 ]
[.51642 -0.0125 -6 -9 ]
[.51642 -0.0125 6 0 ]
[.68062 -0.0125 -6 -9 ]
[.68062 -0.0125 6 0 ]
[.84483 -0.0125 -6 -9 ]
[.84483 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .0932 -6 -4.5 ]
[-0.0125 .0932 0 4.5 ]
[-0.0125 .17168 -6 -4.5 ]
[-0.0125 .17168 0 4.5 ]
[-0.0125 .25016 -6 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .32864 -6 -4.5 ]
[-0.0125 .32864 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .4856 -12 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .56408 -12 -4.5 ]
[-0.0125 .56408 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18801 0 m
.18801 .00625 L
s
[(5)] .18801 -0.0125 0 1 Mshowa
.35222 0 m
.35222 .00625 L
s
[(10)] .35222 -0.0125 0 1 Mshowa
.51642 0 m
.51642 .00625 L
s
[(15)] .51642 -0.0125 0 1 Mshowa
.68062 0 m
.68062 .00625 L
s
[(20)] .68062 -0.0125 0 1 Mshowa
.84483 0 m
.84483 .00625 L
s
[(25)] .84483 -0.0125 0 1 Mshowa
.125 Mabswid
.05665 0 m
.05665 .00375 L
s
.08949 0 m
.08949 .00375 L
s
.12233 0 m
.12233 .00375 L
s
.15517 0 m
.15517 .00375 L
s
.22085 0 m
.22085 .00375 L
s
.25369 0 m
.25369 .00375 L
s
.28654 0 m
.28654 .00375 L
s
.31938 0 m
.31938 .00375 L
s
.38506 0 m
.38506 .00375 L
s
.4179 0 m
.4179 .00375 L
s
.45074 0 m
.45074 .00375 L
s
.48358 0 m
.48358 .00375 L
s
.54926 0 m
.54926 .00375 L
s
.5821 0 m
.5821 .00375 L
s
.61494 0 m
.61494 .00375 L
s
.64778 0 m
.64778 .00375 L
s
.71346 0 m
.71346 .00375 L
s
.74631 0 m
.74631 .00375 L
s
.77915 0 m
.77915 .00375 L
s
.81199 0 m
.81199 .00375 L
s
.87767 0 m
.87767 .00375 L
s
.91051 0 m
.91051 .00375 L
s
.94335 0 m
.94335 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .0932 m
.00625 .0932 L
s
[(2)] -0.0125 .0932 1 0 Mshowa
0 .17168 m
.00625 .17168 L
s
[(4)] -0.0125 .17168 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(6)] -0.0125 .25016 1 0 Mshowa
0 .32864 m
.00625 .32864 L
s
[(8)] -0.0125 .32864 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(10)] -0.0125 .40712 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(12)] -0.0125 .4856 1 0 Mshowa
0 .56408 m
.00625 .56408 L
s
[(14)] -0.0125 .56408 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .11282 m
.00375 .11282 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .1913 m
.00375 .1913 L
s
0 .21092 m
.00375 .21092 L
s
0 .23054 m
.00375 .23054 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .30902 m
.00375 .30902 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .50522 m
.00375 .50522 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .5837 m
.00375 .5837 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18801 .61178 m
.18801 .61803 L
s
.35222 .61178 m
.35222 .61803 L
s
.51642 .61178 m
.51642 .61803 L
s
.68062 .61178 m
.68062 .61803 L
s
.84483 .61178 m
.84483 .61803 L
s
.125 Mabswid
.05665 .61428 m
.05665 .61803 L
s
.08949 .61428 m
.08949 .61803 L
s
.12233 .61428 m
.12233 .61803 L
s
.15517 .61428 m
.15517 .61803 L
s
.22085 .61428 m
.22085 .61803 L
s
.25369 .61428 m
.25369 .61803 L
s
.28654 .61428 m
.28654 .61803 L
s
.31938 .61428 m
.31938 .61803 L
s
.38506 .61428 m
.38506 .61803 L
s
.4179 .61428 m
.4179 .61803 L
s
.45074 .61428 m
.45074 .61803 L
s
.48358 .61428 m
.48358 .61803 L
s
.54926 .61428 m
.54926 .61803 L
s
.5821 .61428 m
.5821 .61803 L
s
.61494 .61428 m
.61494 .61803 L
s
.64778 .61428 m
.64778 .61803 L
s
.71346 .61428 m
.71346 .61803 L
s
.74631 .61428 m
.74631 .61803 L
s
.77915 .61428 m
.77915 .61803 L
s
.81199 .61428 m
.81199 .61803 L
s
.87767 .61428 m
.87767 .61803 L
s
.91051 .61428 m
.91051 .61803 L
s
.94335 .61428 m
.94335 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .0932 m
1 .0932 L
s
.99375 .17168 m
1 .17168 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .32864 m
1 .32864 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .56408 m
1 .56408 L
s
.125 Mabswid
.99625 .03434 m
1 .03434 L
s
.99625 .05396 m
1 .05396 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .15206 m
1 .15206 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .23054 m
1 .23054 L
s
.99625 .26978 m
1 .26978 L
s
.99625 .2894 m
1 .2894 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .34826 m
1 .34826 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .44636 m
1 .44636 L
s
.99625 .46598 m
1 .46598 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .52484 m
1 .52484 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .5837 m
1 .5837 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .01472 L
s
.05665 .01472 m
.05665 .01472 L
s
.08949 .01472 m
.08949 .01472 L
s
.12233 .01472 m
.12233 .60332 L
s
.15517 .01472 m
.15517 .01472 L
s
.18801 .01472 m
.18801 .01472 L
s
.22085 .01472 m
.22085 .01472 L
s
.25369 .01472 m
.25369 .01472 L
s
.28654 .01472 m
.28654 .01472 L
s
.31938 .01472 m
.31938 .01472 L
s
.35222 .01472 m
.35222 .01472 L
s
.38506 .01472 m
.38506 .01472 L
s
.4179 .01472 m
.4179 .01472 L
s
.45074 .01472 m
.45074 .01472 L
s
.48358 .01472 m
.48358 .01472 L
s
.51642 .01472 m
.51642 .01472 L
s
.54926 .01472 m
.54926 .01472 L
s
.5821 .01472 m
.5821 .01472 L
s
.61494 .01472 m
.61494 .01472 L
s
.64778 .01472 m
.64778 .01472 L
s
.68062 .01472 m
.68062 .01472 L
s
.71346 .01472 m
.71346 .01472 L
s
.74631 .01472 m
.74631 .01472 L
s
.77915 .01472 m
.77915 .01472 L
s
.81199 .01472 m
.81199 .01472 L
s
.84483 .01472 m
.84483 .01472 L
s
.87767 .01472 m
.87767 .01472 L
s
.91051 .01472 m
.91051 .60332 L
s
.94335 .01472 m
.94335 .01472 L
s
.97619 .01472 m
.97619 .01472 L
s
.015 w
.02381 .01472 Mdot
.05665 .01472 Mdot
.08949 .01472 Mdot
.12233 .60332 Mdot
.15517 .01472 Mdot
.18801 .01472 Mdot
.22085 .01472 Mdot
.25369 .01472 Mdot
.28654 .01472 Mdot
.31938 .01472 Mdot
.35222 .01472 Mdot
.38506 .01472 Mdot
.4179 .01472 Mdot
.45074 .01472 Mdot
.48358 .01472 Mdot
.51642 .01472 Mdot
.54926 .01472 Mdot
.5821 .01472 Mdot
.61494 .01472 Mdot
.64778 .01472 Mdot
.68062 .01472 Mdot
.71346 .01472 Mdot
.74631 .01472 Mdot
.77915 .01472 Mdot
.81199 .01472 Mdot
.84483 .01472 Mdot
.87767 .01472 Mdot
.91051 .60332 Mdot
.94335 .01472 Mdot
.97619 .01472 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005oooool2o`0002Wooooo0ol0000Uooooo`?o00001?ooool2o`0002?ooooo0ol00003oooo
o`?o00008_ooool5o`0000?ooooo0_l0000Qooooo`Go00000_ooool3o`0002[ooooo000Fooooo`04
o`000?ooooooooooo`0002Oooooo00Go0000ooooooooooooooooo`00000Uooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00008oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool08?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
027ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo02Oooooo000F
ooooo`04o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02Oooooo000Fooooo`04o`000?ooooooooooo`0002_o
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
02?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Rooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool09oooool001Kooooo00Co0000oooooooooooo00009oooool4o`0002Kooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co0000
8_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0
003ooooooooooooooooo0000ooooo`Co0000:_ooool001Kooooo00Co0000oooooooooooo00009ooo
ool00ol0003oooooooooo`0Vooooo`;o00001?ooool01?l0003oooooooooool0000Rooooo`;o0000
0oooool00ol0003oooooooooo`0Sooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool0000Pooooo`07o`000?ooooooooooooooool0003oooooo`00000]ooooo`005oooool2
o`0002Sooooo1Ol0000Uooooo`03o`000?oooooooooo00?ooooo0_l0000Tooooo`04o`000?oooooo
ooooooooo`Go00008_ooool3o`0000Cooooo0_l0000Rooooo`?o00000_ooool5o`0002Wooooo003o
ooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Aoooooooo00003Ol0
0003ooooo`002_ooool2o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`01
ooooo`002Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02
ooooo`?oo`001_ooool3ool000Kooooo0ooo000>ooooo`?oo`001_ooool3ool000Kooooo0ooo0006
ooooo`?oo`001Oooool3ool000Kooooo0ooo0006ooooo`?oo`001_ooool3ool000Gooooo0ooo0006
ooooo`?oo`001_ooool3ool000Kooooo0ooo0005ooooo`?oo`001_ooool3ool000Kooooo0ooo0006
ooooo`?oo`001Oooool3ool000Kooooo0ooo0006ooooo`?oo`001_ooool3ool000Gooooo0ooo0006
ooooo`?oo`001_ooool3ool000kooooo0ooo0006ooooo`?oo`001Oooool00ol0003oooooooooo`01
ooooo`002Oooool01?l0003oooooooooool00004ooooo`?o00000_ooool3ool000Kooooo0ooo0006
ooooo`?oo`001oooool00ooo003oooooooooo`04ooooo`?oo`001_ooool3ool000Kooooo0ooo0006
ooooo`?oo`001Oooool3ool000Kooooo0ooo0006ooooo`?oo`001_ooool3ool000Gooooo0ooo0006
ooooo`?oo`001_ooool3ool000Kooooo0ooo0005ooooo`?oo`001_ooool3ool000Kooooo0ooo0006
ooooo`?oo`001Oooool3ool000Kooooo0ooo0006ooooo`?oo`001_ooool3ool000Gooooo0ooo0006
ooooo`?oo`001_ooool3ool000Oooooo00?oo`00ooooooooool01?ooool3ool000Kooooo0ooo0003
ooooo`?o00000oooool000Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02
ooooo`?oo`001_ooool3ool000Kooooo0ooo0007ooooo`03ool00?oooooooooo00Cooooo0ooo0006
ooooo`?oo`001_ooool3ool000Kooooo0ooo0005ooooo`?oo`001_ooool3ool000Kooooo0ooo0006
ooooo`?oo`001Oooool3ool000Kooooo0ooo0006ooooo`?oo`001_ooool3ool000Gooooo0ooo0006
ooooo`?oo`001_ooool3ool000Kooooo0ooo0005ooooo`?oo`001_ooool3ool000Kooooo0ooo0006
ooooo`?oo`001Oooool3ool000Kooooo0ooo0006ooooo`?oo`001oooool00ooo003oooooooooo`04
ooooo`?oo`001_ooool3ool000Gooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo0<oooooo00?oo`00
ooooooooool05Oooool00ol0003oooooooooo`01ooooo`002_ooool2o`0000Gooooo00?o0000oooo
ooooool07_ooool00ooo003oooooooooo`3?ooooo`03ool00?oooooooooo01Gooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`3?ooooo`03
ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo0_l0000Oooooo`03ool0
0?oooooooooo0<oooooo00?oo`00ooooooooool05?ooool2o`0000?ooooo000Aooooo`03o`000?oo
oooooooo01kooooo00?oo`00ooooooooool0coooool00ooo003oooooooooo`0Eooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool0coooool0
0ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
01kooooo00?oo`00ooooooooool0coooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool0coooool00ooo003o
ooooooooo`0Eooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00007oooool00ooo003ooooo
ooooo`3?ooooo`03ool00?oooooooooo01Cooooo0_l00003ooooo`004Oooool00ol0003ooooooooo
o`0Nooooo`03ool00?oooooooooo0<oooooo00?oo`00ooooooooool05Oooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo0<oooooo00?oo`00
ooooooooool05Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Noooo
o`03ool00?oooooooooo0<oooooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo0<oooooo00?oo`00oooooooo
ool05Oooool00ol0003oooooooooo`01ooooo`004Oooool2o`0001oooooo00?oo`00ooooooooool0
coooool00ooo003oooooooooo`0Dooooo`;o00000oooool0017ooooo00?o0000ooooooooool07_oo
ool00ooo003oooooooooo`3?ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`3?ooooo`03ool00?oooooo
oooo01Gooooo00?o0000ooooooooool00Oooool000Sooooo1Ol00004ooooo`03o`000?oooooooooo
01kooooo00?oo`00ooooooooool0coooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo
007ooooo0009ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool07_ooool00ooo
003oooooooooo`3?ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool000[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo0<oo
oooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`01ooooo`002oooool00ol0003ooooo
ooooo`03ooooo`?o00007_ooool00ooo003oooooooooo`3?ooooo`03ool00?oooooooooo01?ooooo
0ol00003ooooo`002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
7_ooool00ooo003oooooooooo`3?ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool0
0Oooool000Sooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo01kooooo
00?oo`00ooooooooool0coooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo
0009ooooo`?o00001Oooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo0<oooooo00?o
o`00ooooooooool05Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0N
ooooo`03ool00?oooooooooo0<oooooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`01
ooooo`004Oooool2o`0001oooooo00?oo`00ooooooooool0coooool00ooo003oooooooooo`0Doooo
o`;o00000oooool0017ooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`3?ooooo`03
ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
7_ooool00ooo003oooooooooo`3?ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`3?ooooo`03ool00?oo
oooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool07_ooool0
0ooo003oooooooooo`3?ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0
017ooooo0_l0000Oooooo`03ool00?oooooooooo0<oooooo00?oo`00ooooooooool05?ooool2o`00
00?ooooo000Aooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool0coooool00ooo003o
ooooooooo`0Eooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01kooooo
00?oo`00ooooooooool0coooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool0coooool00ooo003ooooooooo
o`0Eooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01kooooo00?oo`00
ooooooooool0coooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo000Aoooo
o`;o00007oooool00ooo003oooooooooo`3?ooooo`03ool00?oooooooooo01Cooooo0_l00003oooo
o`004Oooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo0<oooooo00?oo`00oooooooo
ool05Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Nooooo`03ool0
0?oooooooooo0<oooooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`01ooooo`002_oo
ool3o`0000Cooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`3?ooooo`03ool00?oo
oooooooo01Gooooo00?o0000ooooooooool00Oooool000_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Nooooo`03ool00?oooooooooo0<oooooo00?oo`00ooooooooool05Oooool0
0ol0003oooooooooo`01ooooo`002?ooool5o`0000Cooooo00?o0000ooooooooool07_ooool00ooo
003oooooooooo`3?ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool000So
oooo00Co0000oooooooooooo00001Oooool3o`0001kooooo00?oo`00ooooooooool0coooool00ooo
003oooooooooo`0Cooooo`?o00000oooool000Wooooo00?o0000ooooool000001Oooool00ol0003o
ooooooooo`0Nooooo`03ool00?oooooooooo0<oooooo00?oo`00ooooooooool05Oooool00ol0003o
ooooooooo`01ooooo`002_ooool2o`0000Gooooo00?o0000ooooooooool07_ooool00ooo003ooooo
ooooo`3?ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool000_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo0<oooooo00?o
o`00ooooooooool05Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0N
ooooo`03ool00?oooooooooo0<oooooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`01
ooooo`004Oooool2o`0001oooooo00?oo`00ooooooooool0coooool00ooo003oooooooooo`0Doooo
o`;o00000oooool0017ooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`3?ooooo`03
ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
7_ooool00ooo003oooooooooo`3?ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`3?ooooo`03ool00?oo
oooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool07_ooool0
0ooo003oooooooooo`3?ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0
017ooooo0_l0000Oooooo`03ool00?oooooooooo0<oooooo00?oo`00ooooooooool05?ooool2o`00
00?ooooo000Aooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool0coooool00ooo003o
ooooooooo`0Eooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01kooooo
00?oo`00ooooooooool0coooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool0coooool00ooo003ooooooooo
o`0Eooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01kooooo00?oo`00
ooooooooool0coooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo000Aoooo
o`;o00007oooool00ooo003oooooooooo`3?ooooo`03ool00?oooooooooo01Cooooo0_l00003oooo
o`004Oooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo0<oooooo00?oo`00oooooooo
ool05Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Nooooo`03ool0
0?oooooooooo0<oooooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`01ooooo`002Ooo
ool3o`0000Gooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`3?ooooo`03ool00?oo
oooooooo01Gooooo00?o0000ooooooooool00Oooool000Sooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool0coooool00ooo003ooooooooo
o`0Eooooo`03o`000?oooooooooo007ooooo0008ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo0<oooooo00?oo`00ooooooooool05Ooo
ool00ol0003oooooooooo`01ooooo`002?ooool4o`0000Gooooo0ol0000Nooooo`03ool00?oooooo
oooo0<oooooo00?oo`00ooooooooool04oooool3o`0000?ooooo0008ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`3?ooooo`03ool00?oooooooooo
01Gooooo00?o0000ooooooooool00Oooool000Wooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Nooooo`03ool00?oooooooooo0<oooooo00?oo`00ooooooooool05Oooool00ol0003o
ooooooooo`01ooooo`002_ooool2o`0000Gooooo00?o0000ooooooooool07_ooool00ooo003ooooo
ooooo`3?ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool07_ooool00ooo003oooooooooo`3?ooooo`03ool00?oooooooooo01Gooooo00?o
0000ooooooooool00Oooool0017ooooo0_l0000Oooooo`03ool00?oooooooooo0<oooooo00?oo`00
ooooooooool05?ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo01kooooo00?oo`00oooo
ooooool0coooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo01kooooo00?oo`00ooooooooool0coooool00ooo003oooooooooo`0Eooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool0
coooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo01kooooo00?oo`00ooooooooool0coooool00ooo003oooooooooo`0Eooooo`03o`000?oo
oooooooo007ooooo000Aooooo`;o00007oooool00ooo003oooooooooo`3?ooooo`03ool00?oooooo
oooo01Cooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo
0<oooooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`0Nooooo`03ool00?oooooooooo0<oooooo00?oo`00ooooooooool05Oooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo0<oooooo
00?oo`00ooooooooool05Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`0Nooooo`03ool00?oooooooooo0<oooooo00?oo`00ooooooooool05Oooool00ol0003ooooooooo
o`01ooooo`004Oooool2o`0001oooooo00?oo`00ooooooooool0coooool00ooo003oooooooooo`0D
ooooo`;o00000oooool0017ooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`3?oooo
o`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool07_ooool00ooo003oooooooooo`3?ooooo`03ool00?oooooooooo01Gooooo00?o0000oooooooo
ool00Oooool000Wooooo0ol00005ooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool0
coooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo0008ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo0<oooooo
00?oo`00ooooooooool05Oooool00ol0003oooooooooo`01ooooo`002?ooool01Ol0003ooooooooo
oooooooo000000Cooooo0ol0000Nooooo`03ool00?oooooooooo0<oooooo00?oo`00ooooooooool0
4oooool3o`0000?ooooo0009ooooo`?o00001Oooool00ol0003oooooooooo`0Nooooo`03ool00?oo
oooooooo0<oooooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`01ooooo`002?ooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool07_ooool00ooo003ooooooooo
o`3?ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool000Sooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool0cooo
ool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo0009ooooo`?o00001Oooool0
0ol0003oooooooooo`0Nooooo`03ool00?oooooooooo0<oooooo00?oo`00ooooooooool05Oooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo
0<oooooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`01ooooo`004Oooool2o`0001oo
oooo00?oo`00ooooooooool0coooool00ooo003oooooooooo`0Dooooo`;o00000oooool0017ooooo
00?o0000ooooooooool07_ooool00ooo003oooooooooo`3?ooooo`03ool00?oooooooooo01Gooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool07_ooool00ooo003ooooooooo
o`3?ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool07_ooool00ooo003oooooooooo`3?ooooo`03ool00?oooooooooo01Gooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`3?oooo
o`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo0_l0000Oooooo`03
ool00?oooooooooo0<oooooo00?oo`00ooooooooool05?ooool2o`0000?ooooo000Aooooo`03o`00
0?oooooooooo01kooooo00?oo`00ooooooooool0coooool00ooo003oooooooooo`0Eooooo`03o`00
0?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool0cooo
ool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo01kooooo00?oo`00ooooooooool0coooool00ooo003oooooooooo`0Eooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool0coooool00ooo
003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00007oooool00ooo003o
ooooooooo`3?ooooo`03ool00?oooooooooo01Cooooo0_l00003ooooo`004Oooool00ol0003ooooo
ooooo`0Nooooo`03ool00?oooooooooo0<oooooo00?oo`00ooooooooool05Oooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo0<oooooo00?o
o`00ooooooooool05Oooool00ol0003oooooooooo`01ooooo`000oooool3o`0000Cooooo0_l00005
ooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool0coooool00ooo003oooooooooo`0E
ooooo`03o`000?oooooooooo007ooooo0004ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo0<oooooo00?oo`00
ooooooooool05Oooool00ol0003oooooooooo`01ooooo`001?ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000Cooooo0ol0000Nooooo`03ool00?oooooooooo0<oooooo00?oo`00
ooooooooool04oooool3o`0000?ooooo0004ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo0<oooooo00?oo`00
ooooooooool05Oooool00ol0003oooooooooo`01ooooo`001?ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`3?
ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool000?ooooo0_l00004oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`3?
ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool000Cooooo00?o0000oooo
ooooool00oooool2o`0000Gooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`3?oooo
o`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool07_ooool00ooo003oooooooooo`3?ooooo`03ool00?oooooooooo01Gooooo00?o0000oooooooo
ool00Oooool0017ooooo0_l0000Oooooo`03ool00?oooooooooo0<oooooo00?oo`00ooooooooool0
5?ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool0cooo
ool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo01kooooo00?oo`00ooooooooool0coooool00ooo003oooooooooo`0Eooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool0coooool00ooo
003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01ko
oooo00?oo`00ooooooooool0coooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007o
oooo000Aooooo`;o00007oooool00ooo003oooooooooo`3?ooooo`03ool00?oooooooooo01Cooooo
0_l00003ooooo`004Oooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo0<oooooo00?o
o`00ooooooooool05Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0N
ooooo`03ool00?oooooooooo0<oooooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo0<oooooo00?oo`00oooo
ooooool05Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Nooooo`03
ool00?oooooooooo0<oooooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`01ooooo`00
4Oooool2o`0001oooooo00?oo`00ooooooooool0coooool00ooo003oooooooooo`0Dooooo`;o0000
0oooool0017ooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`3?ooooo`03ool00?oo
oooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool07_ooool0
0ooo003oooooooooo`3?ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0
00?ooooo0ol00002ooooo`Go00001?ooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo
0<oooooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`01ooooo`001?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool07_ooool00ooo
003oooooooooo`3?ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool000Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`?o00007_ooool00ooo003o
ooooooooo`3?ooooo`03ool00?oooooooooo01?ooooo0ol00003ooooo`001?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07_ooool00ooo003ooooo
ooooo`3?ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool000Cooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
7_ooool00ooo003oooooooooo`3?ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool0
0Oooool000?ooooo0_l00003ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`0Nooooo`03ool00?oooooooooo0<oooooo00?oo`00ooooooooool05Oooool00ol0003ooooo
ooooo`01ooooo`001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003ooooooooo
o`0Nooooo`03ool00?oooooooooo0<oooooo00?oo`00ooooooooool05Oooool00ol0003ooooooooo
o`01ooooo`004Oooool2o`0001oooooo00?oo`00ooooooooool0coooool00ooo003oooooooooo`0D
ooooo`;o00000oooool0017ooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`3?oooo
o`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool07_ooool00ooo003oooooooooo`3?ooooo`03ool00?oooooooooo01Gooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`3?ooooo`03ool0
0?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool07_oo
ool00ooo003oooooooooo`3?ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`3?ooooo`03ool00?oooooo
oooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo0_l0000Oooooo`03ool00?oooooooooo
0<oooooo00?oo`00ooooooooool05?ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo01ko
oooo00?oo`00ooooooooool0coooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007o
oooo000Aooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool0coooool00ooo003ooooo
ooooo`0Eooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01kooooo00?o
o`00ooooooooool0coooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool0coooool00ooo003oooooooooo`0E
ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00007oooool00ooo003oooooooooo`3?oooo
o`03ool00?oooooooooo01Cooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`0Nooooo`03
ool00?oooooooooo0<oooooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo0<oooooo00?oo`00ooooooooool0
5Oooool00ol0003oooooooooo`01ooooo`000oooool3o`0000Cooooo0ol00004ooooo`03o`000?oo
oooooooo01kooooo00?oo`00ooooooooool0coooool00ooo003oooooooooo`0Eooooo`03o`000?oo
oooooooo007ooooo0004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Nooooo`03ool00?oooooooooo0<oooooo00?oo`00ooooooooool05Oooool0
0ol0003oooooooooo`01ooooo`001?ooool01?l0003oooooooooooooool5o`0000Cooooo0ol0000N
ooooo`03ool00?oooooooooo0<oooooo00?oo`00ooooooooool04oooool3o`0000?ooooo0004oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01kooooo00?oo`00ooooooooool0coooool00ooo003oooooooooo`0Eooooo`03o`000?oooooo
oooo007ooooo0004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001Oooool00ol0
003oooooooooo`0Nooooo`03ool00?oooooooooo0<oooooo00?oo`00ooooooooool05Oooool00ol0
003oooooooooo`01ooooo`000oooool2o`0000Gooooo0_l00005ooooo`03o`000?oooooooooo01ko
oooo00?oo`00ooooooooool0coooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007o
oooo0004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Nooooo`03ool00?oooooooooo0<oooooo00?oo`00ooooooooool05Oooool00ol0003ooooo
ooooo`01ooooo`004Oooool2o`0001oooooo00?oo`00ooooooooool0coooool00ooo003ooooooooo
o`0Dooooo`;o00000oooool0017ooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`3?
ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool07_ooool00ooo003oooooooooo`3?ooooo`03ool00?oooooooooo01Gooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`3?ooooo`03
ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
7_ooool00ooo003oooooooooo`3?ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool07Oooool3ool00<oooooo0ooo000Fooooo`03o`000?oo
oooooooo007ooooo000Aooooo`;o00007_ooool3ool00<oooooo0ooo000Eooooo`;o00000oooool0
017ooooo00?o0000ooooooooool07Oooool3ool00<oooooo0ooo000Fooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00Oooool0017ooooo
ool0000=o`0000?ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.77509, -1.55477, \
0.114327, 0.095682}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Phase plot of DFT as a function of index k", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fft\  = \ DFT[xd];\)\), "\n", 
    \(\(g4 = 
        DiscreteListPlot[\({#[\([1]\)], \ 
                Arg[#[\([2]\)] + 0.0000001]} &\)\  /@ \ fft, Red, \ 
          PlotRange \[Rule] {\(-\[Pi]\), \ \[Pi]}, \ Frame \[Rule] True, \ 
          Axes \[Rule] False];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0328407 0.309017 0.0983632 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18801 -0.0125 -3 -9 ]
[.18801 -0.0125 3 0 ]
[.35222 -0.0125 -6 -9 ]
[.35222 -0.0125 6 0 ]
[.51642 -0.0125 -6 -9 ]
[.51642 -0.0125 6 0 ]
[.68062 -0.0125 -6 -9 ]
[.68062 -0.0125 6 0 ]
[.84483 -0.0125 -6 -9 ]
[.84483 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01393 -12 -4.5 ]
[-0.0125 .01393 0 4.5 ]
[-0.0125 .11229 -12 -4.5 ]
[-0.0125 .11229 0 4.5 ]
[-0.0125 .21065 -12 -4.5 ]
[-0.0125 .21065 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40738 -6 -4.5 ]
[-0.0125 .40738 0 4.5 ]
[-0.0125 .50574 -6 -4.5 ]
[-0.0125 .50574 0 4.5 ]
[-0.0125 .60411 -6 -4.5 ]
[-0.0125 .60411 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18801 0 m
.18801 .00625 L
s
[(5)] .18801 -0.0125 0 1 Mshowa
.35222 0 m
.35222 .00625 L
s
[(10)] .35222 -0.0125 0 1 Mshowa
.51642 0 m
.51642 .00625 L
s
[(15)] .51642 -0.0125 0 1 Mshowa
.68062 0 m
.68062 .00625 L
s
[(20)] .68062 -0.0125 0 1 Mshowa
.84483 0 m
.84483 .00625 L
s
[(25)] .84483 -0.0125 0 1 Mshowa
.125 Mabswid
.05665 0 m
.05665 .00375 L
s
.08949 0 m
.08949 .00375 L
s
.12233 0 m
.12233 .00375 L
s
.15517 0 m
.15517 .00375 L
s
.22085 0 m
.22085 .00375 L
s
.25369 0 m
.25369 .00375 L
s
.28654 0 m
.28654 .00375 L
s
.31938 0 m
.31938 .00375 L
s
.38506 0 m
.38506 .00375 L
s
.4179 0 m
.4179 .00375 L
s
.45074 0 m
.45074 .00375 L
s
.48358 0 m
.48358 .00375 L
s
.54926 0 m
.54926 .00375 L
s
.5821 0 m
.5821 .00375 L
s
.61494 0 m
.61494 .00375 L
s
.64778 0 m
.64778 .00375 L
s
.71346 0 m
.71346 .00375 L
s
.74631 0 m
.74631 .00375 L
s
.77915 0 m
.77915 .00375 L
s
.81199 0 m
.81199 .00375 L
s
.87767 0 m
.87767 .00375 L
s
.91051 0 m
.91051 .00375 L
s
.94335 0 m
.94335 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01393 m
.00625 .01393 L
s
[(-3)] -0.0125 .01393 1 0 Mshowa
0 .11229 m
.00625 .11229 L
s
[(-2)] -0.0125 .11229 1 0 Mshowa
0 .21065 m
.00625 .21065 L
s
[(-1)] -0.0125 .21065 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .40738 m
.00625 .40738 L
s
[(1)] -0.0125 .40738 1 0 Mshowa
0 .50574 m
.00625 .50574 L
s
[(2)] -0.0125 .50574 1 0 Mshowa
0 .60411 m
.00625 .60411 L
s
[(3)] -0.0125 .60411 1 0 Mshowa
.125 Mabswid
0 .0336 m
.00375 .0336 L
s
0 .05327 m
.00375 .05327 L
s
0 .07295 m
.00375 .07295 L
s
0 .09262 m
.00375 .09262 L
s
0 .13196 m
.00375 .13196 L
s
0 .15164 m
.00375 .15164 L
s
0 .17131 m
.00375 .17131 L
s
0 .19098 m
.00375 .19098 L
s
0 .23033 m
.00375 .23033 L
s
0 .25 m
.00375 .25 L
s
0 .26967 m
.00375 .26967 L
s
0 .28934 m
.00375 .28934 L
s
0 .32869 m
.00375 .32869 L
s
0 .34836 m
.00375 .34836 L
s
0 .36803 m
.00375 .36803 L
s
0 .38771 m
.00375 .38771 L
s
0 .42705 m
.00375 .42705 L
s
0 .44673 m
.00375 .44673 L
s
0 .4664 m
.00375 .4664 L
s
0 .48607 m
.00375 .48607 L
s
0 .52542 m
.00375 .52542 L
s
0 .54509 m
.00375 .54509 L
s
0 .56476 m
.00375 .56476 L
s
0 .58443 m
.00375 .58443 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18801 .61178 m
.18801 .61803 L
s
.35222 .61178 m
.35222 .61803 L
s
.51642 .61178 m
.51642 .61803 L
s
.68062 .61178 m
.68062 .61803 L
s
.84483 .61178 m
.84483 .61803 L
s
.125 Mabswid
.05665 .61428 m
.05665 .61803 L
s
.08949 .61428 m
.08949 .61803 L
s
.12233 .61428 m
.12233 .61803 L
s
.15517 .61428 m
.15517 .61803 L
s
.22085 .61428 m
.22085 .61803 L
s
.25369 .61428 m
.25369 .61803 L
s
.28654 .61428 m
.28654 .61803 L
s
.31938 .61428 m
.31938 .61803 L
s
.38506 .61428 m
.38506 .61803 L
s
.4179 .61428 m
.4179 .61803 L
s
.45074 .61428 m
.45074 .61803 L
s
.48358 .61428 m
.48358 .61803 L
s
.54926 .61428 m
.54926 .61803 L
s
.5821 .61428 m
.5821 .61803 L
s
.61494 .61428 m
.61494 .61803 L
s
.64778 .61428 m
.64778 .61803 L
s
.71346 .61428 m
.71346 .61803 L
s
.74631 .61428 m
.74631 .61803 L
s
.77915 .61428 m
.77915 .61803 L
s
.81199 .61428 m
.81199 .61803 L
s
.87767 .61428 m
.87767 .61803 L
s
.91051 .61428 m
.91051 .61803 L
s
.94335 .61428 m
.94335 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01393 m
1 .01393 L
s
.99375 .11229 m
1 .11229 L
s
.99375 .21065 m
1 .21065 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .40738 m
1 .40738 L
s
.99375 .50574 m
1 .50574 L
s
.99375 .60411 m
1 .60411 L
s
.125 Mabswid
.99625 .0336 m
1 .0336 L
s
.99625 .05327 m
1 .05327 L
s
.99625 .07295 m
1 .07295 L
s
.99625 .09262 m
1 .09262 L
s
.99625 .13196 m
1 .13196 L
s
.99625 .15164 m
1 .15164 L
s
.99625 .17131 m
1 .17131 L
s
.99625 .19098 m
1 .19098 L
s
.99625 .23033 m
1 .23033 L
s
.99625 .25 m
1 .25 L
s
.99625 .26967 m
1 .26967 L
s
.99625 .28934 m
1 .28934 L
s
.99625 .32869 m
1 .32869 L
s
.99625 .34836 m
1 .34836 L
s
.99625 .36803 m
1 .36803 L
s
.99625 .38771 m
1 .38771 L
s
.99625 .42705 m
1 .42705 L
s
.99625 .44673 m
1 .44673 L
s
.99625 .4664 m
1 .4664 L
s
.99625 .48607 m
1 .48607 L
s
.99625 .52542 m
1 .52542 L
s
.99625 .54509 m
1 .54509 L
s
.99625 .56476 m
1 .56476 L
s
.99625 .58443 m
1 .58443 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .30902 m
.02381 .30902 L
s
.05665 .30902 m
.05665 .30902 L
s
.08949 .30902 m
.08949 .30902 L
s
.12233 .30902 m
.12233 .30902 L
s
.15517 .30902 m
.15517 .30902 L
s
.18801 .30902 m
.18801 .30902 L
s
.22085 .30902 m
.22085 .30902 L
s
.25369 .30902 m
.25369 .30902 L
s
.28654 .30902 m
.28654 .30902 L
s
.31938 .30902 m
.31938 .30902 L
s
.35222 .30902 m
.35222 .30902 L
s
.38506 .30902 m
.38506 .30902 L
s
.4179 .30902 m
.4179 .30902 L
s
.45074 .30902 m
.45074 .30902 L
s
.48358 .30902 m
.48358 .30902 L
s
.51642 .30902 m
.51642 .30902 L
s
.54926 .30902 m
.54926 .30902 L
s
.5821 .30902 m
.5821 .30902 L
s
.61494 .30902 m
.61494 .30902 L
s
.64778 .30902 m
.64778 .30902 L
s
.68062 .30902 m
.68062 .30902 L
s
.71346 .30902 m
.71346 .30902 L
s
.74631 .30902 m
.74631 .30902 L
s
.77915 .30902 m
.77915 .30902 L
s
.81199 .30902 m
.81199 .30902 L
s
.84483 .30902 m
.84483 .30902 L
s
.87767 .30902 m
.87767 .30902 L
s
.91051 .30902 m
.91051 .30902 L
s
.94335 .30902 m
.94335 .30902 L
s
.97619 .30902 m
.97619 .30902 L
s
.015 w
.02381 .30902 Mdot
.05665 .30902 Mdot
.08949 .30902 Mdot
.12233 .30902 Mdot
.15517 .30902 Mdot
.18801 .30902 Mdot
.22085 .30902 Mdot
.25369 .30902 Mdot
.28654 .30902 Mdot
.31938 .30902 Mdot
.35222 .30902 Mdot
.38506 .30902 Mdot
.4179 .30902 Mdot
.45074 .30902 Mdot
.48358 .30902 Mdot
.51642 .30902 Mdot
.54926 .30902 Mdot
.5821 .30902 Mdot
.61494 .30902 Mdot
.64778 .30902 Mdot
.68062 .30902 Mdot
.71346 .30902 Mdot
.74631 .30902 Mdot
.77915 .30902 Mdot
.81199 .30902 Mdot
.84483 .30902 Mdot
.87767 .30902 Mdot
.91051 .30902 Mdot
.94335 .30902 Mdot
.97619 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005oooool2o`0002Wooooo0ol0000Uooooo`?o00001?ooool2o`0002?ooooo0ol00003oooo
o`?o00008Oooool5o`0000?ooooo0_l0000Rooooo`Go00000_ooool3o`0002[ooooo000Fooooo`04
o`000?ooooooooooo`0002Oooooo00Go0000ooooooooooooooooo`00000Uooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00008oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool07oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
02;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo02Oooooo000F
ooooo`04o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02Oooooo000Fooooo`04o`000?ooooooooooo`0002_o
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
02?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Qooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool09oooool001Kooooo00Co0000oooooooooooo00009oooool4o`0002Kooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co0000
8Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00008Oooool01_l0
003ooooooooooooooooo0000ooooo`Co0000:_ooool001Kooooo00Co0000oooooooooooo00009ooo
ool00ol0003oooooooooo`0Vooooo`;o00001?ooool01?l0003oooooooooool0000Rooooo`;o0000
0oooool00ol0003oooooooooo`0Rooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool0000Qooooo`07o`000?ooooooooooooooool0003oooooo`00000]ooooo`005oooool2
o`0002Sooooo1Ol0000Uooooo`03o`000?oooooooooo00?ooooo0_l0000Tooooo`04o`000?oooooo
ooooooooo`Go00008Oooool3o`0000Cooooo0_l0000Sooooo`?o00000_ooool5o`0002Wooooo003o
ooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Boooooooo00002ol0
0004ooooo`002_ooool3o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`002Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`02ooooo`000oooool5o`0000Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool000_ooooo0_l00005ooooo`?o
0000ooooool5ooooo`?o00001?ooool000gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool000Wooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`002_oo
ool3o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000B
ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool2o`00
0?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003o
ooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool0
0_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000B
ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool2o`00
0?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003o
ooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool0
0_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000B
ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool2o`00
0?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003o
ooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool0
0_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000B
ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool2o`00
0?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003o
ooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool0
0_ooool000Wooooo1Ol00004ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooooooo
o`02ooooo`002_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo0?oooooo1ooo
ool00ol0003oooooooooo`02ooooo`000oooool5o`0000?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool000cooooo00?o0000oooo
ooooool00oooool3o`000?oooooo1Oooool3o`0000Cooooo0009ooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool000Wo
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0
003oooooooooo`02ooooo`002_ooool3o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`03
o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooo
ooooo`02ooooo`004_ooool2o`000?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooo
oooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3ooooo
o`Oooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03
o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooo
ooooo`02ooooo`004_ooool2o`000?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooo
oooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3ooooo
o`Oooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03
o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooo
ooooo`02ooooo`004_ooool2o`000?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooo
oooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3ooooo
o`Oooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03
o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooo
ooooo`02ooooo`004_ooool2o`000?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooo
oooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3ooooo
o`Oooooo00?o0000ooooooooool00_ooool000[ooooo0ol00005ooooo`03o`000?oooooooooo0?oo
oooo1oooool00ol0003oooooooooo`02ooooo`002oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`000oooool5o`0000?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_oo
ool000_ooooo00?o0000ooooooooool01?ooool3o`000?oooooo1Oooool3o`0000Cooooo000;oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo
00;ooooo000:ooooo`;o00001_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000oooooooo
ool00_ooool000_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00;ooooo000Booooo`;o0000ooooool7ooooo`;o00001?ooool001;ooooo00?o0000oooo
ooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oo
oooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00;ooooo000Booooo`;o0000ooooool7ooooo`;o00001?ooool001;ooooo00?o0000oooo
ooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oo
oooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00;ooooo000Booooo`;o0000ooooool7ooooo`;o00001?ooool001;ooooo00?o0000oooo
ooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oo
oooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02
ooooo`004_ooool2o`000?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo0?oo
oooo1oooool00ol0003oooooooooo`02ooooo`002oooool2o`0000Gooooo00?o0000ooooooooool0
ooooool7ooooo`03o`000?oooooooooo00;ooooo000:ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000:ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool00_ooool3ool000Kooooo0ooo0005ooooo`?oo`00
1_ooool3ool000Kooooo0ooo0005ooooo`?oo`001_ooool3ool000Kooooo0ooo0006ooooo`?oo`00
1Oooool3ool000Kooooo0ooo0006ooooo`?oo`001Oooool3ool000Kooooo0ooo0006ooooo`?oo`00
1_ooool3ool000Gooooo0ooo0006ooooo`?oo`001_ooool3ool000Gooooo0ooo0006ooooo`?oo`00
1_ooool3ool000Gooooo0ooo0006ooooo`?oo`001_ooool3ool000Kooooo0ooo0005ooooo`?oo`00
1_ooool3ool000Kooooo0ooo0005ooooo`?oo`001Oooool00ol0003oooooooooo`02ooooo`002_oo
ool01?l0003oooooooooool00004ooooo`?o00000_ooool3ool000Kooooo0ooo0005ooooo`?oo`00
1_ooool3ool000Kooooo0ooo0005ooooo`?oo`001_ooool3ool000Kooooo0ooo0006ooooo`?oo`00
1Oooool3ool000Kooooo0ooo0006ooooo`?oo`001Oooool3ool000Kooooo0ooo0006ooooo`?oo`00
1_ooool3ool000Gooooo0ooo0006ooooo`?oo`001_ooool3ool000Gooooo0ooo0006ooooo`?oo`00
1_ooool3ool000Gooooo0ooo0006ooooo`?oo`001_ooool3ool000Kooooo0ooo0005ooooo`?oo`00
1_ooool3ool000Kooooo0ooo0005ooooo`?oo`000oooool3o`0000Cooooo000:ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool00_ooool3ool000Kooooo0ooo0005ooooo`?oo`00
1_ooool3ool000Kooooo0ooo0005ooooo`?oo`001_ooool3ool000Kooooo0ooo0006ooooo`?oo`00
1Oooool3ool000Kooooo0ooo0006ooooo`?oo`001Oooool3ool000Kooooo0ooo0006ooooo`?oo`00
1_ooool3ool000Gooooo0ooo0006ooooo`?oo`001_ooool3ool000Gooooo0ooo0006ooooo`?oo`00
1_ooool3ool000Gooooo0ooo0006ooooo`?oo`001_ooool3ool000Kooooo0ooo0005ooooo`?oo`00
1_ooool3ool000Kooooo0ooo0005ooooo`?oo`001Oooool00ol0003oooooooooo`02ooooo`002_oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooo
ooooo`02ooooo`002oooool2o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02
ooooo`004_ooool2o`000?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo0?oo
oooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02
ooooo`004_ooool2o`000?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo0?oo
oooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02
ooooo`004_ooool2o`000?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo0?oo
oooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02
ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool001;o
oooo0_l0003oooooo`Oooooo0_l00004ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool00_ooool000[ooooo0ol00005ooooo`03o`000?oooooooooo0?oooooo1ooo
ool00ol0003oooooooooo`02ooooo`002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`002oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`002oooool00ol0003o
ooooooooo`04ooooo`?o0000ooooool5ooooo`?o00001?ooool000_ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool000[ooooo0_l0
0006ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`002oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02
ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool001;o
oooo0_l0003oooooo`Oooooo0_l00004ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02
ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool001;o
oooo0_l0003oooooo`Oooooo0_l00004ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02
ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool001;o
oooo0_l0003oooooo`Oooooo0_l00004ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02
ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool001;o
oooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000Booooo`;o0000
ooooool7ooooo`;o00001?ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00;ooooo0009ooooo`Go00001?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000
ooooooooool00_ooool000[ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3o
ooooo`Oooooo00?o0000ooooooooool00_ooool000_ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool000cooooo00?o0000oooooooo
ool00oooool3o`000?oooooo1Oooool3o`0000Cooooo0009ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool000Wooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003o
ooooooooo`02ooooo`002_ooool3o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`03o`00
0?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooooooo
o`02ooooo`004_ooool2o`000?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo
0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oo
oooo00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`00
0?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooooooo
o`02ooooo`004_ooool2o`000?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo
0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oo
oooo00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`00
0?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooooooo
o`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool0
01;ooooo0_l0003oooooo`Oooooo0_l00004ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oo
oooo00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`00
0?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooooooo
o`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool0
01;ooooo0_l0003oooooo`Oooooo0_l00004ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oo
oooo00?o0000ooooooooool00_ooool000[ooooo0ol00005ooooo`03o`000?oooooooooo0?oooooo
1oooool00ol0003oooooooooo`02ooooo`002Oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000=ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000;
ooooo`;o00001Oooool3o`000?oooooo1Oooool3o`0000Cooooo000=ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo0009ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
00;ooooo000:ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo000Boooooooo00002ol00004ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.85793, -3.6139, 0.114882, \
0.0383558}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Rearrange and scale DFT result", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g5 = 
        DiscreteListPlot[FourierRearrange[Abs[Last\  /@ \ fft], fs], Red, 
          PlotRange \[Rule] All, ImageSize \[Rule] 504, \ 
          Frame \[Rule] True, \ Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g6\  = \ Show[g1, g5];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.0147151 0.0391184 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09295 -6 -4.5 ]
[-0.0125 .09295 0 4.5 ]
[-0.0125 .17119 -6 -4.5 ]
[-0.0125 .17119 0 4.5 ]
[-0.0125 .24943 -6 -4.5 ]
[-0.0125 .24943 0 4.5 ]
[-0.0125 .32766 -6 -4.5 ]
[-0.0125 .32766 0 4.5 ]
[-0.0125 .4059 -12 -4.5 ]
[-0.0125 .4059 0 4.5 ]
[-0.0125 .48414 -12 -4.5 ]
[-0.0125 .48414 0 4.5 ]
[-0.0125 .56237 -12 -4.5 ]
[-0.0125 .56237 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09295 m
.00625 .09295 L
s
[(2)] -0.0125 .09295 1 0 Mshowa
0 .17119 m
.00625 .17119 L
s
[(4)] -0.0125 .17119 1 0 Mshowa
0 .24943 m
.00625 .24943 L
s
[(6)] -0.0125 .24943 1 0 Mshowa
0 .32766 m
.00625 .32766 L
s
[(8)] -0.0125 .32766 1 0 Mshowa
0 .4059 m
.00625 .4059 L
s
[(10)] -0.0125 .4059 1 0 Mshowa
0 .48414 m
.00625 .48414 L
s
[(12)] -0.0125 .48414 1 0 Mshowa
0 .56237 m
.00625 .56237 L
s
[(14)] -0.0125 .56237 1 0 Mshowa
.125 Mabswid
0 .03427 m
.00375 .03427 L
s
0 .05383 m
.00375 .05383 L
s
0 .07339 m
.00375 .07339 L
s
0 .11251 m
.00375 .11251 L
s
0 .13207 m
.00375 .13207 L
s
0 .15163 m
.00375 .15163 L
s
0 .19075 m
.00375 .19075 L
s
0 .21031 m
.00375 .21031 L
s
0 .22987 m
.00375 .22987 L
s
0 .26898 m
.00375 .26898 L
s
0 .28854 m
.00375 .28854 L
s
0 .3081 m
.00375 .3081 L
s
0 .34722 m
.00375 .34722 L
s
0 .36678 m
.00375 .36678 L
s
0 .38634 m
.00375 .38634 L
s
0 .42546 m
.00375 .42546 L
s
0 .44502 m
.00375 .44502 L
s
0 .46458 m
.00375 .46458 L
s
0 .5037 m
.00375 .5037 L
s
0 .52325 m
.00375 .52325 L
s
0 .54281 m
.00375 .54281 L
s
0 .58193 m
.00375 .58193 L
s
0 .60149 m
.00375 .60149 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09295 m
1 .09295 L
s
.99375 .17119 m
1 .17119 L
s
.99375 .24943 m
1 .24943 L
s
.99375 .32766 m
1 .32766 L
s
.99375 .4059 m
1 .4059 L
s
.99375 .48414 m
1 .48414 L
s
.99375 .56237 m
1 .56237 L
s
.125 Mabswid
.99625 .03427 m
1 .03427 L
s
.99625 .05383 m
1 .05383 L
s
.99625 .07339 m
1 .07339 L
s
.99625 .11251 m
1 .11251 L
s
.99625 .13207 m
1 .13207 L
s
.99625 .15163 m
1 .15163 L
s
.99625 .19075 m
1 .19075 L
s
.99625 .21031 m
1 .21031 L
s
.99625 .22987 m
1 .22987 L
s
.99625 .26898 m
1 .26898 L
s
.99625 .28854 m
1 .28854 L
s
.99625 .3081 m
1 .3081 L
s
.99625 .34722 m
1 .34722 L
s
.99625 .36678 m
1 .36678 L
s
.99625 .38634 m
1 .38634 L
s
.99625 .42546 m
1 .42546 L
s
.99625 .44502 m
1 .44502 L
s
.99625 .46458 m
1 .46458 L
s
.99625 .5037 m
1 .5037 L
s
.99625 .52325 m
1 .52325 L
s
.99625 .54281 m
1 .54281 L
s
.99625 .58193 m
1 .58193 L
s
.99625 .60149 m
1 .60149 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .01472 m
.02847 .03212 L
.03089 .03996 L
.03218 .04355 L
.03355 .04687 L
.03484 .04946 L
.03602 .05133 L
.03659 .05205 L
.0372 .05271 L
.03779 .0532 L
.03832 .05353 L
.03862 .05367 L
.03888 .05377 L
.03903 .05381 L
.03919 .05385 L
.03935 .05387 L
.03949 .05389 L
.03963 .0539 L
.03977 .0539 L
.03989 .05389 L
.04002 .05388 L
.04016 .05386 L
.04031 .05383 L
.04058 .05375 L
.04088 .05364 L
.04119 .05347 L
.04177 .05309 L
.04245 .05246 L
.04307 .05175 L
.04426 .04998 L
.04537 .0479 L
.04787 .04177 L
.05032 .03419 L
.05261 .02602 L
.05368 .02199 L
.0548 .01765 L
.05509 .01655 L
.05539 .01536 L
.05548 .01501 L
.05556 .01475 L
.05572 .01537 L
.05603 .01658 L
.05716 .02096 L
.0618 .03761 L
.06415 .04444 L
.0654 .04745 L
.06674 .05013 L
.06802 .05211 L
.06919 .05341 L
.06976 .05385 L
Mistroke
.07005 .05403 L
.07037 .05419 L
.07053 .05425 L
.07068 .0543 L
.07082 .05434 L
.07095 .05438 L
.07108 .0544 L
.07121 .05442 L
.07134 .05443 L
.07149 .05443 L
.07165 .05443 L
.07179 .05442 L
.07187 .05441 L
.07195 .05439 L
.07212 .05436 L
.07227 .05432 L
.07243 .05426 L
.07272 .05414 L
.07331 .05379 L
.07385 .05336 L
.07508 .05196 L
.07637 .04989 L
.07876 .04459 L
.08097 .03815 L
.08324 .0304 L
.08569 .0211 L
.08634 .01853 L
.0867 .01711 L
.08703 .01579 L
.08718 .01521 L
.08732 .01477 L
.08747 .0154 L
.08762 .01598 L
.08827 .01855 L
.0907 .02802 L
.09532 .04357 L
.0977 .04949 L
.0989 .05178 L
.09955 .05279 L
.10023 .0537 L
.10081 .05433 L
.10145 .05487 L
.10173 .05506 L
.10203 .05522 L
.10231 .05535 L
.10256 .05544 L
.10272 .05548 L
.10289 .05551 L
.10297 .05552 L
.10306 .05553 L
Mistroke
.10314 .05554 L
.10324 .05554 L
.10332 .05554 L
.10341 .05554 L
.1035 .05553 L
.10357 .05553 L
.10372 .0555 L
.10388 .05547 L
.10404 .05543 L
.1042 .05537 L
.10451 .05524 L
.10508 .0549 L
.10567 .05441 L
.10622 .05383 L
.10748 .05206 L
.10871 .04978 L
.11002 .04676 L
.11502 .0308 L
.11623 .02614 L
.11751 .021 L
.11804 .01884 L
.11861 .01651 L
.11877 .01586 L
.11886 .0155 L
.11894 .01517 L
.11908 .01485 L
.11924 .01549 L
.11982 .01791 L
.12445 .03607 L
.12671 .04364 L
.12916 .05026 L
.1305 .05304 L
.13174 .05501 L
.13235 .05577 L
.13292 .05635 L
.13351 .05681 L
.13383 .05699 L
.13401 .05708 L
.13417 .05714 L
.13431 .0572 L
.13447 .05724 L
.13456 .05726 L
.13464 .05728 L
.1348 .0573 L
.13494 .05731 L
.13509 .05732 L
.13524 .05731 L
.13539 .0573 L
.13547 .05729 L
.13556 .05727 L
Mistroke
.13573 .05723 L
.13603 .05713 L
.13639 .05696 L
.13672 .05676 L
.13728 .05631 L
.1379 .05567 L
.13915 .05391 L
.14037 .0516 L
.14149 .049 L
.144 .04163 L
.14649 .03267 L
.14879 .0233 L
.14934 .02096 L
.14994 .01841 L
.15021 .01723 L
.1505 .01598 L
.15062 .01546 L
.15075 .01491 L
.15089 .01513 L
.15102 .0157 L
.15227 .02109 L
.1534 .02593 L
.15579 .03567 L
.15838 .04504 L
.16088 .05225 L
.16207 .05493 L
.16319 .05695 L
.16427 .05843 L
.16488 .05905 L
.16544 .05947 L
.16574 .05964 L
.16602 .05976 L
.16617 .05982 L
.16632 .05986 L
.1664 .05988 L
.16649 .0599 L
.16665 .05992 L
.1668 .05993 L
.16689 .05993 L
.16697 .05993 L
.16706 .05993 L
.16713 .05992 L
.16722 .05991 L
.16731 .05989 L
.16746 .05986 L
.1676 .05982 L
.16792 .0597 L
.16824 .05953 L
.16854 .05933 L
.1692 .05875 L
Mistroke
.16978 .05808 L
.1704 .05722 L
.17265 .05274 L
.17379 .0497 L
.17502 .04592 L
.17723 .03794 L
.17962 .02797 L
.18088 .02233 L
.18158 .01917 L
.18191 .01762 L
.18222 .01618 L
.18237 .01551 L
.1825 .01489 L
.18264 .01519 L
.1828 .0159 L
.18341 .01877 L
.18472 .02483 L
.18703 .03512 L
.1893 .0443 L
.19175 .05268 L
.19309 .05639 L
.19433 .05919 L
.19551 .06126 L
.1961 .06206 L
.19676 .06277 L
.19706 .06302 L
.19739 .06325 L
.1977 .06343 L
.19785 .06349 L
.19798 .06354 L
.19812 .06359 L
.19824 .06362 L
.19838 .06364 L
.19853 .06366 L
.19866 .06367 L
.19881 .06366 L
.19896 .06365 L
.19911 .06363 L
.19926 .06359 L
.19943 .06354 L
.19974 .06341 L
.20005 .06324 L
.20032 .06304 L
.20096 .06245 L
.20163 .06163 L
.20276 .05975 L
.20398 .05708 L
.20619 .05067 L
.20857 .04175 L
.21116 .03018 L
Mistroke
.21237 .02435 L
.21303 .02108 L
.21365 .01795 L
.21393 .01652 L
.21408 .01574 L
.21423 .01501 L
.21438 .01522 L
.21447 .01564 L
.21456 .01609 L
.21486 .01762 L
.21595 .0232 L
.22094 .04686 L
.22344 .0564 L
.22454 .05988 L
.22575 .06312 L
.22691 .06559 L
.22799 .06733 L
.22859 .06803 L
.22914 .06851 L
.22942 .0687 L
.22974 .06886 L
.2299 .06892 L
.23007 .06897 L
.23015 .06899 L
.23023 .069 L
.23037 .06902 L
.23051 .06903 L
.23066 .06903 L
.2308 .06901 L
.23093 .06899 L
.23108 .06895 L
.23125 .0689 L
.23155 .06876 L
.23186 .06857 L
.23219 .06831 L
.23279 .06769 L
.23339 .06688 L
.23396 .06594 L
.23501 .06375 L
.23744 .05666 L
.23967 .04788 L
.24214 .0361 L
.24334 .02975 L
.24444 .02373 L
.24498 .02067 L
.24527 .01904 L
.24558 .01731 L
.24584 .01579 L
.24599 .01493 L
.24614 .01532 L
Mistroke
.24627 .01606 L
.24639 .01674 L
.24665 .01828 L
.24903 .03182 L
.25151 .04526 L
.25381 .05637 L
.25618 .06577 L
.25734 .06946 L
.25841 .07226 L
.2596 .07463 L
.26023 .07555 L
.26055 .07594 L
.26089 .07629 L
.26118 .07653 L
.26144 .0767 L
.26157 .07677 L
.26171 .07684 L
.26183 .07689 L
.26196 .07693 L
.2621 .07696 L
.26225 .07698 L
.2624 .07699 L
.26249 .07699 L
.26257 .07698 L
.2627 .07696 L
.26284 .07693 L
.26299 .07689 L
.26313 .07683 L
.26345 .07666 L
.26374 .07645 L
.2644 .07578 L
.26498 .07497 L
.2656 .07389 L
.26666 .07149 L
.26784 .06808 L
.27018 .05904 L
.2727 .0464 L
.27508 .03231 L
.27634 .02426 L
.27702 .01973 L
.27736 .01749 L
.27751 .0165 L
.27759 .01597 L
.27767 .01541 L
.27783 .01508 L
.27798 .01606 L
.2783 .01823 L
.27898 .02279 L
.28016 .03074 L
.28247 .04585 L
Mistroke
.28486 .06022 L
.28746 .0734 L
.28867 .07841 L
.28996 .0828 L
.29106 .08574 L
.29163 .08696 L
.29227 .08804 L
.29286 .08881 L
.29318 .08912 L
.29349 .08934 L
.29363 .08942 L
.29377 .08948 L
.29389 .08953 L
.29403 .08957 L
.29417 .08959 L
.29433 .08961 L
.29446 .0896 L
.2946 .08958 L
.29468 .08956 L
.29477 .08954 L
.29493 .08948 L
.29509 .08941 L
.29523 .08932 L
.29556 .08907 L
.2959 .08872 L
.29654 .08783 L
.29712 .08678 L
.29833 .08377 L
.29945 .08007 L
.30196 .06865 L
.30424 .055 L
.30673 .03714 L
.30795 .02763 L
.30854 .02281 L
.30909 .01829 L
.30925 .01698 L
.3094 .01574 L
.30956 .01498 L
.30964 .01566 L
.30973 .0164 L
.31041 .02217 L
.31162 .03231 L
.31659 .07217 L
.31907 .08872 L
.32028 .09548 L
.32138 .10074 L
.32245 .10501 L
.32361 .10857 L
.32424 .11004 L
.32483 .11108 L
Mistroke
.32512 .11147 L
.32539 .11177 L
.32567 .11202 L
.32582 .11211 L
.32598 .1122 L
.32613 .11225 L
.32621 .11227 L
.32629 .11228 L
.32645 .11229 L
.32654 .11229 L
.32662 .11228 L
.32676 .11225 L
.32691 .11219 L
.32706 .11211 L
.32721 .11201 L
.32755 .11171 L
.32785 .11133 L
.32854 .11016 L
.32914 .10877 L
.32979 .10687 L
.33097 .10238 L
.33211 .09677 L
.33337 .08922 L
.3359 .06985 L
.33845 .04569 L
.33965 .0329 L
.34077 .02044 L
.34091 .01888 L
.34106 .01717 L
.3412 .01556 L
.34133 .01536 L
.34148 .01711 L
.34164 .01896 L
.34192 .02224 L
.34317 .03704 L
.34545 .06424 L
.35004 .11522 L
.35259 .13823 L
.35492 .1539 L
.35607 .15942 L
.35673 .1618 L
.35733 .1635 L
.35786 .16458 L
.35816 .16502 L
.35844 .16532 L
.35858 .16543 L
.35873 .16552 L
.35886 .16556 L
.35901 .16559 L
.35916 .16558 L
Mistroke
.35924 .16556 L
.35932 .16553 L
.35947 .16545 L
.35962 .16535 L
.35975 .16521 L
.3599 .16504 L
.36018 .16464 L
.3605 .16401 L
.36079 .16331 L
.36143 .16131 L
.36203 .15884 L
.3631 .15306 L
.36426 .1447 L
.36664 .12079 L
.36917 .08562 L
.37033 .06641 L
.37155 .04416 L
.37205 .0344 L
.37258 .02362 L
.37274 .02037 L
.37289 .01727 L
.37303 .01497 L
.37317 .01804 L
.37372 .02979 L
.37605 .08321 L
.37857 .14597 L
.3835 .27663 L
.38824 .39861 L
.39281 .49801 L
.39515 .53827 L
.39767 .57152 L
.39889 .58355 L
.39953 .58878 L
.40022 .59348 L
.40088 .59714 L
.40148 .59973 L
.40177 .60073 L
.40208 .60163 L
.40237 .6023 L
.40264 .60277 L
.4028 .60297 L
.40294 .60312 L
.40307 .60322 L
.40321 .60329 L
.40336 .60332 L
.40344 .60332 L
.40353 .6033 L
.40368 .60324 L
.40382 .60314 L
.40395 .60301 L
Mistroke
.40409 .60284 L
.40435 .60243 L
.40462 .60185 L
.40492 .60106 L
.40554 .59884 L
.40621 .59564 L
.40741 .58778 L
.40864 .57695 L
.40998 .56221 L
.41241 .52807 L
.41735 .43456 L
.42211 .32492 L
.42668 .21458 L
.43154 .10539 L
.43379 .06128 L
.43497 .04003 L
.43562 .02903 L
.43594 .02381 L
.43623 .01912 L
.43639 .01655 L
.43647 .01527 L
.43656 .01556 L
.43665 .01695 L
.43675 .01844 L
.43692 .02108 L
.43755 .03033 L
.43878 .04697 L
.44121 .07422 L
.44244 .08519 L
.44378 .09493 L
.44504 .10208 L
.4456 .10464 L
.4462 .10698 L
.44681 .1089 L
.44737 .11029 L
.44764 .11083 L
.44793 .11133 L
.4482 .11172 L
.44846 .11201 L
.44862 .11215 L
.44879 .11228 L
.44894 .11237 L
.44908 .11243 L
.44924 .11247 L
.44933 .11248 L
.44941 .11249 L
.44949 .11248 L
.44957 .11247 L
.44966 .11246 L
.44975 .11243 L
Mistroke
.44989 .11238 L
.45005 .11229 L
.45032 .11209 L
.45062 .11179 L
.45095 .11136 L
.45154 .11034 L
.45216 .10894 L
.45328 .10566 L
.45448 .10109 L
.45579 .09503 L
.46068 .06562 L
.46539 .03328 L
.46663 .02506 L
.46728 .02085 L
.46763 .01859 L
.46796 .01651 L
.46811 .01559 L
.46825 .01472 L
.46833 .01519 L
.46842 .01571 L
.46857 .01661 L
.46923 .02054 L
.47039 .02711 L
.47297 .03976 L
.4753 .04872 L
.47647 .05226 L
.47773 .05536 L
.47893 .05757 L
.48002 .05901 L
.48059 .05954 L
.4809 .05977 L
.4812 .05994 L
.48147 .06007 L
.48162 .06012 L
.48177 .06017 L
.4819 .0602 L
.48205 .06023 L
.48218 .06024 L
.4823 .06025 L
.48244 .06025 L
.4826 .06024 L
.48268 .06023 L
.48277 .06022 L
.48292 .06019 L
.48308 .06015 L
.48322 .0601 L
.4835 .05999 L
.48382 .05982 L
.48412 .05962 L
.48479 .05905 L
Mistroke
.48596 .05765 L
.48706 .0559 L
.48955 .05052 L
.49423 .03627 L
.49662 .02765 L
.49788 .0229 L
.49857 .02025 L
.49922 .01775 L
.49949 .01668 L
.49978 .01555 L
.49994 .01496 L
.50002 .01481 L
.5001 .01512 L
.5004 .01626 L
.50171 .0213 L
.50401 .03 L
.50872 .04577 L
.51129 .05252 L
.51247 .05502 L
.51372 .05718 L
.51486 .05869 L
.51551 .05933 L
.51583 .05958 L
.51613 .05979 L
.51639 .05994 L
.51669 .06007 L
.51681 .06011 L
.51695 .06016 L
.51708 .06019 L
.5172 .06021 L
.51735 .06024 L
.51743 .06024 L
.51751 .06025 L
.51765 .06025 L
.5178 .06024 L
.51794 .06023 L
.51808 .0602 L
.51822 .06017 L
.51835 .06013 L
.51863 .06003 L
.51893 .05987 L
.51955 .05943 L
.52012 .05886 L
.52065 .05819 L
.52186 .05619 L
.52316 .05326 L
.52557 .04566 L
.52812 .03476 L
.52936 .02846 L
.53053 .02197 L
Mistroke
.53104 .019 L
.53131 .01733 L
.53158 .01576 L
.53171 .01493 L
.53186 .0154 L
.53194 .01591 L
.53202 .0164 L
.53217 .01733 L
.53271 .02078 L
.53508 .03647 L
.53761 .05392 L
.54222 .08414 L
.54479 .09788 L
.54601 .10308 L
.54713 .10697 L
.5483 .11001 L
.54891 .11115 L
.54922 .11159 L
.54956 .11198 L
.54972 .11212 L
.54986 .11223 L
.54999 .11232 L
.55013 .11239 L
.55029 .11244 L
.55043 .11247 L
.55058 .11249 L
.55067 .11248 L
.55075 .11247 L
.55088 .11244 L
.55103 .11238 L
.55115 .11232 L
.55128 .11223 L
.55158 .11197 L
.55185 .11165 L
.55246 .11063 L
.55281 .10988 L
.55313 .10907 L
.55433 .10496 L
.55542 .09974 L
.55657 .09264 L
.55893 .07283 L
.56114 .04789 L
.5624 .03094 L
.5627 .02661 L
.56302 .02188 L
.5633 .01775 L
.56345 .01536 L
.5636 .01634 L
.56373 .01841 L
.56387 .0206 L
Mistroke
.56411 .02458 L
.56467 .0338 L
.56583 .05427 L
.57043 .14774 L
.57531 .2624 L
.58002 .3754 L
.58502 .48298 L
.58753 .52714 L
.58984 .56004 L
.59209 .58372 L
.59323 .59226 L
.59387 .59603 L
.59447 .5989 L
.59506 .60099 L
.59539 .60188 L
.5957 .60251 L
.59585 .60275 L
.59598 .60294 L
.59611 .60308 L
.59624 .60319 L
.59638 .60327 L
.59652 .60331 L
.59666 .60332 L
.59682 .60328 L
.5969 .60324 L
.59699 .60318 L
.59715 .60304 L
.5973 .60285 L
.59745 .60263 L
.59777 .60199 L
.59812 .60108 L
.5987 .59904 L
.59934 .59603 L
.60056 .5881 L
.60167 .57835 L
.60419 .54805 L
.60647 .51124 L
.60897 .46218 L
.61386 .34592 L
.61858 .22121 L
.62098 .15772 L
.62358 .09202 L
.6248 .06298 L
.62547 .04769 L
.62609 .0338 L
.62663 .02229 L
.62678 .01904 L
.62692 .01598 L
.62705 .01618 L
.6272 .01913 L
Mistroke
.62841 .04327 L
.63099 .08813 L
.63332 .12032 L
.63449 .13329 L
.63576 .14483 L
.63695 .15337 L
.63805 .1592 L
.63862 .16148 L
.63893 .16251 L
.63923 .16335 L
.6395 .16401 L
.6398 .1646 L
.64007 .16501 L
.64032 .16529 L
.64047 .16541 L
.64062 .1655 L
.64077 .16556 L
.6409 .16559 L
.64106 .16558 L
.64114 .16556 L
.64123 .16554 L
.64138 .16546 L
.64146 .16541 L
.64153 .16535 L
.64185 .16501 L
.64203 .16476 L
.6422 .16449 L
.64282 .16312 L
.64338 .16143 L
.64399 .15914 L
.64509 .15387 L
.64758 .13687 L
.65014 .11345 L
.65257 .08731 L
.65476 .0617 L
.65601 .04677 L
.65719 .03277 L
.65775 .02617 L
.65834 .01928 L
.65848 .01756 L
.65864 .01571 L
.65873 .01477 L
.65882 .01573 L
.65898 .01759 L
.65957 .0243 L
.66211 .05128 L
.66461 .07423 L
.66693 .09111 L
.66809 .09785 L
.66918 .10302 L
Mistroke
.67031 .10721 L
.67092 .10893 L
.67156 .11038 L
.67187 .11092 L
.6722 .1114 L
.67251 .11176 L
.67279 .11201 L
.67296 .11212 L
.67312 .1122 L
.6732 .11223 L
.67329 .11226 L
.67338 .11228 L
.67347 .11229 L
.67356 .11229 L
.67363 .11229 L
.67378 .11227 L
.67387 .11225 L
.67394 .11222 L
.67412 .11215 L
.67426 .11207 L
.67441 .11196 L
.67468 .11171 L
.675 .11132 L
.67529 .11089 L
.6759 .10974 L
.67654 .10818 L
.6777 .10449 L
.67893 .09938 L
.68114 .08743 L
.68615 .05088 L
.68737 .04079 L
.68867 .02993 L
.68977 .02064 L
.69007 .0181 L
.69024 .01671 L
.69039 .0154 L
.69054 .01525 L
.6907 .01658 L
.69098 .01888 L
.69562 .05408 L
.698 .06846 L
.69922 .07454 L
.70054 .08001 L
.70176 .08403 L
.7023 .08546 L
.70288 .08678 L
.7034 .08774 L
.70395 .08855 L
.70426 .08889 L
.70454 .08915 L
Mistroke
.70482 .08935 L
.70509 .08949 L
.70522 .08954 L
.70537 .08958 L
.70551 .0896 L
.70564 .08961 L
.70579 .0896 L
.70588 .08959 L
.70596 .08957 L
.7061 .08953 L
.70626 .08947 L
.70642 .08939 L
.70659 .08929 L
.70691 .08904 L
.70749 .08838 L
.70806 .08752 L
.70865 .08638 L
.70972 .08375 L
.71086 .08012 L
.71209 .07537 L
.7143 .06482 L
.71669 .05111 L
.71929 .03441 L
.7205 .02631 L
.72116 .02183 L
.72149 .01964 L
.72179 .01764 L
.72204 .01591 L
.72217 .01504 L
.72232 .01534 L
.72246 .01629 L
.72261 .01731 L
.72288 .01913 L
.7241 .02706 L
.7265 .04185 L
.7291 .05572 L
.73032 .06121 L
.73161 .06621 L
.73282 .07009 L
.73393 .0729 L
.73506 .07504 L
.73569 .07589 L
.73598 .0762 L
.73629 .07647 L
.73658 .07667 L
.73684 .07681 L
.73696 .07687 L
.7371 .07691 L
.73723 .07695 L
.73734 .07697 L
Mistroke
.73748 .07698 L
.73761 .07699 L
.73775 .07698 L
.7379 .07696 L
.73806 .07692 L
.73821 .07687 L
.7385 .07674 L
.73878 .07656 L
.73905 .07634 L
.73966 .07569 L
.74026 .07485 L
.7409 .07371 L
.74206 .07108 L
.74313 .06805 L
.74541 .0597 L
.74791 .04821 L
.75048 .03457 L
.75281 .02135 L
.75338 .01809 L
.75369 .01632 L
.75384 .01545 L
.75398 .01477 L
.75413 .01563 L
.75429 .01656 L
.75464 .01852 L
.75524 .02193 L
.75753 .03437 L
.76002 .04651 L
.76233 .05585 L
.76457 .06273 L
.7657 .06529 L
.76631 .0664 L
.76695 .06736 L
.76753 .06804 L
.76784 .06833 L
.76817 .06859 L
.76847 .06877 L
.76875 .06889 L
.76888 .06894 L
.76902 .06898 L
.76916 .06901 L
.76928 .06902 L
.76943 .06903 L
.76958 .06903 L
.76973 .06901 L
.76986 .06899 L
.77002 .06895 L
.77019 .06889 L
.7705 .06874 L
.77083 .06854 L
Mistroke
.77117 .06826 L
.7718 .0676 L
.77244 .0667 L
.77304 .06569 L
.77438 .0628 L
.77682 .05553 L
.78158 .03542 L
.78281 .02939 L
.78398 .02353 L
.78503 .01821 L
.78531 .01675 L
.78547 .01595 L
.78562 .0152 L
.78574 .01486 L
.78588 .01555 L
.78617 .017 L
.78852 .02867 L
.79104 .04013 L
.79342 .04933 L
.79467 .0534 L
.79601 .05706 L
.79731 .05988 L
.79849 .06178 L
.79906 .06247 L
.79936 .06277 L
.79967 .06304 L
.79995 .06323 L
.80026 .06341 L
.80039 .06347 L
.80053 .06353 L
.80067 .06357 L
.80079 .06361 L
.80087 .06362 L
.80095 .06364 L
.8011 .06366 L
.80118 .06366 L
.80127 .06367 L
.80143 .06366 L
.80157 .06365 L
.80171 .06363 L
.80186 .06359 L
.80202 .06354 L
.80237 .06339 L
.80271 .06319 L
.80335 .06267 L
.80395 .062 L
.80451 .06123 L
.80577 .05899 L
.80803 .05333 L
.81052 .04499 L
Mistroke
.81306 .03474 L
.81538 .02436 L
.81652 .01907 L
.81684 .01761 L
.81717 .01605 L
.81725 .01569 L
.81734 .0153 L
.81749 .01485 L
.81764 .01554 L
.81777 .01617 L
.82005 .02655 L
.82252 .03694 L
.82482 .04537 L
.82703 .05192 L
.82826 .05478 L
.8294 .0569 L
.82998 .05777 L
.83062 .05856 L
.83127 .05918 L
.83162 .05944 L
.83196 .05964 L
.83225 .05977 L
.8324 .05982 L
.83257 .05987 L
.83271 .0599 L
.83285 .05992 L
.833 .05993 L
.83312 .05993 L
.8332 .05993 L
.83329 .05993 L
.83343 .05991 L
.83352 .0599 L
.8336 .05988 L
.83377 .05984 L
.83407 .05973 L
.83438 .05958 L
.83469 .05938 L
.83502 .05913 L
.8356 .05857 L
.83694 .05675 L
.83821 .05435 L
.83936 .05164 L
.8442 .03573 L
.84642 .0267 L
.84768 .02132 L
.84829 .01867 L
.84885 .01624 L
.84899 .01564 L
.84914 .015 L
.84922 .01477 L
Mistroke
.8493 .01513 L
.84945 .01578 L
.85002 .01822 L
.85126 .02353 L
.85381 .0338 L
.85634 .04276 L
.85866 .04937 L
.85984 .05204 L
.86094 .05405 L
.86208 .05565 L
.86269 .05629 L
.863 .05656 L
.86333 .0568 L
.86364 .05698 L
.86398 .05714 L
.86413 .05719 L
.86428 .05724 L
.86443 .05727 L
.86457 .05729 L
.86465 .0573 L
.86474 .05731 L
.8649 .05732 L
.86499 .05732 L
.86507 .05731 L
.86516 .05731 L
.86526 .05729 L
.86534 .05728 L
.86542 .05727 L
.8656 .05722 L
.86591 .05711 L
.86623 .05696 L
.86652 .05679 L
.86717 .05627 L
.86777 .05563 L
.86834 .0549 L
.86951 .05301 L
.87075 .05046 L
.87298 .04459 L
.87754 .02855 L
.87874 .02376 L
.87989 .01911 L
.88051 .01652 L
.88069 .01581 L
.88078 .01542 L
.88087 .01505 L
.88095 .01472 L
.88104 .01509 L
.8812 .01574 L
.8824 .02066 L
.88476 .02997 L
Mistroke
.88735 .03914 L
.88984 .04643 L
.89212 .05138 L
.89333 .05327 L
.89388 .05395 L
.89447 .05454 L
.89477 .05479 L
.8951 .05502 L
.8954 .0552 L
.89568 .05533 L
.89601 .05544 L
.89618 .05548 L
.89626 .0555 L
.89636 .05552 L
.89651 .05553 L
.89666 .05554 L
.89675 .05554 L
.89684 .05554 L
.89699 .05553 L
.89713 .05551 L
.89728 .05548 L
.89742 .05544 L
.89755 .0554 L
.89787 .05528 L
.89817 .05512 L
.89876 .05471 L
.89941 .0541 L
.90056 .05262 L
.90164 .05082 L
.90412 .04513 L
.90636 .03843 L
.90889 .02957 L
.90999 .02538 L
.9112 .02065 L
.91177 .01841 L
.91208 .01717 L
.91238 .01599 L
.91251 .01546 L
.91265 .0149 L
.91281 .01514 L
.91295 .01571 L
.91347 .01778 L
.91586 .02706 L
.92042 .04236 L
.92276 .04818 L
.92408 .05068 L
.92466 .05159 L
.92528 .05243 L
.9259 .05312 L
.92647 .05363 L
Mistroke
.92674 .05383 L
.92703 .05401 L
.92731 .05416 L
.92757 .05426 L
.92787 .05435 L
.92803 .05439 L
.92812 .0544 L
.9282 .05441 L
.92829 .05442 L
.92837 .05443 L
.92845 .05443 L
.92854 .05443 L
.9287 .05443 L
.92879 .05442 L
.92887 .05441 L
.92902 .05438 L
.92917 .05435 L
.92945 .05426 L
.92974 .05414 L
.93007 .05396 L
.9307 .0535 L
.93131 .05292 L
.93243 .05148 L
.93364 .04943 L
.93496 .04664 L
.93989 .03191 L
.94234 .02285 L
.94296 .02049 L
.94354 .01822 L
.94407 .01618 L
.94421 .01562 L
.94437 .01502 L
.94451 .01497 L
.94464 .01548 L
.94684 .02396 L
.94921 .03257 L
.95173 .04064 L
.95404 .04664 L
.95522 .04905 L
.95631 .05089 L
.95745 .05236 L
.95805 .05294 L
.95837 .05319 L
.9587 .05341 L
.959 .05358 L
.95934 .05372 L
.95948 .05377 L
.95964 .05382 L
.95979 .05385 L
.95993 .05387 L
Mistroke
.96001 .05388 L
.96009 .05389 L
.96024 .0539 L
.96033 .0539 L
.96042 .0539 L
.9605 .05389 L
.96058 .05388 L
.96066 .05387 L
.96075 .05386 L
.96094 .05382 L
.96111 .05377 L
.96126 .05372 L
.96158 .05358 L
.96188 .05342 L
.96243 .05303 L
.96304 .05247 L
.96369 .05171 L
.96482 .05004 L
.96607 .04768 L
.9686 .04141 L
.97345 .0252 L
.97619 .01472 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.05556 .01472 m
.05556 .01472 L
s
.0873 .01472 m
.0873 .01472 L
s
.11905 .01472 m
.11905 .01472 L
s
.15079 .01472 m
.15079 .01472 L
s
.18254 .01472 m
.18254 .01472 L
s
.21429 .01472 m
.21429 .01472 L
s
.24603 .01472 m
.24603 .01472 L
s
.27778 .01472 m
.27778 .01472 L
s
.30952 .01472 m
.30952 .01472 L
s
.34127 .01472 m
.34127 .01472 L
s
.37302 .01472 m
.37302 .01472 L
s
.40476 .01472 m
.40476 .60149 L
s
.43651 .01472 m
.43651 .01472 L
s
.46825 .01472 m
.46825 .01472 L
s
.5 .01472 m
.5 .01472 L
s
.53175 .01472 m
.53175 .01472 L
s
.56349 .01472 m
.56349 .01472 L
s
.59524 .01472 m
.59524 .60149 L
s
.62698 .01472 m
.62698 .01472 L
s
.65873 .01472 m
.65873 .01472 L
s
.69048 .01472 m
.69048 .01472 L
s
.72222 .01472 m
.72222 .01472 L
s
.75397 .01472 m
.75397 .01472 L
s
.78571 .01472 m
.78571 .01472 L
s
.81746 .01472 m
.81746 .01472 L
s
.84921 .01472 m
.84921 .01472 L
s
.88095 .01472 m
.88095 .01472 L
s
.9127 .01472 m
.9127 .01472 L
s
.94444 .01472 m
.94444 .01472 L
s
.97619 .01472 m
.97619 .01472 L
s
.015 w
.05556 .01472 Mdot
.0873 .01472 Mdot
.11905 .01472 Mdot
.15079 .01472 Mdot
.18254 .01472 Mdot
.21429 .01472 Mdot
.24603 .01472 Mdot
.27778 .01472 Mdot
.30952 .01472 Mdot
.34127 .01472 Mdot
.37302 .01472 Mdot
.40476 .60149 Mdot
.43651 .01472 Mdot
.46825 .01472 Mdot
.5 .01472 Mdot
.53175 .01472 Mdot
.56349 .01472 Mdot
.59524 .60149 Mdot
.62698 .01472 Mdot
.65873 .01472 Mdot
.69048 .01472 Mdot
.72222 .01472 Mdot
.75397 .01472 Mdot
.78571 .01472 Mdot
.81746 .01472 Mdot
.84921 .01472 Mdot
.88095 .01472 Mdot
.9127 .01472 Mdot
.94444 .01472 Mdot
.97619 .01472 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<oooool3o`0002kooooo1Ol0000]ooooo`;o0000;_ooool5o`00033ooooo0ol0000Roooo
o`00=?ooool00ol0003oooooooooo`0^ooooo`04o`000?ooooooooooo`0002cooooo00Co0000oooo
oooooooo0000;_ooool01?l0003oooooooooool0000aooooo`03o`000?oooooooooo027ooooo000[
ooooo`Go000000?oooooo`000?l000000ol0000Xooooo`Go00000oooool00ol0003oooooooooo`0/
ooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool0;_ooool5o`0002;ooooo000a
ooooo`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool0:oooool01?l0003ooooooooo
ool0000`ooooo`03o`000?oooooooooo02gooooo00Co0000oooooooooooo00008oooool003;ooooo
00?o0000ooooool00000;oooool01Ol0003ooooooooooooooooo000002cooooo00Co0000oooooooo
oooo0000;Oooool01Ol0003ooooooooooooooooo000002oooooo00?o0000ooooool000008oooool0
03?ooooo0_l0000_ooooo`05o`000?ooooooooooooooool00000;?ooool01?l0003oooooooooool0
000]ooooo`05o`000?ooooooooooooooool00000<?ooool2o`0002?ooooo000dooooo`03o`000?oo
oooooooo02kooooo0ol0000^ooooo`;o0000;oooool3o`0003;ooooo00?o0000ooooooooool08Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0017oooooool0
000=o`0000?ooooo000:ooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo007ooooo0009ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00Oooool0
00Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0;ooooo`?oo`001Oooool3
ool000Kooooo0ooo0005ooooo`?oo`001_ooool3ool000Gooooo0ooo0006ooooo`?oo`001Oooool3
ool000Gooooo0ooo0006ooooo`?oo`001Oooool3ool000kooooo0ooo0006ooooo`?oo`001Oooool3
ool000Kooooo0ooo0005ooooo`?oo`003_ooool3ool000Gooooo0ooo0006ooooo`?oo`001Oooool3
ool000Kooooo0ooo0005ooooo`?oo`001_ooool3ool000Gooooo0ooo0006ooooo`?oo`001Oooool3
ool000Kooooo0ooo0005ooooo`?oo`001Oooool00ol0003oooooooooo`01ooooo`002Oooool01?l0
003oooooooooool00004ooooo`?o00001?ooool00ol00?ooooooooooo`04ooooo`?oo`001Oooool3
ool000Kooooo0ooo0005ooooo`?oo`001_ooool3ool000Gooooo0ooo0006ooooo`?oo`001Oooool3
ool000Gooooo0ooo0006ooooo`?oo`001Oooool3ool000Oooooo00?oo`00ooooooooool01?ooool3
ool000Kooooo0ooo0005ooooo`?oo`001_ooool3ool000Gooooo0ooo0007ooooo`03ool00?oooooo
oooo00Cooooo0ooo0005ooooo`?oo`001_ooool3ool000Gooooo0ooo0006ooooo`?oo`001Oooool3
ool000Kooooo0ooo0005ooooo`?oo`001_ooool3ool000Gooooo0ooo0006ooooo`?oo`001Oooool3
ool000?ooooo0ol00003ooooo`002Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00_ooooo0ooo0005ooooo`?oo`001_ooool3ool000Gooooo0ooo0006ooooo`?oo`001Oooool3
ool000Kooooo0ooo0005ooooo`?oo`001Oooool3ool000Kooooo0ooo0005ooooo`?oo`001oooool0
0ooo003oooooooooo`04ooooo`?oo`001_ooool3ool000Gooooo0ooo0006ooooo`?oo`001Oooool3
ool000Oooooo00?oo`00ooooooooool01?ooool3ool000Gooooo0ooo0006ooooo`?oo`001Oooool3
ool000Kooooo0ooo0005ooooo`?oo`001_ooool3ool000Gooooo0ooo0006ooooo`?oo`001Oooool3
ool000Kooooo0ooo0005ooooo`?oo`001Oooool00ol0003oooooooooo`01ooooo`002Oooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00cooooo0_l00?l?ooooo`03o`00oooooooo
oooo00Gooooo0_l00?l7ooooo`;o003o1_ooool2o`00o`Oooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo0_l00?l7ooooo`03o`00oooooooo
oooo00Gooooo00?oo`00ooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`;o003o1oooool0
0ooo003oooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo0_l00?l6ooooo`;o003o1oooool0
0ol00?ooooooooooo`05ooooo`;o003o1_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooo
oooo00gooooo00?o0000ooooooooool00Oooool000[ooooo0_l00005ooooo`03o`000?oooooooooo
00Gooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o
00Kooooo0_l00?l6ooooo`03o`00oooooooo003o00Kooooo0_l00?l8ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`06ooooo`;o003o3oooool00ooo
003oooooooooo`05ooooo`;o003o1oooool2o`00o`Kooooo00?o003oo`000?ooool01Oooool2o`00
o`Oooooo0_l00?l7ooooo`03ool00?oooooooooo00Gooooo0_l00?l7ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01?ooool2o`00o`Oooooo0_l00?l6ooooo`;o003o1oooool2o`00
o`Kooooo0_l00?l8ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool02oooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Ko
oooo0_l00?l8ooooo`03o`00oooooooooooo00Cooooo0_l00?l6ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`06ooooo`;o003o1oooool00ol00?oo
ooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?o003oooooooooool01?ooool00ol00?oo
ooooo`00o`06ooooo`03o`00ool0003ooooo00Gooooo00?o003oooooool00?l01_ooool00ol00?oo
ooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_l00?l7ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Co
oooo0ol00?l5ooooo`03o`00oooooooooooo00Kooooo0_l00?l8ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Go
oooo00?o0000ooooooooool00Oooool0017ooooo0_l00006ooooo`03o`00oooooooooooo00cooooo
00?o003oooooool00?l05_ooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool01_ooool2o`00o`Kooooo0_l00?l@ooooo`03o`00oooooooooooo00Gooooo
00?oo`00ooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`04o`00oooooooo0000o`00o`Go
oooo00?o003oooooooooool03oooool00ooo003oooooooooo`05ooooo`;o003o3oooool2o`00o`Ko
oooo00?o003oooooool00?l09oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo003o00Ko
oooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`04ooooo`;o00000oooool0017ooooo
00?o0000ooooooooool02_ooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooo
oooo003o2?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003o
ooooooooool03_ooool00ol00?ooooooo`00o`06ooooo`;o003o1_ooool2o`00o`Oooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03ool00?oooooooooo00Gooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`05ooooo`03o`000?l00?oooooo00gooooo0_l00?l7
ooooo`03ool00?oooooooooo00Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`06
ooooo`;o003o1_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool02?ooool2o`00o`Cooooo00Co003ooooooooooooo003o1Oooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`04oooo
o`03o`00oooooooooooo00Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool02_ooool01Ol00?oooooooooooooooooo003o00cooooo00Go003oooooooooooooooooo`00o`04
ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l5ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`04ooooo`;o003o1_ooool00ol00?ooooooooooo`06ooooo`03ool00?oooooooooo00Go
oooo0_l00?l6ooooo`03o`00oooooooo003o00Oooooo00?o0000ooooool00?l01_ooool00ol00?oo
ooooooooo`04ooooo`;o003o1oooool00ooo003oooooooooo`05ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00?o
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`05o`00oooooooo
ooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`06ooooo`05o`00ooooooooooooooooool0
0?l01?ooool00ol00?ooooooooooo`09ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooo
ooooooooo`00o`Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00Kooooo0_l00?l?ooooo`03ool00?oooooooooo00Gooooo0_l00?l6ooooo`04o`00
ooooooooooooo`00o`?ooooo00Co003ooooooooooooo00001Oooool01?l00?ooooooooooool00?l6
ooooo`;o003o1oooool00ooo003oooooooooo`05ooooo`;o003o1_ooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooo003o00Kooooo00?o003oooooooooool01Oooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`;o
003o2oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`07ooooo`04o`00
oooooooo003oo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l8
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool01?l00?oooooooooooooo
ool2o`00o`;ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooool00?l01oooool00ol00?ooooooooooo`05ooooo`03ool00?oo
oooooooo00Kooooo00?o003oooooooooool01?ooool01?l00?ooooooooooool00?l3ooooo`04o`00
ooooooooooooo`0000Gooooo00Co003ooooooooooooo003o1_ooool2o`00o`Oooooo00?oo`00oooo
ooooool01Oooool2o`00o`Kooooo00?o003oooooool00?l01oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00Gooooo00Go003oooooooooooooooooo`00o`04ooooo`;o003o00?oooooo`00ooooool01?oo
ool01?l00?ooooooo`00ool00?l8ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00002?oo
ool00ol00?ooooooooooo`06ooooo`;o003o1_ooool2o`00oaKooooo00?o003oooooooooool01_oo
ool01Ol00?oooooooooooooooooo003o00Sooooo00Co003ooooooooooooo003o1?ooool01?l00?oo
ooooooooool00?l7ooooo`03o`00oooooooooooo00Cooooo0_l00?l7ooooo`03ool00?oooooooooo
00Kooooo00?o003oooooooooool02_ooool01_l00?oooooooooooooooooo0000ooooo`;o003o0_oo
ool00ol00?ooooooooooo`0@ooooo`03ool00?oooooooooo00Gooooo0_l00?l8ooooo`03o`00oooo
oooooooo00?ooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l8ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Cooooo0ol00?l5ooooo`?o003o2?ooool2o`0000?ooooo000Aooooo`03o`00
0?oooooooooo01Sooooo0_l00?l7ooooo`;o003o1_ooool00ol00?ooooooo`00o`0Aooooo`05o`00
ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`Gooooo00?o003oooooooooool01_ooool2o`00o`Oooooo00?oo`00ooooooooool01Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00?ooooo00Co0000oooooooooooo003o3?oo
ool2o`00o`Oooooo00?oo`00ooooooooool01_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Gooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0;ooooo`?o003o1_ooool3o`00o`Ko
oooo0_l00?lJooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo02Wooooo
0_l00?l6ooooo`?o003o1Oooool01?l00?ooooooooooool00?l4ooooo`05o`00oooooooooooooooo
ool00?l02oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Kooooo0_l00?l7oooo
o`03ool00?oooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02oooo
o`?o003o0oooool01Ol0003ooooooooooooooooo003o00Gooooo00?o003oooooooooool00oooool2
o`00o`Oooooo00?oo`00ooooooooool03Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo
oooo00Wooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Gooooo
00?o003oooooool00?l01_ooool2o`00ob_ooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool0<_ooool2o`00o`Kooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l03oooool00ooo003ooooooooo
o`05ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01oooool00ooo003ooooooooo
o`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l01Oooool00ol00?oooooooooo
o`05ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`04o`00
oooooooo003oo`00o`Gooooo0_l00?ldooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo03[ooooo0_l00?l6ooooo`03o`00oooooooooooo00Gooooo00Go003ooooooooooooo
ooooo`00o`08ooooo`03o`00oooooooo003o00Oooooo00?o003oooooooooool01Oooool00ooo003o
ooooooooo`05ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool02?ooool00ol0003o
ooooooooo`07ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01oooool00ooo003o
ooooooooo`05ooooo`;o003o1_ooool00ol00?ooooooo`00o`08ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`;o003o??ooool00ol0003o
ooooooooo`01ooooo`004Oooool2o`0004Gooooo00?o003oooooooooool00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`03ooooo`;o
003o1oooool00ooo003oooooooooo`07ooooo`03o`00oooooooooooo00gooooo00?o0000oooooooo
ool01oooool00ol00?ooooooooooo`0<ooooo`03ool00?oooooooooo00Gooooo0_l00?l8ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool0@oooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo04?o
oooo0_l00?l5ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool02oooool00ol0
0?ooooooo`00o`06ooooo`03ool00?oooooooooo00Gooooo00?o003oooooooooool03oooool00ol0
003oooooooooo`0Fooooo`03ool00?oooooooooo00Kooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Gooooo0_l00?m5ooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo05;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooo003o00Kooooo00?oo`00ooooooooool01Oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02?ooool01ol0
0?oooooooooooooooooo003oooooool00?l01oooool00ooo003oooooooooo`0<ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool0D_ooool00ol0003oooooooooo`01ooooo`002?ooool5
o`0000Cooooo00?o0000ooooooooool0D_ooool00ol00?ooooooooooo`02ooooo`04o`00oooooooo
ooooo`00o`Gooooo00?o003oooooooooool01_ooool00ooo003oooooooooo`05ooooo`03o`00oooo
oooo003o00Cooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`08ooooo`07o`00oooo
ooooooooooooool00?ooooooo`00o`07ooooo`03ool00?oooooooooo00Gooooo00?o003ooooooooo
ool01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0D_ooool00ol0
003oooooooooo`01ooooo`002Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
04_ooooo0ol00?l8ooooo`05o`00ooooooooooooooooool00?l03_ooool00ooo003oooooooooo`05
ooooo`03o`00oooooooo003o00?ooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`08
ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`04ooooo`03ool00?oo
oooooooo00Gooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l02?ooool3o`00odgooooo
00?o0000ooooooooool00Oooool000[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1;ooooo`;o003o1_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooool00?l01_ooool00ooo003oooooooooo`07ooooo`05o`00ooooooooooooooooool00?l0
2oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?oo`00ooooooooool0
1Oooool2o`00o`Wooooo00?o003oooooooooool01oooool2o`00odgooooo00?o0000ooooooooool0
0Oooool000_ooooo00?o0000ooooooooool00oooool3o`0005?ooooo00?o003oooooooooool02_oo
ool00ol00?ooooooo`00o`06ooooo`03ool00?oooooooooo00Sooooo00?o003oooooooooool03?oo
ool00ol0003oooooooooo`0Fooooo`03ool00?oooooooooo00Cooooo00Co003ooooooooooooo003o
3?ooool00ol00?ooooooooooo`1@ooooo`?o00000oooool000Sooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo05?ooooo00Co003ooooooooooooo003o2?ooool01?l00?oo
ooooooooool00?l6ooooo`03ool00?oooooooooo00Cooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00Go003oooooooooooooooooo`00o`06
ooooo`03ool00?oooooooooo00Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo05?ooooo00?o0000ooooooooool00Oooool000Sooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo05?ooooo00Co003ooooooooooooo003o0ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Oooooo00?oo`00ooooooooool01?oo
ool01ol00?oooooooooooooooooo003oooooool00?l03?ooool00ol0003oooooooooo`09ooooo`03
o`00oooooooo003o00?ooooo00?o003oooooooooool01?ooool00ooo003oooooooooo`04ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`1Eooooo`03
o`000?oooooooooo007ooooo0009ooooo`?o00001Oooool00ol0003oooooooooo`1Eooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool03?ooool00ooo003oooooooooo`04ooooo`07o`00
ooooooooooooooooool00?ooooooo`00o`0<ooooo`03o`000?oooooooooo00Wooooo00?o003ooooo
ool00?l00oooool00ol00?ooooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00Co003ooooo
oooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05Gooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0EOooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ooo003oooooooooo`08oooo
o`?o003o3?ooool00ol0003oooooooooo`09ooooo`03o`00oooooooo003o00?ooooo00?o003ooooo
ooooool01?ooool00ooo003oooooooooo`04ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`1Eooooo`03o`000?oooooooooo007ooooo000Aoooo
o`;o0000G?ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool01?ooool0
0ooo003oooooooooo`09ooooo`03o`00oooooooooooo00_ooooo00?o0000ooooooooool05_ooool0
0ooo003oooooooooo`04ooooo`04o`00ooooooooooooo`00o`Wooooo0_l00?mEooooo`;o00000ooo
ool0017ooooo00?o0000ooooooooool0Goooool01?l00?ooooooooooool00?l6ooooo`03ool00?oo
oooooooo00Cooooo00?o003oooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`00oooo
oooooooo00Cooooo00?oo`00ooooooooool01oooool01Ol00?oooooooooooooooooo003o05gooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Foooool01Ol00?oooooooooo
oooooooo003o00;ooooo00?o003oooooooooool01?ooool00ooo003oooooooooo`04ooooo`03o`00
oooooooooooo013ooooo00?o0000ooooooooool03oooool00ol00?ooooooooooo`04ooooo`03ool0
0?oooooooooo00_ooooo00?o003oooooooooool0Foooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`1Kooooo`03o`00oooooooooooo00_ooooo00?oo`00ooooooooool01?oo
ool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o003oooooooooool01?oo
ool00ooo003oooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0Fooo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Kooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01?ooool00ooo003oooooooooo`04ooooo`03o`00oooooooo
oooo013ooooo00?o0000ooooooooool03oooool00ol00?ooooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`1Kooooo`03o`000?oo
oooooooo007ooooo000Aooooo`;o0000G?ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o
003oooooooooool01?ooool00ooo003oooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo00?o
o`00ooooooooool01?ooool01?l00?ooooooooooool00?mPooooo`;o00000oooool0017ooooo00?o
0000ooooooooool0Goooool01?l00?ooooooooooool00?l6ooooo`03ool00?oooooooooo00Cooooo
00?o003oooooooooool04?ooool00ol0003oooooooooo`0Fooooo`03ool00?oooooooooo00Oooooo
00?o003oooooooooool0Goooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`1Oooooo`04o`00ooooooooooooo`00o`Kooooo00?oo`00ooooooooool01?ooool00ol00?oooooo
ooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o003oooooooooool01?ooool00ooo003ooooo
ooooo`0;ooooo`03o`00oooooooooooo05_ooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool0Foooool01Ol00?oooooooooooooooooo003o00Wooooo00?oo`00ooooooooool0
1?ooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o003oooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
Foooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Kooooo`03o`00oooo
oooooooo00_ooooo00?oo`00ooooooooool01?ooool00ol00?ooooooooooo`0@ooooo`03o`000?oo
oooooooo00oooooo00?o003oooooooooool01?ooool00ooo003oooooooooo`04ooooo`07o`00oooo
ooooooooooooool00?ooooooo`00o`1Nooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000
GOooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00Cooooo00?oo`00ooooooooool0
5oooool00ol0003oooooooooo`0Fooooo`03ool00?oooooooooo00Cooooo00Go003ooooooooooooo
ooooo`00o`1Oooooo`;o00000oooool0017ooooo00?o0000ooooooooool0G_ooool01Ol00?oooooo
oooooooooooo003o00Kooooo00?oo`00ooooooooool05oooool00ol0003oooooooooo`0Fooooo`03
ool00?oooooooooo00Sooooo00?o003oooooooooool0G_ooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`1Nooooo`05o`00ooooooooooooooooool00?l01_ooool00ooo003o
ooooooooo`04ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool03oooool00ol00?oo
ooooooooo`04ooooo`03ool00?oooooooooo00[ooooo00?o003oooooooooool0G?ooool00ol0003o
ooooooooo`01ooooo`002_ooool3o`0000Cooooo00?o0000ooooooooool0G?ooool3o`00o`[ooooo
00?oo`00ooooooooool01?ooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo00oooooo
00?o003oooooooooool01?ooool00ooo003oooooooooo`04ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool0G?ooool00ol0003oooooooooo`01ooooo`002oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo05gooooo00?o003oooooooooool02Oooool00ooo003ooooooooo
o`04ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool04?ooool00ol00?oooooooooo
o`03ooooo`03ool00?oooooooooo00Cooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`1Mooooo`03o`000?oooooooooo007ooooo0008ooooo`Go00001?ooool3o`0006;ooooo00?o003o
ooooooooool01?ooool00ooo003oooooooooo`0Gooooo`03o`000?oooooooooo013ooooo00?o003o
ooooooooool00oooool00ooo003oooooooooo`04ooooo`03o`00oooooooooooo063ooooo0ol00003
ooooo`002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo06;ooooo00?o003o
ooooooooool01?ooool00ooo003oooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo00?oo`00
ooooooooool01?ooool00ol00?ooooooooooo`1Rooooo`03o`000?oooooooooo007ooooo0009oooo
o`03o`000?oooooo000000Gooooo00?o0000ooooooooool0Hoooool00ol00?ooooooooooo`03oooo
o`03ool00?oooooooooo00?ooooo00?o003oooooooooool04Oooool00ol0003oooooooooo`0@oooo
o`03o`00oooooooooooo00?ooooo00?oo`00ooooooooool0JOooool00ol0003oooooooooo`01oooo
o`002_ooool2o`0000Gooooo00?o0000ooooooooool0JOooool00ooo003oooooooooo`03ooooo`03
o`00oooooooooooo017ooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03
ool00?oooooooooo00Cooooo00?o003oooooooooool0H_ooool00ol0003oooooooooo`01ooooo`00
2oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06Wooooo00?oo`00ooooooooool0
0oooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool0
0oooool00ooo003oooooooooo`04ooooo`03o`00oooooooooooo06;ooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool0Hoooool00ol00?ooooooooooo`03ooooo`03ool00?oo
oooooooo00?ooooo00?o003oooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`00oooo
oooooooo00?ooooo00?oo`00ooooooooool00oooool00ol00?ooooooooooo`1Sooooo`03o`000?oo
oooooooo007ooooo000Aooooo`;o0000I?ooool00ol00?ooooooooooo`03ooooo`03ool00?oooooo
oooo01Oooooo00?o0000ooooooooool05_ooool00ooo003oooooooooo`03ooooo`03o`00oooooooo
oooo06;ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1Sooooo`03o`00oooooooooooo
00?ooooo00?oo`00ooooooooool00oooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo
01Kooooo00?oo`00ooooooooool0JOooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`1Sooooo`03o`00oooooooooooo00?ooooo00?oo`00ooooooooool00oooool00ol00?oo
ooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool00oooool00ooo003o
ooooooooo`1Yooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06Wooooo
00?oo`00ooooooooool00oooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo013ooooo
00?o003oooooooooool00oooool00ooo003oooooooooo`03ooooo`03o`00oooooooooooo06?ooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Hoooool00ol00?oooooooooo
o`03ooooo`03ool00?oooooooooo00?ooooo00?o003oooooooooool04Oooool00ol0003ooooooooo
o`0@ooooo`03o`00oooooooooooo00?ooooo00?oo`00ooooooooool00oooool00ol00?oooooooooo
o`1Sooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000I?ooool00ol00?ooooooooooo`03
ooooo`03ool00?oooooooooo01Oooooo00?o0000ooooooooool05_ooool00ooo003oooooooooo`03
ooooo`03o`00oooooooooooo06;ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1Soooo
o`03o`00oooooooooooo00?ooooo00?oo`00ooooooooool05oooool00ol0003oooooooooo`0Foooo
o`03ool00?oooooooooo06Wooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0Hoooool00ol00?ooooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?o003ooooooooo
ool04Oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?oo`00oooooooo
ool0JOooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Yooooo`03ool0
0?oooooooooo00?ooooo00?o003oooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`00
oooooooooooo00?ooooo00?oo`00ooooooooool00oooool00ol00?ooooooooooo`1Sooooo`03o`00
0?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06Wooooo00?oo`00ooooooooool00ooo
ool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool00ooo
ool00ooo003oooooooooo`03ooooo`03o`00oooooooooooo06?ooooo00?o0000ooooooooool00Ooo
ool0017ooooo0_l0001Tooooo`03o`00oooooooooooo00?ooooo00?oo`00ooooooooool05oooool0
0ol0003oooooooooo`0Fooooo`03ool00?oooooooooo00?ooooo00?o003oooooooooool0H_ooool2
o`0000?ooooo000Aooooo`03o`000?oooooooooo06?ooooo00?o003oooooooooool00oooool00ooo
003oooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool00oooool00ol0
0?ooooooooooo`1Sooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06?o
oooo00?o003oooooooooool00oooool00ooo003oooooooooo`03ooooo`03o`00oooooooooooo017o
oooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03ool00?oooooooooo06Wo
oooo00?o0000ooooooooool00Oooool000Wooooo0ol00005ooooo`03o`000?oooooooooo06Wooooo
00?oo`00ooooooooool00oooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo013ooooo
00?o003oooooooooool00oooool00ooo003oooooooooo`03ooooo`03o`00oooooooooooo06?ooooo
00?o0000ooooooooool00Oooool000Sooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo06Wooooo00?oo`00ooooooooool00oooool00ol00?ooooooooooo`0Aooooo`03o`00
0?oooooooooo013ooooo00?o003oooooooooool00oooool00ooo003oooooooooo`03ooooo`03o`00
oooooooooooo06?ooooo00?o0000ooooooooool00Oooool000Sooooo00Go0000oooooooooooooooo
o`000004ooooo`?o0000Hoooool00ol00?ooooooooooo`03ooooo`03ool00?oooooooooo00?ooooo
00?o003oooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo
00?oo`00ooooooooool00oooool00ol00?ooooooooooo`1Qooooo`?o00000oooool000Sooooo1?l0
0005ooooo`03o`000?oooooooooo06?ooooo00?o003oooooooooool00oooool00ooo003ooooooooo
o`0Gooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool00oooool00ol00?oooooooooo
o`1Sooooo`03o`000?oooooooooo007ooooo0008ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0Hoooool00ol00?ooooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?o003o
ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?oo`00
ooooooooool0JOooool00ol0003oooooooooo`01ooooo`002Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo06?ooooo00?o003oooooooooool00oooool00ooo003oooooooooo`03oooo
o`03o`00oooooooooooo017ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`02oooo
o`03ool00?oooooooooo06Wooooo00?o0000ooooooooool00Oooool000[ooooo0_l00005ooooo`03
o`000?oooooooooo06Wooooo00?oo`00ooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03
o`000?oooooooooo017ooooo00?o003oooooooooool00_ooool00ooo003oooooooooo`03ooooo`03
o`00oooooooooooo06?ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
Hoooool00ol00?ooooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?o003oooooooooool0
4_ooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool0
0oooool00ol00?ooooooooooo`1Sooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000I?oo
ool00ol00?ooooooooooo`03ooooo`03ool00?oooooooooo01Oooooo00?o0000ooooooooool05_oo
ool00ooo003oooooooooo`03ooooo`03o`00oooooooooooo06;ooooo0_l00003ooooo`004Oooool0
0ol0003oooooooooo`1Tooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool05oooool0
0ol0003oooooooooo`0Fooooo`03ool00?oooooooooo06Wooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool0I?ooool00ol00?ooooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo
00;ooooo00?oo`00ooooooooool0JOooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`1Yooooo`03ool00?oooooooooo00;ooooo00?o003oooooooooool04_ooool00ol0003o
ooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool00oooool00ol00?oo
ooooooooo`1Sooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06Wooooo
00?oo`00ooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo017ooooo
00?o003oooooooooool00_ooool00ooo003oooooooooo`03ooooo`03o`00oooooooooooo06?ooooo
00?o0000ooooooooool00Oooool0017ooooo0_l0001Uooooo`03o`00oooooooooooo00;ooooo00?o
o`00ooooooooool05oooool00ol0003oooooooooo`0Fooooo`03ool00?oooooooooo00;ooooo00?o
003oooooooooool0Hoooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo06Cooooo00?o003o
ooooooooool00_ooool00ooo003oooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo00?oo`00
ooooooooool00_ooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo06Cooooo00?o003oooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03o`00oooooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`02oooo
o`03ool00?oooooooooo06Wooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0JOooool00ooo003oooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o0000oooooooo
ool04Oooool00ol00?ooooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o003ooooooooo
ool0I?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Yooooo`03ool0
0?oooooooooo00;ooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`00
oooooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ol00?ooooooooooo`1Tooooo`03o`00
0?oooooooooo007ooooo000Aooooo`;o0000IOooool00ol00?ooooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`00oooo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ol00?ooooooooooo`1Sooooo`;o00000ooo
ool0017ooooo00?o0000ooooooooool0I?ooool00ol00?ooooooooooo`02ooooo`03ool00?oooooo
oooo01Oooooo00?o0000ooooooooool05_ooool00ooo003oooooooooo`02ooooo`03o`00oooooooo
oooo06Cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0I?ooool00ol0
0?ooooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o003oooooooooool04_ooool00ol0
003oooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool0JOooool00ol0
003oooooooooo`01ooooo`002Oooool3o`0000Gooooo00?o0000ooooooooool0I?ooool00ol00?oo
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o003oooooooooool04_ooool00ol0003o
ooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool0JOooool00ol0003o
ooooooooo`01ooooo`002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool0JOooool00ooo003oooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o0000oooooooo
ool04Oooool00ol00?ooooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o003ooooooooo
ool0I?ooool00ol0003oooooooooo`01ooooo`002?ooool01Ol0003ooooooooooooooooo000000Co
oooo0ol0001Tooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ol00?oo
ooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o003oooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03o`00oooooooooooo06;ooooo0ol00003ooooo`002Oooool3o`0000Gooooo
00?o0000ooooooooool0I?ooool00ol00?ooooooooooo`02ooooo`03ool00?oooooooooo01Oooooo
00?o0000ooooooooool05_ooool00ooo003oooooooooo`02ooooo`03o`00oooooooooooo06Cooooo
00?o0000ooooooooool00Oooool000Sooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo06Cooooo00?o003oooooooooool00_ooool00ooo003oooooooooo`0Gooooo`03o`00
0?oooooooooo01Kooooo00?oo`00ooooooooool0JOooool00ol0003oooooooooo`01ooooo`002?oo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0I?ooool00ol00?oooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o003oooooooooool04_ooool00ol0003ooooo
ooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool0JOooool00ol0003ooooo
ooooo`01ooooo`002Oooool3o`0000Gooooo00?o0000ooooooooool0JOooool00ooo003ooooooooo
o`02ooooo`03o`00oooooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol00?oooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?o003oooooooooool0I?ooool00ol0003ooooooooo
o`01ooooo`004Oooool2o`0006[ooooo00?oo`00ooooooooool00_ooool00ol00?ooooooooooo`0B
ooooo`03o`000?oooooooooo01;ooooo00Go003oooooooooooooooooool00004ooooo`03o`00oooo
oooooooo06?ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1Tooooo`03o`00oooooooo
oooo00;ooooo00?oo`00ooooooooool05oooool00ol0003oooooooooo`0Fooooo`03ool00?oooooo
oooo00;ooooo00?o003oooooooooool0I?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`1Tooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool05oooool00ol0
003oooooooooo`0Fooooo`03ool00?oooooooooo00;ooooo00?o003oooooooooool0I?ooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Tooooo`03o`00oooooooooooo00;o
oooo00Goo`00ooooooooooooooooo`00o`0Eooooo`03o`000?oooooooooo01;ooooo00Go003ooooo
ooooooooooooool0001[ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
06Wooooo00Goo`00ooooooooooooooooo`00o`0Eooooo`03o`000?oooooooooo01;ooooo00Go003o
ooooooooooooooooool00004ooooo`03o`00oooooooooooo06Cooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0JOooool01Ooo003ooooooooooooooooo003o01Gooooo00?o
0000ooooooooool04_ooool01Ol00?ooooooooooooooooooo`0000Cooooo00?o003oooooooooool0
I?ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0006Kooooo00Go003ooooooooooooooooo
ool00003ooooo`03o`00oooooooooooo01?ooooo00?o0000ooooooooool04_ooool01Ol00?oooooo
ooooooooooooo`0000Cooooo00?o003oooooooooool0Hoooool2o`0000?ooooo000Aooooo`03o`00
0?oooooooooo06Gooooo00Go003oooooooooooooooooool0000Iooooo`03o`000?oooooooooo01Ko
oooo00?oo`00ooooooooool00_ooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo007o
oooo000Aooooo`03o`000?oooooooooo06Gooooo00Go003oooooooooooooooooool00003ooooo`03
o`00oooooooooooo01?ooooo00?o0000ooooooooool04_ooool01Ol00?ooooooooooooooooooo`00
06_ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0IOooool01Ol00?oo
ooooooooooooooooo`0000?ooooo00?o003oooooooooool04oooool00ol0003oooooooooo`0Boooo
o`05o`00oooooooooooooooooooo0000Joooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`1Yooooo`05ool00?ooooooooooooooool00?l05Oooool00ol0003oooooooooo`0B
ooooo`05o`00oooooooooooooooooooo00000oooool00ol00?ooooooooooo`1Uooooo`03o`000?oo
oooooooo007ooooo000Aooooo`;o0000I_ooool01Ol00?ooooooooooooooooooo`0000?ooooo00?o
003oooooooooool04oooool00ol0003oooooooooo`0Booooo`05o`00oooooooooooooooooooo0000
0oooool00ol00?ooooooooooo`1Tooooo`;o00000oooool0017ooooo00?o0000ooooooooool0IOoo
ool01Ol00?ooooooooooooooooooo`0001Wooooo00?o0000ooooooooool05_ooool01Ooo003ooooo
oooooooooooo003o06Oooooo00?o0000ooooooooool00Oooool000?ooooo0ol00004ooooo`;o0000
1Oooool00ol0003oooooooooo`1Uooooo`05o`00oooooooooooooooooooo00006Oooool00ol0003o
ooooooooo`0Fooooo`03ool00?oooooooooo06Wooooo00?o0000ooooooooool00Oooool000Cooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo06Go
oooo00Go003oooooooooooooooooool00003ooooo`03o`00oooooooooooo01?ooooo00?o0000oooo
ooooool04_ooool01Ol00?ooooooooooooooooooo`0006_ooooo00?o0000ooooooooool00Oooool0
00Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo06Wooooo00Goo`00ooooooooooooooooo`00o`0Eooooo`03o`000?oooooooooo01;ooooo00Go
003oooooooooooooooooool00003ooooo`03o`00oooooooooooo06Gooooo00?o0000ooooooooool0
0Oooool000Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`?o0000
JOooool01Ooo003ooooooooooooooooo003o01Gooooo00?o0000ooooooooool04_ooool01Ol00?oo
ooooooooooooooooo`0000?ooooo00?o003oooooooooool0Hoooool3o`0000?ooooo0004ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Uoooo
o`05o`00oooooooooooooooooooo00006Oooool00ol0003oooooooooo`0Fooooo`05ool00?oooooo
ooooooooool00?l0Ioooool00ol0003oooooooooo`01ooooo`000oooool2o`0000Cooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`1Uooooo`05o`00oooooooooooooooooooo0000
6Oooool00ol0003oooooooooo`0Fooooo`05ool00?ooooooooooooooool00?l0Ioooool00ol0003o
ooooooooo`01ooooo`001?ooool00ol0003oooooooooo`03ooooo`;o00001Oooool00ol0003ooooo
ooooo`1Uooooo`05o`00oooooooooooooooooooo00000oooool00ol00?ooooooooooo`0Cooooo`03
o`000?oooooooooo01;ooooo00Go003oooooooooooooooooool0001[ooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo06Wooooo00Goo`00ooooooooooooooooo`00o`0Eoooo
o`03o`000?oooooooooo01;ooooo00Go003oooooooooooooooooool00003ooooo`03o`00oooooooo
oooo06Gooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001Zooooo`05ool00?oooooooooo
ooooool00?l05Oooool00ol0003oooooooooo`0Cooooo`04o`00ooooooooooooool000?ooooo00?o
003oooooooooool0I?ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo06Gooooo00Go003o
ooooooooooooooooool00003ooooo`03o`00oooooooooooo01?ooooo00?o0000ooooooooool04ooo
ool01?l00?oooooooooooooo0003ooooo`03o`00oooooooooooo06Gooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool0IOooool01Ol00?ooooooooooooooooooo`0001Wooooo
00?o0000ooooooooool05_ooool01Ooo003ooooooooooooooooo003o06Oooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool0IOooool01Ol00?ooooooooooooooooooo`0000?o
oooo00?o003oooooooooool04oooool00ol0003oooooooooo`0Cooooo`04o`00ooooooooooooool0
06_ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0IOooool01Ol00?oo
ooooooooooooooooo`0000?ooooo00?o003oooooooooool04oooool00ol0003oooooooooo`0Coooo
o`04o`00ooooooooooooool006_ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001Zoooo
o`04ool00?ooooooooooo`00oaKooooo00?o0000ooooooooool04oooool01?l00?oooooooooooooo
0003ooooo`03o`00oooooooooooo06Cooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1U
ooooo`05o`00oooooooooooooooooooo00000_ooool00ol00?ooooooooooo`0Dooooo`03o`000?oo
oooooooo01?ooooo00Co003oooooooooooooo`000oooool00ol00?ooooooooooo`1Uooooo`03o`00
0?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06Gooooo00Go003ooooooooooooooooo
ool0000Iooooo`03o`000?oooooooooo01Kooooo00Goo`00ooooooooooooooooo`00o`1Wooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06Kooooo00Co003ooooooooooooo
o`006Oooool00ol0003oooooooooo`0Fooooo`03ool00?oooooooooo06Wooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool0I_ooool01?l00?oooooooooooooo0002ooooo`03
o`00oooooooooooo01Cooooo00?o0000ooooooooool04oooool01?l00?oooooooooooooo001[oooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06Wooooo00Coo`00oooooooo
oooo003o5_ooool00ol0003oooooooooo`0Cooooo`04o`00ooooooooooooool000?ooooo00?o003o
ooooooooool0IOooool00ol0003oooooooooo`01ooooo`004Oooool2o`0006[ooooo00Coo`00oooo
oooooooo003o5_ooool00ol0003oooooooooo`0Cooooo`04o`00ooooooooooooool000?ooooo00?o
003oooooooooool0I?ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo06Kooooo00Co003o
ooooooooooooo`006Oooool00ol0003oooooooooo`0Fooooo`04ool00?ooooooooooo`00ofSooooo
00?o0000ooooooooool00Oooool000?ooooo0ol00002ooooo`Go00001?ooool00ol0003ooooooooo
o`1Vooooo`04o`00ooooooooooooool001Wooooo00?o0000ooooooooool05_ooool01?oo003ooooo
ooooool00?mXooooo`03o`000?oooooooooo007ooooo0004ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Vooooo`04o`00ooooooooooooool0
00;ooooo00?o003oooooooooool05?ooool00ol0003oooooooooo`0Cooooo`04o`00oooooooooooo
ool006_ooooo00?o0000ooooooooool00Oooool000Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo06Wooooo00Coo`00oooooooooooo003o5_ooool0
0ol0003oooooooooo`0Cooooo`04o`00ooooooooooooool000;ooooo00?o003oooooooooool0I_oo
ool00ol0003oooooooooo`01ooooo`001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo0ol0001Yooooo`04ool00?ooooooooooo`00oaKooooo00?o0000ooooooooool04ooo
ool01?l00?oooooooooooooo0002ooooo`03o`00oooooooooooo06Cooooo0ol00003ooooo`001?oo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1Vooooo`04o`00ooooooooooooool000;ooooo00?o003oooooooooool05?ooool00ol0003o
ooooooooo`0Cooooo`04o`00ooooooooooooool000;ooooo00?o003oooooooooool0I_ooool00ol0
003oooooooooo`01ooooo`000oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo06Kooooo00Co003oooooooooooooo`006Oooool00ol0003oooooooooo`0F
ooooo`04ool00?ooooooooooo`00ofSooooo00?o0000ooooooooool00Oooool000Cooooo00?o0000
ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0I_ooool01?l00?oooooooooooooo
0002ooooo`03o`00oooooooooooo01Cooooo00?o0000ooooooooool04oooool01?l00?oooooooooo
oooo001[ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06Kooooo00Co
003oooooooooooooo`000_ooool00ol00?ooooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo
00Co003oooooooooooooo`00Joooool00ol0003oooooooooo`01ooooo`004Oooool2o`0006[ooooo
00Coo`00oooooooooooo003o5_ooool00ol0003oooooooooo`0Dooooo`03o`00ooooooooo`0000;o
oooo00?o003oooooooooool0IOooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo06Kooooo
00Co003oooooooooooooo`000_ooool00ol00?ooooooooooo`0Dooooo`03o`000?oooooooooo01Co
oooo00?o003ooooooooo00000_ooool00ol00?ooooooooooo`1Vooooo`03o`000?oooooooooo007o
oooo000Aooooo`03o`000?oooooooooo06Kooooo00Co003oooooooooooooo`006Oooool00ol0003o
ooooooooo`0Fooooo`04ool00?ooooooooooo`00ofSooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool0I_ooool01?l00?oooooooooooooo000Iooooo`03o`000?oooooooooo
01Kooooo00?oo`00ooooooooool0JOooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`1Vooooo`06o`00ooooooooooooool00?oooooo003o5oooool00ol0003oooooooooo`0D
ooooo`03o`00ooooooooo`0006_ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001Zoooo
o`03ool00?oooooo003o01Oooooo00?o0000ooooooooool05?ooool00ol00?ooooooool00002oooo
o`03o`00oooooooooooo06Gooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1Yooooo`03
ool00?oooooo003o01Oooooo00?o0000ooooooooool05?ooool00ol00?ooooooool00002ooooo`03
o`00oooooooooooo06Kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
I_ooool01?l00?oooooooooooooo000Iooooo`03o`000?oooooooooo01Kooooo00Coo`00oooooooo
oooo003oJ?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Vooooo`04
o`00ooooooooooooool001Wooooo00?o0000ooooooooool05_ooool01?oo003oooooooooool00?mX
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06Oooooo00Go003ooooo
oooo003oooooo`00o`0Gooooo`03o`000?oooooooooo01Cooooo00?o003ooooooooo0000Joooool0
0ol0003oooooooooo`01ooooo`004Oooool2o`0006[ooooo00?oo`00ooooool00?l05oooool00ol0
003oooooooooo`0Dooooo`05o`00ooooooooo`00ooooool00?l0J?ooool2o`0000?ooooo000Aoooo
o`03o`000?oooooooooo06Wooooo00?oo`00ooooool00?l05oooool00ol0003oooooooooo`0Doooo
o`05o`00ooooooooo`00ooooool00?l0JOooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`1Wooooo`05o`00ooooooooo`00ooooool00?l05oooool00ol0003oooooooooo`0D
ooooo`05o`00ooooooooo`00ooooool00?l0JOooool00ol0003oooooooooo`01ooooo`000oooool3
o`0000Cooooo0ol00004ooooo`03o`000?oooooooooo06Oooooo00?o003ooooooooo00006Oooool0
0ol0003oooooooooo`0Fooooo`03ool00?oooooo003o06Wooooo00?o0000ooooooooool00Oooool0
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
06Oooooo00Go003ooooooooo003oooooo`00o`0Gooooo`03o`000?oooooooooo01Cooooo00?o003o
oooooooo0000Joooool00ol0003oooooooooo`01ooooo`001?ooool01?l0003oooooooooooooool5
o`0000Cooooo00?o0000ooooooooool0Ioooool01Ol00?ooooooool00?oooooo003o01Oooooo00?o
0000ooooooooool05Oooool00ol00?ooo`00ooooo`1Zooooo`03o`000?oooooooooo007ooooo0004
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`03ooooo`?o0000JOoo
ool00ooo003oooooo`00o`0Gooooo`03o`000?oooooooooo01Gooooo00Co003oool00?oooooo003o
Ioooool3o`0000?ooooo0004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001Ooo
ool00ol0003oooooooooo`1Wooooo`05o`00ooooooooo`00ooooool00?l05oooool00ol0003ooooo
ooooo`0Eooooo`04o`00oooo003oooooo`00ofWooooo00?o0000ooooooooool00Oooool000?ooooo
0_l00005ooooo`;o00001Oooool00ol0003oooooooooo`1Wooooo`03o`00ooooooooo`0001Wooooo
00?o0000ooooooooool05_ooool00ooo003oooooo`00o`1Yooooo`03o`000?oooooooooo007ooooo
0004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1Wooooo`04o`00ooooooooo`00o`00oaSooooo00?o0000ooooooooool05_ooool00ooo003ooooo
ooooo`1Yooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06Oooooo00Co
003ooooooooo003o003o6?ooool00ol0003oooooooooo`0Eooooo`03o`00oooo003ooooo06[ooooo
00?o0000ooooooooool00Oooool0017ooooo0_l0001Zooooo`03ool00?l00?oooooo01Oooooo00?o
0000ooooooooool05Oooool01?l00?ooo`00ooooool00?mXooooo`;o00000oooool0017ooooo00?o
0000ooooooooool0JOooool00ooo003o003oooooo`0Gooooo`03o`000?oooooooooo01Gooooo00Co
003oool00?oooooo003oJOooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`1Xooooo`03o`00oooo003ooooo01Sooooo00?o0000ooooooooool05_ooool00ooo003o003ooooo
o`1Yooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06Sooooo00?o003o
ool00?ooool06?ooool00ol0003oooooooooo`0Fooooo`03ool00?l00?oooooo06Wooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0J?ooool00ol00?ooo`00o`00o`0Hoooo
o`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool0JOooool00ol0003oooooooooo`01oooo
o`004Oooool2o`0006Wooooo0ooo000Hooooo`03o`000?oooooooooo01Gooooo0ooo001Yooooo`;o
00000oooool0017ooooo00?o0000ooooooooool0J?ooool3ool001Sooooo00?o0000ooooooooool0
5Oooool3ool006[ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0J?oo
ool3ool001Sooooo00?o0000ooooooooool05Oooool3ool006[ooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooooooo`00
00go00000oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.95693, -1.55961, \
0.0394232, 0.0959801}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g7 = 
        DiscreteListPlot[
          FourierRearrange[Arg[\(\((Last[#] +  .0000001)\) &\)\  /@ \ fft], 
            fs], Red, PlotRange \[Rule] All, ImageSize \[Rule] 504, \ 
          Frame \[Rule] True, \ Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g8 = \ Show[g2, g7];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309351 0.0997283 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01017 -12 -4.5 ]
[-0.0125 .01017 0 4.5 ]
[-0.0125 .10989 -12 -4.5 ]
[-0.0125 .10989 0 4.5 ]
[-0.0125 .20962 -12 -4.5 ]
[-0.0125 .20962 0 4.5 ]
[-0.0125 .30935 -6 -4.5 ]
[-0.0125 .30935 0 4.5 ]
[-0.0125 .40908 -6 -4.5 ]
[-0.0125 .40908 0 4.5 ]
[-0.0125 .50881 -6 -4.5 ]
[-0.0125 .50881 0 4.5 ]
[-0.0125 .60854 -6 -4.5 ]
[-0.0125 .60854 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01017 m
.00625 .01017 L
s
[(-3)] -0.0125 .01017 1 0 Mshowa
0 .10989 m
.00625 .10989 L
s
[(-2)] -0.0125 .10989 1 0 Mshowa
0 .20962 m
.00625 .20962 L
s
[(-1)] -0.0125 .20962 1 0 Mshowa
0 .30935 m
.00625 .30935 L
s
[(0)] -0.0125 .30935 1 0 Mshowa
0 .40908 m
.00625 .40908 L
s
[(1)] -0.0125 .40908 1 0 Mshowa
0 .50881 m
.00625 .50881 L
s
[(2)] -0.0125 .50881 1 0 Mshowa
0 .60854 m
.00625 .60854 L
s
[(3)] -0.0125 .60854 1 0 Mshowa
.125 Mabswid
0 .03011 m
.00375 .03011 L
s
0 .05006 m
.00375 .05006 L
s
0 .07 m
.00375 .07 L
s
0 .08995 m
.00375 .08995 L
s
0 .12984 m
.00375 .12984 L
s
0 .14979 m
.00375 .14979 L
s
0 .16973 m
.00375 .16973 L
s
0 .18968 m
.00375 .18968 L
s
0 .22957 m
.00375 .22957 L
s
0 .24951 m
.00375 .24951 L
s
0 .26946 m
.00375 .26946 L
s
0 .28941 m
.00375 .28941 L
s
0 .3293 m
.00375 .3293 L
s
0 .34924 m
.00375 .34924 L
s
0 .36919 m
.00375 .36919 L
s
0 .38913 m
.00375 .38913 L
s
0 .42903 m
.00375 .42903 L
s
0 .44897 m
.00375 .44897 L
s
0 .46892 m
.00375 .46892 L
s
0 .48886 m
.00375 .48886 L
s
0 .52875 m
.00375 .52875 L
s
0 .5487 m
.00375 .5487 L
s
0 .56864 m
.00375 .56864 L
s
0 .58859 m
.00375 .58859 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01017 m
1 .01017 L
s
.99375 .10989 m
1 .10989 L
s
.99375 .20962 m
1 .20962 L
s
.99375 .30935 m
1 .30935 L
s
.99375 .40908 m
1 .40908 L
s
.99375 .50881 m
1 .50881 L
s
.99375 .60854 m
1 .60854 L
s
.125 Mabswid
.99625 .03011 m
1 .03011 L
s
.99625 .05006 m
1 .05006 L
s
.99625 .07 m
1 .07 L
s
.99625 .08995 m
1 .08995 L
s
.99625 .12984 m
1 .12984 L
s
.99625 .14979 m
1 .14979 L
s
.99625 .16973 m
1 .16973 L
s
.99625 .18968 m
1 .18968 L
s
.99625 .22957 m
1 .22957 L
s
.99625 .24951 m
1 .24951 L
s
.99625 .26946 m
1 .26946 L
s
.99625 .28941 m
1 .28941 L
s
.99625 .3293 m
1 .3293 L
s
.99625 .34924 m
1 .34924 L
s
.99625 .36919 m
1 .36919 L
s
.99625 .38913 m
1 .38913 L
s
.99625 .42903 m
1 .42903 L
s
.99625 .44897 m
1 .44897 L
s
.99625 .46892 m
1 .46892 L
s
.99625 .48886 m
1 .48886 L
s
.99625 .52875 m
1 .52875 L
s
.99625 .5487 m
1 .5487 L
s
.99625 .56864 m
1 .56864 L
s
.99625 .58859 m
1 .58859 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30935 m
1 .30935 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .466 m
.02847 .42171 L
.03355 .37341 L
.03832 .32805 L
.04291 .28442 L
.0478 .23798 L
.0525 .19328 L
.05373 .18157 L
.05438 .1754 L
.05474 .17202 L
.05507 .16886 L
.05536 .16611 L
.05544 .16531 L
.05552 .16456 L
.05567 .47645 L
.05575 .4757 L
.05584 .47489 L
.05599 .47344 L
.05633 .47016 L
.0575 .45908 L
.06251 .41141 L
.06735 .36548 L
.072 .32129 L
.07694 .27429 L
.0817 .22903 L
.0841 .20626 L
.08514 .19632 L
.08628 .18551 L
.08659 .18261 L
.08691 .17954 L
.08704 .17828 L
.08719 .17692 L
.08734 .48873 L
.08749 .48733 L
.08864 .47645 L
.09116 .45248 L
.09612 .40532 L
.1009 .35991 L
.10549 .31624 L
.11039 .26975 L
.1151 .225 L
.11633 .21327 L
.11767 .20054 L
.11828 .19471 L
.11862 .19151 L
.11878 .18995 L
.11893 .18853 L
.11907 .50053 L
.1192 .49929 L
.11949 .49656 L
Mistroke
.1201 .49076 L
.12471 .44693 L
.12962 .4003 L
.13435 .3554 L
.13937 .3077 L
.14421 .26173 L
.14643 .24064 L
.14769 .22867 L
.14886 .21751 L
.15003 .20646 L
.15036 .20327 L
.15052 .20171 L
.15068 .20026 L
.15082 .51226 L
.15096 .51087 L
.15127 .50793 L
.15381 .48378 L
.15837 .44048 L
.16323 .39437 L
.1679 .35 L
.17287 .30283 L
.17765 .25739 L
.18006 .23448 L
.18112 .2245 L
.18167 .21925 L
.18197 .21638 L
.18225 .2137 L
.1824 .21231 L
.18256 .52413 L
.18265 .52328 L
.18273 .52248 L
.18289 .52097 L
.18347 .51542 L
.18462 .5045 L
.18715 .4805 L
.19177 .43666 L
.19669 .39001 L
.20142 .3451 L
.20597 .30193 L
.20849 .27796 L
.21081 .25596 L
.21308 .23442 L
.21363 .22919 L
.21394 .22631 L
.21409 .22489 L
.21422 .22359 L
.2143 .53615 L
.21439 .53535 L
.21456 .53368 L
.21487 .53075 L
Mistroke
.21547 .52504 L
.22004 .48173 L
.2249 .43562 L
.22958 .39125 L
.23455 .34408 L
.23934 .29865 L
.24176 .27573 L
.24395 .25496 L
.24454 .24939 L
.24518 .24337 L
.24547 .24061 L
.24563 .2391 L
.24578 .23769 L
.2459 .23648 L
.24604 .5485 L
.24619 .54707 L
.24633 .54577 L
.24886 .52179 L
.25366 .47623 L
.25829 .43241 L
.26321 .3858 L
.26795 .34093 L
.2725 .29781 L
.27503 .27385 L
.27614 .26336 L
.27673 .25781 L
.27705 .25477 L
.27735 .25189 L
.2775 .25053 L
.27765 .24908 L
.27773 .24833 L
.27782 .56081 L
.27797 .55935 L
.27853 .55404 L
.27963 .54367 L
.28202 .52102 L
.28689 .47498 L
.29158 .43067 L
.29656 .38359 L
.30135 .33825 L
.30597 .29466 L
.30719 .28308 L
.30835 .27219 L
.30899 .26616 L
.30916 .2645 L
.30935 .26276 L
.3095 .26127 L
.30959 .57373 L
.30968 .57295 L
.31088 .56159 L
Mistroke
.31558 .51722 L
.32058 .47008 L
.32539 .42469 L
.33002 .38105 L
.33495 .33464 L
.3374 .31159 L
.3386 .30031 L
.33969 .28999 L
.34023 .28493 L
.34052 .28225 L
.34082 .2794 L
.34097 .27799 L
.34111 .27666 L
.34124 .27547 L
.34138 .58748 L
.34151 .58625 L
.34164 .58496 L
.34189 .58263 L
.34426 .5604 L
.34883 .51738 L
.35371 .47161 L
.3584 .42761 L
.36339 .38088 L
.36819 .33592 L
.37039 .31538 L
.37164 .30369 L
.37225 .29797 L
.37252 .29546 L
.37266 .29413 L
.37281 .29272 L
.37296 .2913 L
.3731 .60332 L
.37324 .60203 L
.37337 .6008 L
.37396 .59531 L
.37519 .58376 L
.37773 .56012 L
.38236 .5169 L
.3873 .471 L
.39205 .42688 L
.39662 .38456 L
.40148 .33961 L
.40616 .29647 L
.41114 .25075 L
.41593 .20688 L
.42054 .16486 L
.42545 .12037 L
.43017 .07778 L
.43259 .05614 L
.43385 .04479 L
Mistroke
.43519 .03284 L
.43577 .02767 L
.43609 .02482 L
.43625 .02343 L
.4364 .02213 L
.43648 .0214 L
.43657 .33392 L
.43665 .33313 L
.43675 .33226 L
.43708 .32937 L
.43771 .32372 L
.44003 .30321 L
.44488 .26055 L
.44955 .21997 L
.45452 .17742 L
.4593 .13715 L
.4639 .0992 L
.46627 .08 L
.46696 .07452 L
.4676 .06938 L
.46788 .06713 L
.46803 .06591 L
.46818 .06477 L
.46833 .37684 L
.46841 .37619 L
.4685 .37549 L
.4688 .37311 L
.47378 .33423 L
.47858 .29812 L
.4832 .26471 L
.48811 .23061 L
.49285 .19902 L
.49739 .16947 L
.49853 .16217 L
.49915 .15819 L
.49945 .15625 L
.49972 .15448 L
.49988 .15349 L
.50002 .46585 L
.50018 .46485 L
.50035 .46377 L
.50103 .45937 L
.50224 .45163 L
.50717 .41961 L
.51191 .38791 L
.51648 .35627 L
.52134 .32117 L
.52601 .28602 L
.52839 .26767 L
.52965 .25784 L
Mistroke
.53034 .25242 L
.53099 .24729 L
.53129 .24487 L
.53146 .24355 L
.53161 .24232 L
.53169 .24167 L
.53178 .55429 L
.53188 .55352 L
.53196 .55282 L
.53229 .55023 L
.53347 .54077 L
.53578 .52211 L
.54058 .4825 L
.54521 .44361 L
.55012 .40151 L
.55486 .36039 L
.55941 .32039 L
.56175 .29975 L
.56239 .29407 L
.56274 .29098 L
.56306 .28809 L
.5632 .28682 L
.56334 .28562 L
.56349 .59755 L
.56364 .59629 L
.56426 .59069 L
.5689 .5492 L
.57384 .50476 L
.57859 .46169 L
.58316 .42008 L
.58803 .37558 L
.59271 .33259 L
.59769 .28673 L
.60249 .24242 L
.6071 .1997 L
.61201 .15413 L
.61674 .11017 L
.62176 .06337 L
.62428 .03984 L
.62539 .02952 L
.62597 .02405 L
.62629 .02105 L
.6266 .0182 L
.62674 .01687 L
.62689 .01545 L
.62697 .01472 L
.62706 .32721 L
.62721 .32577 L
.62777 .32055 L
.62886 .31033 L
Mistroke
.63126 .28799 L
.63611 .24254 L
.64078 .19876 L
.64575 .15215 L
.65054 .10722 L
.65514 .06397 L
.65636 .05249 L
.65751 .04168 L
.65815 .03569 L
.65832 .03405 L
.65851 .03232 L
.65867 .03084 L
.65875 .3433 L
.65884 .34252 L
.66004 .3312 L
.66473 .28707 L
.66972 .24012 L
.67452 .19487 L
.67914 .15131 L
.68405 .10494 L
.68649 .08191 L
.68769 .07063 L
.68879 .06027 L
.68985 .05021 L
.69011 .04776 L
.69025 .04642 L
.69039 .04515 L
.69055 .35695 L
.69069 .35558 L
.69097 .35291 L
.69334 .33062 L
.69797 .28682 L
.7029 .24022 L
.70765 .19532 L
.71222 .15214 L
.71708 .10615 L
.71932 .08498 L
.7205 .07379 L
.72115 .06765 L
.72176 .06187 L
.72192 .06034 L
.72209 .05872 L
.72218 .05787 L
.72228 .37024 L
.72237 .3694 L
.72246 .36861 L
.72308 .36265 L
.72431 .35103 L
.72674 .32809 L
.73143 .28364 L
Mistroke
.73642 .23637 L
.74123 .19082 L
.74586 .14699 L
.7482 .12482 L
.75078 .10036 L
.75196 .0892 L
.75258 .08335 L
.75323 .07718 L
.7535 .07456 L
.7538 .07176 L
.75388 .07094 L
.75397 .07015 L
.75412 .382 L
.75427 .38063 L
.75442 .37914 L
.75552 .36875 L
.76046 .32194 L
.76521 .27685 L
.76979 .23349 L
.77465 .18732 L
.77934 .14288 L
.78172 .12026 L
.78298 .10832 L
.78432 .09562 L
.78499 .08923 L
.78533 .08609 L
.78547 .08472 L
.78563 .08322 L
.78577 .39516 L
.78591 .39389 L
.7862 .39112 L
.78681 .3853 L
.78912 .3634 L
.79382 .31878 L
.79882 .27135 L
.80363 .22565 L
.80827 .18168 L
.81061 .15943 L
.81319 .1349 L
.81438 .1237 L
.81564 .11165 L
.81626 .10581 L
.81684 .10027 L
.8171 .09786 L
.81724 .09653 L
.81737 .09529 L
.81752 .40712 L
.81766 .40578 L
.81794 .40316 L
.82259 .35902 L
Mistroke
.82753 .31207 L
.8323 .26685 L
.83687 .22337 L
.84175 .17707 L
.84644 .13251 L
.84767 .12086 L
.84831 .11471 L
.84867 .11134 L
.84884 .10969 L
.849 .10818 L
.84914 .10685 L
.84929 .41875 L
.84944 .41734 L
.8496 .4158 L
.85026 .40952 L
.85143 .39844 L
.85632 .35198 L
.86103 .30725 L
.86603 .25971 L
.87085 .2139 L
.87549 .16983 L
.87784 .1475 L
.87909 .13566 L
.87977 .12914 L
.88011 .12592 L
.88043 .12294 L
.88072 .12012 L
.88081 .11931 L
.88089 .11854 L
.88104 .43042 L
.88112 .42964 L
.88121 .42883 L
.88136 .42736 L
.88171 .42406 L
.88288 .41293 L
.88518 .3911 L
.88976 .34753 L
.89464 .30115 L
.89934 .2565 L
.90434 .20904 L
.90684 .18528 L
.90915 .16332 L
.91139 .14198 L
.91194 .13679 L
.91223 .13407 L
.91253 .13121 L
.9126 .13047 L
.91269 .12968 L
.91278 .44212 L
.91286 .44131 L
Mistroke
.91317 .43838 L
.91378 .43264 L
.91879 .38502 L
.92361 .33913 L
.92826 .29499 L
.9332 .24803 L
.93796 .2028 L
.94035 .18007 L
.94253 .15932 L
.94311 .15383 L
.94374 .14785 L
.94403 .14512 L
.94418 .14362 L
.94433 .14221 L
.94446 .45432 L
.94459 .45303 L
.94488 .45029 L
.9474 .42633 L
.95236 .37921 L
.95714 .33383 L
.96173 .29018 L
.96661 .24373 L
.97132 .19901 L
.97619 .1527 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.05556 .30935 m
.05556 .30935 L
s
.0873 .30935 m
.0873 .30935 L
s
.11905 .30935 m
.11905 .30935 L
s
.15079 .30935 m
.15079 .30935 L
s
.18254 .30935 m
.18254 .30935 L
s
.21429 .30935 m
.21429 .30935 L
s
.24603 .30935 m
.24603 .30935 L
s
.27778 .30935 m
.27778 .30935 L
s
.30952 .30935 m
.30952 .30935 L
s
.34127 .30935 m
.34127 .30935 L
s
.37302 .30935 m
.37302 .30935 L
s
.40476 .30935 m
.40476 .30935 L
s
.43651 .30935 m
.43651 .30935 L
s
.46825 .30935 m
.46825 .30935 L
s
.5 .30935 m
.5 .30935 L
s
.53175 .30935 m
.53175 .30935 L
s
.56349 .30935 m
.56349 .30935 L
s
.59524 .30935 m
.59524 .30935 L
s
.62698 .30935 m
.62698 .30935 L
s
.65873 .30935 m
.65873 .30935 L
s
.69048 .30935 m
.69048 .30935 L
s
.72222 .30935 m
.72222 .30935 L
s
.75397 .30935 m
.75397 .30935 L
s
.78571 .30935 m
.78571 .30935 L
s
.81746 .30935 m
.81746 .30935 L
s
.84921 .30935 m
.84921 .30935 L
s
.88095 .30935 m
.88095 .30935 L
s
.9127 .30935 m
.9127 .30935 L
s
.94444 .30935 m
.94444 .30935 L
s
.97619 .30935 m
.97619 .30935 L
s
.015 w
.05556 .30935 Mdot
.0873 .30935 Mdot
.11905 .30935 Mdot
.15079 .30935 Mdot
.18254 .30935 Mdot
.21429 .30935 Mdot
.24603 .30935 Mdot
.27778 .30935 Mdot
.30952 .30935 Mdot
.34127 .30935 Mdot
.37302 .30935 Mdot
.40476 .30935 Mdot
.43651 .30935 Mdot
.46825 .30935 Mdot
.5 .30935 Mdot
.53175 .30935 Mdot
.56349 .30935 Mdot
.59524 .30935 Mdot
.62698 .30935 Mdot
.65873 .30935 Mdot
.69048 .30935 Mdot
.72222 .30935 Mdot
.75397 .30935 Mdot
.78571 .30935 Mdot
.81746 .30935 Mdot
.84921 .30935 Mdot
.88095 .30935 Mdot
.9127 .30935 Mdot
.94444 .30935 Mdot
.97619 .30935 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00=?ooool3o`0002gooooo1Ol0000]ooooo`;o0000;_ooool5o`0002oooooo0ol0000Soooo
o`00=Oooool00ol0003oooooooooo`0]ooooo`04o`000?ooooooooooo`0002cooooo00Co0000oooo
oooooooo0000;_ooool01?l0003oooooooooool0000`ooooo`03o`000?oooooooooo02;ooooo000/
ooooo`Go000000?oooooo`000?l000000ol0000Wooooo`Go00000oooool00ol0003oooooooooo`0/
ooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool0;Oooool5o`0002?ooooo000b
ooooo`04o`000?ooooooooooo`00037ooooo00?o0000ooooooooool0:oooool01?l0003ooooooooo
ool0000`ooooo`03o`000?oooooooooo02cooooo00Co0000oooooooooooo00009?ooool003?ooooo
00?o0000ooooool00000;_ooool01Ol0003ooooooooooooooooo000002cooooo00Co0000oooooooo
oooo0000;Oooool01Ol0003ooooooooooooooooo000002kooooo00?o0000ooooool000009?ooool0
03Cooooo0_l0000^ooooo`05o`000?ooooooooooooooool00000;?ooool01?l0003oooooooooool0
000]ooooo`05o`000?ooooooooooooooool00000;oooool2o`0002Cooooo000eooooo`03o`000?oo
oooooooo02gooooo0ol0000^ooooo`;o0000;oooool3o`00037ooooo00?o0000ooooooooool08_oo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool000_ooooo0ol0
0005oooooooo00002Ol00005ooooo`002_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`001?ooool5o`0000Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo083ooooo00?o0000
ooooooooool00oooool000cooooo0_l00005ooooo`?o0000POooool00ol0003oooooooooo`1ooooo
o`;o00001Oooool000kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`21ooooo`03
o`000?oooooooooo01kooooo00?o003oooooooooool0Goooool00ol0003oooooooooo`03ooooo`00
2_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0L?ooool00ol00?oo
ooooooooo`0>ooooo`03o`000?oooooooooo01kooooo00?o003oooooooooool0Goooool00ol0003o
ooooooooo`03ooooo`002oooool3o`0000Gooooo00?o0000ooooooooool0L?ooool00ol00?oooooo
ooooo`0>ooooo`03o`000?oooooooooo01kooooo00?o003oooooooooool0Goooool00ol0003ooooo
ooooo`03ooooo`004oooool00ol0003oooooooooo`1`ooooo`03o`00oooooooooooo00kooooo00?o
0000ooooooooool07_ooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo00?ooooo000C
ooooo`;o0000LOooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo01kooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`1Fooooo`;o00001Oooool001?ooooo00?o0000oooo
ooooool0L?ooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo01gooooo0_l00?l7oooo
o`03o`00oooooooooooo05Oooooo00?o0000ooooooooool00oooool001?ooooo00?o0000oooooooo
ool0Koooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooooooo01kooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`1Gooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`00
0?oooooooooo06oooooo0_l00?l@ooooo`03o`000?oooooooooo01kooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`1Gooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oo
oooooooo06oooooo0_l00?l@ooooo`03o`000?oooooooooo01gooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04kooooo00?o0000ooooooooool00ooo
ool001?ooooo0_l0001aooooo`03o`00oooooooooooo00kooooo00?o0000ooooooooool07Oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0COooool2
o`0000Gooooo000Cooooo`03o`000?oooooooooo06oooooo00?o003oooooooooool03oooool00ol0
003oooooooooo`0Mooooo`;o003o1oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
04kooooo00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool0Koooool00ol00?oo
ooooooooo`0?ooooo`03o`000?oooooooooo01kooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo04oooooo00?o0000ooooooooool00oooool001?ooooo
00?o0000ooooooooool0Koooool2o`00oa3ooooo00?o0000ooooooooool07_ooool00ol00?oooooo
ooooo`04ooooo`;o003o1oooool2o`00o`Oooooo00?o003oooooooooool0A_ooool00ol0003ooooo
ooooo`03ooooo`004oooool00ol0003oooooooooo`1_ooooo`;o003o1oooool00ol00?oooooooooo
o`06ooooo`03o`000?oooooooooo01gooooo0_l00?l7ooooo`03o`00oooooooooooo00Gooooo0_l0
0?l7ooooo`03o`00oooooooooooo04Kooooo00?o0000ooooooooool00oooool001?ooooo0_l0001a
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`0M
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool2o`00o`Oooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0mooooo`;o00001Oooool001?ooooo00?o0000oooo
ooooool0L?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o0000oooo
ooooool07?ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo03kooooo00?o0000oooo
ooooool00oooool001?ooooo00?o0000ooooooooool0K_ooool00ol00?ooooooooooo`0@ooooo`03
o`000?oooooooooo01cooooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool0?_ooool00ol0003oooooooooo`03ooooo`00
4oooool00ol0003oooooooooo`1^ooooo`03o`00oooooooo003o00Oooooo00?o003oooooooooool0
1_ooool00ol0003oooooooooo`0Nooooo`03o`00oooooooooooo00Cooooo0_l00?l7ooooo`03o`00
oooooooooooo04oooooo00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool0K_oo
ool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool07?oo
ool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00Gooooo0_l00?l6ooooo`;o003o1ooo
ool00ol00?ooooooooooo`0nooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooo
oooo073ooooo00?o003oooooooooool01?ooool2o`00o`Sooooo00?o0000ooooooooool07?ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01_ooool2
o`00o`Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0eooooo`03o`000?oooooo
oooo00?ooooo000Cooooo`;o0000LOooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Kooooo00?o0000ooooooooool07?ooool00ol00?ooooooooooo`06ooooo`;o003o2?ooool00ol0
0?ooooooooooo`04ooooo`;o003o1oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
03Cooooo0_l00005ooooo`004oooool00ol0003oooooooooo`1^ooooo`03o`00oooooooooooo013o
oooo00?o0000ooooooooool07?ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo01Oo
oooo00?o003oooooooooool01Oooool2o`00o`Oooooo00?o003oooooooooool0;Oooool00ol0003o
ooooooooo`03ooooo`002_ooool5o`0000Cooooo00?o0000ooooooooool0K_ooool00ol00?oooooo
o`00o`06ooooo`;o003o2?ooool00ol0003oooooooooo`0Nooooo`03o`00oooooooooooo00?ooooo
00?o003oooooool00?l01_ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool0;Oooool00ol0003oooooooooo`03ooooo`002oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo06gooooo00Co003ooooooooooooo003o1_ooool2o`00o`So
oooo00?o0000ooooooooool07_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooool00?l01_ooool2o`00o`Kooooo00?o003oooooooooool03oooool00ol00?oo
ooooooooo`0]ooooo`03o`000?oooooooooo00?ooooo0004ooooo`Go00000oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo073ooooo00?o003oooooooooool01?ooool2o`00o`Sooooo
00?o0000ooooooooool06oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooool00?l01_ooool2o`00o`Kooooo0_l00?l8ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo
000=ooooo`03o`000?oooooooooo00?ooooo0ol0001`ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01_ooool00ol0003oooooooooo`0Kooooo`03o`00oooooooooooo00Kooooo00?o
003oooooool00?l02?ooool00ol00?ooooooooooo`04ooooo`;o003o1_ooool2o`00o`Oooooo0_l0
0?l7ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool09?ooool2o`0000Gooooo000:
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1]ooooo`03o`00oooo
oooooooo017ooooo00?o0000ooooooooool06oooool01?l00?ooooooooooool00?l5ooooo`03o`00
oooooooooooo00kooooo00?o003oooooooooool01_ooool2o`00o`Oooooo0_l00?l7ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool09Oooool00ol0003oooooooooo`03ooooo`002_oo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0KOooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool07_ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool09Oooool00ol0003ooooo
ooooo`03ooooo`002oooool3o`0000Gooooo00?o0000ooooooooool0KOooool01?l00?oooooooooo
ool00?l5ooooo`03o`00oooooooo003o00Sooooo00?o0000ooooooooool07_ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`0?ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo01cooooo00?o0000ooooooooool00oooool001?ooooo00?o
0000ooooooooool0KOooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Sooooo
00?o0000ooooooooool06oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00?ooooo
00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`06ooooo`;o003o2?ooool00ol00?oo
ooooooooo`04ooooo`;o003o1oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01co
oooo00?o0000ooooooooool00oooool001?ooooo0_l0001aooooo`03o`00oooooooooooo00?ooooo
00?o003oooooool00?l02?ooool00ol0003oooooooooo`0Kooooo`03o`00oooooooooooo00Kooooo
00?o003oooooool00?l02?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Kooooo
0_l00?l6ooooo`03o`00oooooooo003o00Oooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`05ooooo`;o003o1oooool00ol00?ooooooooooo`0Cooooo`;o00001Oooool001?ooooo00?o
0000ooooooooool0KOooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo01_ooooo00Co
003ooooooooooooo003o1Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooool00?l01_ooool2o`00o`Kooooo00?o003oooooool00?l01oooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0Dooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo06gooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo01kooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Oooooo00?o
003oooooool00?l01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo000C
ooooo`03o`000?oooooooooo06cooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooo
oooo003o00Sooooo00?o0000ooooooooool07_ooool00ol00?ooooooooooo`02ooooo`04o`00oooo
ooooooooo`00o`Gooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`0>ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00oooooo00?o003oooooooooool02oooool00ol0003oooooooooo`03ooooo`00
4oooool00ol0003oooooooooo`1/ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?oo
ooooooooool00?l8ooooo`03o`000?oooooooooo01[ooooo00Go003oooooooooooooooooo`00o`07
ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooo003o00Sooooo00?o003oooooooooool01?ooool2o`00o`Kooooo00?o
003oooooooooool01_ooool2o`00o`Oooooo00?o003oooooooooool01Oooool2o`00o`gooooo00?o
0000ooooooooool00oooool001?ooooo0_l0001aooooo`03o`00oooooooooooo00;ooooo00Co003o
oooooooooooo003o2?ooool00ol0003oooooooooo`0Jooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool00oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Go
oooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01Oooool2o`00o`Oooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0;ooooo`;o00001Oooool001?ooooo00?o0000ooooooooool0K?ooool01Ol00?oooooo
oooooooooooo003o00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Jooooo`05
o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00;ooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo
003o00Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool2
o`00oa3ooooo00?o003oooooooooool00oooool00ol0003oooooooooo`03ooooo`004oooool00ol0
003oooooooooo`1/ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02?ooool2o`00
oacooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooool00?l01_ooool2o`00o`Sooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`06
ooooo`;o003o3Oooool00ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`1/oooo
o`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l8ooooo`03o`00oooo
oooooooo01kooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l5ooooo`03o`00
oooooooooooo01Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03_ooool2o`00o`gooooo00?o0000ooooooooool0
0oooool001?ooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`1Mooooo`05o`00oooo
ooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l7ooooo`03o`00ool0003ooooo01_o
oooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l03_oo
ool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`05ooooo`;o003o1oooool00ol00?ooooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo000Cooooo`03o`000?oooooooooo00_ooooo0_l00?mSooooo`03o`00oooooooo
oooo00;ooooo00Co003ooooooooooooo003o1oooool00ol00?oo0000ooooo`0Kooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo
00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`08ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Ko
oooo0_l00?l7ooooo`;o003o1oooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo000Cooooo`;o00003?ooool00ol00?ooooooooooo`1Rooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01Oooool2o`00oa_ooooo00?o003oooooooooool01_ooool01Ol00?oooooo
oooooooooooo003o00Sooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l5oooo
o`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01_ooool2o`00o`oooooo00?o003o
ooooooooool00oooool2o`0000Gooooo000Cooooo`03o`000?oooooooooo00_ooooo0_l00?l7oooo
o`03o`00oooooooooooo05Cooooo00?o003oooooooooool04_ooool2o`00oa_ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o01[ooooo00?o003oooooool00?l01Oooool0
1?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Kooooo0_l00?l8ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Cooooo00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool03?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo05Cooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01kooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool05oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00Kooooo0_l00?l6ooooo`03o`00oooooooooooo00kooooo00?o
003oooooool00?l03Oooool00ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`0;
ooooo`;o003o1oooool00ol00?ooooooooooo`1Dooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool01?l00?ooooooooooool00?l6ooooo`03o`00oooooooo003o01_ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003ooooooooo
ool03oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Kooooo00?o003ooooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`0;ooooo`;o003o
1oooool00ol00?ooooooooooo`1Iooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooo000001_ooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool00oooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l01_ooool2o`00o`Kooooo00?o
003oooooool00?l01_ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo000C
ooooo`;o00003?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo05Wooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o01_ooooo00?o003o
ooooooooool01_ooool01Ol00?oooooooooooooooooo003o00Sooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1Oooool01?l00?oo
ooooooooool00?l7ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooo`00o`06ooooo`;o003o3oooool00ol00?ooooooooooo`03ooooo`;o00001Oooool001?o
oooo00?o0000ooooooooool02oooool2o`00o`Oooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`1<ooooo`03o`00oooooooooooo017ooooo00?o003oooooool00?l06oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l04?ooool01Ol00?oooooooooooooooooo
003o00Cooooo00Co003ooooooooooooo003o1Oooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`Gooooo00?o003oooooool00?l02?ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooo003o00oooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`00
4oooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo0_l00?l7ooooo`03o`00
oooooooooooo04cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo01kooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo01Oo
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo003o01Oo
oooo00?o003oooooool00?l03Oooool00ol0003oooooooooo`03ooooo`002oooool3o`0000Gooooo
00?o0000ooooooooool02oooool2o`00o`Oooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo04?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Nooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01?oo
ool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Gooooo00?o0000ooooooooool00ooo
ool000cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`;o003o1oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0A?ooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`03ooooo`04o`00ooooooooooooo`0001_ooooo00?o003oooooooooool02_ooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Co003ooooooooooooo003o2?ooool00ol00?ooooooooooo`02ooooo`04o`00oooooooo
ooooo`00o`Gooooo00?o003oooooooooool01_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooo
oooo003o00Kooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo0004ooooo`Go00000oooool00ol0003oooooooooo`04ooooo`?o00002_ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0BOooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00oooool01?l00?oooooooooo
ool0000Kooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`06ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`04
o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooo
oooo003o00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`;o00001Ooo
ool000cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`00oooooooo
oooo00Kooooo0_l00?l7ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0jooooo`03o`00oooooooooooo017ooooo00Co003ooooooooooooo003o6_oo
ool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`gooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`02ooooo`04o`00oooooooo
ooooo`00o`Sooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooo
oooooooo00Gooooo00?o0000ooooooooool00oooool000cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo0_l00?l7ooooo`03o`00oooooooo
oooo00Gooooo0_l00?l7ooooo`03o`00oooooooooooo03[ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01kooooo00Co003ooooooooooooo003o2?oo
ool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o2?ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o3Oooool00ol0
003oooooooooo`03ooooo`002oooool2o`0000Kooooo00?o0000ooooooooool03?ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Cooooo0_l00?l7ooooo`;o003o1oooool00ol00?oo
ooooooooo`0jooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o1?ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo01kooooo00Co003ooooooooooooo003o1?ooool0
1Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00kooooo00Co003ooooooooooooo003o3Oooool00ol0003o
ooooooooo`03ooooo`003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo
00?o003oooooool00?l01oooool00ol00?ooooooooooo`04ooooo`;o003o1oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo03[ooooo00?o003oooooooooool00oooool01?l00?oooooo
ooooool00?l4ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo00006_ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00Go003oooooooooooooooooo`00o`04
ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00Kooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool01_ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`Gooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo000Cooooo`;o00002oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo03Sooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`03ooooo`04o`00oooo
ooooooooo`0001[ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01ooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o
1?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01?ooool2o`0000Gooooo000Cooooo`03o`000?oooooooooo00[ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`05ooooo`;o003o2?ooool00ol00?ooooooooooo`04ooooo`;o003o
1oooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l06_ooool00ol00?oo
ooooooooo`03ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool01_ooool01?l0
0?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l>ooooo`03
o`00oooooooooooo00Gooooo00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool0
3?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Kooooo0_l00?l7ooooo`;o003o
1oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0
0oooool00ol00?ooooooo`00o`08ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04oooo
o`04o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`06
ooooo`04o`00ooooooooooooo`00o`gooooo00?o0000ooooooooool00oooool001?ooooo00?o0000
ooooooooool03?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Kooooo0_l00?l7
ooooo`;o003o1oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool0:?ooool00ol00?ooooooooooo`04ooooo`04o`00ooooooooooooo`00o`Cooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooo003o00Gooooo00Co
003ooooooooooooo003o6Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo
00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`0?ooooo`04o`00ooooooooooooo`00
o`gooooo00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool02Oooool01?l00?oo
ooooooooool00?l7ooooo`03o`00oooooooooooo00Cooooo0_l00?l7ooooo`;o003o1_ooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo02Sooooo00?o003oooooooooool01?ooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`000007
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05
ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool02_ooool01Ol00?oooooooooooooooooo003o
00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00?ooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`06ooooo`03o`000?oooooo
oooo00?ooooo000Cooooo`03o`000?oooooooooo00Wooooo00Co003ooooooooooooo003o1Oooool0
0ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`05ooooo`;o003o1oooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooo
003o00Gooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo000000Oooooo00?o
003oooooooooool03oooool00ol00?ooooooooooo`0<ooooo`04o`00ooooooooooooo`00o`Gooooo
00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1Ooo
ool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool0
0oooool001?ooooo0_l0000:ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Cooooo0_l00?l7ooooo`03o`00oooo
oooooooo00Gooooo0_l00?l7ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?oooooo
ooooo`0?ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`06ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01Ol0
0?oooooooooooooooooo003o00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooo
ooooooooo`00o`gooooo00?o003oooooooooool01Oooool2o`0000Gooooo000Cooooo`03o`000?oo
oooooooo00cooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`05ooooo`03o`00oooo
oooo003o00Sooooo00?o003oooooooooool01?ooool2o`00o`Kooooo0_l00?l@ooooo`03o`00oooo
oooooooo023ooooo00?o003oooooooooool04Oooool01Ol00?oooooooooooooooooo003o00Oooooo
00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Sooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`03
ooooo`004oooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Oooooo00?o003ooooo
ooooool01?ooool2o`00o`Oooooo00?o003oooooooooool0:Oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Goooo
o`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o6Oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00Gooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooo
oooooooo00kooooo00Go003oooooooooooooooooo`00o`0=ooooo`03o`000?oooooooooo00?ooooo
000Cooooo`03o`000?oooooooooo00Wooooo00Co003ooooooooooooo003o1oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l01_ooool2o`00o`oooooo
0_l00?l7ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool06?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`04ooooo`03
o`00oooooooooooo00Cooooo0_l00?lAooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooo
oooo003o4?ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l02?ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`04ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool00oooool001?ooooo00?o0000
ooooooooool02Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo
0_l00?l7ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool07oooool00ol00?oooooo
o`00o`05ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol0003oooooooooo`05ooooo`03
o`00oooooooooooo00oooooo00?o003oooooooooool03?ooool00ol00?ooooooo`00o`06ooooo`03
o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`06oooo
o`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool01_ooool00ol0
003oooooooooo`03ooooo`004oooool2o`0000[ooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0Gooooo`03o`00oooooooo003o00Kooooo0_l00?l7ooooo`;o003o1oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool01Oooool01Ol00?oo
oooooooooooooooo003o00Cooooo00?o003oooooooooool01?ooool2o`00oa7ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l01?oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0=ooooo`03
o`00oooooooooooo00Gooooo0_l00005ooooo`004oooool00ol0003oooooooooo`09ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`08oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01_ooool2o`00o`Sooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Sooooo00?o003ooooo
ooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool04?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00kooooo00?o003ooooo
ool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`06ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo00Kooooo00?o0000ooooooooool00oooool001?ooooo00?o0000oooooooo
ool03?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003ooooo
ool00?l01Oooool01?l00?ooooooooooool00?l7ooooo`03o`00oooooooooooo00Cooooo0_l00?lH
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0G
ooooo`;o003o2?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00?ooooo00Co003o
oooooooooooo003o2?ooool01Ol00?oooooooooooooooooo003o00Sooooo00?o003oooooooooool0
2_ooool01Ol00?oooooooooooooooooo003o00gooooo00?o0000ooooooooool00oooool001?ooooo
00?o0000ooooooooool02?ooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003ooooooooo
ool00oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003ooooo
ool00?l03_ooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Cooooo0_l00?lHoooo
o`;o003o1_ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Gooooo00?o003ooooo
ooooool04Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`07ooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo
00Sooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooool00?l01_ooool2o`00o`Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0F
ooooo`;o003o1_ooool01?l00?ooooooooooool00?l5ooooo`03o`000?oooooooooo00Gooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Gooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`04o`00ooooooooooooo`00o`Cooooo
00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooo
oooo003o00Wooooo00?o0000ooooooooool00oooool001?ooooo0_l00009ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
003o00Kooooo0_l00?l6ooooo`03o`00oooooooo003o00Kooooo0_l00?l7ooooo`03o`00oooooooo
oooo00Gooooo0_l00?lHooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o1Ooo
ool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01_oo
ool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o
1Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00Kooooo0_l00005ooooo`004oooool00ol0003oooooooooo`08ooooo`03
o`00oooooooooooo00Kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l8
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01_ooool2o`00o`Sooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo013ooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Oooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`05ooooo`;o003o3oooool2o`00o`Kooooo00?o003o
ooooool00?l01Oooool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Cooooo
00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`06ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo00?o0000oooo
ooooool00oooool001?ooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`02ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool01?l00?ooooooooooool0
0?l7ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l03oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo00kooooo0_l00?l8ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool00oooool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Oo
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`06ooooo`05o`00oooooooooooooooo
ool00?l01oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00_ooooo00?o0000oooo
ooooool00oooool000cooooo0_l00005ooooo`03o`000?oooooooooo00cooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooo
oooooooo003o1oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool01?ooool2o`00o`Oooooo0_l00?l@ooooo`03o`00oooooooooooo00Gooooo0_l00?l6
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`07
ooooo`03o`00oooooooooooo00kooooo0_l00?l6ooooo`03o`00oooooooo003o00Kooooo0_l00?l6
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00_ooooo00?o0000ooooooooool00oooool000_ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`08ooooo`05o`00ooooooooooooooooool00?l01ooo
ool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l0
1oooool00ol00?ooooooooooo`05ooooo`;o003o1oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00Gooooo0_l00?l6ooooo`04o`00ooooooooooooo`00o`Gooooo00?o0000oooooooo
ool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`05ooooo`;o003o1oooool2o`00o`Kooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooo
oooo003o2?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003o
ooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l02Oooool00ol0003ooooo
ooooo`03ooooo`002oooool01?l0003oooooooooool00004ooooo`_o000000?o003oo`000?oo0000
0_oo0003o`000003o`00ool0003o000000?oo`001Ol00003ool000Co000000Co003oool00?oo003o
o`001?l000000ol00?oo0000ool00002ool000Co000000Co003oool00?oo003oo`001Ol00003ool0
00Go000000Co003oool00?oo003oo`001Ol00003ool000Go00000ooo0006o`0000?oo`001Ol00003
ool000Go00000ooo00000ol00?oo0000o`000003o`0000?oo`0000?o0000o`00ool000000_l00003
ool000Ko00000ooo0005o`0000?oo`001Ol00003ool000Ko00000ooo0005o`0000?oo`001Ol00003
ool00003o`00ool0003o000000?o00000ooo00000ol00?oo0000o`000002o`0000?oo`0000?o003o
o`000?l000000_l00003ool000Ko00000ooo0005o`0000?oo`0000?o0000o`00ool00?l00_l00003
ool000;o000000Co003oo`000?l0003o00000ooo0002o`000003o`00ool0003o000000?oo`000ol0
00000ol00?oo0000ool00002ool000Ko00001Oooool000_ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00?oo`000oooool00ol00?oooooooooo
o`03ool000?ooooo00?o003ooooooooo00000_oo0005ooooo`?oo`001?ooool00ol00?ooooooool0
0002ool000Cooooo00Co003oool00?oo003oo`001Oooool3ool000Gooooo00Co003oool00?oo003o
o`001Oooool3ool000Gooooo0ooo0006ooooo`?oo`001Oooool3ool000Gooooo0ooo0006ooooo`?o
o`0000?o003oooooooooool00_ooool3ool000Gooooo00Co003oool00?oo003oo`001Oooool3ool0
00Gooooo0ooo0006ooooo`?oo`001Oooool3ool000Gooooo0ooo00000ol00?ooooooooooo`03oooo
o`?oo`0000?o003oooooooooool00_ooool3ool00003o`00oooooooooooo00;ooooo0ooo0006oooo
o`?oo`001Oooool3ool000Gooooo0ooo0002ooooo`04o`00ooooooooooooooooo`?oo`001Oooool3
ool000;ooooo00?o003oooooooooool00ooo0005ooooo`03o`000?oooooooooo00?ooooo000;oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool02_ooool3ool000?ooooo00?o003o
ooooooooool00ooo0003ooooo`03o`00ooooooooo`0000;oo`000oooool00ol00?ooooooool00002
ool000Kooooo0ooo0004ooooo`04o`00oooo003oo`00ool000Gooooo0ooo0005ooooo`04o`00oooo
003oo`00ool000Gooooo0ooo0005ooooo`?oo`001_ooool3ool000Gooooo0ooo0005ooooo`?oo`00
1_ooool3ool000Gooooo0ooo0005ooooo`04o`00oooo003oo`00ool000Gooooo0ooo0005ooooo`?o
o`001_ooool3ool000Gooooo0ooo0005ooooo`?oo`001_ooool3ool00003o`00oooooooooooo00;o
oooo0ooo00000ol00?ooooooooooo`02ooooo`?oo`0000?oooooo`00ooooool00oooool3ool00003
ooooool00?oooooo00;ooooo0ooo0005ooooo`?oo`000_ooool01?l00?ooooooooooooooool3ool0
00;ooooo00?o003oooooooooool00ooo0005ooooo`?oo`001Oooool00ol0003oooooooooo`03oooo
o`002oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?oo
ool01Ol00?oooooooooooooooooo003o00Oooooo00?o003oooooooooool00oooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool2o`00o`Sooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Gooooo
0_l00?lAooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o4Oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00_ooooo00?o0000ooooooooool00oooool000cooooo
0_l00005ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool01Ol00?oo
oooooooooooooooo003o00Cooooo00?o003oooooooooool03_ooool01?l00?ooooooooooool00?l7
ooooo`03o`00oooooooooooo00Cooooo0_l00?l6ooooo`03o`00oooooooo003o00Oooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooool00?l01_ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Kooooo0_l0
0?l7ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool2o`00o`Oooooo0_l0
0?l6ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooo003o00Sooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`02ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o2_ooool00ol0003o
ooooooooo`03ooooo`004oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`0@ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01Oooool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003o
ooooool00?l01oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Kooooo0_l00?l@
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l01_ooool00ol0003oooooooooo`05
ooooo`03o`00oooooooooooo00Cooooo0_l00?l7ooooo`03o`00oooooooooooo00kooooo0_l00?l7
ooooo`;o003o1_ooool2o`00o`Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o1Oooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o2_ooool00ol0
003oooooooooo`03ooooo`004oooool2o`0000Sooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00_ooool01?l00?oo
ooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o1Ooo
ool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo00?o003oooooooooool01_oo
ool2o`00oa3ooooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooo
oooooooo00;ooooo00Co003ooooooooooooo003o1oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`;o003o
1_ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1Oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Gooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`07ooooo`;o00001Oooool001?ooooo00?o0000ooooooooool0
3?ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03ooo
ool2o`00o`Oooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`06ooooo`;o003o1_oo
ool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooool00?l01Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00_ooooo00?o0000ooooooooool00ooo
ool001?ooooo00?o0000ooooooooool03?ooool01?l00?ooooooooooool00?l4ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l01oooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooo`00o`08ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0Gooooo`05o`00ooooooooooooooooool00?l02_ooool0
0ol00?ooooooooooo`0Gooooo`;o003o4?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`03ooooo`04o`00oooooooo
ooooo`00oa3ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0;ooooo`03o`000?oo
oooooooo00?ooooo000Cooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`05ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00go
oooo00Co003ooooooooooooo003o1oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o
00Kooooo00?o003oooooool00?l03oooool00ol00?ooooooooooo`0>ooooo`;o003o1oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool01?ooool2o`00o`Oooooo00?o003o
ooooooooool03_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool02oooool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`[ooooo
00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool01oooool00ol00?oooooooooo
o`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00oooooo00Co003ooooooooooooo003o1?ooool01?l00?oo
ooooooooool00?l7ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01_ooool2o`00
oaSooooo0_l00?l7ooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool00oooool00ol0
0?ooooooo`00o`07ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool01Oooool2o`00
o`Kooooo00?o003oooooooooool01_ooool2o`00o`Kooooo00?o003oooooooooool01Oooool00ol0
0?ooooooo`00o`06ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1Oooool0
1?l00?ooooooooooool00?l:ooooo`03o`000?oooooooooo00?ooooo000Cooooo`;o00001oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Oooooo00Go003oooooooooooooooooo`00
o`04ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o1?ooool01?l00?oo
ooooooooool00?l5ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l01_ooool2o`00
oaSooooo0_l00?l7ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`05
ooooo`;o003o1_ooool2o`00o`Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00Sooooo0_l00005ooooo`004oooool00ol0003oooooooooo`06oooo
o`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool01_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l8ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooo003o00Ko
oooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`05ooooo`05o`00oooooooooooooooo
ool00?l02oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01Sooooo00?o003ooooo
ooooool01Oooool2o`00o`Kooooo0_l00?l7ooooo`;o003o1_ooool00ol00?ooooooo`00o`05oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00Wooooo00?o0000ooooooooool00oooool001?ooooo00?o0000oooooooo
ool03?ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool03oooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0Hooooo`05o`00ooooooooooooooooool00?l02Oooool00ol00?ooooooooooo`0Yooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool2o`00o`Oooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`00
0?oooooooooo00Kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00;o003o0oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00[ooooo00Go003oooooooooooooooooo`00o`07
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool0
0?l>ooooo`03o`00oooooooooooo00oooooo0_l00?l7ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o02Wooooo00?o003oooooooooool0
3oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
3?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00_ooooo00?o0000oooooooo
ool00oooool001?ooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00kooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00
o`Oooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l7ooooo`03o`00oooooooo
oooo01Kooooo0_l00?l7ooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool00oooool0
0ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`06ooooo`;o003o1_ooool2o`00o`Sooooo00?o003oooooooooool01?ooool0
0ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l02oooool0
0ol0003oooooooooo`03ooooo`004oooool2o`0000Oooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0Gooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Oo
oooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o
01Sooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo
00Gooooo0_l00?l7ooooo`03o`00oooooooooooo00Gooooo0_l00?l6ooooo`03o`00oooooooo003o
00Kooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
00Sooooo0_l00005ooooo`004oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Ko
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooool00?l01_ooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooooooo003o1?oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0:?oo
ool2o`00o`Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Kooooo0_l00?l6ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02Ooo
ool00ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`0<ooooo`03o`00oooooooo
003o00Gooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00Cooooo
00?o003oooooooooool01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00oooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0Hooooo`04o`00ooooooooooooo`00o`Wooooo00?o003ooooo
ooooool0<_ooool2o`00o`Oooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06oooo
o`;o003o2?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00_ooooo00?o0000oooo
ooooool00oooool001?ooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo
003o00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l5ooooo`04o`00oooo
ooooooooo`00o`gooooo00?o003oooooooooool06Oooool01?l00?ooooooooooool00?l4ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool0<oooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool02oooool00ol0003oooooooooo`03ooooo`00
4oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
1Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooo
oooooooo003o4Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`07ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o1oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo01Wooooo00?o0000ooooooooool01Oooool00ol00?oo
ooooooooo`02ooooo`04o`00ooooooooooooo`00o`Kooooo00?o003oooooooooool0<Oooool00ol0
0?ooooooooooo`05ooooo`;o003o2?ooool00ol00?ooooooooooo`04ooooo`;o003o1_ooool00ol0
0?ooooooo`00o`06ooooo`03o`00oooooooo003o00_ooooo00?o0000ooooooooool00oooool001?o
oooo0_l00006ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l4ooooo`04o`00oooo
ooooooooo`00ob7ooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`02ooooo`04o`00
ooooooooooooo`00o`Kooooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`05ooooo`;o
003o1_ooool2o`00o`Oooooo0_l00?l6ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool0
0?l02_ooool2o`0000Gooooo000Cooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
1_ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`06ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool01Oooool01?l00?oooooooooo
ool00?l5ooooo`03o`00oooooooooooo01Wooooo00Co003ooooooooooooo003o1?ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0<_ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool2o`00o`Ko
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo00?o
oooo000Cooooo`03o`000?oooooooooo00cooooo00?o003oooooool00?l01Oooool01?l00?oooooo
ooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool01Oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00kooooo00Co003ooooooooooooo003o1Oooool00ol00?oooooooooo
o`0Iooooo`04o`00ooooooooooooo`00odOooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Kooooo0_l00?l7ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool02oooool00ol0003oooooooooo`03ooooo`002oooool3o`0000Gooooo00?o
0000ooooooooool03?ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Co
003ooooooooooooo003o1Oooool00ol00?ooooooooooo`05ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00cooooo00?o003oooooooooool00_ooool01?l0
0?ooooooooooool00?l8ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool06Oooool0
0ol00?ooooooo`00o`0:ooooo`03o`00oooooooooooo04?ooooo00?o003oooooooooool01Oooool2
o`00oa3ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0;ooooo`03o`000?oooooo
oooo00?ooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l01Oooool01?l0
0?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00oa3ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01?l00?oooooo
ooooool00?l4ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo01Wooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02oooo
o`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool0>_ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01?ooool2o`00o`Oooooo0_l00?l<
ooooo`03o`000?oooooooooo00?ooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o013ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00
ooooooooooooo`00ob7ooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`02ooooo`04
o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool0>_ooool00ol00?ooooooooooo`05oooo
o`;o003o1oooool2o`00o`Kooooo0_l00?l7ooooo`;o003o3?ooool00ol0003oooooooooo`03oooo
o`003?ooool00ol0003oooooooooo`04ooooo`?o00001Oooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo01Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l4oooo
o`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Kooooo
00Co003ooooooooooooo003o8Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`12ooooo`;o003o1oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool2o`0000Go
oooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool2o`00o`Kooooo
00?o003oooooool00?l01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo
00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`06ooooo`04o`00ooooooooooooo`00
o`Sooooo00?o003oooooooooool03oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo
oooo01Wooooo00?o003oooooool00?l03Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo04?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`;o003o1oooool0
0ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo000;ooooo`;o00001_ooool00ol0
003oooooooooo`0<ooooo`;o003o1_ooool00ol00?ooooooo`00o`05ooooo`04o`00oooooooooooo
o`00o`Gooooo00?o003oooooooooool01Oooool01?l00?ooooooooooool00?l4ooooo`05o`00oooo
ooooooooooooool00?l04?ooool01Ol00?oooooooooooooooooo003o00Sooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Wooooo0_l00?l:ooooo`03
o`00oooooooooooo04gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00_ooooo00?o0000ooooooooool00oooool000cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool0
0?l01Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00cooooo00?o003oooooooooool06_ooool2o`00o`Kooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0E?oo
ool2o`00o`Oooooo00?o003oooooooooool02oooool00ol0003oooooooooo`03ooooo`004oooool0
0ol0003oooooooooo`04ooooo`03o`00oooooooooooo00Gooooo0_l00?l6ooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l4ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`0Qooooo`03o`000?oooooooooo00Gooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0C?ooool00ol0
0?ooooooooooo`05ooooo`;o003o1oooool00ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo
00?ooooo000Cooooo`;o00001Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Oo
oooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`Gooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`0Oooooo`;o003o1_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool0C?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool02_ooool2o`0000Gooooo000Cooooo`03o`000?oooooooooo00Co
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`04ooooo`;o003o1_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooooooo`06ooooo`04o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool03_ooool01Ol0
0?oooooooooooooooooo003o00Cooooo00?o003oooooooooool06_ooool2o`00o`Kooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05Cooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo000Coooo
o`03o`000?oooooooooo00cooooo0_l00?l6ooooo`;o003o1_ooool00ol00?ooooooo`00o`06oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l@
ooooo`03o`00oooooooooooo00_ooooo00Go003oooooooooooooooooo`00o`08ooooo`03o`00oooo
oooooooo01[ooooo0_l00?l:ooooo`03o`00oooooooooooo05gooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooo
oooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool0
0ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool02?ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o1?oo
ool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`0Jooooo`;o003o1_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool0FOooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00_ooooo00?o0000oooooooo
ool00oooool001?ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00kooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l4ooooo`03
o`00oooooooooooo00Gooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool07oooool00ol0003oooooooooo`05ooooo`04o`00oooooooooooo
o`00o`Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Mooooo`03o`00oooooooo
oooo00_ooooo00?o0000ooooooooool00oooool001?ooooo0_l00005ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00?ooooo00Co003ooooooooooooo003o1Oooool01?l00?ooooooooooool00?l4ooooo`03o`00oooo
oooooooo00Gooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooo
oooo003o1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05gooooo00?o003ooooo
ooooool02_ooool2o`0000Gooooo000Cooooo`03o`000?oooooooooo00Cooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01_ooool2o`00o`Kooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o2?ooool00ol00?ooooooooooo`06oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01Oooool01Ol00?oooooooooooooooooo003o063ooooo00?o
003oooooooooool02oooool00ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`0<
ooooo`03o`00oooooooooooo00Gooooo0_l00?l6ooooo`03o`00oooooooo003o00Kooooo00?o003o
ooooooooool01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`0Mooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0MOoo
ool00ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`03ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01Oooool2o`00o`Kooooo00?o003oooooool00?l01_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o3Ooo
ool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool01Oooool01?l00?oo
ooooooooool00?mgooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo00?o
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool2o`00o`Oo
oooo0_l00?lAooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooooooo`05ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`05oooo
o`05o`00ooooooooooooooooool00?l07Oooool00ol0003oooooooooo`05ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`1^ooooo`03o`000?oooooooooo00?ooooo
000Cooooo`;o00003Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Kooooo00?o
003oooooool00?l01Oooool00ol00?ooooooooooo`05ooooo`04o`00ooooooooooooo`00o`Gooooo
00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`0Oooooo`03o`000?oooooooooo00Go
oooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o06gooooo0_l00005
ooooo`004oooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`06ooooo`;o003o1_ooool00ol00?ooooooo`00o`05oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o01gooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`05ooooo`05o`00
ooooooooooooooooool00?l0K_ooool00ol0003oooooooooo`03ooooo`004oooool00ol0003ooooo
ooooo`0<ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool2o`00o`Oooooo
00?o003oooooooooool01Oooool2o`00o`Kooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o01gooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`1fooooo`03
o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo01Cooooo00?o003oooooooooool0
1Oooool2o`00o`Oooooo00?o003oooooooooool01Oooool2o`00o`Kooooo00?o003oooooool00?l0
3_ooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`0Kooooo`03o`000?oooooooooo00Oooooo00?o003ooooooooo
ool0M_ooool00ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`0Dooooo`03o`00
oooooooooooo00Gooooo0_l00?l7ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0
1?ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo
003o1Oooool00ol00?ooooooooooo`05ooooo`05o`00ooooooooooooooooool00?l07Oooool00ol0
003oooooooooo`05ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`1^
ooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo01gooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ool00?l01_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Gooooo00Co003ooooo
oooooooo003o1Oooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo01oooooo00?o
0000ooooooooool01Oooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l0
K_ooool00ol0003oooooooooo`03ooooo`004oooool2o`0002Kooooo00?o003oooooooooool01Ooo
ool2o`00o`Kooooo00?o003oooooool00?l01_ooool2o`00o`Kooooo00?o003oooooool00?l01Ooo
ool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooo
oooo003o7_ooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00Co003ooooo
oooooooo003oK_ooool2o`0000Gooooo000Cooooo`03o`000?oooooooooo01cooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool00ol00?ooooooooooo`06oooo
o`;o003o2?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00?ooooo00Co003ooooo
oooooooo003o7_ooool00ol0003oooooooooo`0=ooooo`04o`00ooooooooooooo`00ofoooooo00?o
0000ooooooooool00oooool000[ooooo1Ol00004ooooo`03o`000?oooooooooo01cooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool2o`00oa7ooooo00?o003o
ooooooooool03?ooool00ol00?ooooooo`00o`08ooooo`03o`00oooooooooooo01cooooo00?o0000
ooooooooool01oooool00ol00?ooooooooooo`1fooooo`03o`000?oooooooooo00?ooooo000;oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool07?ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool07?ooool00ol0003oooooooooo`05
ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003oKoooool00ol0003ooooooooo
o`03ooooo`003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Gooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo0_l00?l6
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooooooo01oooooo00?o0000ooooooooool01Oooool2o`00o`Kooooo00Co003o
oooooooooooo003oKoooool00ol0003oooooooooo`03ooooo`003Oooool00ol0003oooooooooo`03
ooooo`?o00009Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo0_l00?l7
ooooo`;o003o1_ooool2o`00o`Kooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooooooo01oooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`05
ooooo`04o`00ooooooooooooo`00ofkooooo0_l00005ooooo`002_ooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool09Oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool01_ooool2o`00o`Oooooo00?o003oooooooooool03ooo
ool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00oakooooo00?o0000ooooooooool0
1Oooool00ol00?ooooooooooo`05ooooo`04o`00ooooooooooooo`00ofoooooo00?o0000oooooooo
ool00oooool000[ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo02go
oooo00?o003oooooooooool01Oooool2o`00oa3ooooo00?o003oooooooooool03Oooool00ol00?oo
ooooo`00o`08ooooo`03o`00oooooooooooo01cooooo00?o0000ooooooooool01_ooool00ol00?oo
ooooooooo`1gooooo`03o`000?oooooooooo00?ooooo000;ooooo`?o00001Oooool00ol0003ooooo
ooooo`0]ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`05ooooo`;o003o1_ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool07Oooool00ol0003oooooooooo`05ooooo`;o003o1_ooool00ol00?oooooo
o`00o`1`ooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo03Kooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooool00?l01_ooool2o`00o`Kooooo00?o003oooooooooool07oooool00ol0003ooooooooo
o`05ooooo`;o003o1_ooool00ol00?ooooooo`00o`1`ooooo`03o`000?oooooooooo00?ooooo000C
ooooo`;o0000=_ooool2o`00o`Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooo003o00Kooooo0_l00?l6ooooo`03o`00oooooooooooo01oooooo00?o0000
ooooooooool01Oooool2o`00o`Kooooo00?o003oooooool00?l0Koooool2o`0000Gooooo000Coooo
o`03o`000?oooooooooo03Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05oooo
o`;o003o2?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ool00?l07oooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ool00?l0L?ooool00ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`0eooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooool00?l07oooool00ol0003oooooooooo`06ooooo`03
o`00oooooooooooo07Oooooo00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool0
A_ooool2o`00o`Kooooo0_l00?l7ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
7Oooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo07Sooooo00?o0000ooooooooool0
0oooool001?ooooo00?o0000ooooooooool0?_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Gooooo0_l00?l7ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l07ooo
ool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l0L?oo
ool00ol0003oooooooooo`03ooooo`004oooool2o`0003oooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`05ooooo`;o003o1oooool2o`00o`Kooooo00?o003oooooooooool07oooool0
0ol0003oooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l0Koooool2
o`0000Gooooo000Cooooo`03o`000?oooooooooo04Kooooo00?o003oooooooooool01Oooool2o`00
o`Sooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`0Oooooo`03o`000?oooooooooo
00Gooooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`1`ooooo`03o`000?oooooooooo
00?ooooo000Cooooo`03o`000?oooooooooo04Kooooo00?o003oooooooooool03oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooo003o01oooooo00?o0000ooooooooool0P?ooool00ol0003o
ooooooooo`03ooooo`004oooool00ol0003oooooooooo`16ooooo`03o`00oooooooooooo00Gooooo
0_l00?l7ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool07_ooool00ol0003ooooo
ooooo`20ooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo04kooooo0_l0
0?l7ooooo`03o`00oooooooooooo00Gooooo0_l00?lPooooo`03o`000?oooooooooo00gooooo0_l0
0?maooooo`03o`000?oooooooooo00?ooooo000Cooooo`;o0000Coooool2o`00o`Oooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0Oooooo`03o`000?oooooooooo00gooooo0_l00?m`
ooooo`;o00001Oooool001?ooooo00?o0000ooooooooool0C_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Gooooo0_l00?lPooooo`03o`000?oooooooooo00gooooo0_l00?maoooo
o`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo05Oooooo00?o003ooooooooo
ool01Oooool2o`00ob3ooooo00?o0000ooooooooool03Oooool2o`00og7ooooo00?o0000oooooooo
ool00oooool001?ooooo00?o0000ooooooooool0Eoooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo01kooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`03ooooo`004ooo
ool00ol0003oooooooooo`1Gooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool07_oo
ool00ol0003oooooooooo`0=ooooo`;o003oLOooool00ol0003oooooooooo`03ooooo`004oooool0
0ol0003oooooooooo`1Gooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool07oooool0
0ol0003oooooooooo`0=ooooo`;o003oLOooool00ol0003oooooooooo`03ooooo`004oooool2o`00
063ooooo00?o003oooooooooool07oooool00ol0003oooooooooo`0=ooooo`03o`00oooooooooooo
06oooooo0_l00005ooooo`004oooool00ol0003oooooooooo`1Oooooo`03o`00oooooooooooo01oo
oooo00?o0000ooooooooool03Oooool00ol00?ooooooooooo`1`ooooo`03o`000?oooooooooo00?o
oooo000;ooooo`?o00001Oooool00ol0003oooooooooo`1Oooooo`03o`00oooooooooooo01oooooo
00?o0000ooooooooool0P?ooool00ol0003oooooooooo`03ooooo`002_ooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool0Goooool00ol00?ooooooooooo`0Oooooo`03o`00
0?oooooooooo083ooooo00?o0000ooooooooool00oooool000kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool00ooo
ool000cooooo0_l00005ooooo`?o0000POooool00ol0003oooooooooo`1oooooo`;o00001Oooool0
00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`03ooooo`002_ooool01Ol0003o
oooooooooooooooo000000Coooooool00009o`0000Gooooo000;ooooo`?o0000oooooolCooooo`00
oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-6.02802, -3.57023, \
0.039899, 0.0381025}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Show all", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{{g3, g4}, {g6, g8}}], \ 
        ImageSize \[Rule] 504];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 504 311.489 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.0147151 0.0391184 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09295 -6 -4.5 ]
[-0.0125 .09295 0 4.5 ]
[-0.0125 .17119 -6 -4.5 ]
[-0.0125 .17119 0 4.5 ]
[-0.0125 .24943 -6 -4.5 ]
[-0.0125 .24943 0 4.5 ]
[-0.0125 .32766 -6 -4.5 ]
[-0.0125 .32766 0 4.5 ]
[-0.0125 .4059 -12 -4.5 ]
[-0.0125 .4059 0 4.5 ]
[-0.0125 .48414 -12 -4.5 ]
[-0.0125 .48414 0 4.5 ]
[-0.0125 .56237 -12 -4.5 ]
[-0.0125 .56237 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09295 m
.00625 .09295 L
s
[(2)] -0.0125 .09295 1 0 Mshowa
0 .17119 m
.00625 .17119 L
s
[(4)] -0.0125 .17119 1 0 Mshowa
0 .24943 m
.00625 .24943 L
s
[(6)] -0.0125 .24943 1 0 Mshowa
0 .32766 m
.00625 .32766 L
s
[(8)] -0.0125 .32766 1 0 Mshowa
0 .4059 m
.00625 .4059 L
s
[(10)] -0.0125 .4059 1 0 Mshowa
0 .48414 m
.00625 .48414 L
s
[(12)] -0.0125 .48414 1 0 Mshowa
0 .56237 m
.00625 .56237 L
s
[(14)] -0.0125 .56237 1 0 Mshowa
.125 Mabswid
0 .03427 m
.00375 .03427 L
s
0 .05383 m
.00375 .05383 L
s
0 .07339 m
.00375 .07339 L
s
0 .11251 m
.00375 .11251 L
s
0 .13207 m
.00375 .13207 L
s
0 .15163 m
.00375 .15163 L
s
0 .19075 m
.00375 .19075 L
s
0 .21031 m
.00375 .21031 L
s
0 .22987 m
.00375 .22987 L
s
0 .26898 m
.00375 .26898 L
s
0 .28854 m
.00375 .28854 L
s
0 .3081 m
.00375 .3081 L
s
0 .34722 m
.00375 .34722 L
s
0 .36678 m
.00375 .36678 L
s
0 .38634 m
.00375 .38634 L
s
0 .42546 m
.00375 .42546 L
s
0 .44502 m
.00375 .44502 L
s
0 .46458 m
.00375 .46458 L
s
0 .5037 m
.00375 .5037 L
s
0 .52325 m
.00375 .52325 L
s
0 .54281 m
.00375 .54281 L
s
0 .58193 m
.00375 .58193 L
s
0 .60149 m
.00375 .60149 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09295 m
1 .09295 L
s
.99375 .17119 m
1 .17119 L
s
.99375 .24943 m
1 .24943 L
s
.99375 .32766 m
1 .32766 L
s
.99375 .4059 m
1 .4059 L
s
.99375 .48414 m
1 .48414 L
s
.99375 .56237 m
1 .56237 L
s
.125 Mabswid
.99625 .03427 m
1 .03427 L
s
.99625 .05383 m
1 .05383 L
s
.99625 .07339 m
1 .07339 L
s
.99625 .11251 m
1 .11251 L
s
.99625 .13207 m
1 .13207 L
s
.99625 .15163 m
1 .15163 L
s
.99625 .19075 m
1 .19075 L
s
.99625 .21031 m
1 .21031 L
s
.99625 .22987 m
1 .22987 L
s
.99625 .26898 m
1 .26898 L
s
.99625 .28854 m
1 .28854 L
s
.99625 .3081 m
1 .3081 L
s
.99625 .34722 m
1 .34722 L
s
.99625 .36678 m
1 .36678 L
s
.99625 .38634 m
1 .38634 L
s
.99625 .42546 m
1 .42546 L
s
.99625 .44502 m
1 .44502 L
s
.99625 .46458 m
1 .46458 L
s
.99625 .5037 m
1 .5037 L
s
.99625 .52325 m
1 .52325 L
s
.99625 .54281 m
1 .54281 L
s
.99625 .58193 m
1 .58193 L
s
.99625 .60149 m
1 .60149 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .01472 m
.02847 .03212 L
.03089 .03996 L
.03218 .04355 L
.03355 .04687 L
.03484 .04946 L
.03602 .05133 L
.03659 .05205 L
.0372 .05271 L
.03779 .0532 L
.03832 .05353 L
.03862 .05367 L
.03888 .05377 L
.03903 .05381 L
.03919 .05385 L
.03935 .05387 L
.03949 .05389 L
.03963 .0539 L
.03977 .0539 L
.03989 .05389 L
.04002 .05388 L
.04016 .05386 L
.04031 .05383 L
.04058 .05375 L
.04088 .05364 L
.04119 .05347 L
.04177 .05309 L
.04245 .05246 L
.04307 .05175 L
.04426 .04998 L
.04537 .0479 L
.04787 .04177 L
.05032 .03419 L
.05261 .02602 L
.05368 .02199 L
.0548 .01765 L
.05509 .01655 L
.05539 .01536 L
.05548 .01501 L
.05556 .01475 L
.05572 .01537 L
.05603 .01658 L
.05716 .02096 L
.0618 .03761 L
.06415 .04444 L
.0654 .04745 L
.06674 .05013 L
.06802 .05211 L
.06919 .05341 L
.06976 .05385 L
Mistroke
.07005 .05403 L
.07037 .05419 L
.07053 .05425 L
.07068 .0543 L
.07082 .05434 L
.07095 .05438 L
.07108 .0544 L
.07121 .05442 L
.07134 .05443 L
.07149 .05443 L
.07165 .05443 L
.07179 .05442 L
.07187 .05441 L
.07195 .05439 L
.07212 .05436 L
.07227 .05432 L
.07243 .05426 L
.07272 .05414 L
.07331 .05379 L
.07385 .05336 L
.07508 .05196 L
.07637 .04989 L
.07876 .04459 L
.08097 .03815 L
.08324 .0304 L
.08569 .0211 L
.08634 .01853 L
.0867 .01711 L
.08703 .01579 L
.08718 .01521 L
.08732 .01477 L
.08747 .0154 L
.08762 .01598 L
.08827 .01855 L
.0907 .02802 L
.09532 .04357 L
.0977 .04949 L
.0989 .05178 L
.09955 .05279 L
.10023 .0537 L
.10081 .05433 L
.10145 .05487 L
.10173 .05506 L
.10203 .05522 L
.10231 .05535 L
.10256 .05544 L
.10272 .05548 L
.10289 .05551 L
.10297 .05552 L
.10306 .05553 L
Mistroke
.10314 .05554 L
.10324 .05554 L
.10332 .05554 L
.10341 .05554 L
.1035 .05553 L
.10357 .05553 L
.10372 .0555 L
.10388 .05547 L
.10404 .05543 L
.1042 .05537 L
.10451 .05524 L
.10508 .0549 L
.10567 .05441 L
.10622 .05383 L
.10748 .05206 L
.10871 .04978 L
.11002 .04676 L
.11502 .0308 L
.11623 .02614 L
.11751 .021 L
.11804 .01884 L
.11861 .01651 L
.11877 .01586 L
.11886 .0155 L
.11894 .01517 L
.11908 .01485 L
.11924 .01549 L
.11982 .01791 L
.12445 .03607 L
.12671 .04364 L
.12916 .05026 L
.1305 .05304 L
.13174 .05501 L
.13235 .05577 L
.13292 .05635 L
.13351 .05681 L
.13383 .05699 L
.13401 .05708 L
.13417 .05714 L
.13431 .0572 L
.13447 .05724 L
.13456 .05726 L
.13464 .05728 L
.1348 .0573 L
.13494 .05731 L
.13509 .05732 L
.13524 .05731 L
.13539 .0573 L
.13547 .05729 L
.13556 .05727 L
Mistroke
.13573 .05723 L
.13603 .05713 L
.13639 .05696 L
.13672 .05676 L
.13728 .05631 L
.1379 .05567 L
.13915 .05391 L
.14037 .0516 L
.14149 .049 L
.144 .04163 L
.14649 .03267 L
.14879 .0233 L
.14934 .02096 L
.14994 .01841 L
.15021 .01723 L
.1505 .01598 L
.15062 .01546 L
.15075 .01491 L
.15089 .01513 L
.15102 .0157 L
.15227 .02109 L
.1534 .02593 L
.15579 .03567 L
.15838 .04504 L
.16088 .05225 L
.16207 .05493 L
.16319 .05695 L
.16427 .05843 L
.16488 .05905 L
.16544 .05947 L
.16574 .05964 L
.16602 .05976 L
.16617 .05982 L
.16632 .05986 L
.1664 .05988 L
.16649 .0599 L
.16665 .05992 L
.1668 .05993 L
.16689 .05993 L
.16697 .05993 L
.16706 .05993 L
.16713 .05992 L
.16722 .05991 L
.16731 .05989 L
.16746 .05986 L
.1676 .05982 L
.16792 .0597 L
.16824 .05953 L
.16854 .05933 L
.1692 .05875 L
Mistroke
.16978 .05808 L
.1704 .05722 L
.17265 .05274 L
.17379 .0497 L
.17502 .04592 L
.17723 .03794 L
.17962 .02797 L
.18088 .02233 L
.18158 .01917 L
.18191 .01762 L
.18222 .01618 L
.18237 .01551 L
.1825 .01489 L
.18264 .01519 L
.1828 .0159 L
.18341 .01877 L
.18472 .02483 L
.18703 .03512 L
.1893 .0443 L
.19175 .05268 L
.19309 .05639 L
.19433 .05919 L
.19551 .06126 L
.1961 .06206 L
.19676 .06277 L
.19706 .06302 L
.19739 .06325 L
.1977 .06343 L
.19785 .06349 L
.19798 .06354 L
.19812 .06359 L
.19824 .06362 L
.19838 .06364 L
.19853 .06366 L
.19866 .06367 L
.19881 .06366 L
.19896 .06365 L
.19911 .06363 L
.19926 .06359 L
.19943 .06354 L
.19974 .06341 L
.20005 .06324 L
.20032 .06304 L
.20096 .06245 L
.20163 .06163 L
.20276 .05975 L
.20398 .05708 L
.20619 .05067 L
.20857 .04175 L
.21116 .03018 L
Mistroke
.21237 .02435 L
.21303 .02108 L
.21365 .01795 L
.21393 .01652 L
.21408 .01574 L
.21423 .01501 L
.21438 .01522 L
.21447 .01564 L
.21456 .01609 L
.21486 .01762 L
.21595 .0232 L
.22094 .04686 L
.22344 .0564 L
.22454 .05988 L
.22575 .06312 L
.22691 .06559 L
.22799 .06733 L
.22859 .06803 L
.22914 .06851 L
.22942 .0687 L
.22974 .06886 L
.2299 .06892 L
.23007 .06897 L
.23015 .06899 L
.23023 .069 L
.23037 .06902 L
.23051 .06903 L
.23066 .06903 L
.2308 .06901 L
.23093 .06899 L
.23108 .06895 L
.23125 .0689 L
.23155 .06876 L
.23186 .06857 L
.23219 .06831 L
.23279 .06769 L
.23339 .06688 L
.23396 .06594 L
.23501 .06375 L
.23744 .05666 L
.23967 .04788 L
.24214 .0361 L
.24334 .02975 L
.24444 .02373 L
.24498 .02067 L
.24527 .01904 L
.24558 .01731 L
.24584 .01579 L
.24599 .01493 L
.24614 .01532 L
Mistroke
.24627 .01606 L
.24639 .01674 L
.24665 .01828 L
.24903 .03182 L
.25151 .04526 L
.25381 .05637 L
.25618 .06577 L
.25734 .06946 L
.25841 .07226 L
.2596 .07463 L
.26023 .07555 L
.26055 .07594 L
.26089 .07629 L
.26118 .07653 L
.26144 .0767 L
.26157 .07677 L
.26171 .07684 L
.26183 .07689 L
.26196 .07693 L
.2621 .07696 L
.26225 .07698 L
.2624 .07699 L
.26249 .07699 L
.26257 .07698 L
.2627 .07696 L
.26284 .07693 L
.26299 .07689 L
.26313 .07683 L
.26345 .07666 L
.26374 .07645 L
.2644 .07578 L
.26498 .07497 L
.2656 .07389 L
.26666 .07149 L
.26784 .06808 L
.27018 .05904 L
.2727 .0464 L
.27508 .03231 L
.27634 .02426 L
.27702 .01973 L
.27736 .01749 L
.27751 .0165 L
.27759 .01597 L
.27767 .01541 L
.27783 .01508 L
.27798 .01606 L
.2783 .01823 L
.27898 .02279 L
.28016 .03074 L
.28247 .04585 L
Mistroke
.28486 .06022 L
.28746 .0734 L
.28867 .07841 L
.28996 .0828 L
.29106 .08574 L
.29163 .08696 L
.29227 .08804 L
.29286 .08881 L
.29318 .08912 L
.29349 .08934 L
.29363 .08942 L
.29377 .08948 L
.29389 .08953 L
.29403 .08957 L
.29417 .08959 L
.29433 .08961 L
.29446 .0896 L
.2946 .08958 L
.29468 .08956 L
.29477 .08954 L
.29493 .08948 L
.29509 .08941 L
.29523 .08932 L
.29556 .08907 L
.2959 .08872 L
.29654 .08783 L
.29712 .08678 L
.29833 .08377 L
.29945 .08007 L
.30196 .06865 L
.30424 .055 L
.30673 .03714 L
.30795 .02763 L
.30854 .02281 L
.30909 .01829 L
.30925 .01698 L
.3094 .01574 L
.30956 .01498 L
.30964 .01566 L
.30973 .0164 L
.31041 .02217 L
.31162 .03231 L
.31659 .07217 L
.31907 .08872 L
.32028 .09548 L
.32138 .10074 L
.32245 .10501 L
.32361 .10857 L
.32424 .11004 L
.32483 .11108 L
Mistroke
.32512 .11147 L
.32539 .11177 L
.32567 .11202 L
.32582 .11211 L
.32598 .1122 L
.32613 .11225 L
.32621 .11227 L
.32629 .11228 L
.32645 .11229 L
.32654 .11229 L
.32662 .11228 L
.32676 .11225 L
.32691 .11219 L
.32706 .11211 L
.32721 .11201 L
.32755 .11171 L
.32785 .11133 L
.32854 .11016 L
.32914 .10877 L
.32979 .10687 L
.33097 .10238 L
.33211 .09677 L
.33337 .08922 L
.3359 .06985 L
.33845 .04569 L
.33965 .0329 L
.34077 .02044 L
.34091 .01888 L
.34106 .01717 L
.3412 .01556 L
.34133 .01536 L
.34148 .01711 L
.34164 .01896 L
.34192 .02224 L
.34317 .03704 L
.34545 .06424 L
.35004 .11522 L
.35259 .13823 L
.35492 .1539 L
.35607 .15942 L
.35673 .1618 L
.35733 .1635 L
.35786 .16458 L
.35816 .16502 L
.35844 .16532 L
.35858 .16543 L
.35873 .16552 L
.35886 .16556 L
.35901 .16559 L
.35916 .16558 L
Mistroke
.35924 .16556 L
.35932 .16553 L
.35947 .16545 L
.35962 .16535 L
.35975 .16521 L
.3599 .16504 L
.36018 .16464 L
.3605 .16401 L
.36079 .16331 L
.36143 .16131 L
.36203 .15884 L
.3631 .15306 L
.36426 .1447 L
.36664 .12079 L
.36917 .08562 L
.37033 .06641 L
.37155 .04416 L
.37205 .0344 L
.37258 .02362 L
.37274 .02037 L
.37289 .01727 L
.37303 .01497 L
.37317 .01804 L
.37372 .02979 L
.37605 .08321 L
.37857 .14597 L
.3835 .27663 L
.38824 .39861 L
.39281 .49801 L
.39515 .53827 L
.39767 .57152 L
.39889 .58355 L
.39953 .58878 L
.40022 .59348 L
.40088 .59714 L
.40148 .59973 L
.40177 .60073 L
.40208 .60163 L
.40237 .6023 L
.40264 .60277 L
.4028 .60297 L
.40294 .60312 L
.40307 .60322 L
.40321 .60329 L
.40336 .60332 L
.40344 .60332 L
.40353 .6033 L
.40368 .60324 L
.40382 .60314 L
.40395 .60301 L
Mistroke
.40409 .60284 L
.40435 .60243 L
.40462 .60185 L
.40492 .60106 L
.40554 .59884 L
.40621 .59564 L
.40741 .58778 L
.40864 .57695 L
.40998 .56221 L
.41241 .52807 L
.41735 .43456 L
.42211 .32492 L
.42668 .21458 L
.43154 .10539 L
.43379 .06128 L
.43497 .04003 L
.43562 .02903 L
.43594 .02381 L
.43623 .01912 L
.43639 .01655 L
.43647 .01527 L
.43656 .01556 L
.43665 .01695 L
.43675 .01844 L
.43692 .02108 L
.43755 .03033 L
.43878 .04697 L
.44121 .07422 L
.44244 .08519 L
.44378 .09493 L
.44504 .10208 L
.4456 .10464 L
.4462 .10698 L
.44681 .1089 L
.44737 .11029 L
.44764 .11083 L
.44793 .11133 L
.4482 .11172 L
.44846 .11201 L
.44862 .11215 L
.44879 .11228 L
.44894 .11237 L
.44908 .11243 L
.44924 .11247 L
.44933 .11248 L
.44941 .11249 L
.44949 .11248 L
.44957 .11247 L
.44966 .11246 L
.44975 .11243 L
Mistroke
.44989 .11238 L
.45005 .11229 L
.45032 .11209 L
.45062 .11179 L
.45095 .11136 L
.45154 .11034 L
.45216 .10894 L
.45328 .10566 L
.45448 .10109 L
.45579 .09503 L
.46068 .06562 L
.46539 .03328 L
.46663 .02506 L
.46728 .02085 L
.46763 .01859 L
.46796 .01651 L
.46811 .01559 L
.46825 .01472 L
.46833 .01519 L
.46842 .01571 L
.46857 .01661 L
.46923 .02054 L
.47039 .02711 L
.47297 .03976 L
.4753 .04872 L
.47647 .05226 L
.47773 .05536 L
.47893 .05757 L
.48002 .05901 L
.48059 .05954 L
.4809 .05977 L
.4812 .05994 L
.48147 .06007 L
.48162 .06012 L
.48177 .06017 L
.4819 .0602 L
.48205 .06023 L
.48218 .06024 L
.4823 .06025 L
.48244 .06025 L
.4826 .06024 L
.48268 .06023 L
.48277 .06022 L
.48292 .06019 L
.48308 .06015 L
.48322 .0601 L
.4835 .05999 L
.48382 .05982 L
.48412 .05962 L
.48479 .05905 L
Mistroke
.48596 .05765 L
.48706 .0559 L
.48955 .05052 L
.49423 .03627 L
.49662 .02765 L
.49788 .0229 L
.49857 .02025 L
.49922 .01775 L
.49949 .01668 L
.49978 .01555 L
.49994 .01496 L
.50002 .01481 L
.5001 .01512 L
.5004 .01626 L
.50171 .0213 L
.50401 .03 L
.50872 .04577 L
.51129 .05252 L
.51247 .05502 L
.51372 .05718 L
.51486 .05869 L
.51551 .05933 L
.51583 .05958 L
.51613 .05979 L
.51639 .05994 L
.51669 .06007 L
.51681 .06011 L
.51695 .06016 L
.51708 .06019 L
.5172 .06021 L
.51735 .06024 L
.51743 .06024 L
.51751 .06025 L
.51765 .06025 L
.5178 .06024 L
.51794 .06023 L
.51808 .0602 L
.51822 .06017 L
.51835 .06013 L
.51863 .06003 L
.51893 .05987 L
.51955 .05943 L
.52012 .05886 L
.52065 .05819 L
.52186 .05619 L
.52316 .05326 L
.52557 .04566 L
.52812 .03476 L
.52936 .02846 L
.53053 .02197 L
Mistroke
.53104 .019 L
.53131 .01733 L
.53158 .01576 L
.53171 .01493 L
.53186 .0154 L
.53194 .01591 L
.53202 .0164 L
.53217 .01733 L
.53271 .02078 L
.53508 .03647 L
.53761 .05392 L
.54222 .08414 L
.54479 .09788 L
.54601 .10308 L
.54713 .10697 L
.5483 .11001 L
.54891 .11115 L
.54922 .11159 L
.54956 .11198 L
.54972 .11212 L
.54986 .11223 L
.54999 .11232 L
.55013 .11239 L
.55029 .11244 L
.55043 .11247 L
.55058 .11249 L
.55067 .11248 L
.55075 .11247 L
.55088 .11244 L
.55103 .11238 L
.55115 .11232 L
.55128 .11223 L
.55158 .11197 L
.55185 .11165 L
.55246 .11063 L
.55281 .10988 L
.55313 .10907 L
.55433 .10496 L
.55542 .09974 L
.55657 .09264 L
.55893 .07283 L
.56114 .04789 L
.5624 .03094 L
.5627 .02661 L
.56302 .02188 L
.5633 .01775 L
.56345 .01536 L
.5636 .01634 L
.56373 .01841 L
.56387 .0206 L
Mistroke
.56411 .02458 L
.56467 .0338 L
.56583 .05427 L
.57043 .14774 L
.57531 .2624 L
.58002 .3754 L
.58502 .48298 L
.58753 .52714 L
.58984 .56004 L
.59209 .58372 L
.59323 .59226 L
.59387 .59603 L
.59447 .5989 L
.59506 .60099 L
.59539 .60188 L
.5957 .60251 L
.59585 .60275 L
.59598 .60294 L
.59611 .60308 L
.59624 .60319 L
.59638 .60327 L
.59652 .60331 L
.59666 .60332 L
.59682 .60328 L
.5969 .60324 L
.59699 .60318 L
.59715 .60304 L
.5973 .60285 L
.59745 .60263 L
.59777 .60199 L
.59812 .60108 L
.5987 .59904 L
.59934 .59603 L
.60056 .5881 L
.60167 .57835 L
.60419 .54805 L
.60647 .51124 L
.60897 .46218 L
.61386 .34592 L
.61858 .22121 L
.62098 .15772 L
.62358 .09202 L
.6248 .06298 L
.62547 .04769 L
.62609 .0338 L
.62663 .02229 L
.62678 .01904 L
.62692 .01598 L
.62705 .01618 L
.6272 .01913 L
Mistroke
.62841 .04327 L
.63099 .08813 L
.63332 .12032 L
.63449 .13329 L
.63576 .14483 L
.63695 .15337 L
.63805 .1592 L
.63862 .16148 L
.63893 .16251 L
.63923 .16335 L
.6395 .16401 L
.6398 .1646 L
.64007 .16501 L
.64032 .16529 L
.64047 .16541 L
.64062 .1655 L
.64077 .16556 L
.6409 .16559 L
.64106 .16558 L
.64114 .16556 L
.64123 .16554 L
.64138 .16546 L
.64146 .16541 L
.64153 .16535 L
.64185 .16501 L
.64203 .16476 L
.6422 .16449 L
.64282 .16312 L
.64338 .16143 L
.64399 .15914 L
.64509 .15387 L
.64758 .13687 L
.65014 .11345 L
.65257 .08731 L
.65476 .0617 L
.65601 .04677 L
.65719 .03277 L
.65775 .02617 L
.65834 .01928 L
.65848 .01756 L
.65864 .01571 L
.65873 .01477 L
.65882 .01573 L
.65898 .01759 L
.65957 .0243 L
.66211 .05128 L
.66461 .07423 L
.66693 .09111 L
.66809 .09785 L
.66918 .10302 L
Mistroke
.67031 .10721 L
.67092 .10893 L
.67156 .11038 L
.67187 .11092 L
.6722 .1114 L
.67251 .11176 L
.67279 .11201 L
.67296 .11212 L
.67312 .1122 L
.6732 .11223 L
.67329 .11226 L
.67338 .11228 L
.67347 .11229 L
.67356 .11229 L
.67363 .11229 L
.67378 .11227 L
.67387 .11225 L
.67394 .11222 L
.67412 .11215 L
.67426 .11207 L
.67441 .11196 L
.67468 .11171 L
.675 .11132 L
.67529 .11089 L
.6759 .10974 L
.67654 .10818 L
.6777 .10449 L
.67893 .09938 L
.68114 .08743 L
.68615 .05088 L
.68737 .04079 L
.68867 .02993 L
.68977 .02064 L
.69007 .0181 L
.69024 .01671 L
.69039 .0154 L
.69054 .01525 L
.6907 .01658 L
.69098 .01888 L
.69562 .05408 L
.698 .06846 L
.69922 .07454 L
.70054 .08001 L
.70176 .08403 L
.7023 .08546 L
.70288 .08678 L
.7034 .08774 L
.70395 .08855 L
.70426 .08889 L
.70454 .08915 L
Mistroke
.70482 .08935 L
.70509 .08949 L
.70522 .08954 L
.70537 .08958 L
.70551 .0896 L
.70564 .08961 L
.70579 .0896 L
.70588 .08959 L
.70596 .08957 L
.7061 .08953 L
.70626 .08947 L
.70642 .08939 L
.70659 .08929 L
.70691 .08904 L
.70749 .08838 L
.70806 .08752 L
.70865 .08638 L
.70972 .08375 L
.71086 .08012 L
.71209 .07537 L
.7143 .06482 L
.71669 .05111 L
.71929 .03441 L
.7205 .02631 L
.72116 .02183 L
.72149 .01964 L
.72179 .01764 L
.72204 .01591 L
.72217 .01504 L
.72232 .01534 L
.72246 .01629 L
.72261 .01731 L
.72288 .01913 L
.7241 .02706 L
.7265 .04185 L
.7291 .05572 L
.73032 .06121 L
.73161 .06621 L
.73282 .07009 L
.73393 .0729 L
.73506 .07504 L
.73569 .07589 L
.73598 .0762 L
.73629 .07647 L
.73658 .07667 L
.73684 .07681 L
.73696 .07687 L
.7371 .07691 L
.73723 .07695 L
.73734 .07697 L
Mistroke
.73748 .07698 L
.73761 .07699 L
.73775 .07698 L
.7379 .07696 L
.73806 .07692 L
.73821 .07687 L
.7385 .07674 L
.73878 .07656 L
.73905 .07634 L
.73966 .07569 L
.74026 .07485 L
.7409 .07371 L
.74206 .07108 L
.74313 .06805 L
.74541 .0597 L
.74791 .04821 L
.75048 .03457 L
.75281 .02135 L
.75338 .01809 L
.75369 .01632 L
.75384 .01545 L
.75398 .01477 L
.75413 .01563 L
.75429 .01656 L
.75464 .01852 L
.75524 .02193 L
.75753 .03437 L
.76002 .04651 L
.76233 .05585 L
.76457 .06273 L
.7657 .06529 L
.76631 .0664 L
.76695 .06736 L
.76753 .06804 L
.76784 .06833 L
.76817 .06859 L
.76847 .06877 L
.76875 .06889 L
.76888 .06894 L
.76902 .06898 L
.76916 .06901 L
.76928 .06902 L
.76943 .06903 L
.76958 .06903 L
.76973 .06901 L
.76986 .06899 L
.77002 .06895 L
.77019 .06889 L
.7705 .06874 L
.77083 .06854 L
Mistroke
.77117 .06826 L
.7718 .0676 L
.77244 .0667 L
.77304 .06569 L
.77438 .0628 L
.77682 .05553 L
.78158 .03542 L
.78281 .02939 L
.78398 .02353 L
.78503 .01821 L
.78531 .01675 L
.78547 .01595 L
.78562 .0152 L
.78574 .01486 L
.78588 .01555 L
.78617 .017 L
.78852 .02867 L
.79104 .04013 L
.79342 .04933 L
.79467 .0534 L
.79601 .05706 L
.79731 .05988 L
.79849 .06178 L
.79906 .06247 L
.79936 .06277 L
.79967 .06304 L
.79995 .06323 L
.80026 .06341 L
.80039 .06347 L
.80053 .06353 L
.80067 .06357 L
.80079 .06361 L
.80087 .06362 L
.80095 .06364 L
.8011 .06366 L
.80118 .06366 L
.80127 .06367 L
.80143 .06366 L
.80157 .06365 L
.80171 .06363 L
.80186 .06359 L
.80202 .06354 L
.80237 .06339 L
.80271 .06319 L
.80335 .06267 L
.80395 .062 L
.80451 .06123 L
.80577 .05899 L
.80803 .05333 L
.81052 .04499 L
Mistroke
.81306 .03474 L
.81538 .02436 L
.81652 .01907 L
.81684 .01761 L
.81717 .01605 L
.81725 .01569 L
.81734 .0153 L
.81749 .01485 L
.81764 .01554 L
.81777 .01617 L
.82005 .02655 L
.82252 .03694 L
.82482 .04537 L
.82703 .05192 L
.82826 .05478 L
.8294 .0569 L
.82998 .05777 L
.83062 .05856 L
.83127 .05918 L
.83162 .05944 L
.83196 .05964 L
.83225 .05977 L
.8324 .05982 L
.83257 .05987 L
.83271 .0599 L
.83285 .05992 L
.833 .05993 L
.83312 .05993 L
.8332 .05993 L
.83329 .05993 L
.83343 .05991 L
.83352 .0599 L
.8336 .05988 L
.83377 .05984 L
.83407 .05973 L
.83438 .05958 L
.83469 .05938 L
.83502 .05913 L
.8356 .05857 L
.83694 .05675 L
.83821 .05435 L
.83936 .05164 L
.8442 .03573 L
.84642 .0267 L
.84768 .02132 L
.84829 .01867 L
.84885 .01624 L
.84899 .01564 L
.84914 .015 L
.84922 .01477 L
Mistroke
.8493 .01513 L
.84945 .01578 L
.85002 .01822 L
.85126 .02353 L
.85381 .0338 L
.85634 .04276 L
.85866 .04937 L
.85984 .05204 L
.86094 .05405 L
.86208 .05565 L
.86269 .05629 L
.863 .05656 L
.86333 .0568 L
.86364 .05698 L
.86398 .05714 L
.86413 .05719 L
.86428 .05724 L
.86443 .05727 L
.86457 .05729 L
.86465 .0573 L
.86474 .05731 L
.8649 .05732 L
.86499 .05732 L
.86507 .05731 L
.86516 .05731 L
.86526 .05729 L
.86534 .05728 L
.86542 .05727 L
.8656 .05722 L
.86591 .05711 L
.86623 .05696 L
.86652 .05679 L
.86717 .05627 L
.86777 .05563 L
.86834 .0549 L
.86951 .05301 L
.87075 .05046 L
.87298 .04459 L
.87754 .02855 L
.87874 .02376 L
.87989 .01911 L
.88051 .01652 L
.88069 .01581 L
.88078 .01542 L
.88087 .01505 L
.88095 .01472 L
.88104 .01509 L
.8812 .01574 L
.8824 .02066 L
.88476 .02997 L
Mistroke
.88735 .03914 L
.88984 .04643 L
.89212 .05138 L
.89333 .05327 L
.89388 .05395 L
.89447 .05454 L
.89477 .05479 L
.8951 .05502 L
.8954 .0552 L
.89568 .05533 L
.89601 .05544 L
.89618 .05548 L
.89626 .0555 L
.89636 .05552 L
.89651 .05553 L
.89666 .05554 L
.89675 .05554 L
.89684 .05554 L
.89699 .05553 L
.89713 .05551 L
.89728 .05548 L
.89742 .05544 L
.89755 .0554 L
.89787 .05528 L
.89817 .05512 L
.89876 .05471 L
.89941 .0541 L
.90056 .05262 L
.90164 .05082 L
.90412 .04513 L
.90636 .03843 L
.90889 .02957 L
.90999 .02538 L
.9112 .02065 L
.91177 .01841 L
.91208 .01717 L
.91238 .01599 L
.91251 .01546 L
.91265 .0149 L
.91281 .01514 L
.91295 .01571 L
.91347 .01778 L
.91586 .02706 L
.92042 .04236 L
.92276 .04818 L
.92408 .05068 L
.92466 .05159 L
.92528 .05243 L
.9259 .05312 L
.92647 .05363 L
Mistroke
.92674 .05383 L
.92703 .05401 L
.92731 .05416 L
.92757 .05426 L
.92787 .05435 L
.92803 .05439 L
.92812 .0544 L
.9282 .05441 L
.92829 .05442 L
.92837 .05443 L
.92845 .05443 L
.92854 .05443 L
.9287 .05443 L
.92879 .05442 L
.92887 .05441 L
.92902 .05438 L
.92917 .05435 L
.92945 .05426 L
.92974 .05414 L
.93007 .05396 L
.9307 .0535 L
.93131 .05292 L
.93243 .05148 L
.93364 .04943 L
.93496 .04664 L
.93989 .03191 L
.94234 .02285 L
.94296 .02049 L
.94354 .01822 L
.94407 .01618 L
.94421 .01562 L
.94437 .01502 L
.94451 .01497 L
.94464 .01548 L
.94684 .02396 L
.94921 .03257 L
.95173 .04064 L
.95404 .04664 L
.95522 .04905 L
.95631 .05089 L
.95745 .05236 L
.95805 .05294 L
.95837 .05319 L
.9587 .05341 L
.959 .05358 L
.95934 .05372 L
.95948 .05377 L
.95964 .05382 L
.95979 .05385 L
.95993 .05387 L
Mistroke
.96001 .05388 L
.96009 .05389 L
.96024 .0539 L
.96033 .0539 L
.96042 .0539 L
.9605 .05389 L
.96058 .05388 L
.96066 .05387 L
.96075 .05386 L
.96094 .05382 L
.96111 .05377 L
.96126 .05372 L
.96158 .05358 L
.96188 .05342 L
.96243 .05303 L
.96304 .05247 L
.96369 .05171 L
.96482 .05004 L
.96607 .04768 L
.9686 .04141 L
.97345 .0252 L
.97619 .01472 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.05556 .01472 m
.05556 .01472 L
s
.0873 .01472 m
.0873 .01472 L
s
.11905 .01472 m
.11905 .01472 L
s
.15079 .01472 m
.15079 .01472 L
s
.18254 .01472 m
.18254 .01472 L
s
.21429 .01472 m
.21429 .01472 L
s
.24603 .01472 m
.24603 .01472 L
s
.27778 .01472 m
.27778 .01472 L
s
.30952 .01472 m
.30952 .01472 L
s
.34127 .01472 m
.34127 .01472 L
s
.37302 .01472 m
.37302 .01472 L
s
.40476 .01472 m
.40476 .60149 L
s
.43651 .01472 m
.43651 .01472 L
s
.46825 .01472 m
.46825 .01472 L
s
.5 .01472 m
.5 .01472 L
s
.53175 .01472 m
.53175 .01472 L
s
.56349 .01472 m
.56349 .01472 L
s
.59524 .01472 m
.59524 .60149 L
s
.62698 .01472 m
.62698 .01472 L
s
.65873 .01472 m
.65873 .01472 L
s
.69048 .01472 m
.69048 .01472 L
s
.72222 .01472 m
.72222 .01472 L
s
.75397 .01472 m
.75397 .01472 L
s
.78571 .01472 m
.78571 .01472 L
s
.81746 .01472 m
.81746 .01472 L
s
.84921 .01472 m
.84921 .01472 L
s
.88095 .01472 m
.88095 .01472 L
s
.9127 .01472 m
.9127 .01472 L
s
.94444 .01472 m
.94444 .01472 L
s
.97619 .01472 m
.97619 .01472 L
s
.015 w
.05556 .01472 Mdot
.0873 .01472 Mdot
.11905 .01472 Mdot
.15079 .01472 Mdot
.18254 .01472 Mdot
.21429 .01472 Mdot
.24603 .01472 Mdot
.27778 .01472 Mdot
.30952 .01472 Mdot
.34127 .01472 Mdot
.37302 .01472 Mdot
.40476 .60149 Mdot
.43651 .01472 Mdot
.46825 .01472 Mdot
.5 .01472 Mdot
.53175 .01472 Mdot
.56349 .01472 Mdot
.59524 .60149 Mdot
.62698 .01472 Mdot
.65873 .01472 Mdot
.69048 .01472 Mdot
.72222 .01472 Mdot
.75397 .01472 Mdot
.78571 .01472 Mdot
.81746 .01472 Mdot
.84921 .01472 Mdot
.88095 .01472 Mdot
.9127 .01472 Mdot
.94444 .01472 Mdot
.97619 .01472 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309351 0.0997283 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01017 -12 -4.5 ]
[-0.0125 .01017 0 4.5 ]
[-0.0125 .10989 -12 -4.5 ]
[-0.0125 .10989 0 4.5 ]
[-0.0125 .20962 -12 -4.5 ]
[-0.0125 .20962 0 4.5 ]
[-0.0125 .30935 -6 -4.5 ]
[-0.0125 .30935 0 4.5 ]
[-0.0125 .40908 -6 -4.5 ]
[-0.0125 .40908 0 4.5 ]
[-0.0125 .50881 -6 -4.5 ]
[-0.0125 .50881 0 4.5 ]
[-0.0125 .60854 -6 -4.5 ]
[-0.0125 .60854 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01017 m
.00625 .01017 L
s
[(-3)] -0.0125 .01017 1 0 Mshowa
0 .10989 m
.00625 .10989 L
s
[(-2)] -0.0125 .10989 1 0 Mshowa
0 .20962 m
.00625 .20962 L
s
[(-1)] -0.0125 .20962 1 0 Mshowa
0 .30935 m
.00625 .30935 L
s
[(0)] -0.0125 .30935 1 0 Mshowa
0 .40908 m
.00625 .40908 L
s
[(1)] -0.0125 .40908 1 0 Mshowa
0 .50881 m
.00625 .50881 L
s
[(2)] -0.0125 .50881 1 0 Mshowa
0 .60854 m
.00625 .60854 L
s
[(3)] -0.0125 .60854 1 0 Mshowa
.125 Mabswid
0 .03011 m
.00375 .03011 L
s
0 .05006 m
.00375 .05006 L
s
0 .07 m
.00375 .07 L
s
0 .08995 m
.00375 .08995 L
s
0 .12984 m
.00375 .12984 L
s
0 .14979 m
.00375 .14979 L
s
0 .16973 m
.00375 .16973 L
s
0 .18968 m
.00375 .18968 L
s
0 .22957 m
.00375 .22957 L
s
0 .24951 m
.00375 .24951 L
s
0 .26946 m
.00375 .26946 L
s
0 .28941 m
.00375 .28941 L
s
0 .3293 m
.00375 .3293 L
s
0 .34924 m
.00375 .34924 L
s
0 .36919 m
.00375 .36919 L
s
0 .38913 m
.00375 .38913 L
s
0 .42903 m
.00375 .42903 L
s
0 .44897 m
.00375 .44897 L
s
0 .46892 m
.00375 .46892 L
s
0 .48886 m
.00375 .48886 L
s
0 .52875 m
.00375 .52875 L
s
0 .5487 m
.00375 .5487 L
s
0 .56864 m
.00375 .56864 L
s
0 .58859 m
.00375 .58859 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01017 m
1 .01017 L
s
.99375 .10989 m
1 .10989 L
s
.99375 .20962 m
1 .20962 L
s
.99375 .30935 m
1 .30935 L
s
.99375 .40908 m
1 .40908 L
s
.99375 .50881 m
1 .50881 L
s
.99375 .60854 m
1 .60854 L
s
.125 Mabswid
.99625 .03011 m
1 .03011 L
s
.99625 .05006 m
1 .05006 L
s
.99625 .07 m
1 .07 L
s
.99625 .08995 m
1 .08995 L
s
.99625 .12984 m
1 .12984 L
s
.99625 .14979 m
1 .14979 L
s
.99625 .16973 m
1 .16973 L
s
.99625 .18968 m
1 .18968 L
s
.99625 .22957 m
1 .22957 L
s
.99625 .24951 m
1 .24951 L
s
.99625 .26946 m
1 .26946 L
s
.99625 .28941 m
1 .28941 L
s
.99625 .3293 m
1 .3293 L
s
.99625 .34924 m
1 .34924 L
s
.99625 .36919 m
1 .36919 L
s
.99625 .38913 m
1 .38913 L
s
.99625 .42903 m
1 .42903 L
s
.99625 .44897 m
1 .44897 L
s
.99625 .46892 m
1 .46892 L
s
.99625 .48886 m
1 .48886 L
s
.99625 .52875 m
1 .52875 L
s
.99625 .5487 m
1 .5487 L
s
.99625 .56864 m
1 .56864 L
s
.99625 .58859 m
1 .58859 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30935 m
1 .30935 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .466 m
.02847 .42171 L
.03355 .37341 L
.03832 .32805 L
.04291 .28442 L
.0478 .23798 L
.0525 .19328 L
.05373 .18157 L
.05438 .1754 L
.05474 .17202 L
.05507 .16886 L
.05536 .16611 L
.05544 .16531 L
.05552 .16456 L
.05567 .47645 L
.05575 .4757 L
.05584 .47489 L
.05599 .47344 L
.05633 .47016 L
.0575 .45908 L
.06251 .41141 L
.06735 .36548 L
.072 .32129 L
.07694 .27429 L
.0817 .22903 L
.0841 .20626 L
.08514 .19632 L
.08628 .18551 L
.08659 .18261 L
.08691 .17954 L
.08704 .17828 L
.08719 .17692 L
.08734 .48873 L
.08749 .48733 L
.08864 .47645 L
.09116 .45248 L
.09612 .40532 L
.1009 .35991 L
.10549 .31624 L
.11039 .26975 L
.1151 .225 L
.11633 .21327 L
.11767 .20054 L
.11828 .19471 L
.11862 .19151 L
.11878 .18995 L
.11893 .18853 L
.11907 .50053 L
.1192 .49929 L
.11949 .49656 L
Mistroke
.1201 .49076 L
.12471 .44693 L
.12962 .4003 L
.13435 .3554 L
.13937 .3077 L
.14421 .26173 L
.14643 .24064 L
.14769 .22867 L
.14886 .21751 L
.15003 .20646 L
.15036 .20327 L
.15052 .20171 L
.15068 .20026 L
.15082 .51226 L
.15096 .51087 L
.15127 .50793 L
.15381 .48378 L
.15837 .44048 L
.16323 .39437 L
.1679 .35 L
.17287 .30283 L
.17765 .25739 L
.18006 .23448 L
.18112 .2245 L
.18167 .21925 L
.18197 .21638 L
.18225 .2137 L
.1824 .21231 L
.18256 .52413 L
.18265 .52328 L
.18273 .52248 L
.18289 .52097 L
.18347 .51542 L
.18462 .5045 L
.18715 .4805 L
.19177 .43666 L
.19669 .39001 L
.20142 .3451 L
.20597 .30193 L
.20849 .27796 L
.21081 .25596 L
.21308 .23442 L
.21363 .22919 L
.21394 .22631 L
.21409 .22489 L
.21422 .22359 L
.2143 .53615 L
.21439 .53535 L
.21456 .53368 L
.21487 .53075 L
Mistroke
.21547 .52504 L
.22004 .48173 L
.2249 .43562 L
.22958 .39125 L
.23455 .34408 L
.23934 .29865 L
.24176 .27573 L
.24395 .25496 L
.24454 .24939 L
.24518 .24337 L
.24547 .24061 L
.24563 .2391 L
.24578 .23769 L
.2459 .23648 L
.24604 .5485 L
.24619 .54707 L
.24633 .54577 L
.24886 .52179 L
.25366 .47623 L
.25829 .43241 L
.26321 .3858 L
.26795 .34093 L
.2725 .29781 L
.27503 .27385 L
.27614 .26336 L
.27673 .25781 L
.27705 .25477 L
.27735 .25189 L
.2775 .25053 L
.27765 .24908 L
.27773 .24833 L
.27782 .56081 L
.27797 .55935 L
.27853 .55404 L
.27963 .54367 L
.28202 .52102 L
.28689 .47498 L
.29158 .43067 L
.29656 .38359 L
.30135 .33825 L
.30597 .29466 L
.30719 .28308 L
.30835 .27219 L
.30899 .26616 L
.30916 .2645 L
.30935 .26276 L
.3095 .26127 L
.30959 .57373 L
.30968 .57295 L
.31088 .56159 L
Mistroke
.31558 .51722 L
.32058 .47008 L
.32539 .42469 L
.33002 .38105 L
.33495 .33464 L
.3374 .31159 L
.3386 .30031 L
.33969 .28999 L
.34023 .28493 L
.34052 .28225 L
.34082 .2794 L
.34097 .27799 L
.34111 .27666 L
.34124 .27547 L
.34138 .58748 L
.34151 .58625 L
.34164 .58496 L
.34189 .58263 L
.34426 .5604 L
.34883 .51738 L
.35371 .47161 L
.3584 .42761 L
.36339 .38088 L
.36819 .33592 L
.37039 .31538 L
.37164 .30369 L
.37225 .29797 L
.37252 .29546 L
.37266 .29413 L
.37281 .29272 L
.37296 .2913 L
.3731 .60332 L
.37324 .60203 L
.37337 .6008 L
.37396 .59531 L
.37519 .58376 L
.37773 .56012 L
.38236 .5169 L
.3873 .471 L
.39205 .42688 L
.39662 .38456 L
.40148 .33961 L
.40616 .29647 L
.41114 .25075 L
.41593 .20688 L
.42054 .16486 L
.42545 .12037 L
.43017 .07778 L
.43259 .05614 L
.43385 .04479 L
Mistroke
.43519 .03284 L
.43577 .02767 L
.43609 .02482 L
.43625 .02343 L
.4364 .02213 L
.43648 .0214 L
.43657 .33392 L
.43665 .33313 L
.43675 .33226 L
.43708 .32937 L
.43771 .32372 L
.44003 .30321 L
.44488 .26055 L
.44955 .21997 L
.45452 .17742 L
.4593 .13715 L
.4639 .0992 L
.46627 .08 L
.46696 .07452 L
.4676 .06938 L
.46788 .06713 L
.46803 .06591 L
.46818 .06477 L
.46833 .37684 L
.46841 .37619 L
.4685 .37549 L
.4688 .37311 L
.47378 .33423 L
.47858 .29812 L
.4832 .26471 L
.48811 .23061 L
.49285 .19902 L
.49739 .16947 L
.49853 .16217 L
.49915 .15819 L
.49945 .15625 L
.49972 .15448 L
.49988 .15349 L
.50002 .46585 L
.50018 .46485 L
.50035 .46377 L
.50103 .45937 L
.50224 .45163 L
.50717 .41961 L
.51191 .38791 L
.51648 .35627 L
.52134 .32117 L
.52601 .28602 L
.52839 .26767 L
.52965 .25784 L
Mistroke
.53034 .25242 L
.53099 .24729 L
.53129 .24487 L
.53146 .24355 L
.53161 .24232 L
.53169 .24167 L
.53178 .55429 L
.53188 .55352 L
.53196 .55282 L
.53229 .55023 L
.53347 .54077 L
.53578 .52211 L
.54058 .4825 L
.54521 .44361 L
.55012 .40151 L
.55486 .36039 L
.55941 .32039 L
.56175 .29975 L
.56239 .29407 L
.56274 .29098 L
.56306 .28809 L
.5632 .28682 L
.56334 .28562 L
.56349 .59755 L
.56364 .59629 L
.56426 .59069 L
.5689 .5492 L
.57384 .50476 L
.57859 .46169 L
.58316 .42008 L
.58803 .37558 L
.59271 .33259 L
.59769 .28673 L
.60249 .24242 L
.6071 .1997 L
.61201 .15413 L
.61674 .11017 L
.62176 .06337 L
.62428 .03984 L
.62539 .02952 L
.62597 .02405 L
.62629 .02105 L
.6266 .0182 L
.62674 .01687 L
.62689 .01545 L
.62697 .01472 L
.62706 .32721 L
.62721 .32577 L
.62777 .32055 L
.62886 .31033 L
Mistroke
.63126 .28799 L
.63611 .24254 L
.64078 .19876 L
.64575 .15215 L
.65054 .10722 L
.65514 .06397 L
.65636 .05249 L
.65751 .04168 L
.65815 .03569 L
.65832 .03405 L
.65851 .03232 L
.65867 .03084 L
.65875 .3433 L
.65884 .34252 L
.66004 .3312 L
.66473 .28707 L
.66972 .24012 L
.67452 .19487 L
.67914 .15131 L
.68405 .10494 L
.68649 .08191 L
.68769 .07063 L
.68879 .06027 L
.68985 .05021 L
.69011 .04776 L
.69025 .04642 L
.69039 .04515 L
.69055 .35695 L
.69069 .35558 L
.69097 .35291 L
.69334 .33062 L
.69797 .28682 L
.7029 .24022 L
.70765 .19532 L
.71222 .15214 L
.71708 .10615 L
.71932 .08498 L
.7205 .07379 L
.72115 .06765 L
.72176 .06187 L
.72192 .06034 L
.72209 .05872 L
.72218 .05787 L
.72228 .37024 L
.72237 .3694 L
.72246 .36861 L
.72308 .36265 L
.72431 .35103 L
.72674 .32809 L
.73143 .28364 L
Mistroke
.73642 .23637 L
.74123 .19082 L
.74586 .14699 L
.7482 .12482 L
.75078 .10036 L
.75196 .0892 L
.75258 .08335 L
.75323 .07718 L
.7535 .07456 L
.7538 .07176 L
.75388 .07094 L
.75397 .07015 L
.75412 .382 L
.75427 .38063 L
.75442 .37914 L
.75552 .36875 L
.76046 .32194 L
.76521 .27685 L
.76979 .23349 L
.77465 .18732 L
.77934 .14288 L
.78172 .12026 L
.78298 .10832 L
.78432 .09562 L
.78499 .08923 L
.78533 .08609 L
.78547 .08472 L
.78563 .08322 L
.78577 .39516 L
.78591 .39389 L
.7862 .39112 L
.78681 .3853 L
.78912 .3634 L
.79382 .31878 L
.79882 .27135 L
.80363 .22565 L
.80827 .18168 L
.81061 .15943 L
.81319 .1349 L
.81438 .1237 L
.81564 .11165 L
.81626 .10581 L
.81684 .10027 L
.8171 .09786 L
.81724 .09653 L
.81737 .09529 L
.81752 .40712 L
.81766 .40578 L
.81794 .40316 L
.82259 .35902 L
Mistroke
.82753 .31207 L
.8323 .26685 L
.83687 .22337 L
.84175 .17707 L
.84644 .13251 L
.84767 .12086 L
.84831 .11471 L
.84867 .11134 L
.84884 .10969 L
.849 .10818 L
.84914 .10685 L
.84929 .41875 L
.84944 .41734 L
.8496 .4158 L
.85026 .40952 L
.85143 .39844 L
.85632 .35198 L
.86103 .30725 L
.86603 .25971 L
.87085 .2139 L
.87549 .16983 L
.87784 .1475 L
.87909 .13566 L
.87977 .12914 L
.88011 .12592 L
.88043 .12294 L
.88072 .12012 L
.88081 .11931 L
.88089 .11854 L
.88104 .43042 L
.88112 .42964 L
.88121 .42883 L
.88136 .42736 L
.88171 .42406 L
.88288 .41293 L
.88518 .3911 L
.88976 .34753 L
.89464 .30115 L
.89934 .2565 L
.90434 .20904 L
.90684 .18528 L
.90915 .16332 L
.91139 .14198 L
.91194 .13679 L
.91223 .13407 L
.91253 .13121 L
.9126 .13047 L
.91269 .12968 L
.91278 .44212 L
.91286 .44131 L
Mistroke
.91317 .43838 L
.91378 .43264 L
.91879 .38502 L
.92361 .33913 L
.92826 .29499 L
.9332 .24803 L
.93796 .2028 L
.94035 .18007 L
.94253 .15932 L
.94311 .15383 L
.94374 .14785 L
.94403 .14512 L
.94418 .14362 L
.94433 .14221 L
.94446 .45432 L
.94459 .45303 L
.94488 .45029 L
.9474 .42633 L
.95236 .37921 L
.95714 .33383 L
.96173 .29018 L
.96661 .24373 L
.97132 .19901 L
.97619 .1527 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.05556 .30935 m
.05556 .30935 L
s
.0873 .30935 m
.0873 .30935 L
s
.11905 .30935 m
.11905 .30935 L
s
.15079 .30935 m
.15079 .30935 L
s
.18254 .30935 m
.18254 .30935 L
s
.21429 .30935 m
.21429 .30935 L
s
.24603 .30935 m
.24603 .30935 L
s
.27778 .30935 m
.27778 .30935 L
s
.30952 .30935 m
.30952 .30935 L
s
.34127 .30935 m
.34127 .30935 L
s
.37302 .30935 m
.37302 .30935 L
s
.40476 .30935 m
.40476 .30935 L
s
.43651 .30935 m
.43651 .30935 L
s
.46825 .30935 m
.46825 .30935 L
s
.5 .30935 m
.5 .30935 L
s
.53175 .30935 m
.53175 .30935 L
s
.56349 .30935 m
.56349 .30935 L
s
.59524 .30935 m
.59524 .30935 L
s
.62698 .30935 m
.62698 .30935 L
s
.65873 .30935 m
.65873 .30935 L
s
.69048 .30935 m
.69048 .30935 L
s
.72222 .30935 m
.72222 .30935 L
s
.75397 .30935 m
.75397 .30935 L
s
.78571 .30935 m
.78571 .30935 L
s
.81746 .30935 m
.81746 .30935 L
s
.84921 .30935 m
.84921 .30935 L
s
.88095 .30935 m
.88095 .30935 L
s
.9127 .30935 m
.9127 .30935 L
s
.94444 .30935 m
.94444 .30935 L
s
.97619 .30935 m
.97619 .30935 L
s
.015 w
.05556 .30935 Mdot
.0873 .30935 Mdot
.11905 .30935 Mdot
.15079 .30935 Mdot
.18254 .30935 Mdot
.21429 .30935 Mdot
.24603 .30935 Mdot
.27778 .30935 Mdot
.30952 .30935 Mdot
.34127 .30935 Mdot
.37302 .30935 Mdot
.40476 .30935 Mdot
.43651 .30935 Mdot
.46825 .30935 Mdot
.5 .30935 Mdot
.53175 .30935 Mdot
.56349 .30935 Mdot
.59524 .30935 Mdot
.62698 .30935 Mdot
.65873 .30935 Mdot
.69048 .30935 Mdot
.72222 .30935 Mdot
.75397 .30935 Mdot
.78571 .30935 Mdot
.81746 .30935 Mdot
.84921 .30935 Mdot
.88095 .30935 Mdot
.9127 .30935 Mdot
.94444 .30935 Mdot
.97619 .30935 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0328407 0.0147151 0.0392403 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18801 -0.0125 -3 -9 ]
[.18801 -0.0125 3 0 ]
[.35222 -0.0125 -6 -9 ]
[.35222 -0.0125 6 0 ]
[.51642 -0.0125 -6 -9 ]
[.51642 -0.0125 6 0 ]
[.68062 -0.0125 -6 -9 ]
[.68062 -0.0125 6 0 ]
[.84483 -0.0125 -6 -9 ]
[.84483 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .0932 -6 -4.5 ]
[-0.0125 .0932 0 4.5 ]
[-0.0125 .17168 -6 -4.5 ]
[-0.0125 .17168 0 4.5 ]
[-0.0125 .25016 -6 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .32864 -6 -4.5 ]
[-0.0125 .32864 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .4856 -12 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .56408 -12 -4.5 ]
[-0.0125 .56408 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18801 0 m
.18801 .00625 L
s
[(5)] .18801 -0.0125 0 1 Mshowa
.35222 0 m
.35222 .00625 L
s
[(10)] .35222 -0.0125 0 1 Mshowa
.51642 0 m
.51642 .00625 L
s
[(15)] .51642 -0.0125 0 1 Mshowa
.68062 0 m
.68062 .00625 L
s
[(20)] .68062 -0.0125 0 1 Mshowa
.84483 0 m
.84483 .00625 L
s
[(25)] .84483 -0.0125 0 1 Mshowa
.125 Mabswid
.05665 0 m
.05665 .00375 L
s
.08949 0 m
.08949 .00375 L
s
.12233 0 m
.12233 .00375 L
s
.15517 0 m
.15517 .00375 L
s
.22085 0 m
.22085 .00375 L
s
.25369 0 m
.25369 .00375 L
s
.28654 0 m
.28654 .00375 L
s
.31938 0 m
.31938 .00375 L
s
.38506 0 m
.38506 .00375 L
s
.4179 0 m
.4179 .00375 L
s
.45074 0 m
.45074 .00375 L
s
.48358 0 m
.48358 .00375 L
s
.54926 0 m
.54926 .00375 L
s
.5821 0 m
.5821 .00375 L
s
.61494 0 m
.61494 .00375 L
s
.64778 0 m
.64778 .00375 L
s
.71346 0 m
.71346 .00375 L
s
.74631 0 m
.74631 .00375 L
s
.77915 0 m
.77915 .00375 L
s
.81199 0 m
.81199 .00375 L
s
.87767 0 m
.87767 .00375 L
s
.91051 0 m
.91051 .00375 L
s
.94335 0 m
.94335 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .0932 m
.00625 .0932 L
s
[(2)] -0.0125 .0932 1 0 Mshowa
0 .17168 m
.00625 .17168 L
s
[(4)] -0.0125 .17168 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(6)] -0.0125 .25016 1 0 Mshowa
0 .32864 m
.00625 .32864 L
s
[(8)] -0.0125 .32864 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(10)] -0.0125 .40712 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(12)] -0.0125 .4856 1 0 Mshowa
0 .56408 m
.00625 .56408 L
s
[(14)] -0.0125 .56408 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .11282 m
.00375 .11282 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .1913 m
.00375 .1913 L
s
0 .21092 m
.00375 .21092 L
s
0 .23054 m
.00375 .23054 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .30902 m
.00375 .30902 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .50522 m
.00375 .50522 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .5837 m
.00375 .5837 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18801 .61178 m
.18801 .61803 L
s
.35222 .61178 m
.35222 .61803 L
s
.51642 .61178 m
.51642 .61803 L
s
.68062 .61178 m
.68062 .61803 L
s
.84483 .61178 m
.84483 .61803 L
s
.125 Mabswid
.05665 .61428 m
.05665 .61803 L
s
.08949 .61428 m
.08949 .61803 L
s
.12233 .61428 m
.12233 .61803 L
s
.15517 .61428 m
.15517 .61803 L
s
.22085 .61428 m
.22085 .61803 L
s
.25369 .61428 m
.25369 .61803 L
s
.28654 .61428 m
.28654 .61803 L
s
.31938 .61428 m
.31938 .61803 L
s
.38506 .61428 m
.38506 .61803 L
s
.4179 .61428 m
.4179 .61803 L
s
.45074 .61428 m
.45074 .61803 L
s
.48358 .61428 m
.48358 .61803 L
s
.54926 .61428 m
.54926 .61803 L
s
.5821 .61428 m
.5821 .61803 L
s
.61494 .61428 m
.61494 .61803 L
s
.64778 .61428 m
.64778 .61803 L
s
.71346 .61428 m
.71346 .61803 L
s
.74631 .61428 m
.74631 .61803 L
s
.77915 .61428 m
.77915 .61803 L
s
.81199 .61428 m
.81199 .61803 L
s
.87767 .61428 m
.87767 .61803 L
s
.91051 .61428 m
.91051 .61803 L
s
.94335 .61428 m
.94335 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .0932 m
1 .0932 L
s
.99375 .17168 m
1 .17168 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .32864 m
1 .32864 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .56408 m
1 .56408 L
s
.125 Mabswid
.99625 .03434 m
1 .03434 L
s
.99625 .05396 m
1 .05396 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .15206 m
1 .15206 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .23054 m
1 .23054 L
s
.99625 .26978 m
1 .26978 L
s
.99625 .2894 m
1 .2894 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .34826 m
1 .34826 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .44636 m
1 .44636 L
s
.99625 .46598 m
1 .46598 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .52484 m
1 .52484 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .5837 m
1 .5837 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .01472 L
s
.05665 .01472 m
.05665 .01472 L
s
.08949 .01472 m
.08949 .01472 L
s
.12233 .01472 m
.12233 .60332 L
s
.15517 .01472 m
.15517 .01472 L
s
.18801 .01472 m
.18801 .01472 L
s
.22085 .01472 m
.22085 .01472 L
s
.25369 .01472 m
.25369 .01472 L
s
.28654 .01472 m
.28654 .01472 L
s
.31938 .01472 m
.31938 .01472 L
s
.35222 .01472 m
.35222 .01472 L
s
.38506 .01472 m
.38506 .01472 L
s
.4179 .01472 m
.4179 .01472 L
s
.45074 .01472 m
.45074 .01472 L
s
.48358 .01472 m
.48358 .01472 L
s
.51642 .01472 m
.51642 .01472 L
s
.54926 .01472 m
.54926 .01472 L
s
.5821 .01472 m
.5821 .01472 L
s
.61494 .01472 m
.61494 .01472 L
s
.64778 .01472 m
.64778 .01472 L
s
.68062 .01472 m
.68062 .01472 L
s
.71346 .01472 m
.71346 .01472 L
s
.74631 .01472 m
.74631 .01472 L
s
.77915 .01472 m
.77915 .01472 L
s
.81199 .01472 m
.81199 .01472 L
s
.84483 .01472 m
.84483 .01472 L
s
.87767 .01472 m
.87767 .01472 L
s
.91051 .01472 m
.91051 .60332 L
s
.94335 .01472 m
.94335 .01472 L
s
.97619 .01472 m
.97619 .01472 L
s
.015 w
.02381 .01472 Mdot
.05665 .01472 Mdot
.08949 .01472 Mdot
.12233 .60332 Mdot
.15517 .01472 Mdot
.18801 .01472 Mdot
.22085 .01472 Mdot
.25369 .01472 Mdot
.28654 .01472 Mdot
.31938 .01472 Mdot
.35222 .01472 Mdot
.38506 .01472 Mdot
.4179 .01472 Mdot
.45074 .01472 Mdot
.48358 .01472 Mdot
.51642 .01472 Mdot
.54926 .01472 Mdot
.5821 .01472 Mdot
.61494 .01472 Mdot
.64778 .01472 Mdot
.68062 .01472 Mdot
.71346 .01472 Mdot
.74631 .01472 Mdot
.77915 .01472 Mdot
.81199 .01472 Mdot
.84483 .01472 Mdot
.87767 .01472 Mdot
.91051 .60332 Mdot
.94335 .01472 Mdot
.97619 .01472 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0328407 0.309017 0.0983632 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18801 -0.0125 -3 -9 ]
[.18801 -0.0125 3 0 ]
[.35222 -0.0125 -6 -9 ]
[.35222 -0.0125 6 0 ]
[.51642 -0.0125 -6 -9 ]
[.51642 -0.0125 6 0 ]
[.68062 -0.0125 -6 -9 ]
[.68062 -0.0125 6 0 ]
[.84483 -0.0125 -6 -9 ]
[.84483 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01393 -12 -4.5 ]
[-0.0125 .01393 0 4.5 ]
[-0.0125 .11229 -12 -4.5 ]
[-0.0125 .11229 0 4.5 ]
[-0.0125 .21065 -12 -4.5 ]
[-0.0125 .21065 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40738 -6 -4.5 ]
[-0.0125 .40738 0 4.5 ]
[-0.0125 .50574 -6 -4.5 ]
[-0.0125 .50574 0 4.5 ]
[-0.0125 .60411 -6 -4.5 ]
[-0.0125 .60411 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18801 0 m
.18801 .00625 L
s
[(5)] .18801 -0.0125 0 1 Mshowa
.35222 0 m
.35222 .00625 L
s
[(10)] .35222 -0.0125 0 1 Mshowa
.51642 0 m
.51642 .00625 L
s
[(15)] .51642 -0.0125 0 1 Mshowa
.68062 0 m
.68062 .00625 L
s
[(20)] .68062 -0.0125 0 1 Mshowa
.84483 0 m
.84483 .00625 L
s
[(25)] .84483 -0.0125 0 1 Mshowa
.125 Mabswid
.05665 0 m
.05665 .00375 L
s
.08949 0 m
.08949 .00375 L
s
.12233 0 m
.12233 .00375 L
s
.15517 0 m
.15517 .00375 L
s
.22085 0 m
.22085 .00375 L
s
.25369 0 m
.25369 .00375 L
s
.28654 0 m
.28654 .00375 L
s
.31938 0 m
.31938 .00375 L
s
.38506 0 m
.38506 .00375 L
s
.4179 0 m
.4179 .00375 L
s
.45074 0 m
.45074 .00375 L
s
.48358 0 m
.48358 .00375 L
s
.54926 0 m
.54926 .00375 L
s
.5821 0 m
.5821 .00375 L
s
.61494 0 m
.61494 .00375 L
s
.64778 0 m
.64778 .00375 L
s
.71346 0 m
.71346 .00375 L
s
.74631 0 m
.74631 .00375 L
s
.77915 0 m
.77915 .00375 L
s
.81199 0 m
.81199 .00375 L
s
.87767 0 m
.87767 .00375 L
s
.91051 0 m
.91051 .00375 L
s
.94335 0 m
.94335 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01393 m
.00625 .01393 L
s
[(-3)] -0.0125 .01393 1 0 Mshowa
0 .11229 m
.00625 .11229 L
s
[(-2)] -0.0125 .11229 1 0 Mshowa
0 .21065 m
.00625 .21065 L
s
[(-1)] -0.0125 .21065 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .40738 m
.00625 .40738 L
s
[(1)] -0.0125 .40738 1 0 Mshowa
0 .50574 m
.00625 .50574 L
s
[(2)] -0.0125 .50574 1 0 Mshowa
0 .60411 m
.00625 .60411 L
s
[(3)] -0.0125 .60411 1 0 Mshowa
.125 Mabswid
0 .0336 m
.00375 .0336 L
s
0 .05327 m
.00375 .05327 L
s
0 .07295 m
.00375 .07295 L
s
0 .09262 m
.00375 .09262 L
s
0 .13196 m
.00375 .13196 L
s
0 .15164 m
.00375 .15164 L
s
0 .17131 m
.00375 .17131 L
s
0 .19098 m
.00375 .19098 L
s
0 .23033 m
.00375 .23033 L
s
0 .25 m
.00375 .25 L
s
0 .26967 m
.00375 .26967 L
s
0 .28934 m
.00375 .28934 L
s
0 .32869 m
.00375 .32869 L
s
0 .34836 m
.00375 .34836 L
s
0 .36803 m
.00375 .36803 L
s
0 .38771 m
.00375 .38771 L
s
0 .42705 m
.00375 .42705 L
s
0 .44673 m
.00375 .44673 L
s
0 .4664 m
.00375 .4664 L
s
0 .48607 m
.00375 .48607 L
s
0 .52542 m
.00375 .52542 L
s
0 .54509 m
.00375 .54509 L
s
0 .56476 m
.00375 .56476 L
s
0 .58443 m
.00375 .58443 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18801 .61178 m
.18801 .61803 L
s
.35222 .61178 m
.35222 .61803 L
s
.51642 .61178 m
.51642 .61803 L
s
.68062 .61178 m
.68062 .61803 L
s
.84483 .61178 m
.84483 .61803 L
s
.125 Mabswid
.05665 .61428 m
.05665 .61803 L
s
.08949 .61428 m
.08949 .61803 L
s
.12233 .61428 m
.12233 .61803 L
s
.15517 .61428 m
.15517 .61803 L
s
.22085 .61428 m
.22085 .61803 L
s
.25369 .61428 m
.25369 .61803 L
s
.28654 .61428 m
.28654 .61803 L
s
.31938 .61428 m
.31938 .61803 L
s
.38506 .61428 m
.38506 .61803 L
s
.4179 .61428 m
.4179 .61803 L
s
.45074 .61428 m
.45074 .61803 L
s
.48358 .61428 m
.48358 .61803 L
s
.54926 .61428 m
.54926 .61803 L
s
.5821 .61428 m
.5821 .61803 L
s
.61494 .61428 m
.61494 .61803 L
s
.64778 .61428 m
.64778 .61803 L
s
.71346 .61428 m
.71346 .61803 L
s
.74631 .61428 m
.74631 .61803 L
s
.77915 .61428 m
.77915 .61803 L
s
.81199 .61428 m
.81199 .61803 L
s
.87767 .61428 m
.87767 .61803 L
s
.91051 .61428 m
.91051 .61803 L
s
.94335 .61428 m
.94335 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01393 m
1 .01393 L
s
.99375 .11229 m
1 .11229 L
s
.99375 .21065 m
1 .21065 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .40738 m
1 .40738 L
s
.99375 .50574 m
1 .50574 L
s
.99375 .60411 m
1 .60411 L
s
.125 Mabswid
.99625 .0336 m
1 .0336 L
s
.99625 .05327 m
1 .05327 L
s
.99625 .07295 m
1 .07295 L
s
.99625 .09262 m
1 .09262 L
s
.99625 .13196 m
1 .13196 L
s
.99625 .15164 m
1 .15164 L
s
.99625 .17131 m
1 .17131 L
s
.99625 .19098 m
1 .19098 L
s
.99625 .23033 m
1 .23033 L
s
.99625 .25 m
1 .25 L
s
.99625 .26967 m
1 .26967 L
s
.99625 .28934 m
1 .28934 L
s
.99625 .32869 m
1 .32869 L
s
.99625 .34836 m
1 .34836 L
s
.99625 .36803 m
1 .36803 L
s
.99625 .38771 m
1 .38771 L
s
.99625 .42705 m
1 .42705 L
s
.99625 .44673 m
1 .44673 L
s
.99625 .4664 m
1 .4664 L
s
.99625 .48607 m
1 .48607 L
s
.99625 .52542 m
1 .52542 L
s
.99625 .54509 m
1 .54509 L
s
.99625 .56476 m
1 .56476 L
s
.99625 .58443 m
1 .58443 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .30902 m
.02381 .30902 L
s
.05665 .30902 m
.05665 .30902 L
s
.08949 .30902 m
.08949 .30902 L
s
.12233 .30902 m
.12233 .30902 L
s
.15517 .30902 m
.15517 .30902 L
s
.18801 .30902 m
.18801 .30902 L
s
.22085 .30902 m
.22085 .30902 L
s
.25369 .30902 m
.25369 .30902 L
s
.28654 .30902 m
.28654 .30902 L
s
.31938 .30902 m
.31938 .30902 L
s
.35222 .30902 m
.35222 .30902 L
s
.38506 .30902 m
.38506 .30902 L
s
.4179 .30902 m
.4179 .30902 L
s
.45074 .30902 m
.45074 .30902 L
s
.48358 .30902 m
.48358 .30902 L
s
.51642 .30902 m
.51642 .30902 L
s
.54926 .30902 m
.54926 .30902 L
s
.5821 .30902 m
.5821 .30902 L
s
.61494 .30902 m
.61494 .30902 L
s
.64778 .30902 m
.64778 .30902 L
s
.68062 .30902 m
.68062 .30902 L
s
.71346 .30902 m
.71346 .30902 L
s
.74631 .30902 m
.74631 .30902 L
s
.77915 .30902 m
.77915 .30902 L
s
.81199 .30902 m
.81199 .30902 L
s
.84483 .30902 m
.84483 .30902 L
s
.87767 .30902 m
.87767 .30902 L
s
.91051 .30902 m
.91051 .30902 L
s
.94335 .30902 m
.94335 .30902 L
s
.97619 .30902 m
.97619 .30902 L
s
.015 w
.02381 .30902 Mdot
.05665 .30902 Mdot
.08949 .30902 Mdot
.12233 .30902 Mdot
.15517 .30902 Mdot
.18801 .30902 Mdot
.22085 .30902 Mdot
.25369 .30902 Mdot
.28654 .30902 Mdot
.31938 .30902 Mdot
.35222 .30902 Mdot
.38506 .30902 Mdot
.4179 .30902 Mdot
.45074 .30902 Mdot
.48358 .30902 Mdot
.51642 .30902 Mdot
.54926 .30902 Mdot
.5821 .30902 Mdot
.61494 .30902 Mdot
.64778 .30902 Mdot
.68062 .30902 Mdot
.71346 .30902 Mdot
.74631 .30902 Mdot
.77915 .30902 Mdot
.81199 .30902 Mdot
.84483 .30902 Mdot
.87767 .30902 Mdot
.91051 .30902 Mdot
.94335 .30902 Mdot
.97619 .30902 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 311.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0001=b000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00=oooool3o`0002?ooooo1Ol0000Rooooo`;o0000
9?ooool5o`0002Gooooo0ol0001Looooo`?o00008_ooool5o`0002;ooooo0_l0000Sooooo`Go0000
9?ooool3o`0002Sooooo000hooooo`03o`000?oooooooooo02?ooooo00Co0000oooooooooooo0000
8Oooool01?l0003oooooooooool0000Tooooo`04o`000?ooooooooooo`0002Kooooo00?o0000oooo
ooooool0G?ooool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`00027ooooo00Co0000
oooooooooooo00008oooool01?l0003oooooooooool0000Uooooo`03o`000?oooooooooo02Oooooo
000_ooooo`Go000000?oooooo`000?l000000ol0000Mooooo`Go00000oooool00ol0003ooooooooo
o`0Qooooo`04o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool08oooool5o`0005Cooooo
1Ol000000ooooooo0000o`000003o`0001cooooo1Ol00003ooooo`03o`000?oooooooooo027ooooo
00Co0000oooooooooooo00009?ooool00ol0003oooooooooo`0Rooooo`Go0000:?ooool003Gooooo
00Co0000oooooooooooo00009oooool00ol0003oooooooooo`0Pooooo`04o`000?ooooooooooo`00
02Kooooo00?o0000ooooooooool08_ooool01?l0003oooooooooool0001Kooooo`04o`000?oooooo
ooooo`0002Kooooo00?o0000ooooooooool08?ooool01?l0003oooooooooool0000Uooooo`03o`00
0?oooooooooo027ooooo00Co0000oooooooooooo0000:Oooool003Kooooo00?o0000ooooool00000
9?ooool01Ol0003ooooooooooooooooo0000027ooooo00Co0000oooooooooooo00008oooool01Ol0
003ooooooooooooooooo000002Cooooo00?o0000ooooool00000G?ooool00ol0003oooooo`00000S
ooooo`05o`000?ooooooooooooooool000008Oooool01?l0003oooooooooool0000Rooooo`05o`00
0?ooooooooooooooool000008oooool00ol0003oooooo`00000Yooooo`00=oooool2o`0002Cooooo
00Go0000ooooooooooooooooo`00000Qooooo`04o`000?ooooooooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000Uooooo`;o0000GOooool2o`0002?ooooo00Go0000ooooooooooooooooo`00
000Qooooo`04o`000?ooooooooooo`0002;ooooo00Go0000ooooooooooooooooo`00000Tooooo`;o
0000:Oooool003Sooooo00?o0000ooooooooool08oooool3o`0002?ooooo0_l0000Uooooo`?o0000
9oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo02;ooooo0ol0000Sooooo`;o0000
9?ooool3o`0002Kooooo00?o0000ooooooooool09oooool00?oooooonOooool00?oooooonOooool0
0?oooooonOooool00?oooooonOooool001coooood_l0000Sooooo`?o00001Oooooo>o`00017ooooo
000Fooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo023ooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
3oooool001Gooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`08ooooo`?oo`00
1?ooool3ool000?ooooo0ooo0004ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`00
0oooool3ool000Cooooo0ooo0004ooooo`?oo`000oooool3ool000_ooooo0ooo0003ooooo`?oo`00
1?ooool3ool000Cooooo0ooo0003ooooo`?oo`002_ooool3ool000Cooooo0ooo0004ooooo`?oo`00
0oooool3ool000Cooooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo0003ooooo`?oo`00
1?ooool3ool000Cooooo0ooo0003ooooo`?oo`000oooool00ol0003oooooooooo`0Jooooo`Go0000
1Oooool00ol0003oooooooooo`02ooooo`;o0000IOooool00ol0003oooooooooo`1Rooooo`;o0000
4Oooool001Gooooo00Co0000oooooooooooo00000oooool3o`0000;ooooo00?o003oooooooooool0
0oooool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000Cooooo0ooo0003ooooo`?oo`00
1?ooool3ool000?ooooo0ooo0004ooooo`?oo`001?ooool3ool000?ooooo0ooo0005ooooo`03ool0
0?oooooooooo00?ooooo0ooo0003ooooo`?oo`001?ooool3ool000Cooooo0ooo0003ooooo`?oo`00
1Oooool00ooo003oooooooooo`02ooooo`?oo`001?ooool3ool000Cooooo0ooo0003ooooo`?oo`00
1?ooool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`00
1?ooool3ool000?ooooo0ooo0002ooooo`;o00009?ooool2o`0000Gooooo00?o0000ooooooooool0
I?ooool00ol0003oooooooooo`0Gooooo`03o`00oooooooooooo04Wooooo00?o0000ooooooooool0
3oooool001Gooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`08ooooo`?oo`00
1?ooool3ool000?ooooo0ooo0004ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`00
0oooool3ool000Cooooo0ooo0004ooooo`?oo`000oooool3ool000Gooooo00?oo`00ooooooooool0
0oooool3ool000?ooooo0ooo0004ooooo`?oo`001?ooool3ool000?ooooo0ooo0005ooooo`03ool0
0?oooooooooo00;ooooo0ooo0004ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`00
1?ooool3ool000?ooooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo0004ooooo`?oo`00
0oooool3ool000?ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo06Cooooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`19ooooo`03o`00
0?oooooooooo00oooooo000Eooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
0oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`03ooooo`;o003o1Oooool2o`00o`Cooooo0_l00?l5ooooo`;o003o
3?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?oo`00ooooooooool0
1?ooool00ol00?ooooooooooo`03ooooo`;o003o1Oooool00ol0003oooooooooo`04ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ooo003oooooooooo`04ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo00?ooooo0_l00?l6ooooo`03o`00oooooooooooo00;ooooo0_l00?l5ooooo`;o003o
1Oooool2o`00o`Cooooo0_l00?l5ooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool0
8?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0E_ooool00ol00?oo
ooooooooo`0;ooooo`03o`000?oooooooooo01Kooooo0_l00?m;ooooo`03o`000?oooooooooo00oo
oooo000Eooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooo003o00Cooooo0_l00?l5ooooo`;o003o1Oooool2o`00o`Co
oooo0_l00?l5ooooo`;o003o3?ooool00ol00?ooooooooooo`03ooooo`;o003o1Oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00?oo`00ooooooooool00oooool2o`00o`Go
oooo00?o003oooooooooool00oooool00ol00?oo0000o`00o`04ooooo`;o003o1Oooool00ol00?oo
ooooooooo`04ooooo`03ool00?oooooooooo00?ooooo0_l00?l5ooooo`03o`00oooooooooooo00?o
oooo0_l00?l5ooooo`;o003o1Oooool00ol00?ooooooooooo`03ooooo`;o003o1Oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00Cooooo0_l00?l5ooooo`;o003o1?ooool2o`00o`[o
oooo00?o0000ooooooooool08Oooool3o`0000Gooooo0_l0001Gooooo`03o`00oooooooooooo00_o
oooo00?o0000ooooooooool05_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo04;o
oooo0_l0000Aooooo`005_ooool2o`0000Cooooo0_l00004ooooo`;o003o2_ooool2o`00o`Cooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool01?ooool00ol00?ooooooo`00o`04ooooo`;o003o1Oooool2o`00o`Cooooo
00?o003oooooooooool01?ooool2o`00o`Gooooo00?oo`00ooooooooool00oooool00ol00?oooooo
ooooo`04ooooo`;o003o1?ooool00ol00?oo0000o`00o`04ooooo`03o`00oooooooooooo00Cooooo
0_l00?l5ooooo`03ool00?oooooooooo00?ooooo0_l00?l5ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool00oooool2o`00o`Cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooo003o00Cooooo00?o003oooooool00?l01Oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Cooooo00Go003oooooooooooooooooo`00o`05ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0E_ooool00ol00?ooooooooooo`0;ooooo`03
o`000?oooooooooo01Kooooo0_l00?l5ooooo`03o`00oooooooooooo04?ooooo00?o0000oooooooo
ool03oooool001cooooo00?o0000ooooooooool02?ooool00ol00?ooooooo`00o`03ooooo`04o`00
ooooooooooooo`00o`Gooooo00?o003oooooooooool01?ooool01Ol00?oooooooooooooooooo003o
00gooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`03ooooo`?o003o1Oooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ol0
0?ooooooooooo`04ooooo`04o`00ooooooooooooooooo`;o003o00?o0000o`00ooooool00oooool2
o`00o`Gooooo00?o003oooooooooool01?ooool00ooo003oooooooooo`03ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`;o003o1_ooool0
0ol00?ooooooooooo`04ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`06ooooo`05o`00
ooooooooooooooooool00?l00_ooool01Ol00?oooooooooooooooooo003o00Kooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0E_ooool00ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo01Oooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`13ooooo`03o`000?oooooooooo00oooooo000Looooo`03
o`000?oooooooooo00Cooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`07oooo
o`04o`00ooooooooooooo`00o`?ooooo00?o003oooooool00?l00oooool01?l00?ooooooooooool0
0?l3ooooo`03o`00oooooooo003o00Cooooo00?o003oooooool00?l00oooool00ol00?ooooooo`00
o`0;ooooo`;o003o1Oooool2o`00o`Gooooo00?oo`00ooooooooool00oooool2o`00o`Cooooo00Co
003ooooooooooooo003o1?ooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00?ooooo
0_l00?l5ooooo`03ool00?oooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`03ooooo`;o003o1Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00?ooooo
00Co003ooooooooooooo003o1_ooool01?l00?ooooooooooool00?l2ooooo`05o`00oooooooooooo
ooooool00?l00_ooool01?l00?ooooooooooool00?l3ooooo`07o`00ooooooooooooooooool00?oo
ooooo`00o`03ooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`1Fooooo`03o`00oooooooooooo00_ooooo00?o0000ooooooooool05_ooool2o`00o`Go
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0looooo`03o`000?oooooooooo00oo
oooo000Looooo`03o`000?oooooooooo00Cooooo0_l00?l00ooooooo003oooooo`02ooooo`03o`00
oooooooo003o00Cooooo00?o003oooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`04
o`00ooooooooooooo`00o`;ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`02ooooo`;o003o1Oooool2
o`00o`Gooooo00?oo`00ooooooooool00oooool2o`00o`Cooooo00?o003oooooooooool00oooool0
1Ol00?ooooooo`000?oooooo003o00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?oooooo
ooooo`04ooooo`03ool00?oooooooooo00?ooooo0_l00?l5ooooo`;o003o1?ooool2o`00o`Oooooo
00Oo003oooooooooooooooooo`00oooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01oooool0
1?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool0:Ooo
ool2o`0005Oooooo00?o003oooooooooool02oooool00ol0003oooooooooo`0Fooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool00oooool2o`00ocgooooo0_l0000Aooooo`007?ooool2
o`0000Kooooo00?o003oooooooooool01?ooool2o`00o`Cooooo0ol00?l6ooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool00_l00?l2ooooo`04o`00ooooooooooooo`00o`Sooooo00?o
003oooooooooool00_ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool00oooool00ooo003oooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00Co
003ooooooooooooo003o0_ooool01Ol00?ooooooo`000?oooooo003o00;ooooo00?o003ooooooooo
ool01Oooool2o`00o`Gooooo00?oo`00ooooooooool00oooool2o`00o`Cooooo00?o003ooooooooo
ool01_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`05
ooooo`03o`00oooooooooooo00?ooooo00Go003oooooooooooooooooo`00o`02ooooo`05o`00oooo
ooooooooooooool00?l01_ooool2o`00o`Gooooo0_l00?l4ooooo`?o003o1_ooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo05Kooooo00?o003oooooooooool02oooool00ol0003ooooo
ooooo`0Fooooo`;o003o1Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo03cooooo
00?o0000ooooooooool03oooool001cooooo00?o0000ooooooooool04oooool00ol00?oooooooooo
o`03ooooo`;o003o1?ooool3o`00o`gooooo00Co003ooooooooooooo003o0oooool01?l00?oooooo
ooooool00?l3ooooo`03o`00oooooooo003o00Kooooo00?o003oooooooooool00_ooool2o`00o`Go
oooo00?oo`00ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`?o003o0_ooool00ol0003o
ooooooooo`03o`00o`;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03
ool00?oooooooooo00?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o1_ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooo003o00Cooooo0_l00?l5ooooo`;o003o1?ooool2o`00oaCooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`1Fooooo`03o`00oooooooooooo00_ooooo00?o0000oooo
ooooool05oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool0?Oooool00ol0003oooooooooo`0?ooooo`007?ooool00ol0003oooooooooo`0Pooooo`;o
003o1?ooool3o`00o`?ooooo0_l00?l01Ooooooo003ooooooooooooo003o00?ooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooo003o00Cooooo00?o003ooooo
ooooool01?ooool00ooo003oooooooooo`03ooooo`;o003o1?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o0000ooooooooool01Oooool01ol00?oooooooooooooooooo003oooooool00?l0
1Oooool00ooo003oooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l0
1?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00?ooooo00Oo003ooooooooooooo
ooooo`00oooooooo003o00Cooooo0_l00?l5ooooo`03o`00oooooooooooo023ooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`1Eooooo`;o003o1_ooool00ol00?ooooooooooo`04oooo
o`03o`000?oooooooooo01Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`03oooo
o`;o003o1Oooool00ol00?ooooooooooo`0fooooo`03o`000?oooooooooo00oooooo000Looooo`03
o`000?oooooooooo02gooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l2oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooool00?l01?ooool2o`00o`Gooooo00?oo`00oooo
ooooool00oooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00Gooooo00?o0000oooo
ooooool01Oooool01Ol00?oooooooooooooooooo003o00Oooooo00?oo`00ooooooooool00oooool2
o`00o`Cooooo00?o003oooooool00?l00oooool01?l00?ooooooooooool00?l9ooooo`07o`00oooo
ooooooooooooool00?ooooooo`00o`0^ooooo`03o`000?oooooooooo02Wooooo0_l0001Gooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`0Eooooo`03
o`00oooooooooooo00Cooooo0_l00?l5ooooo`;o003o1Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo02kooooo0_l0000Aooooo`007?ooool2o`0003_ooooo00?o003oooooool00?l0
0_ooool2o`00o`?ooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`03ooooo`03ool0
0?oooooooooo00?ooooo00?o003oooooool00?l00oooool00ol00?ooooooooooo`05ooooo`03o`00
0?oooooooooo00Wooooo00?o003oooooooooool01Oooool00ooo003oooooooooo`03ooooo`;o003o
1?ooool00ol00?ooooooooooo`06ooooo`04o`00ooooooooooooo`00o`?ooooo0_l00?l00ooooooo
003oooooo`0cooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0EOooool2o`00o`Ko
oooo00?o003oooooooooool01?ooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00Co
oooo0_l00?l6ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool2o`00oc7o
oooo00?o0000ooooooooool03oooool001cooooo00?o0000ooooooooool0=?ooool2o`00o`Cooooo
00?o003oooooool00?l00oooool00ol00?ooooooooooo`08ooooo`;o003o1Oooool00ooo003ooooo
ooooo`08ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00?ooooo00?oo`00ooooooooool00oooool00ol00?oooooo
ooooo`05ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo03Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Eooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`0Gooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo02oooooo00?o0000ooooooooool03oooool001Cooooo1Ol00003ooooo`03o`00
0?oooooooooo03cooooo00Go003oooooooooooooooooo`00o`02ooooo`04o`00ooooooooooooo`00
o`Cooooo00?o003oooooooooool01?ooool00ooo003oooooooooo`03ooooo`03o`00oooooooo003o
00_ooooo00?o0000ooooooooool01_ooool01_l00?ooooooooooool00?ooooooo`00o`Gooooo00?o
o`00ooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00?ooooo00Oo
003oooooooooooooooooo`00oooooooo003o03_ooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`1Eooooo`;o003o1_ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo01Go
oooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`03ooooo`;o003o1?ooool2o`00o`Go
oooo00?o003oooooooooool0<?ooool00ol0003oooooooooo`0?ooooo`005Oooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo03[ooooo00?o003oooooooooool01_ooool01?l00?oo
ooooooooool00?l4ooooo`;o003o1Oooool00ooo003oooooooooo`03ooooo`03o`00oooooooo003o
00;ooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`06ooooo`06o`00oooooooooooo
o`00oooooooo003o1Oooool00ooo003oooooooooo`03ooooo`;o003o1?ooool01?l00?oooooooooo
ool00?l2ooooo`05o`00ooooooooooooooooool00?l0?Oooool00ol0003oooooooooo`0Yooooo`;o
0000Eoooool00ol00?ooooooooooo`03ooooo`;o003o1_ooool00ol0003oooooooooo`0Eooooo`03
o`00oooooooo003o00Cooooo0_l00?l5ooooo`;o003o1?ooool2o`00o`Gooooo0_l00?l5ooooo`03
o`00oooooooooooo02Sooooo0_l0000Aooooo`005_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo03_ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l2ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ooo003oooooooooo`03ooooo`03
o`00oooooooo003o00;ooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`09ooooo`03
o`00oooooooooooo00Gooooo00?oo`00ooooooooool00oooool2o`00o`Cooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo03[ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`1Eooooo`;o003o1_ooool00ol00?ooooooooooo`04ooooo`03
o`000?oooooooooo01Gooooo00?o003oooooooooool01?ooool2o`00o`Kooooo00?o003ooooooooo
ool00_ooool2o`00o`Gooooo0_l00?l5ooooo`03o`00oooooooooooo02Wooooo00?o0000oooooooo
ool03oooool001Oooooo00?o0000ooooooooool00_ooool3o`00043ooooo00?o003oooooooooool0
1oooool00ol00?ooooooo`00o`05ooooo`03ool00?oooooooooo00Sooooo00?o003oooooooooool0
1_ooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0oooool00ooo003oooooooooo`03ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
@Oooool2o`0002;ooooo1Ol00004ooooo`03o`000?oooooooooo05Gooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00Go003ooooooooooooo
ooooo`00o`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`03ooooo`;o003o9?ooool00ol0003oooooooooo`0?ooooo`005?ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool0@Oooool00ol00?ooooooo`00o`02ooooo`05
o`00ooooooooooooooooool00?l01oooool00ooo003oooooooooo`03ooooo`03o`00oooooooo003o
00_ooooo00?o0000ooooooooool01_ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo
00?ooooo00?oo`00ooooooooool02?ooool01ol00?oooooooooooooooooo003oooooool00?l0@_oo
ool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
EOooool2o`00o`Gooooo0_l00?l6ooooo`03o`000?oooooooooo01Gooooo00?o003oooooool00?l0
0oooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooo003o00Cooooo0_l00?l5ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Sooooo`03o`00
0?oooooooooo00oooooo000Dooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`12ooooo`;o003o0_ooool01ol00?oooooooooooooooooo003oooooool00?l01Oooool00ooo
003oooooooooo`03ooooo`03o`00oooooooooooo00;o003o2Oooool00ol0003oooooooooo`07oooo
o`;o003o0_ooool00ol00?ooooooooooo`03ooooo`03ool00?oooooooooo00?ooooo0_l00?l3oooo
o`07o`00ooooooooooooooooool00?ooooooo`00o`12ooooo`03o`000?oooooooooo01[ooooo1Ol0
0003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0E_ooool00ol00?oooooooooo
o`03ooooo`;o003o1_ooool00ol0003oooooooooo`0Eooooo`03o`00oooooooo003o00Gooooo00?o
003oooooooooool00_ooool00ol00?ooooooo`00o`04ooooo`;o003o1Oooool2o`00o`Gooooo00?o
003oooooooooool00oooool2o`00obCooooo00?o0000ooooooooool03oooool001Gooooo0ol00004
ooooo`03o`000?oooooooooo047ooooo0_l00?l3ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool00oooool00ooo003oooooooooo`03ooooo`03o`00oooooooooooo00;o003o2Oooool0
0ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Kooooo00?oo`00ooooooooool00oooool2
o`00o`?ooooo00?o003oooooooooool00_ooool2o`00od;ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`03ooooo`;o0000Eoooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Cooooo00?o0000ooooooooool05?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
003o00Kooooo00?o003oooooooooool00_ooool2o`00o`Gooooo0_l00?l4ooooo`;o003o1_ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01_ooooo0_l0000Aooooo`007?ooool2o`00
04_ooooo00?o003oooooool00?l01Oooool00ooo003oooooooooo`06ooooo`;o003o2Oooool00ol0
003oooooooooo`0;ooooo`03o`00oooooooooooo00?ooooo00?oo`00ooooooooool00oooool00ol0
0?ooooooo`00o`02ooooo`03o`00oooooooooooo04Kooooo00?o0000ooooooooool08?ooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0E?ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Gooooo00?o0000ooooooooool05oooool01Ol00?oooooooooooooo
oooo003o00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`02ooooo`;o003o1Ooo
ool2o`00o`Gooooo00?o003oooooooooool07?ooool00ol0003oooooooooo`0?ooooo`007?ooool0
0ol0003oooooooooo`17ooooo`04o`00ooooooooooooo`00o`Oooooo00?oo`00ooooooooool00_oo
ool00ol00?ooooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool00ooo
ool00ooo003oooooooooo`03ooooo`03o`00oooooooooooo04_ooooo00?o0000ooooooooool08?oo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0E?ooool00ol00?oooooo
o`00o`05ooooo`;o003o1_ooool00ol0003oooooooooo`0Dooooo`04o`00ooooooooooooo`00o`?o
oooo00?o003oooooool00?l01?ooool00ol00?ooooooo`00o`04ooooo`;o003o1?ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`03ooooo`;o003o5oooool00ol0003oooooooooo`0?ooooo`007?ooool00ol0003ooooo
ooooo`17ooooo`06o`00ooooooooooooo`00oooooooo003o1Oooool00ooo003oooooooooo`02oooo
o`03o`00oooooooooooo00cooooo00?o0000ooooooooool02oooool00ol00?ooooooooooo`03oooo
o`03ool00?oooooooooo00Gooooo00Co003ooooooooooooo003oB?ooool00ol0003oooooooooo`0Q
ooooo`?o00001Oooool00ol0003oooooooooo`1Dooooo`03o`00oooooooo003o00Cooooo00?o003o
ooooool00?l01_ooool00ol0003oooooooooo`0Dooooo`04o`00ooooooooooooo`00o`Gooooo00?o
003oooooooooool00_ooool00ol00?ooooooo`00o`04ooooo`;o003o1?ooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`03o`00oooooooooooo00?ooooo0_l0
0?lGooooo`03o`000?oooooooooo00oooooo000Looooo`03o`000?oooooooooo04Oooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?o003o
ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo00;ooooo00Co003o
oooooooooooo003o0_ooool00ol00?ooooooooooo`16ooooo`03o`000?oooooooooo02Wooooo0_l0
001Gooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol0003ooooooooo
o`0Dooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01_ooool01ol00?oooooooooo
oooooooo003oooooool00?l01?ooool00ol00?ooooooo`00o`04ooooo`;o003o1_ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`03o`00oooooooooooo00ko
oooo0_l0000Aooooo`007?ooool2o`0004_ooooo00?o003oooooool00?l01Oooool00ooo003ooooo
ooooo`02ooooo`03o`00oooooooooooo00cooooo00?o0000ooooooooool02oooool00ol00?oooooo
ooooo`03ooooo`03ool00?oooooooooo00;ooooo00Co003ooooooooooooo003o0_ooool00ol00?oo
ooooooooo`16ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0E?ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool05oooool01Ol00?oo
oooooooooooooooo003o00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`02oooo
o`;o003o1Oooool2o`00o`Cooooo0_l00?l6ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool03oooool00ol0003oooooooooo`0?ooooo`007?ooool00ol0003oooooooooo`17ooooo`04
o`00ooooooooooooo`00o`Oooooo00?oo`00ooooooooool04Oooool00ol0003oooooooooo`0;oooo
o`03o`00oooooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ol00?ooooooooooo`1<oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0E?ooool00ol00?ooooooo`00o`04oooo
o`03o`00oooooooo003o00Kooooo00?o0000ooooooooool05oooool01ol00?oooooooooooooooooo
003oooooool00?l01?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooo003o00_ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`;o003o1Oooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool03oooool001cooooo00?o0000
ooooooooool0Aoooool01_l00?ooooooooooool00?ooooooo`00o`Gooooo00?oo`00ooooooooool0
0_ooool00ol00?ooooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o003oooooooooool0
0_ooool00ooo003oooooooooo`05ooooo`04o`00ooooooooooooo`00odSooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`1Dooooo`03o`00oooooooo003o00Cooooo00?o003oooooool0
0?l01_ooool00ol0003oooooooooo`0Dooooo`04o`00ooooooooooooo`00o`Gooooo00Go003ooooo
ooooooooooooo`00o`02ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`04ooooo`03o`00
oooooooo003o00Gooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`04ooooo`03o`00
oooooooooooo00Cooooo0_l00?l5ooooo`03o`00oooooooooooo00?ooooo0_l00?l:ooooo`03o`00
0?oooooooooo00oooooo000Looooo`03o`000?oooooooooo04Oooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o003oooooooooool03?oo
ool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo00;ooooo00Co003ooooooooooooo003o
0_ooool00ol00?ooooooooooo`16ooooo`03o`000?oooooooooo02Wooooo0_l0001Gooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`0Dooooo`03o`00
oooooooooooo00?ooooo00Co003ooooooooooooo003o1_ooool01ol00?oooooooooooooooooo003o
ooooool00?l01?ooool00ol00?ooooooo`00o`04ooooo`;o003o1_ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`03o`00oooooooooooo00kooooo0_l0000A
ooooo`007?ooool2o`0004[ooooo00Go003oooooooooooooooooo`00o`04ooooo`03ool00?oooooo
oooo00;ooooo00?o003oooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00oooooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool01_l00?ooooooooooool00?ooooooo`00odWooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Cooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01Oooool00ol00?oo0000ooooo`0Dooooo`05o`00ooooooooooooooooool0
0?l00_ooool00ol00?ooooooooooo`04ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooo`00o`04ooooo`;o003o1?ooool00ol00?ooooooo`00o`04oooo
o`;o003o1_ooool00ol00?ooooooooooo`02ooooo`;o003o1Oooool2o`00o`[ooooo00?o0000oooo
ooooool03oooool001Kooooo0ol00003ooooo`03o`000?oooooooooo04Sooooo0_l00?l8ooooo`03
ool00?oooooooooo017ooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?o003oooooooooool0C?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo05?ooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooo`00o`05oooo
o`03o`00ool0003ooooo01Sooooo00Co003ooooooooooooo003o0_ooool01Ol00?oooooooooooooo
oooo003o00Kooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Cooooo0_l00?l5ooooo`03o`00oooooooooooo00[ooooo0_l00?l5ooooo`03o`00oooo
oooooooo00;ooooo00?o0000ooooooooool03oooool001Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`18ooooo`;o003o2?ooool00ooo003oooooooooo`02ooooo`03o`00oooooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`02ooooo`03ool00?oooooo
oooo00Kooooo0_l00?m9ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02?ooool0
0ol00?ooooooooooo`18ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o
1Oooool00ol00?oo0000ooooo`0Dooooo`05o`00ooooooooooooooooool00?l01Oooool01Ol00?oo
oooooooooooooooo003o00;ooooo00Oo003oooooooooooooooooo`00oooooooo003o00?ooooo00Co
003ooooooooooooo003o1Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Cooooo
00?o003oooooooooool01?ooool2o`00o`Cooooo0_l00?l5ooooo`;o003o1Oooool00ol00?oooooo
ooooo`02ooooo`03o`000?oooooooooo00oooooo000Dooooo`Go00000oooool00ol0003ooooooooo
o`18ooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
003oooooooooool03?ooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo00;ooooo00Co
003ooooooooooooooooo0_l00?m9ooooo`03o`000?oooooooooo02Wooooo0_l00009ooooo`03o`00
oooooooooooo04_ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00
ool0003ooooo01Cooooo00?o003oooooooooool01?ooool01?l00?ooooooooooool00?l6ooooo`07
o`00ooooooooooooooooool00?ooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00?o
003oooooool00?l01_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooool00?l01?ooool2o`00o`cooooo00Co003ooooooooooooooooo0_l0000Aooooo`005?oo
ool01?l0003oooooooooool00004ooooo`?o0000COooool00ol00?ooooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?o003oooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
oooooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ol00?ooooooooooo`1;ooooo`;o0000
:oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
@Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Kooooo00?o003oo`000?ooool0
5?ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool01?ooool01?l00?oo
ooooooooool00?l5ooooo`05o`00ooooooooooooooooool00?l00_ooool01ol00?oooooooooooooo
oooo003oooooool00?l01?ooool00ol00?ooooooo`00o`04ooooo`;o003o1_ooool00ol00?oooooo
ooooo`02ooooo`;o003o1Oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo00oooooo
000Eooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool0COooool00ol00?oooooooooo
o`02ooooo`03ool00?oooooooooo017ooooo00?o0000ooooooooool03?ooool00ol00?oooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?o003oooooooooool0C?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`11ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01_ooool00ol00?oo0000oooo
o`0Hooooo`04o`00ooooooooooooo`00o`;ooooo00Go003oooooooooooooooooo`00o`05ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`;o
003o1?ooool00ol00?ooooooooooo`0;ooooo`;o003o1?ooool00ol00?ooooooooooo`03ooooo`03
o`000?oooooooooo00oooooo000Fooooo`;o00001?ooool00ol0003oooooooooo`1Booooo`03ool0
0?oooooooooo00;ooooo00?o003oooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
oooooooooooo00;ooooo00?oo`00ooooooooool0DOooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo00Sooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`11ooooo`04o`00
ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o1Oooool00ol00?oo0000ooooo`0Doooo
o`05o`00ooooooooooooooooool00?l01Oooool01?l00?ooooooooooool00?l3ooooo`04o`00oooo
ooooooooo`00o`;ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01?ooool2o`00o`Gooooo0_l00?l4ooooo`03o`00oooooooooooo00?o
oooo00?o0000ooooooooool03oooool001Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1=ooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ol00?oooooo
ooooo`0<ooooo`03o`000?oooooooooo017ooooo00?oo`00ooooooooool00_ooool00ol00?oooooo
ooooo`1<ooooo`03o`000?oooooooooo02Wooooo0_l00009ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool0A?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo
00?o003oo`000?ooool05?ooool00ol00?ooooooooooo`04ooooo`04o`00ooooooooooooo`00o`Ko
oooo00Co003ooooooooooooo003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Oo003o
ooooooooooooooooo`00oooooooo003o00Kooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooo003o00Cooooo0_l00?l6ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool2o`00017ooooo000Looooo`;o0000C_ooool00ol00?oooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?o003oooooooooool03?ooool00ol0003ooooooooo
o`0Aooooo`03ool00?oooooooooo00;ooooo00?o003oooooooooool0C?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool00oooool2o`00o`Gooooo00?o
003oooooooooool0>oooool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`Co
oooo0_l00?l00ol0003oooooooooo`0Cooooo`05o`00ooooooooooooooooool00?l00_ooool00ol0
0?ooooooooooo`03ooooo`05o`00ooooooooooooooooool00?l01Oooool01Ol00?oooooooooooooo
oooo003o00;ooooo00Oo003oooooooooooooooooo`00oooooooo003o00?ooooo00Co003ooooooooo
oooo003o0oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00;ooooo0_l00?l4oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol0003oooooooooo`0?oooo
o`007?ooool00ol0003oooooooooo`1=ooooo`03o`00oooooooooooo00;ooooo00?oo`00oooooooo
ool04Oooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ol00?ooooooooooo`1<ooooo`03o`000?oooooooooo027ooooo0ol00005ooooo`03
o`000?oooooooooo00Sooooo00?o003oooooooooool00oooool2o`00o`Gooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`0dooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01_ooool00ol00?oo0000ooooo`0Hooooo`03o`00oooooooo003o00?ooooo00Co003ooooooooo
oooo003o1_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooo003o00[ooooo00?o003ooooo
ool00?l02_ooool00ol0003oooooooooo`0?ooooo`007?ooool00ol0003oooooooooo`1Booooo`03
ool00?oooooooooo00;ooooo00?o003oooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`00oooooooooooo00;ooooo00?oo`00ooooooooool0DOooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0cooooo`05
o`00ooooooooooooooooool00?l00_ooool01Ol00?oooooooooooooooooo003o00Cooooo0_l00?l0
0ol0003oooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00oooool0
1?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00Go003ooooooooooooo
ooooo`00o`02ooooo`03o`00oooooooooooo00?ooooo00Go003oooooooooooooooooo`00o`02oooo
o`05o`00ooooooooooooooooool00?l01_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
003o00Cooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`03ooooo`03o`000?oooooo
oooo00oooooo000Looooo`03o`000?oooooooooo04gooooo00?o003oooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03o`00oooooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
0?ooooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o003oooooooooool0C?ooool00ol0
003oooooooooo`0Jooooo`Go00000oooool00ol0003oooooooooo`04ooooo`;o00002Oooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0=oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool000005?ooool00ol0
0?ooooooooooo`04ooooo`05o`00ooooooooooooooooool00?l01_ooool01?l00?ooooooooooool0
0?l2ooooo`05o`00ooooooooooooooooool00?l00_ooool01?l00?ooooooooooool00?l2ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooo003o00?ooooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo0_l0000Aooooo`007?ooool2o`0004kooooo00?o003oooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03o`00oooooooooooo00cooooo00?o0000ooooooooool0
4Oooool00ooo003oooooooooo`02ooooo`03o`00oooooooooooo04cooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo0_l00?l5ooooo`;o003o
1Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
;Oooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`04oooo
o`;o003o00?o0000ooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o
00Kooooo00Go003oooooooooooooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`?ooooo00Co
003ooooooooooooo003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Oo003ooooooooo
ooooooooo`00oooooooo003o00Kooooo00Oo003oooooooooooooooooo`00oooooooo003o00Cooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00oooooo
000Looooo`03o`000?oooooooooo04gooooo00?o003oooooooooool00_ooool00ooo003ooooooooo
o`0Aooooo`03o`000?oooooooooo00cooooo00?o003oooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03o`00oooooooooooo04cooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool00oooool2o`00o`Gooooo00?o
003oooooooooool00oooool2o`00o`Gooooo00?o003oooooooooool0;Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Oooooo00?o003oo`000?ooool06?ooool00ol00?ooooooo`00
o`06ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l00oooool01?l00?oooooooooo
ool00?l:ooooo`03o`00oooooooo003o00[ooooo00?o0000ooooooooool03oooool001cooooo00?o
0000ooooooooool0D_ooool00ooo003oooooooooo`02ooooo`03o`00oooooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol00?ooooooooooo`02ooooo`03ool00?oooooooooo057ooooo00?o
0000ooooooooool08Oooool2o`0000Kooooo00?o0000ooooooooool01oooool2o`00o`Kooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`;o003o1Oooool00ol00?oooooooooo
o`0]ooooo`05o`00ooooooooooooooooool00?l00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Co003oooooool00?oo00005?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00?ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooo`00o`03ooooo`04o`00oooooooo
ooooo`00o`?ooooo00?o003oooooooooool00oooool01Ol00?oooooooooooooooooo003o00;ooooo
00?o003oooooooooool00_l00?l5ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l0
1?ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool0
3oooool001cooooo00?o0000ooooooooool0COooool00ol00?ooooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?o003oooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00oooo
oooooooo00;ooooo00?oo`00ooooooooool0DOooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00Cooooo0_l00008ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0:_oo
ool00ol00?ooooooooooo`04ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol0003ooooo
ooooo`0Booooo`03o`00oooooooooooo00Cooooo00Go003oooooooooooooooooo`00o`06ooooo`03
o`00oooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool00?l2
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool01Ol00?oooooooooooooo
oooo003o00;ooooo00Oo003oooooooooooooooooo`00oooooooo003o00Kooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`;o00004Oooool001cooooo0_l0001>ooooo`03o`00
oooooooooooo00;ooooo00Goo`00ooooooooooooooooo`00o`0?ooooo`03o`000?oooooooooo017o
oooo00?oo`00ooooooooool00_ooool00ol00?ooooooooooo`1<ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool01oooool2o`00o`Gooooo0_l00?l4ooooo`;o003o1_ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool09_ooool01Ol00?oo
oooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooooooo
003oo`0001Cooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`03ooooo`03o`00oooo
oooo003o00Cooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l3ooooo`04o`00
ooooooooooooo`00o`;ooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool00?l2
ooooo`03o`00oooooooooooo00Cooooo00Oo003oooooooooooooooooo`00oooooooo003o00[ooooo
00?o003oooooooooool01?ooool00ol0003oooooooooo`0?ooooo`007?ooool00ol0003ooooooooo
o`1=ooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool04Oooool00ol0003ooooooooo
o`0<ooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ol00?oooooooooo
o`1<ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02?ooool00ol00?oooooooooo
o`03ooooo`;o003o1?ooool2o`00o`Gooooo0_l00?l5ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01oooool00ol00?oo0000ooooo`0Hooooo`;o003o1_ooool00ol00?oooooooooo
o`0Booooo`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool01?ooool01?l00?oooooo
ooooool00?l3ooooo`04o`00ooooooooooooo`00o`Wooooo00Co003ooooooooooooo003o2_ooool0
0ol0003oooooooooo`0?ooooo`005Oooool3o`0000Cooooo00?o0000ooooooooool0D_ooool00ooo
003oooooooooo`0Aooooo`03o`000?oooooooooo00cooooo00?o003oooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03o`00oooooooooooo04cooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`07ooooo`;o003o1_ooool00ol00?ooooooooooo`02ooooo`;o003o1Oooool2o`00
o`Gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo
00;ooooo00Co003ooooooooooooo003o0oooool02?l00?oooooooooooooooooo003oooooool00?oo
00001Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooo003o00?ooooo00Co003ooooooooo
oooo003o0oooool00ol00?ooooooooooo`06ooooo`05o`00ooooooooooooooooool00?l00_ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l00oooool0
1?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool03ooo
ool001Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo04gooooo00?o
003oooooooooool00_ooool01Ooo003ooooooooooooooooo003o00oooooo00?o0000ooooooooool0
3?ooool00ol00?ooooooooooo`02ooooo`03ool00?oooooooooo057ooooo00?o0000ooooooooool0
:Oooool2o`0000Sooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool00oooool2o`00o`Gooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Cooooo00Go003ooooooooooooo
ooooo`00o`02ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool00ol00?oo
ooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooool00?l00oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00Go003oooooooooooooooooo`00o`02
ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?o
oooo00?o003oooooooooool00oooool2o`00017ooooo000Dooooo`05o`000?ooooooooooooooool0
00000oooool3o`0004gooooo00?o003oooooooooool00_ooool01Ooo003ooooooooooooooooo003o
00oooooo00?o0000ooooooooool04Oooool01Ooo003ooooooooooooooooo003o04kooooo0_l0000[
ooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`04
ooooo`;o003o1_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo0_l00?l5
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooo003o00Cooooo00Co003ooooooooooooo003o0_ooool00ol00?oo0000oooo
o`04ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool00oooool2o`00o`Cooooo00?o
003oooooool00?l01?ooool00ol00?ooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo
00?o003oooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00
o`;ooooo00?o003oooooooooool01?ooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`0?ooooo`005?ooool4o`00
00Cooooo00?o0000ooooooooool0COooool00ol00?ooooooooooo`02ooooo`05ool00?oooooooooo
ooooool00?l03oooool00ol0003oooooooooo`0=ooooo`05o`00oooooooooooooooooooo00000ooo
ool00ol00?ooooooooooo`1=ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02?oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Cooooo0_l00?l5ooooo`;o003o1Ooo
ool00ol00?ooooooooooo`03ooooo`;o003o1Oooool00ol00?ooooooooooo`0Oooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool02?ooool00ol00?oo0000ooooo`04ooooo`03o`00oooo
oooooooo017ooooo0_l00?l6ooooo`03o`00oooooooooooo00oooooo00?o003oooooool00?l00ooo
ool01?l00?ooooooooooool00?l6ooooo`04o`00ooooooooooooo`00o`;ooooo00Go003ooooooooo
ooooooooo`00o`09ooooo`04o`00ooooooooooooo`00o`[ooooo00?o0000ooooooooool03oooool0
01Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Booooo`03ool00?oooooooooo
017ooooo00?o0000ooooooooool03Oooool01Ol00?ooooooooooooooooooo`0000?ooooo00?o003o
ooooooooool0COooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Kooooo00?o003o
ooooool00?l01_ooool00ol00?ooooooooooo`02ooooo`;o003o1Oooool2o`00o`Cooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Cooooo00Co003o
oooooooooooo003o0_ooool00ol00?oo0000ooooo`04ooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Cooooo00?o
003oooooool00?l00oooool00ol00?ooooooo`00o`0=ooooo`05o`00ooooooooooooooooool00?l0
0_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00Co003ooooooooooooo
003o0oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00Cooooo00?o0000oooo
ooooool03oooool001Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1=ooooo`03
o`00oooooooooooo00;ooooo00Goo`00ooooooooooooooooo`00o`0?ooooo`03o`000?oooooooooo
00gooooo00Go003oooooooooooooooooool0001Cooooo`03o`000?oooooooooo02Wooooo0_l00007
ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Cooooo0_l00?l5ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00Cooooo00Co003o
oooooooooooo003o0oooool00ol0003oooooooooo`02ooooo`;o003o3Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00
o`03ooooo`03o`00oooooooo003o00Cooooo00?o003oooooool00?l00oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o0oooool01?l00?oooooo
ooooool00?l2ooooo`05o`00ooooooooooooooooool00?l00_ooool01Ol00?oooooooooooooooooo
003o00Gooooo0_l0000Aooooo`005_ooool2o`0000Cooooo0_l0001>ooooo`03o`00oooooooooooo
00;ooooo00Goo`00ooooooooooooooooo`00o`0?ooooo`03o`000?oooooooooo017ooooo00Goo`00
ooooooooooooooooo`00o`1?ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01_oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Cooooo0_l00?l6ooooo`03o`00oooo
oooooooo00;ooooo0_l00?l5ooooo`;o003o1Oooool00ol00?ooooooooooo`03ooooo`;o003o1Ooo
ool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?oo
ool01?l00?ooooooooooool00?l2ooooo`03o`00ool0003ooooo00?ooooo0_l00?l=ooooo`03o`00
oooooooooooo00?ooooo0_l00?l4ooooo`03o`00oooooooo003o00Cooooo0_l00?l4ooooo`03o`00
oooooooo003o00Cooooo00?o003oooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03
o`00oooooooo003o00?ooooo00?o003oooooooooool01?ooool01?l00?ooooooooooool00?l2oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`0?oooo
o`007?ooool00ol0003oooooooooo`1>ooooo`05o`00oooooooooooooooooooo00000oooool00ol0
0?ooooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00Go003oooooooooooooooooool00003
ooooo`03o`00oooooooooooo04gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`08
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01?ooool2o`00o`Cooooo00?o003o
ooooool00?l01Oooool00ol00?ooooooooooo`03ooooo`;o003o1?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02?ooool00ol00?oo0000ooooo`03
ooooo`03o`00oooooooooooo01;ooooo0_l00?l6ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooool00?l00oooool01?l00?ooooooooooool00?l5ooooo`05o`00ooooooooooooooooool00?l0
0_ooool01Ol00?oooooooooooooooooo003o00Wooooo00Co003ooooooooooooo003o2_ooool00ol0
003oooooooooo`0?ooooo`007?ooool00ol0003oooooooooo`1>ooooo`05o`00oooooooooooooooo
oooo00004oooool00ol0003oooooooooo`0=ooooo`05o`00oooooooooooooooooooo00000oooool0
0ol00?ooooooooooo`1=ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01_ooool0
0ol00?ooooooo`00o`06ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`04ooooo`03o`00
oooooooo003o00Cooooo0_l00?l;ooooo`;o003o1_ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooo003o00Cooooo00Co003ooooooooooooo003o0_ooool00ol00?oo0000ooooo`04ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`;o
003o1Oooool2o`00o`Cooooo00?o003oooooool00?l03?ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooo003o00Kooooo00?o003oooooooooool01?ooool01?l00?ooooooooooool00?l3oooo
o`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`0?
ooooo`007?ooool00ol0003oooooooooo`1Booooo`05ool00?ooooooooooooooool00?l03oooool0
0ol0003oooooooooo`0=ooooo`05o`00oooooooooooooooooooo0000Doooool00ol0003ooooooooo
o`0Yooooo`;o00001oooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooo003o00[ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`;o003o1?ooool2o`00o`Gooooo0_l0
0?l5ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool04?ooool00ol00?ooooooo`00
o`04ooooo`04o`00ooooooooooooo`00o`?ooooo00?o0000ooooooooool00_ooool2o`00o`Gooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo
0_l00?l5ooooo`;o003o1?ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooo003o00?ooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`?o
oooo00Co003ooooooooooooo003o0_ooool01?l00?ooooooooooool00?l3ooooo`04o`00oooooooo
ooooo`00o`Kooooo0_l0000Aooooo`007?ooool2o`0004oooooo00Go003oooooooooooooooooool0
0003ooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool04Oooool01Ooo003ooooooooo
oooooooo003o04oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`06ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`06ooooo`03o`00
oooooooooooo00;ooooo0_l00?l5ooooo`;o003o1Oooool00ol00?ooooooooooo`03ooooo`;o003o
1Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l0
0oooool00ol00?oo0000ooooo`03ooooo`;o003o1Oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`;o003o
1?ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooo003o00?ooooo00?o003oooooool00?l0
1?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l0
0oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o0000ooooooooool0
3oooool001cooooo00?o0000ooooooooool0C_ooool01Ol00?ooooooooooooooooooo`0000?ooooo
00?o003oooooooooool03Oooool00ol0003oooooooooo`0=ooooo`05o`00oooooooooooooooooooo
00000oooool00ol00?ooooooooooo`1=ooooo`03o`000?oooooooooo02;ooooo0_l00005ooooo`03
o`000?oooooooooo00Sooooo00Go003oooooooooooooooooo`00o`02ooooo`07o`00oooooooooooo
ooooool00?ooooooo`00o`04ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool00_oo
ool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Wooooo00?o003oo`000?ooool00_oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00;ooooo0_l00?l4ooooo`03o`00oooo
oooo003o00Cooooo00?o003oooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00
oooooooooooo00Kooooo00Go003oooooooooooooooooo`00o`0:ooooo`03o`000?oooooooooo00oo
oooo000Looooo`03o`000?oooooooooo04kooooo00Go003oooooooooooooooooool0000Cooooo`03
o`000?oooooooooo00gooooo00Go003oooooooooooooooooool00003ooooo`03o`00oooooooooooo
04gooooo00?o0000ooooooooool08Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00Gooooo00?o003ooooooooo00000_oo0004ooooo`?oo`000_ooool01?l00?ooo`00ool00?oo
0003ooooo`04o`00oooo003oo`00ool000;ooooo00Co003oool00?oo003oo`001?ooool3ool000?o
oooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000?o
oooo0ooo0004ooooo`?oo`0000Co003ooooooooooooooooo0ooo0002ooooo`04o`00oooo003oo`00
ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`000oooool3
ool000Cooooo0ooo0003ooooo`?oo`0000Co003ooooooooooooooooo0ooo00000ol00?oooooooooo
o`03ool00004ooooool00?ooooooooooo`?oo`0000?o003oooooooooool00ooo00001?oooooo003o
ooooooooool3ool00003ooooool00?oooooo00?oo`000oooool00ol0003oooooooooo`0?ooooo`00
7?ooool00ol0003oooooooooo`1Booooo`05ool00?ooooooooooooooool00?l03oooool00ol0003o
ooooooooo`0=ooooo`05o`00oooooooooooooooooooo0000Doooool00ol0003oooooooooo`0Qoooo
o`04o`000?ooooooooooo`0000Cooooo2?l000000ol00?oo0000ool00002ool000;o000000?o003o
o`000?oo00000_oo0003o`0000?oo`000ol000001?l00?ooo`00ool00?oo0002o`000004o`00oooo
003oo`00ool000?o000000Co003oool00?oo003oo`000ol00003ool000Co00000ooo0003o`0000?o
o`001?l00003ool000?o00000ooo0004o`0000?oo`000ol00003ool000Co00000ooo00001?l00?oo
0000o`000?l00003ool000?o00000ooo0004o`0000?oo`000ol00003ool000Co00000ooo0003o`00
00?oo`001?l00003ool000?o00000ooo0004o`0000?oo`000ol00003ool000Co00000ooo0003o`00
00?oo`0000Co003oo`000?l0003o00000ooo00000ol00?oo0000o`000003ool00004o`000?l00?oo
0000o`0000?oo`0000?o0000o`00ool000000ooo0004o`00017ooooo000Looooo`;o0000Coooool0
1Ol00?ooooooooooooooooooo`0000?ooooo00?o003oooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`05o`00oooooooooooooooooooo00000oooool00ol00?ooooooooooo`1=ooooo`03o`00
0?oooooooooo027ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03
o`00ooooooooo`0000;oo`000_ooool00ol00?ooooooool00002ool000;ooooo00Co003oool00?oo
003oo`001?ooool3ool000;ooooo00Co003oool00?oo003oo`000oooool01?l00?ooo`00ool00?oo
0003ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo
0003ooooo`?oo`001?ooool3ool00004o`00ooooooooooooooooo`?oo`000_ooool01?l00?ooo`00
ool00?oo0004ooooo`?oo`000oooool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000?o
oooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo00000ol00?ooooooooooo`03ool000Co
oooo0ooo00000ol00?ooooooooooo`03ool000Cooooo0ooo00000ooooooo003oooooo`03ool000?o
oooo00?o0000ooooooooool03oooool001cooooo00?o0000ooooooooool0C_ooool01Ol00?oooooo
ooooooooooooo`0000?ooooo00?o003oooooooooool03Oooool00ol0003oooooooooo`0Aooooo`05
ool00?ooooooooooooooool00?l0Coooool00ol0003oooooooooo`0Qooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool02?ooool01Ol00?oooooooooooooooooo003o00;ooooo00Oo
003oooooooooooooooooo`00oooooooo003o00?ooooo00Co003ooooooooooooo003o1Oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooo003o00[ooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Wooooo00?o003oo`000?ooool00_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00?ooooo0_l00?l4ooooo`03o`00oooooooo003o
00Cooooo00?o003oooooool00?l00oooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo
00?ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`08ooooo`03o`000?oooooo
oooo00oooooo000Eooooo`?o00001?ooool00ol0003oooooooooo`1>ooooo`05o`00oooooooooooo
oooooooo00004oooool00ol0003oooooooooo`0=ooooo`05o`00oooooooooooooooooooo00000ooo
ool00ol00?ooooooooooo`1=ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`05ooooo`04o`00ooooooooooooo`00o`Kooooo00Co003ooooooooo
oooo003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Oo003oooooooooooooooooo`00
oooooooo003o00_ooooo0_l00?l6ooooo`03o`00oooooooooooo00;ooooo0_l00?l5ooooo`;o003o
3?ooool00ol00?ooooooooooo`03ooooo`;o003o1Oooool2o`00o`Cooooo00?o003oo`000?ooool0
0_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`03ooooo`;o003o1Oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooo003o00gooooo00Oo003oooooooooooooooooo`00oooooooo003o00Sooooo00?o0000oooo
ooooool03oooool001Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
05;ooooo00Goo`00ooooooooooooooooo`00o`0?ooooo`03o`000?oooooooooo00gooooo00Go003o
ooooooooooooooooool0001Cooooo`03o`000?oooooooooo02;ooooo0_l00005ooooo`03o`000?oo
oooooooo00Gooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool00?l9ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`;o
003o1?ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`03
o`00oooooooooooo00[ooooo0_l00?l5ooooo`;o003o1Oooool00ol0003oooooooooo`03ooooo`03
o`00oooooooooooo00;ooooo0_l00?l6ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`;o
003o1?ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003ooooo
ool00?l02?ooool00ol0003oooooooooo`0?ooooo`005?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool0C_ooool01Ol00?ooooooooooooooooooo`0000?ooooo00?o003o
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`05o`00oooooooooooooooooooo00000ooo
ool00ol00?ooooooooooo`1=ooooo`03o`000?oooooooooo02Wooooo0_l00006ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l6ooooo`07o`00
ooooooooooooooooool00?ooooooo`00o`04ooooo`03o`00oooooooo003o00?ooooo00?o003ooooo
ool00?l01?ooool00ol00?ooooooo`00o`04ooooo`;o003o1Oooool2o`00o`Gooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00?ooooo0_l00?l5oooo
o`07o`000?ooooooooooooooool00?ooooooo`00o`05ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo0_l0
0?l5ooooo`;o003o1?ooool00ol00?ooooooooooo`04ooooo`;o003o1?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooo003o00?ooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`05ooooo`;o00004Oooool001Gooooo0ol00004ooooo`?o0000C_ooool01Ol00?oooooooooooooo
ooooo`0000?ooooo00?o003oooooooooool03Oooool00ol0003oooooooooo`0Aooooo`05ool00?oo
ooooooooooooool00?l0C_ooool2o`0002_ooooo00?o0000ooooooooool02?ooool01?l00?oooooo
ooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00Go003oooooooooooooooooo`00o`02
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`0:
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02_ooool2o`00o`Gooooo00?o003o
ooooooooool04Oooool00ol00?oo0000ooooo`02ooooo`03o`00oooooooooooo00Cooooo0_l00?lC
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03
ooooo`;o003o1Oooool2o`00o`Cooooo00?o003oooooool00?l01?ooool00ol00?ooooooo`00o`03
ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0?
ooooo`005?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0C_ooool0
1Ol00?ooooooooooooooooooo`0001?ooooo00?o0000ooooooooool03Oooool01Ol00?oooooooooo
ooooooooo`0000?ooooo00?o003oooooooooool0COooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo00Gooooo00Co003ooooooooooooo003o1_ooool01?l00?ooooooooooool00?l2oooo
o`05o`00ooooooooooooooooool00?l00_ooool01ol00?oooooooooooooooooo003oooooool00?l0
0oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Kooooo00?o003oooooooooool0
0_ooool2o`00o`Cooooo00?o003oooooool00?l02oooool00ol00?ooooooooooo`0;ooooo`;o003o
1?ooool01Ol00?oo0000oooooooooooo003o00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooo003o00cooooo00?o003oooooooooool00_ooool00ol00?oo
ooooo`00o`08ooooo`03o`000?oooooooooo00oooooo000Dooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`1Booooo`04ool00?ooooooooooo`00oa3ooooo00?o0000oooo
ooooool03Oooool01Ol00?ooooooooooooooooooo`0005?ooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`05ooooo`04o`00ooooooooooooo`00o`;ooooo00Go003ooooooooooooooooo
o`00o`09ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01_ooool01ol00?oooooo
oooooooooooo003oooooool00?l01?ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooool00?l01?ooool2o`00oa?ooooo0_l00?l4ooooo`03o`00ool0003ooooo
00Cooooo00?o003oooooooooool00_ooool2o`00o`Gooooo00?o003oooooooooool04_ooool00ol0
0?ooooooooooo`03ooooo`;o003o1Oooool00ol00?ooooooooooo`03ooooo`;o003o1Oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo0_l00?l4ooooo`03o`00oooooooo003o
00Cooooo00?o003oooooool00?l02?ooool00ol0003oooooooooo`0?ooooo`005Oooool3o`0000Co
oooo00?o0000ooooooooool0C_ooool01Ol00?ooooooooooooooooooo`0000;ooooo00?o003ooooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`05o`00oooooooooooooooooooo0000Doooool0
0ol0003oooooooooo`0Yooooo`;o00001Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Cooooo00Co003ooooooooooooo003o1_ooool01?l00?ooooooooooool00?l2ooooo`05o`00
ooooooooooooooooool00?l00_ooool01ol00?oooooooooooooooooo003oooooool00?l01?ooool0
0ol00?ooooooo`00o`03ooooo`03o`00oooooooo003o00Cooooo00?o003oooooool00?l01?ooool2
o`00o`Gooooo00?o003oooooooooool02oooool2o`00o`Gooooo00Co0000oooooooooooo003o0_oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04_oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`04ooooo`;o003o1?ooool00ol00?ooooooooooo`04ooooo`;o003o1?oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo0_l0000Aooooo`007?ooool2
o`0004oooooo00Go003oooooooooooooooooool00002ooooo`03o`00oooooooooooo00kooooo00?o
0000ooooooooool04Oooool01Ooo003ooooooooooooooooo003o04oooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`08ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooo
oooo003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool00oooool0
1Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00_ooooo0_l00?l5ooooo`03o`00oooooooooooo017ooooo00Go
003oo`000?ooooooooooo`00o`07ooooo`;o003o6_ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool00oooool2o`00o`Gooooo0_l00?l4ooooo`;o003o
1Oooool2o`00o`Cooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`08ooooo`03o`00
0?oooooooooo00oooooo000Looooo`03o`000?oooooooooo04kooooo00Go003ooooooooooooooooo
ool0000Cooooo`03o`000?oooooooooo00gooooo00Go003oooooooooooooooooool00003ooooo`03
o`00oooooooooooo04gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`04ooooo`05
o`00ooooooooooooooooool00?l01_ooool01?l00?ooooooooooool00?l2ooooo`05o`00oooooooo
ooooooooool00?l00_ooool01?l00?ooooooooooool00?l2ooooo`05o`00ooooooooooooooooool0
0?l01_ooool00ol00?ooooooooooo`06ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`04
ooooo`03o`00oooooooo003o00_ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`03
ooooo`05o`00ool0003oooooooooool00?l01oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo02Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`;o003o3Ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Sooooo00?o0000ooooooooool03ooo
ool001cooooo00?o0000ooooooooool0D_ooool00ooo003oooooooooo`0Aooooo`03o`000?oooooo
oooo00gooooo00Go003oooooooooooooooooool00003ooooo`03o`00oooooooooooo04gooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`04ooooo`05o`00ooooooooooooooooool00?l0
0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Co003ooooooooooooo003o0_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Oooooo00Oo003oooooooooooooooooo`00oooo
oooo003o00?ooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooo003o00Cooooo0_l00?lCooooo`03o`00oooooooooooo00?ooooo00?o003oo`000?ooool0
1?ooool00ol00?ooooooooooo`02ooooo`;o003o1Oooool00ol00?ooooooooooo`0Hooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool00oooool2o`00o`Gooooo0_l00?l5ooooo`03o`00
oooooooooooo00?ooooo0_l00?l4ooooo`03o`00oooooooo003o00Cooooo00?o003oooooool00?l0
2?ooool00ol0003oooooooooo`0?ooooo`007?ooool00ol0003oooooooooo`1>ooooo`05o`00oooo
oooooooooooooooo00000_ooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo00kooooo
00Co003oooooooooooooo`00Doooool00ol0003oooooooooo`0Yooooo`;o00001Oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00kooooo00Co003ooooooooooooo003o0_ooool01Ol0
0?oooooooooooooooooo003o00;ooooo00Oo003oooooooooooooooooo`00oooooooo003o00?ooooo
00Co003ooooooooooooo003o0oooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooo003o00Co
oooo0_l00?l5ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01?ooool00ol0003o
ooooo`00o`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0Hooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`;o003o1?ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Kooooo0_l0000Aooooo`007?ooool2o`0004oooooo
00Go003oooooooooooooooooool00002ooooo`03o`00oooooooooooo00kooooo00?o0000oooooooo
ool04Oooool01Ooo003ooooooooooooooooo003o04oooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`08ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooool00?l00oooool0
1?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00Go003ooooooooooooo
ooooo`00o`02ooooo`03o`00oooooooooooo00?ooooo00Go003oooooooooooooooooo`00o`06oooo
o`03o`00oooooooooooo00_ooooo0_l00?l5ooooo`03o`00oooooooooooo017ooooo00Co003oo`00
0?oooooo003o0oooool01ol00?oooooooooooooooooo003oooooool00?l09oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`04ooooo`;o003o1?ooool2o`00o`Gooooo00?o003oooooooooool02?ooool00ol0003ooooo
ooooo`0?ooooo`007?ooool00ol0003oooooooooo`1>ooooo`05o`00oooooooooooooooooooo0000
0_ooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00Co003ooooooooooooo
o`000oooool00ol00?ooooooooooo`1=ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool01?ooool01Ol00?oooooooooooooooooo003o00Kooooo00?o003oooooool00?l00oooool01?l0
0?ooooooooooool00?l3ooooo`03o`00oooooooooooo00?ooooo00Go003oooooooooooooooooo`00
o`05ooooo`03o`00oooooooooooo00Oooooo00Oo003oooooooooooooooooo`00oooooooo003o00Co
oooo00?o003oooooool00?l02_ooool00ol00?ooooooooooo`0Booooo`04o`00ool0003oooooo`00
o`Oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`;o003o3?ooool00ol0
0?ooooooooooo`03ooooo`;o003o2Oooool00ol0003oooooooooo`0?ooooo`007?ooool00ol0003o
ooooooooo`1Booooo`03ool00?oooooooooo017ooooo00?o0000ooooooooool03_ooool01?l00?oo
oooooooooooo0002ooooo`03o`00oooooooooooo04kooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`04ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`04ooooo`03o`00oooo
oooo003o00?ooooo00Co003ooooooooooooo003o1_ooool00ol00?ooooooooooo`07ooooo`04o`00
ooooooooooooo`00o`;ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooo003o
00Cooooo00?o003oooooooooool04_ooool00ol00?oo0000ooooo`04ooooo`07o`00oooooooooooo
ooooool00?ooooooo`00o`04ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00_oo
ool2o`00o`Gooooo0_l00?l9ooooo`03o`000?oooooooooo00oooooo000Looooo`03o`000?oooooo
oooo04kooooo00Go003oooooooooooooooooool00002ooooo`03o`00oooooooooooo00kooooo00?o
0000ooooooooool03_ooool01?l00?oooooooooooooo001Cooooo`03o`000?oooooooooo02Wooooo
0_l00004ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool01?l00?oooooo
ooooool00?l2ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o0_ooool0
1Ol00?oooooooooooooooooo003o00;ooooo00Oo003oooooooooooooooooo`00oooooooo003o00?o
oooo00Co003ooooooooooooo003o0oooool00ol00?ooooooo`00o`0Jooooo`03o`000?oooooo003o
00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
02Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`;o003o1Oooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo0_l00?l8ooooo`;o00004Oooool001co
oooo0_l0001?ooooo`05o`00oooooooooooooooooooo00000_ooool00ol00?ooooooooooo`0>oooo
o`03o`000?oooooooooo017ooooo00Coo`00oooooooooooo003oD?ooool00ol0003oooooooooo`0Q
ooooo`?o00001Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooo003o00Cooooo00?o003o
ooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooo003o00?ooooo00Co
003ooooooooooooo003o0oooool00ol00?ooooooooooo`03ooooo`05o`00ooooooooooooooooool0
0?l01_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo003o00Cooooo00?o003ooooooooo
ool04_ooool01?l00?oo0000ooooool00?l3ooooo`07o`00ooooooooooooooooool00?ooooooo`00
o`0]ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00?ooooo0_l00?l@ooooo`03o`000?oooooooooo00oooooo000?
ooooo`?o00001?ooool2o`0000Cooooo00?o0000ooooooooool0Coooool01?l00?oooooooooooooo
0002ooooo`03o`00oooooooooooo00kooooo00?o0000ooooooooool03_ooool01?l00?oooooooooo
oooo0002ooooo`03o`00oooooooooooo04kooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool00ol00?oo
ooooooooo`03ooooo`04o`00ooooooooooooo`00o`Kooooo00?o003oooooooooool01oooool01?l0
0?ooooooooooool00?l2ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo01;ooooo00Co003oo`000?oooooo003o1oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo02gooooo00?o003oooooooooool00oooool2o`00o`Gooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`;o003o2Oooool00ol0003ooooo
ooooo`0?ooooo`004?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool0Coooool01?l00?oooooooooooooo000Cooooo`03o`000?oooooooooo00ko
oooo00Co003oooooooooooooo`000_ooool00ol00?ooooooooooo`1>ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooo003o
00Cooooo00?o003oooooool00?l03Oooool01?l00?ooooooooooool00?l3ooooo`04o`00oooooooo
ooooo`00o`Gooooo00Go003oooooooooooooooooo`00o`02ooooo`07o`00ooooooooooooooooool0
0?ooooooo`00o`04ooooo`03o`00oooooooooooo01;ooooo00?o003oo`000?ooool01?ooool01ol0
0?oooooooooooooooooo003oooooool00?l01?ooool00ol00?ooooooooooo`0]ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`;o003o1Ooo
ool2o`00o`Wooooo00?o0000ooooooooool03oooool0013ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo05;ooooo00Coo`00oooooooooooo003o
4?ooool00ol0003oooooooooo`0>ooooo`04o`00ooooooooooooool005?ooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`04ooooo`;o00001?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo017ooooo00Go003oooooooooooooooooo`00o`02ooooo`05o`00oooooooooooo
ooooool00?l00_ooool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo
00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooo003o
01[ooooo00?o0000o`00ooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool0<oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`07ooooo`;o00004Oooool0013o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`?o0000Coooool01?l0
0?oooooooooooooo0002ooooo`03o`00oooooooooooo00kooooo00?o0000ooooooooool04Oooool0
1?oo003oooooooooool00?m?ooooo`;o00009?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Sooooo00?o003oooooool00?l01?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00
oooooooooooo00?ooooo00Co003ooooooooooooo003o1_ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooo003o00Cooooo00?o003oooooooooool04_ooool00ol00?oo0000o`00o`04ooooo`04
o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0coooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool2o`00oa3ooooo00?o0000oooo
ooooool03oooool0013ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo04oooooo00Co003oooooooooooooo`000_ooool00ol00?ooooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00Co003oooooooooooooo`000_ooool00ol00?oooooooooo
o`1>ooooo`03o`000?oooooooooo027ooooo0_l00006ooooo`03o`000?oooooooooo00Sooooo00?o
003oooooool00?l01?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooo003o00Cooooo00?o
003oooooooooool00oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooo003o00[ooooo
00Co003ooooooooooooo003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`0Booooo`03o`00ool0003o003o00Oooooo00?o003ooooo
ooooool0>oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00oooooo000?ooooo`;o
00001?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo04oooooo00Co003ooooo
ooooooooo`004oooool00ol0003oooooooooo`0>ooooo`04o`00ooooooooooooool000;ooooo00?o
003oooooooooool0C_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo0_l0
0?l4ooooo`03o`00oooooooo003o00Cooooo00?o003oooooool00?l03?ooool01Ol00?oooooooooo
oooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`05ooooo`05o`00oooooooooooooooo
ool00?l00_ooool01?l00?ooooooooooool00?l2ooooo`05o`00ooooooooooooooooool00?l05Ooo
ool00ol00?oo0000ooooo`04ooooo`04o`00ooooooooooooo`00o`;ooooo00Go003ooooooooooooo
ooooo`00o`0mooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`08ooooo`03o`000?oooooooooo00oooooo000@ooooo`03o`000?oooooooooo00?ooooo
0_l00004ooooo`03o`000?oooooooooo05;ooooo00Coo`00oooooooooooo003o4?ooool00ol0003o
ooooooooo`0>ooooo`04o`00ooooooooooooool005?ooooo00?o0000ooooooooool0:Oooool2o`00
00Cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Cooooo00Oo003oooooooooooooooooo`00oooooooo003o00Cooooo00?o003oooooool00?l00ooo
ool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00Go003ooooooooo
ooooooooo`00o`02ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool06?ooool0
0ol0003o003oooooo`03ooooo`03o`00oooooooooooo00?ooooo00Go003oooooooooooooooooo`00
o`0mooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`07ooooo`;o00004Oooool001cooooo0_l0001@ooooo`04o`00ooooooooooooool000;ooooo00?o
003oooooooooool03_ooool00ol0003oooooooooo`0>ooooo`04o`00ooooooooooooool000;ooooo
00?o003oooooooooool0C_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00?ooooo
00?o003oooooooooool00_ooool2o`00o`Gooooo0_l00?l4ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooool00?l00oooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00?ooooo
00Co003ooooooooooooo003o1_ooool00ol00?ooooooooooo`0:ooooo`04o`00ooooooooooooo`00
o`?ooooo00?o003oooooooooool04oooool00ol00?oo0000o`00o`04ooooo`03o`00oooooooooooo
00?ooooo00Go003oooooooooooooooooo`00o`13ooooo`03o`00oooooooooooo00oooooo00?o0000
ooooooooool03oooool001cooooo00?o0000ooooooooool0Coooool01?l00?oooooooooooooo0002
ooooo`03o`00oooooooooooo00kooooo00?o0000ooooooooool04Oooool01?oo003oooooooooool0
0?m@ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02?ooool2o`00o`Gooooo0_l0
0?l4ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00oooool00ol00?ooooooo`00
o`04ooooo`03o`00oooooooo003o00gooooo00Co003ooooooooooooo003o0_ooool01Ol00?oooooo
oooooooooooo003o00;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Cooooo`;o
003o2?ooool00ol00?ooooooooooo`18ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool02?ooool00ol0003oooooooooo`0?ooooo`007?ooool00ol0003oooooooooo`1?ooooo`04o`00
ooooooooooooool001?ooooo00?o0000ooooooooool03_ooool01?l00?oooooooooooooo0002oooo
o`03o`00oooooooooooo04kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`02oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool2o`00o`Cooooo00?o003ooooo
ool00?l01?ooool2o`00o`gooooo00Go003oooooooooooooooooo`00o`02ooooo`05o`00oooooooo
ooooooooool00?l01Oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00?ooooo
00Go003oooooooooooooooooo`00o`0Eooooo`03o`00ool0003ooooo00Cooooo00Co003ooooooooo
oooo003o0_ooool01Ol00?oooooooooooooooooo003o04[ooooo00?o003oooooooooool02?ooool0
0ol0003oooooooooo`0?ooooo`007?ooool00ol0003oooooooooo`1Booooo`04ool00?oooooooooo
o`00oa3ooooo00?o0000ooooooooool03_ooool01?l00?oooooooooooooo001Cooooo`03o`000?oo
oooooooo02Wooooo0_l00003ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01?oo
ool00ol00?ooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooool00?l0
0oooool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003ooooo
ooooool06?ooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`;ooooo00Go003o
ooooooooooooooooo`00o`1:ooooo`03o`00oooooooooooo00Oooooo0_l0000Aooooo`007?ooool2
o`00053ooooo00Co003oooooooooooooo`000_ooool00ol00?ooooooooooo`0>ooooo`03o`000?oo
oooooooo00kooooo00Co003oooooooooooooo`000_ooool00ol00?ooooooooooo`1>ooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00?ooooo0_l00?l4ooooo`03o`00oooooooooooo00Cooooo0_l00?l4ooooo`03o`00
oooooooo003o00Cooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`04ooooo`03o`00
oooooooo003o00Kooooo00?o003oooooooooool01?ooool01?l00?ooooooooooool00?l3ooooo`03
o`00oooooooooooo01?ooooo0_l00?l5ooooo`03o`00oooooooooooo00?ooooo00Go003ooooooooo
ooooooooo`00o`1Eooooo`03o`000?oooooooooo00oooooo000Looooo`03o`000?oooooooooo04oo
oooo00Ko003oooooooooooooo`00ooooool00?lAooooo`03o`000?oooooooooo017ooooo00Coo`00
oooooooooooo003oD?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Sooooo0_l0
0?l5ooooo`;o003o1?ooool2o`00o`Gooooo00?o003oooooooooool00oooool00ol00?ooooooo`00
o`04ooooo`03o`00oooooooo003o00cooooo00Go003oooooooooooooooooo`00o`06ooooo`04o`00
ooooooooooooo`00o`Kooooo00?o003oooooooooool04oooool2o`00o`Oooooo00?o003ooooooooo
ool0Foooool00ol0003oooooooooo`0?ooooo`007?ooool00ol0003oooooooooo`1?ooooo`04o`00
ooooooooooooool001?ooooo00?o0000ooooooooool03_ooool01?l00?oooooooooooooo0002oooo
o`03o`00oooooooooooo04kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`02oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03oooo
o`;o003o1Oooool2o`00o`gooooo00Oo003oooooooooooooooooo`00oooooooo003o00Cooooo00?o
003oooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00?ooooo
00Go003oooooooooooooooooo`00o`0Fooooo`03o`00oooooooooooo00?ooooo00?o003oooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o05Gooooo00?o0000ooooooooool03oooool001co
oooo00?o0000ooooooooool0D_ooool00ooo003oooooo`00o`0Aooooo`03o`000?oooooooooo00ko
oooo00Co003oooooooooooooo`000_ooool00ol00?ooooooooooo`1>ooooo`03o`000?oooooooooo
02Wooooo0_l00003ooooo`03o`00oooooooooooo00?ooooo0_l00?l<ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`04ooooo`;o003o1?ooool00ol0
0?ooooooo`00o`04ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o0oooool0
1?l00?ooooooooooool00?l2ooooo`03o`00oooooooooooo01Sooooo00?o0000ooooooooool00ooo
ool00ol00?ooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0E?ooool2o`00017ooooo
000Looooo`;o0000D?ooool01_l00?oooooooooooooo003oooooo`00oa7ooooo00?o0000oooooooo
ool03_ooool01?l00?oooooooooooooo001Cooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool02?ooool2o`00o`Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04oooo
o`;o003o1?ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ool00?l01?ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00Cooooo00Co003ooooo
oooooooo003o0_ooool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?o003o
ooooooooool00oooool01?l00?ooooooooooool00?mFooooo`03o`000?oooooooooo00oooooo000L
ooooo`03o`000?oooooooooo04oooooo00Ko003oooooooooooooo`00ooooool00?lAooooo`03o`00
0?oooooooooo017ooooo00Coo`00oooooooooooo003oD?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo00Sooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`;o
003o1Oooool00ol00?ooooooooooo`03ooooo`;o003o1Oooool2o`00o`gooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo01Gooooo00?o0000oooooooo
ool01Oooool00ol00?ooooooooooo`1Kooooo`03o`000?oooooooooo00oooooo000?ooooo`?o0000
0_ooool5o`0000?ooooo00?o0000ooooooooool0Coooool01_l00?oooooooooooooo003oooooo`00
oa7ooooo00?o0000ooooooooool03oooool00ol00?ooooooool00002ooooo`03o`00oooooooooooo
04kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo
00?ooooo0_l00?l5ooooo`;o003o1?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooool00?l01?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooo003o
00Cooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?lGooooo`03o`000?oooooo
oooo00?ooooo00?o003oooooool00?l00oooool01?l00?ooooooooooool00?mFooooo`03o`000?oo
oooooooo00oooooo000@ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`1Booooo`03ool00?oooooooooo017ooooo00?o0000ooooooooool03ooo
ool00ol00?ooooooool00002ooooo`03o`00oooooooooooo04kooooo00?o0000ooooooooool0:Ooo
ool2o`0001Oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00?ooooo0_l00?l4ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00ooo
ool00ol00?ooooooo`00o`04ooooo`03o`00oooooooo003o00?ooooo00?o003oooooooooool06?oo
ool00ol0003oooooooooo`03ooooo`03o`00oooooooo003o00?ooooo00Co003ooooooooooooo003o
EOooool2o`00017ooooo000@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool3o`0004oooooo00Ko003oooooooooooooo`00ooooool00?lAooooo`03o`000?oooooooooo00oo
oooo00?o003ooooooooo0000D_ooool2o`0002_ooooo00?o0000ooooooooool05Oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooool00?l01?ooool2o`00o`Cooooo00?o003oooooool00?l01_ooool01Ol00?oo
oooooooooooooooo003o00;ooooo00?o003oooooooooool05Oooool00ol0003oooooooooo`03oooo
o`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003oE_ooool00ol0003oooooooooo`0?
ooooo`004?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0Coooool01_l00?oooooooooooooo003oooooo`00oa7ooooo00?o0000ooooooooool04Ooo
ool00ooo003oooooo`00o`1Aooooo`03o`000?oooooooooo023ooooo1Ol00004ooooo`03o`000?oo
oooooooo01Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`;o003o1Ooo
ool2o`00o`cooooo00?o003oooooooooool02Oooool00ol00?ooooooo`00o`03ooooo`04o`00oooo
ooooooooo`00oaOooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`1Looooo`03o`00
0?oooooooooo00oooooo000@ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo0000057ooooo00Ko003oooooooooooooo`00ooooool00?lAooooo`03o`000?oooooo
oooo00oooooo00Go003ooooooooo003oooooo`00o`1Aooooo`03o`000?oooooooooo027ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo
0_l00?l5ooooo`;o003o1?ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool05Oooool00ol0003oooooooooo`03ooooo`;o003o1?ooool01?l00?oooooo
ooooool00?mFooooo`03o`000?oooooooooo00oooooo000?ooooo`;o00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool0D_ooool00ooo003oooooooooo`0Aooooo`03
o`000?oooooooooo00oooooo00Go003ooooooooo003oooooo`00o`1Aooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool01?ooool2o`0001gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`03ooooo`;o003o1?ooool2o`00o`Gooooo00?o003oooooooooool00oooool00ol0
0?ooooooo`00o`04ooooo`03o`00oooooooo003o00?ooooo00?o003oooooooooool06?ooool00ol0
003oooooooooo`03ooooo`;o003o1?ooool01?l00?ooooooooooool00?mEooooo`;o00004Oooool0
013ooooo00?o0000ooooooooool00_ooool3o`0000Cooooo0_l0001Cooooo`03ool00?oooooo003o
017ooooo00?o0000ooooooooool03oooool00ol00?ooooooool0001Cooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Looooo`03o`00oooooooooooo
00?ooooo0_l00?l5ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`;o003o1?ooool00ol0
0?ooooooo`00o`06ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`0Hooooo`03o`000?oo
oooooooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`1Gooooo`03o`000?oo
oooooooo00oooooo000Looooo`03o`000?oooooooooo053ooooo00Go003ooooooooo003oooooo`00
o`0Aooooo`03o`000?oooooooooo017ooooo00?oo`00ooooool00?l0DOooool00ol0003ooooooooo
o`0Pooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Rooooo`;o003o
1Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Wooooo00?o003oooooool00?l0
0oooool00ol00?ooooooo`00o`0Hooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0
G?ooool00ol0003oooooooooo`0?ooooo`007?ooool00ol0003oooooooooo`1@ooooo`05o`00oooo
ooooo`00ooooool00?l04Oooool00ol0003oooooooooo`0?ooooo`05o`00ooooooooo`00ooooool0
0?l0DOooool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`0Rooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool2o`00
o`Gooooo0_l00?l4ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo0_l00?l4ooooo`03o`00oooooooo003o
05Oooooo00?o0000ooooooooool03oooool001cooooo00?o0000ooooooooool0D?ooool00ol00?oo
ooooool0000Cooooo`03o`000?oooooooooo00oooooo00Go003ooooooooo003oooooo`00o`1Aoooo
o`03o`000?oooooooooo027ooooo0ol00005ooooo`;o0000:_ooool00ol00?ooooooooooo`03oooo
o`;o003o1Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Cooooo0_l00?l4oooo
o`03o`00oooooooooooo01Sooooo00?o0000ooooooooool00oooool2o`00o`Cooooo00?o003ooooo
ool00?l0E_ooool2o`00017ooooo000Looooo`;o0000Doooool00ooo003oooooo`00o`0Aooooo`03
o`000?oooooooooo00oooooo00?o003ooooooooo0000Doooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo02Wooooo00?o003oooooooooool00oooool2o`00o`Gooooo0_l00?l4ooooo`;o
003o1_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o01Sooooo00?o0000oooooooo
ool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o05Oooooo00?o0000oooooooo
ool03oooool001cooooo00?o0000ooooooooool0D?ooool01Ol00?ooooooool00?oooooo003o017o
oooo00?o0000ooooooooool04Oooool00ooo003oooooo`00o`1Aooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0:Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o01So
oooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`1Mooooo`03o`000?oooooooooo00oo
oooo000Looooo`03o`000?oooooooooo053ooooo00Go003ooooooooo003oooooo`00o`0Aooooo`03
o`000?oooooooooo017ooooo00?oo`00ooooool00?l0DOooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo02oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`;o
003o1Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Kooooo00?o0000oooooooo
ool00oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo05Gooooo00?o0000oooooooo
ool03oooool001cooooo00?o0000ooooooooool0D?ooool00ol00?ooooooool0000Cooooo`03o`00
0?oooooooooo00oooooo00Go003ooooooooo003oooooo`00o`1Aooooo`03o`000?oooooooooo02Wo
oooo0_l0000`ooooo`;o003o1Oooool00ol00?ooooooooooo`03ooooo`;o003o1Oooool2o`00o`Co
oooo00?o003oooooooooool06?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooool00?l0E_ooool2o`00017ooooo000Looooo`03o`000?oooooooooo05;ooooo
00?oo`00o`00ooooool04Oooool00ol0003oooooooooo`0?ooooo`03o`00ooooooooo`0005?ooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0fooooo`03o`00oooooooooooo00?ooooo
0_l00?l5ooooo`;o003o1?ooool00ol00?ooooooo`00o`0Hooooo`03o`000?oooooooooo00?ooooo
00?o003oooooooooool00oooool00ol00?ooooooo`00o`1Gooooo`03o`000?oooooooooo00oooooo
000Looooo`;o0000DOooool01?l00?ooooooool00?l00?lBooooo`03o`000?oooooooooo00oooooo
00Go003ooooooooo003oooooo`00o`1Aooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool0=_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool0
0?l06?ooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo05Oooooo00?o0000oooooooo
ool03oooool000oooooo0ol00004ooooo`?o00000oooool00ol0003oooooooooo`1@ooooo`04o`00
ooooooooo`00o`00oa;ooooo00?o0000ooooooooool04Oooool00ooo003oooooo`00o`1Aooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0=_ooool00ol00?ooooooooooo`03ooooo`;o
003o1Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01Oooooo00?o0000oooooooo
ool02_ooool00ol00?ooooooooooo`1Fooooo`03o`000?oooooooooo00oooooo000@ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1@ooooo`03o`00
ooooooooo`0001?ooooo00?o0000ooooooooool04?ooool01?l00?ooo`00ooooool00?mAooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0??ooool2o`00o`Gooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0Hooooo`03o`000?oooooooooo00Wooooo0_l00?mHooooo`03
o`000?oooooooooo00oooooo000@ooooo`04o`000?ooooooooooooooo`Go00000oooool00ol0003o
ooooooooo`1Booooo`03ool00?l00?oooooo017ooooo00?o0000ooooooooool04?ooool00ol00?oo
o`00ooooo`1Booooo`03o`000?oooooooooo02Wooooo0_l0000mooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool00oooool2o`00oaWooooo00?o0000ooooooooool02Oooool2o`00oeOo
oooo0_l0000Aooooo`004?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooooooo
ool00_ooool3o`00053ooooo00Co003ooooooooo003o003o4_ooool00ol0003oooooooooo`0@oooo
o`03o`00oooo003o003o057ooooo0_l0000[ooooo`03o`000?oooooooooo04?ooooo00?o003ooooo
ooooool00oooool2o`00oaWooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`1Goooo
o`03o`000?oooooooooo00oooooo000@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool0
00001?ooool00ol0003oooooooooo`1@ooooo`04o`00ooooooooo`00o`00oa;ooooo00?o0000oooo
ooooool04Oooool00ooo003o003oooooo`1Aooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0@oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01Oooooo00?o0000oooo
ooooool02_ooool00ol00?ooooooooooo`1Fooooo`03o`000?oooooooooo00oooooo000?ooooo`;o
00001Oooool2o`0000Cooooo00?o0000ooooooooool0DOooool00ol00?ooo`00ooooo`0Booooo`03
o`000?oooooooooo013ooooo00?o003oool00?l00?l0D_ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo04?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Hooooo`03
o`000?oooooooooo00Wooooo0_l00?mHooooo`03o`000?oooooooooo00oooooo000@ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Booooo`03ool0
0?l00?oooooo017ooooo00?o0000ooooooooool04?ooool00ol00?ooo`00o`00o`1Booooo`03o`00
0?oooooooooo02Wooooo0_l0001:ooooo`;o003o6Oooool00ol0003oooooooooo`09ooooo`;o003o
Eoooool2o`00017ooooo000Looooo`;o0000D_ooool00ol00?ooo`00o`00o`0Booooo`03o`000?oo
oooooooo013ooooo00?o003oool00?ooool0D_ooool00ol0003oooooooooo`0Qooooo`?o00001Ooo
ool00ol0003oooooooooo`19ooooo`;o003o6Oooool00ol0003oooooooooo`0:ooooo`03o`00oooo
oooooooo05Kooooo00?o0000ooooooooool03oooool001cooooo00?o0000ooooooooool0DOooool0
0ol00?ooo`00o`00o`0Booooo`03o`000?oooooooooo017ooooo00?oo`00o`00ooooool0DOooool0
0ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`1:ooooo`03o`00oooooooooooo01Oooooo00?o0000ooooooooool0Hoooool00ol0003ooooooooo
o`0?ooooo`007?ooool00ol0003oooooooooo`1Aooooo`03o`00oooo003ooooo01;ooooo00?o0000
ooooooooool04?ooool00ol00?ooo`00o`00o`1Booooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo06?ooooo00?o0000
ooooooooool03oooool001cooooo00?o0000ooooooooool0DOooool3ool001;ooooo00?o0000oooo
ooooool04?ooool3ool005;ooooo00?o0000ooooooooool08_ooool2o`0000Gooooo0_l0000Foooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool05?ooool2o`00017ooooo000Looooo`;o
0000D_ooool3ool001;ooooo00?o0000ooooooooool04?ooool3ool005;ooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03oooool001cooooo00?o0000ooooooooool0DOooool3ool001;ooooo00?o0000ooooooooool0
4?ooool3ool005;ooooo00?o0000ooooooooool08?ooool01Ol0003ooooooooooooooooo000000Co
ooooc_l0000Aooooo`007?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo027ooooo
0ol0003Tooooo`007?oooooBo`000?oooooo2oooool00?oooooonOooool00?oooooonOooool00?oo
oooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oo
oooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oo
oooonOooool00?oooooonOooool0023ooooo0_l0000Pooooo`?o00007?ooool3o`0000Cooooo0_l0
000Iooooo`?o00000oooool3o`0001Wooooo1Ol00003ooooo`;o00006?ooool5o`0000;ooooo0ol0
001;ooooo`;o00007oooool3o`0001cooooo0ol00004ooooo`;o00006Oooool3o`0000?ooooo0ol0
000Hooooo`Go00000oooool2o`0001Sooooo1Ol00002ooooo`?o0000;Oooool001oooooo00Co0000
oooooooooooo00007_ooool01Ol0003ooooooooooooooooo000001cooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool0000Iooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`0Gooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00006?oo
ool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool0Aoooool01?l0003o
ooooooooool0000Mooooo`05o`000?ooooooooooooooool000007?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0001Wooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo01Kooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Hoooo
o`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`0Zooooo`007oooool0
1?l0003oooooooooool0000Rooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool0000Iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Wooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`17ooooo`04o`000?ooooooooooo`00027ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Wooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00006Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02[ooooo000O
ooooo`04o`000?ooooooooooo`0002;ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0001Wooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Iooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0Aoooool01?l0003oooooooooool0000Qoooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000I
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo02[ooooo000Oooooo`04o`000?ooooooooooo`0001kooooo1?l0000Mooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00006Oooool01?l0003oooooooooooooool4o`0001Wo
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001Oooooo00Ko0000
ooooooooooooooooo`000?ooool4o`0004[ooooo00Co0000oooooooooooo00007Oooool4o`0001go
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Iooooo`04o`000?oooooooooo
ooooo`Co00006?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5oooool01_l0003ooooooooooooooooo0000ooooo`Co0000;Oooool001oooooo00Co0000oooooooo
oooo00007_ooool00ol0003oooooooooo`0Mooooo`;o00001?ooool01?l0003oooooooooool0000H
ooooo`;o00000oooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool0000Gooooo`07o`000?ooooooooooooooool0003oooooo`00001=oooo
o`04o`000?ooooooooooo`0001gooooo00?o0000ooooooooool07Oooool2o`0000Cooooo00Co0000
oooooooooooo00006?ooool2o`0000?ooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00005oooool01ol0003ooooooooooooooooo0000
ooooool00000<?ooool0023ooooo0_l0000Oooooo`Go00007?ooool00ol0003oooooooooo`03oooo
o`;o00006_ooool01?l0003oooooooooooooool5o`0001Wooooo0ol00004ooooo`;o00006Oooool3
o`0000;ooooo1Ol0001:ooooo`;o00007_ooool5o`0001cooooo00?o0000ooooooooool00oooool2
o`0001[ooooo00Co0000oooooooooooooooo1Ol0000Hooooo`?o00001?ooool2o`0001Wooooo0ol0
0002ooooo`Go0000;?ooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooo
nOooool001coooood_l0000Sooooo`?o00001?ooooo@o`00013ooooo000Fooooo`;o00001?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo023ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool001Gooooo00Co0000
oooooooooooo00000oooool01?l0003oooooooooooooool3ool000Cooooo0ooo0004ooooo`?oo`00
2oooool3ool000Cooooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo0004ooooo`?oo`00
1?ooool3ool000Cooooo0ooo0004ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`00
1?ooool3ool000Cooooo0ooo0004ooooo`?oo`001?ooool3ool000Cooooo0ooo0003ooooo`?oo`00
1?ooool3ool000Cooooo0ooo0004ooooo`?oo`001?ooool3ool000Cooooo0ooo000;ooooo`?oo`00
0oooool3ool000?ooooo00?o0000ooooooooool06_ooool5o`0000Gooooo00Go0000oooooooooooo
ooooo`00003>ooooo`03o`000?oooooooooo00kooooo000Eooooo`04o`000?ooooooooooo`0000?o
oooo0ol000001?ooooooo`00ool00?oo0004ooooo`?oo`001?ooool3ool000Gooooo00?oo`00oooo
ooooool00oooool3ool000Cooooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo0004oooo
o`?oo`001?ooool3ool000Cooooo0ooo0004ooooo`?oo`001?ooool3ool000?ooooo0ooo0004oooo
o`?oo`001?ooool3ool000Cooooo0ooo0004ooooo`?oo`001?ooool3ool000Cooooo0ooo0003oooo
o`?oo`001?ooool3ool000Cooooo0ooo0004ooooo`?oo`001?ooool3ool000Cooooo0ooo0005oooo
o`03ool00?oooooooooo00?ooooo0ooo0003ooooo`?oo`000_ooool2o`0002Cooooo0_l00004oooo
o`?o0000b_ooool3o`00013ooooo000Eooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooo
oooooooooooo0ooo0004ooooo`?oo`001?ooool3ool000Gooooo00?oo`00ooooooooool00oooool3
ool000Cooooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo0004ooooo`?oo`001?ooool3
ool000Cooooo0ooo0004ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`001?ooool3
ool000Cooooo0ooo0004ooooo`?oo`001?ooool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3
ool000Cooooo0ooo0004ooooo`?oo`001?ooool3ool000Cooooo0ooo0005ooooo`03ool00?oooooo
oooo00?ooooo0ooo0003ooooo`?oo`000oooool00ol0003oooooooooo`0Tooooo`05o`000?oooooo
ooooooooool00000c_ooool00ol0003oooooooooo`0>ooooo`005Oooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0X_ooool00ooo003ooooooooo
o`0?ooooo`03o`000?oooooooooo023ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo0<cooooo00?o0000ooooooooool03_ooool001Gooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo0:;ooooo00?oo`00ooooooooool0
3oooool00ol0003oooooooooo`0Qooooo`?o00001?ooool00ol0003oooooooooo`3<ooooo`03o`00
0?oooooooooo00kooooo000Fooooo`;o00001?ooool2o`0001Sooooo00?oo`00ooooooooool0X_oo
ool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo02Sooooo0_l0003<ooooo`;o00004?oo
ool001cooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`2Rooooo`03ool00?oooooo
oooo00oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooo
oooo00kooooo000Looooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0X_ooool00ooo
003oooooooooo`0?ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0c?ooool00ol0
003oooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo0:;o
oooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0<co
oooo00?o0000ooooooooool03_ooool001cooooo0_l0000Hooooo`03ool00?oooooooooo0:;ooooo
00?oo`00ooooooooool03oooool00ol0003oooooooooo`0Xooooo`;o0000c?ooool2o`00013ooooo
000Looooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0X_ooool00ooo003ooooooooo
o`0?ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0c?ooool00ol0003ooooooooo
o`0>ooooo`007?ooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo0:;ooooo00?oo`00
ooooooooool03oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0<cooooo00?o0000
ooooooooool03_ooool001cooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`2Roooo
o`03ool00?oooooooooo00oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`3<oooo
o`03o`000?oooooooooo00kooooo000Looooo`;o00006?ooool00ooo003oooooooooo`2Rooooo`03
ool00?oooooooooo00oooooo00?o0000ooooooooool0:?ooool2o`000<cooooo0_l0000@ooooo`00
7?ooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo0:;ooooo00?oo`00ooooooooool0
3oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool0
3_ooool001Cooooo1Ol00003ooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0X_oo
ool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0c?oo
ool00ol0003oooooooooo`0>ooooo`005Oooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo01Oooooo00?oo`00ooooooooool0X_ooool00ooo003oooooooooo`0?ooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`005_ooool0
0ol0003oooooooooo`03ooooo`?o00005oooool00ooo003oooooooooo`2Rooooo`03ool00?oooooo
oooo00kooooo0_l0000Zooooo`;o0000c?ooool2o`00013ooooo000Gooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`2Rooooo`03ool00?oooooooooo
00oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo
00kooooo000Dooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Goooo
o`03ool00?oooooooooo0:;ooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0Poooo
o`Go00000oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000Dooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo
0:;ooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0Qooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`005Oooool3o`00
00Cooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`2Rooooo`03ool00?oooooooooo
00oooooo00?o0000ooooooooool06_ooool5o`0000?ooooo00?o0000ooooooooool00oooool3o`00
0<[ooooo0ol0000@ooooo`007?ooool2o`0001Sooooo00?oo`00ooooooooool0X_ooool00ooo003o
ooooooooo`0?ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000Looooo`03o`000?oooooooooo01Oooooo
00?oo`00ooooooooool0X_ooool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo023ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo0<cooooo00?o0000oooooooo
ool03_ooool001cooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`2Rooooo`03ool0
0?oooooooooo00oooooo00?o0000ooooooooool08?ooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`007?ooool00ol0003ooooo
ooooo`0Gooooo`03ool00?oooooooooo0:;ooooo00?oo`00ooooooooool03oooool00ol0003ooooo
ooooo`0Qooooo`?o00001?ooool2o`000<cooooo0_l0000@ooooo`007?ooool2o`0001Sooooo00?o
o`00ooooooooool0X_ooool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`0G
ooooo`03ool00?oooooooooo0:;ooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool001cooooo00?o0000oooo
ooooool05oooool00ooo003oooooooooo`2Rooooo`03ool00?oooooooooo00oooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000Looooo`03
o`000?oooooooooo01Oooooo00?oo`00ooooooooool0X_ooool00ooo003oooooooooo`0?ooooo`03
o`000?oooooooooo02Sooooo0_l0003<ooooo`;o00004?ooool001cooooo0_l0000Hooooo`03ool0
0?oooooooooo0:;ooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo0<cooooo00?o0000ooooooooool03_ooool001Kooooo0ol00003ooooo`03o`000?oo
oooooooo01Oooooo00?oo`00ooooooooool0X_ooool00ooo003oooooooooo`0?ooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`005oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0X_ooool0
0ooo003oooooooooo`0?ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0c?ooool0
0ol0003oooooooooo`0>ooooo`005?ooool5o`0000?ooooo00?o0000ooooooooool05oooool00ooo
003oooooooooo`2Rooooo`03ool00?oooooooooo00oooooo00?o0000ooooooooool0:?ooool2o`00
0<cooooo0_l0000@ooooo`005?ooool01?l0003oooooooooool00004ooooo`?o00005oooool00ooo
003oooooooooo`2Rooooo`03ool00?oooooooooo00kooooo0_l0000Zooooo`03o`000?oooooooooo
0<cooooo00?o0000ooooooooool03_ooool001Gooooo00?o0000ooooool000001?ooool00ol0003o
ooooooooo`0Gooooo`03ool00?oooooooooo0:;ooooo00?oo`00ooooooooool03oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool001Kooooo
0_l00004ooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0X_ooool00ooo003ooooo
ooooo`0?ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0c?ooool00ol0003ooooo
ooooo`0>ooooo`005oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo00?o
o`00ooooooooool0X_ooool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo02Sooooo0_l0
003<ooooo`;o00004?ooool001cooooo0_l0000Hooooo`03ool00?oooooooooo0:;ooooo00?oo`00
ooooooooool03oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0<cooooo00?o0000
ooooooooool03_ooool001cooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`2Roooo
o`03ool00?oooooooooo00oooooo00?o0000ooooooooool08Oooool3o`0000Cooooo00?o0000oooo
ooooool0c?ooool00ol0003oooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`0Gooooo`03
ool00?oooooooooo0:;ooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`00
7?ooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo0:;ooooo00?oo`00ooooooooool0
3oooool00ol0003oooooooooo`0Jooooo`Go00000oooool00ol0003oooooooooo`03ooooo`?o0000
b_ooool3o`00013ooooo000Looooo`;o00006?ooool00ooo003oooooooooo`2Rooooo`03ool00?oo
oooooooo00oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo0<cooooo00?o0000ooooooooool03_ooool001cooooo00?o0000ooooooooool05oooool0
0ooo003oooooooooo`2Rooooo`03ool00?oooooooooo00oooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool0
01cooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`2Rooooo`03ool00?oooooooooo
00oooooo00?o0000ooooooooool08Oooool2o`0000Gooooo00?o0000ooooooooool0c?ooool00ol0
003oooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo0:;o
oooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?o
oooo0_l0003<ooooo`;o00004?ooool001cooooo0_l0000Hooooo`03ool00?oooooooooo0:;ooooo
00?oo`00ooooooooool03oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0<cooooo
00?o0000ooooooooool03_ooool001cooooo00?o0000ooooooooool05oooool00ooo003ooooooooo
o`2Rooooo`03ool00?oooooooooo00oooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`3<ooooo`03o`000?oooooooooo00kooooo000Eooooo`?o00001?ooool00ol0003oooooooooo`0G
ooooo`03ool00?oooooooooo0:;ooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool001Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0X_ooool0
0ooo003oooooooooo`0?ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0c?ooool0
0ol0003oooooooooo`0>ooooo`005?ooool01Ol0003ooooooooooooooooo000000?ooooo0ol0000G
ooooo`03ool00?oooooooooo0:;ooooo00?oo`00ooooooooool03_ooool2o`0002[ooooo0_l0003<
ooooo`;o00004?ooool001Cooooo1?l00004ooooo`03o`000?oooooooooo01Oooooo00?oo`00oooo
ooooool0X_ooool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0c?ooool00ol0003oooooooooo`0>ooooo`005?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Oooooo00?oo`00ooooooooool0X_ooool00ooo003oooooooooo`0?ooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`00
5Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0
X_ooool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
c?ooool00ol0003oooooooooo`0>ooooo`005_ooool2o`0000Cooooo0_l0000Hooooo`03ool00?oo
oooooooo0:;ooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0Xooooo`;o0000c?oo
ool2o`00013ooooo000Looooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0X_ooool0
0ooo003oooooooooo`0?ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0c?ooool0
0ol0003oooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo
0:;ooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
0<cooooo00?o0000ooooooooool03_ooool001cooooo00?o0000ooooooooool05oooool00ooo003o
ooooooooo`2Rooooo`03ool00?oooooooooo00oooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000Looooo`;o00006?ooool00ooo003ooooo
ooooo`2Rooooo`03ool00?oooooooooo00oooooo00?o0000ooooooooool0:?ooool2o`000<cooooo
0_l0000@ooooo`007?ooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo0:;ooooo00?o
o`00ooooooooool03oooool00ol0003oooooooooo`0Rooooo`;o00001?ooool00ol0003ooooooooo
o`3<ooooo`03o`000?oooooooooo00kooooo000Looooo`03o`000?oooooooooo01Oooooo00?oo`00
ooooooooool0X_ooool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo027ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000L
ooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0X_ooool00ooo003oooooooooo`0?
ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00000oooool01?l0003ooooooooo
ooooool3ool000Cooooo0ooo0004ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`00
1?ooool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000Cooooo0ooo0004ooooo`?oo`00
1?ooool3ool000?ooooo0ooo0004ooooo`?oo`001?ooool3ool000Cooooo0ooo0003ooooo`?oo`00
1?ooool3ool000Cooooo0ooo0004ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`00
1?ooool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000Cooooo0ooo0004ooooo`?oo`00
0oooool00ol0003oooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`0Gooooo`03ool00?oo
oooooooo0:;ooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0Qooooo`04o`000?oo
ooooooooo`0000?ooooo0ol000001?ooooooo`00ool00?oo0004ooooo`?oo`001?ooool3ool000Co
oooo0ooo0003ooooo`?oo`001?ooool3ool000Cooooo0ooo0004ooooo`?oo`000oooool3ool000Co
oooo0ooo0004ooooo`?oo`001?ooool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000Co
oooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo0004ooooo`?oo`001?ooool3ool000Co
oooo0ooo0003ooooo`?oo`001?ooool3ool000Cooooo0ooo0004ooooo`?oo`000oooool3ool000Co
oooo0ooo0004ooooo`?oo`001?ooool3ool00004ooooool0003o0000o`00013ooooo000Looooo`;o
00006?ooool00ooo003oooooooooo`2Rooooo`03ool00?oooooooooo00oooooo00?o0000oooooooo
ool08Oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooooooo`?oo`001?ooool3
ool000Cooooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo0004ooooo`?oo`001?ooool3
ool000?ooooo0ooo0004ooooo`?oo`001?ooool3ool000Cooooo0ooo0004ooooo`?oo`000oooool3
ool000Cooooo0ooo0004ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`001?ooool3
ool000Cooooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo0004ooooo`?oo`001?ooool3
ool000?ooooo0ooo0004ooooo`?oo`001?ooool3ool000Cooooo0ooo0003ooooo`03o`000?oooooo
oooo00kooooo000Eooooo`?o00001?ooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo
0:;ooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0Qooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`005?ooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`2R
ooooo`03ool00?oooooooooo00oooooo00?o0000ooooooooool08_ooool2o`0000Cooooo00?o0000
ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`005?ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`2Rooooo`03ool00?oooooo
oooo00oooooo00?o0000ooooooooool0:?ooool2o`000<cooooo0_l0000@ooooo`005Oooool3o`00
00Cooooo0ol0000Gooooo`03ool00?oooooooooo0:;ooooo00?oo`00ooooooooool03_ooool2o`00
02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`005?ooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`2Roooo
o`03ool00?oooooooooo00oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`3<oooo
o`03o`000?oooooooooo00kooooo000Dooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`0Gooooo`03ool00?oooooooooo0:;ooooo00?oo`00ooooooooool03oooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool001Go
oooo0ol00004ooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0X_ooool00ooo003o
ooooooooo`0?ooooo`03o`000?oooooooooo02Sooooo0_l0003<ooooo`;o00004?ooool001cooooo
0_l0000Hooooo`03ool00?oooooooooo0:;ooooo00?oo`00ooooooooool03oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool001cooooo00?o
0000ooooooooool05oooool00ooo003oooooooooo`2Rooooo`03ool00?oooooooooo00oooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000L
ooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0X_ooool00ooo003oooooooooo`0?
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>
ooooo`007?ooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo0:;ooooo00?oo`00oooo
ooooool03oooool00ol0003oooooooooo`0Xooooo`;o0000c?ooool2o`00013ooooo000Looooo`;o
00006?ooool00ooo003oooooooooo`2Rooooo`03ool00?oooooooooo00oooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000Looooo`03o`00
0?oooooooooo01Oooooo00?oo`00ooooooooool0X_ooool00ooo003oooooooooo`0?ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`007?oo
ool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo0:;ooooo00?oo`00ooooooooool03ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_oo
ool001cooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`2Rooooo`03ool00?oooooo
oooo00oooooo00?o0000ooooooooool0:?ooool2o`000<cooooo0_l0000@ooooo`007?ooool2o`00
01Sooooo00?oo`00ooooooooool0X_ooool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`007?ooool00ol0003o
ooooooooo`0Gooooo`03ool00?oooooooooo0:;ooooo00?oo`00ooooooooool03oooool00ol0003o
ooooooooo`0Qooooo`?o00001?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00ko
oooo000?ooooo`?o00001?ooool2o`0000Cooooo00?o0000ooooooooool05oooool00ooo003ooooo
ooooo`2Rooooo`03ool00?oooooooooo00oooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool0013ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo01Oooooo
00?oo`00ooooooooool0X_ooool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool00oooool3o`000<[ooooo0ol0000@ooooo`004?ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000?ooooo0ol0000Gooooo`03ool00?oooooooooo0:;ooooo
00?oo`00ooooooooool03_ooool2o`0002Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`3<ooooo`03o`000?oooooooooo00kooooo000@ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo0:;ooooo
00?oo`00ooooooooool03oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`004?ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool05oooool00ooo003ooooo
ooooo`2Rooooo`03ool00?oooooooooo00oooooo00?o0000ooooooooool08Oooool2o`0000Gooooo
00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`003oooool2o`0000Cooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo0:;ooooo
00?oo`00ooooooooool03oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo
0_l0003<ooooo`;o00004?ooool0013ooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l0
000Hooooo`03ool00?oooooooooo0:;ooooo00?oo`00ooooooooool03oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool001cooooo00?o0000
ooooooooool05oooool00ooo003oooooooooo`2Rooooo`03ool00?oooooooooo00oooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000Loooo
o`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0X_ooool00ooo003oooooooooo`0?oooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>oooo
o`007?ooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo0:;ooooo00?oo`00oooooooo
ool03oooool00ol0003oooooooooo`0Xooooo`;o0000c?ooool2o`00013ooooo000Looooo`;o0000
6?ooool00ooo003oooooooooo`2Rooooo`03ool00?oooooooooo00oooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000Looooo`03o`000?oo
oooooooo01Oooooo00?oo`00ooooooooool0X_ooool00ooo003oooooooooo`0?ooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`007?ooool0
0ol0003oooooooooo`0Gooooo`03ool00?oooooooooo0:;ooooo00?oo`00ooooooooool03oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool0
01cooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`2Rooooo`03ool00?oooooooooo
00oooooo00?o0000ooooooooool0:?ooool2o`000<cooooo0_l0000@ooooo`007?ooool2o`0001So
oooo00?oo`00ooooooooool0X_ooool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`007?ooool00ol0003ooooo
ooooo`0Gooooo`03ool00?oooooooooo0:;ooooo00?oo`00ooooooooool03oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool000oooooo0ol0
0002ooooo`Go00000oooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo0:;ooooo00?o
o`00ooooooooool03oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0<cooooo00?o
0000ooooooooool03_ooool0013ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0X_ooool00ooo003ooooooooo
o`0?ooooo`03o`000?oooooooooo02Sooooo0_l0003<ooooo`;o00004?ooool0013ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`?o00005oooool00ooo003oooooooooo`2R
ooooo`03ool00?oooooooooo00kooooo0_l0000Zooooo`03o`000?oooooooooo0<cooooo00?o0000
ooooooooool03_ooool0013ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0X_ooool00ooo003oooooooooo`0?oooo
o`03o`000?oooooooooo023ooooo1Ol00003ooooo`03o`000?oooooooooo0<cooooo00?o0000oooo
ooooool03_ooool0013ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000006Oooool00ooo003oooooooooo`2Rooooo`03ool00?oooooooooo00oooooo00?o0000
ooooooooool08Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo0<cooooo00?o
0000ooooooooool03_ooool000oooooo0_l00003ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo0:;ooooo00?oo`00ooooooooool03ooo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo0ol0003:ooooo`?o00004?oo
ool0013ooooo00?o0000ooooooooool00_ooool3o`0000Cooooo00?o0000ooooooooool05oooool0
0ooo003oooooooooo`2Rooooo`03ool00?oooooooooo00oooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool0
01cooooo0_l0000Hooooo`03ool00?oooooooooo0:;ooooo00?oo`00ooooooooool03oooool00ol0
003oooooooooo`0Pooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`3<
ooooo`03o`000?oooooooooo00kooooo000Looooo`03o`000?oooooooooo01Oooooo00?oo`00oooo
ooooool0X_ooool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo023ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool0
01cooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`2Rooooo`03ool00?oooooooooo
00oooooo00?o0000ooooooooool08Oooool3o`0000Cooooo0_l0003<ooooo`;o00004?ooool001co
oooo00?o0000ooooooooool05oooool00ooo003oooooooooo`2Rooooo`03ool00?oooooooooo00oo
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00ko
oooo000Looooo`;o00006?ooool00ooo003oooooooooo`2Rooooo`03ool00?oooooooooo00oooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo
000Looooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0X_ooool00ooo003ooooooooo
o`0?ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0c?ooool00ol0003ooooooooo
o`0>ooooo`007?ooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo0:;ooooo00?oo`00
ooooooooool03oooool00ol0003oooooooooo`0Xooooo`;o0000c?ooool2o`00013ooooo000Loooo
o`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0X_ooool00ooo003oooooooooo`0?oooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>oooo
o`007?ooool2o`0001Sooooo00?oo`00ooooooooool0X_ooool00ooo003oooooooooo`0?ooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`00
3oooool3o`0000Cooooo0ol00003ooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0
X_ooool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
c?ooool00ol0003oooooooooo`0>ooooo`004?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`2Rooooo`03ool00?oo
oooooooo00oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`3<ooooo`03o`000?oo
oooooooo00kooooo000@ooooo`04o`000?ooooooooooooooo`Go00000oooool00ol0003ooooooooo
o`0Gooooo`03ool00?oooooooooo0:;ooooo00?oo`00ooooooooool03oooool00ol0003ooooooooo
o`0Xooooo`;o0000c?ooool2o`00013ooooo000@ooooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooooooo`02ooooo`?o00005oooool00ooo003oooooooooo`2Rooooo`03ool00?oo
oooooooo00kooooo0_l0000Zooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_oo
ool0013ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000004ooooo`03o`000?oooooo
oooo01Oooooo00?oo`00ooooooooool0X_ooool00ooo003oooooooooo`0?ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`003oooool2o`00
00Gooooo0_l00004ooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0X_ooool00ooo
003oooooooooo`0?ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0c?ooool00ol0
003oooooooooo`0>ooooo`004?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool05oooool00ooo003oooooooooo`2Rooooo`03ool00?oooooooooo00oo
oooo00?o0000ooooooooool0:?ooool2o`000<cooooo0_l0000@ooooo`007?ooool2o`0001Sooooo
00?oo`00ooooooooool0X_ooool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo027ooooo
0ol00004ooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool001cooooo00?o
0000ooooooooool05oooool00ooo003oooooooooo`2Rooooo`03ool00?oooooooooo00oooooo00?o
0000ooooooooool08?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
c?ooool00ol0003oooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`0Gooooo`03ool00?oo
oooooooo0:;ooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0Tooooo`05o`000?oo
ooooooooooooool00000c_ooool00ol0003oooooooooo`0>ooooo`007?ooool00ol0003ooooooooo
o`0Fooooo`?oo`00X_ooool3ool0013ooooo00?o0000ooooooooool08_ooool2o`0000Cooooo0ol0
003:ooooo`?o00004?ooool001cooooo0_l0000Gooooo`?oo`00X_ooool3ool0013ooooo00?o0000
ooooooooool09?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03_oo
ool001cooooo00?o0000ooooooooool05_ooool3ool00:;ooooo0ooo000@ooooo`03o`000?oooooo
oooo023ooooo00Go0000ooooooooooooooooo`000003ooooom3o00004?ooool001cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Qooooo`?o0000i?ooool001coooood_l0003ooooo
o`_ooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003ooooo
ooWooooo003oooooooWooooo003oooooooWooooo0000\
\>"],
  ImageRangeCache->{{{0, 503}, {310.438, 0}} -> {-0.0514703, -0.0309082, \
0.0041808, 0.0041808}, {{12.3125, 240.062}, {303, 162.25}} -> {-6.7051, \
-2.7068, 0.0502515, 0.122343}, {{262.875, 490.688}, {303, 162.25}} -> \
{-19.6782, -4.03173, 0.0512455, 0.0489382}, {{12.3125, 240.062}, {148.125, \
7.375}} -> {-4.94479, -21.5874, 0.145729, 0.121963}, {{262.875, 490.688}, \
{148.125, 7.375}} -> {-42.1612, -11.7081, 0.147552, 0.0492634}}]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["DTFT vs. DFT: Example #2: 1Hz cosine wave (higher fs)", "Section"],

Cell[CellGroupData[{

Cell["Sampled sequence", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(x[t_] := Cos[2  \[Pi]\ t];\)\), "\n", 
    \(\(xd = \ sampler[x, fs = 20, {0, 3}];\)\), "\[IndentingNewLine]", 
    \(\(If[OddQ[Length[xd]], \ xd\  = \ Drop[xd, \(-1\)]];\)\), "\n", 
    \(\(gx\  = \ 
        DiscreteListPlot2[xd, \ Blue, \ Frame \[Rule] True, 
          Axes \[Rule] {True, False}, \ ImageSize \[Rule] 504, \ 
          AspectRatio \[Rule] 1/3];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
%%ImageSize: 504 168 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0161421 0.166667 0.15873 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18523 -0.0125 -6 -9 ]
[.18523 -0.0125 6 0 ]
[.34665 -0.0125 -6 -9 ]
[.34665 -0.0125 6 0 ]
[.50807 -0.0125 -6 -9 ]
[.50807 -0.0125 6 0 ]
[.66949 -0.0125 -6 -9 ]
[.66949 -0.0125 6 0 ]
[.83091 -0.0125 -6 -9 ]
[.83091 -0.0125 6 0 ]
[.99233 -0.0125 -6 -9 ]
[.99233 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00794 -12 -4.5 ]
[-0.0125 .00794 0 4.5 ]
[-0.0125 .0873 -24 -4.5 ]
[-0.0125 .0873 0 4.5 ]
[-0.0125 .16667 -6 -4.5 ]
[-0.0125 .16667 0 4.5 ]
[-0.0125 .24603 -18 -4.5 ]
[-0.0125 .24603 0 4.5 ]
[-0.0125 .3254 -6 -4.5 ]
[-0.0125 .3254 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18523 0 m
.18523 .00625 L
s
[(10)] .18523 -0.0125 0 1 Mshowa
.34665 0 m
.34665 .00625 L
s
[(20)] .34665 -0.0125 0 1 Mshowa
.50807 0 m
.50807 .00625 L
s
[(30)] .50807 -0.0125 0 1 Mshowa
.66949 0 m
.66949 .00625 L
s
[(40)] .66949 -0.0125 0 1 Mshowa
.83091 0 m
.83091 .00625 L
s
[(50)] .83091 -0.0125 0 1 Mshowa
.99233 0 m
.99233 .00625 L
s
[(60)] .99233 -0.0125 0 1 Mshowa
.125 Mabswid
.05609 0 m
.05609 .00375 L
s
.08838 0 m
.08838 .00375 L
s
.12066 0 m
.12066 .00375 L
s
.15295 0 m
.15295 .00375 L
s
.21751 0 m
.21751 .00375 L
s
.2498 0 m
.2498 .00375 L
s
.28208 0 m
.28208 .00375 L
s
.31437 0 m
.31437 .00375 L
s
.37893 0 m
.37893 .00375 L
s
.41122 0 m
.41122 .00375 L
s
.4435 0 m
.4435 .00375 L
s
.47579 0 m
.47579 .00375 L
s
.54036 0 m
.54036 .00375 L
s
.57264 0 m
.57264 .00375 L
s
.60492 0 m
.60492 .00375 L
s
.63721 0 m
.63721 .00375 L
s
.70178 0 m
.70178 .00375 L
s
.73406 0 m
.73406 .00375 L
s
.76634 0 m
.76634 .00375 L
s
.79863 0 m
.79863 .00375 L
s
.8632 0 m
.8632 .00375 L
s
.89548 0 m
.89548 .00375 L
s
.92776 0 m
.92776 .00375 L
s
.96005 0 m
.96005 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00794 m
.00625 .00794 L
s
[(-1)] -0.0125 .00794 1 0 Mshowa
0 .0873 m
.00625 .0873 L
s
[(-0.5)] -0.0125 .0873 1 0 Mshowa
0 .16667 m
.00625 .16667 L
s
[(0)] -0.0125 .16667 1 0 Mshowa
0 .24603 m
.00625 .24603 L
s
[(0.5)] -0.0125 .24603 1 0 Mshowa
0 .3254 m
.00625 .3254 L
s
[(1)] -0.0125 .3254 1 0 Mshowa
.125 Mabswid
0 .02381 m
.00375 .02381 L
s
0 .03968 m
.00375 .03968 L
s
0 .05556 m
.00375 .05556 L
s
0 .07143 m
.00375 .07143 L
s
0 .10317 m
.00375 .10317 L
s
0 .11905 m
.00375 .11905 L
s
0 .13492 m
.00375 .13492 L
s
0 .15079 m
.00375 .15079 L
s
0 .18254 m
.00375 .18254 L
s
0 .19841 m
.00375 .19841 L
s
0 .21429 m
.00375 .21429 L
s
0 .23016 m
.00375 .23016 L
s
0 .2619 m
.00375 .2619 L
s
0 .27778 m
.00375 .27778 L
s
0 .29365 m
.00375 .29365 L
s
0 .30952 m
.00375 .30952 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.02381 .32708 m
.02381 .33333 L
s
.18523 .32708 m
.18523 .33333 L
s
.34665 .32708 m
.34665 .33333 L
s
.50807 .32708 m
.50807 .33333 L
s
.66949 .32708 m
.66949 .33333 L
s
.83091 .32708 m
.83091 .33333 L
s
.99233 .32708 m
.99233 .33333 L
s
.125 Mabswid
.05609 .32958 m
.05609 .33333 L
s
.08838 .32958 m
.08838 .33333 L
s
.12066 .32958 m
.12066 .33333 L
s
.15295 .32958 m
.15295 .33333 L
s
.21751 .32958 m
.21751 .33333 L
s
.2498 .32958 m
.2498 .33333 L
s
.28208 .32958 m
.28208 .33333 L
s
.31437 .32958 m
.31437 .33333 L
s
.37893 .32958 m
.37893 .33333 L
s
.41122 .32958 m
.41122 .33333 L
s
.4435 .32958 m
.4435 .33333 L
s
.47579 .32958 m
.47579 .33333 L
s
.54036 .32958 m
.54036 .33333 L
s
.57264 .32958 m
.57264 .33333 L
s
.60492 .32958 m
.60492 .33333 L
s
.63721 .32958 m
.63721 .33333 L
s
.70178 .32958 m
.70178 .33333 L
s
.73406 .32958 m
.73406 .33333 L
s
.76634 .32958 m
.76634 .33333 L
s
.79863 .32958 m
.79863 .33333 L
s
.8632 .32958 m
.8632 .33333 L
s
.89548 .32958 m
.89548 .33333 L
s
.92776 .32958 m
.92776 .33333 L
s
.96005 .32958 m
.96005 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .00794 m
1 .00794 L
s
.99375 .0873 m
1 .0873 L
s
.99375 .16667 m
1 .16667 L
s
.99375 .24603 m
1 .24603 L
s
.99375 .3254 m
1 .3254 L
s
.125 Mabswid
.99625 .02381 m
1 .02381 L
s
.99625 .03968 m
1 .03968 L
s
.99625 .05556 m
1 .05556 L
s
.99625 .07143 m
1 .07143 L
s
.99625 .10317 m
1 .10317 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .13492 m
1 .13492 L
s
.99625 .15079 m
1 .15079 L
s
.99625 .18254 m
1 .18254 L
s
.99625 .19841 m
1 .19841 L
s
.99625 .21429 m
1 .21429 L
s
.99625 .23016 m
1 .23016 L
s
.99625 .2619 m
1 .2619 L
s
.99625 .27778 m
1 .27778 L
s
.99625 .29365 m
1 .29365 L
s
.99625 .30952 m
1 .30952 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
0 .16667 m
1 .16667 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .16667 m
.02381 .3254 L
s
.03995 .16667 m
.03995 .31763 L
s
.05609 .16667 m
.05609 .29508 L
s
.07224 .16667 m
.07224 .25997 L
s
.08838 .16667 m
.08838 .21572 L
s
.10452 .16667 m
.10452 .16667 L
s
.12066 .16667 m
.12066 .11762 L
s
.1368 .16667 m
.1368 .07337 L
s
.15295 .16667 m
.15295 .03825 L
s
.16909 .16667 m
.16909 .01571 L
s
.18523 .16667 m
.18523 .00794 L
s
.20137 .16667 m
.20137 .01571 L
s
.21751 .16667 m
.21751 .03825 L
s
.23366 .16667 m
.23366 .07337 L
s
.2498 .16667 m
.2498 .11762 L
s
.26594 .16667 m
.26594 .16667 L
s
.28208 .16667 m
.28208 .21572 L
s
.29822 .16667 m
.29822 .25997 L
s
.31437 .16667 m
.31437 .29508 L
s
.33051 .16667 m
.33051 .31763 L
s
.34665 .16667 m
.34665 .3254 L
s
.36279 .16667 m
.36279 .31763 L
s
.37893 .16667 m
.37893 .29508 L
s
.39508 .16667 m
.39508 .25997 L
s
.41122 .16667 m
.41122 .21572 L
s
.42736 .16667 m
.42736 .16667 L
s
.4435 .16667 m
.4435 .11762 L
s
.45964 .16667 m
.45964 .07337 L
s
.47579 .16667 m
.47579 .03825 L
s
.49193 .16667 m
.49193 .01571 L
s
.50807 .16667 m
.50807 .00794 L
s
.52421 .16667 m
.52421 .01571 L
s
.54036 .16667 m
.54036 .03825 L
s
.5565 .16667 m
.5565 .07337 L
s
.57264 .16667 m
.57264 .11762 L
s
.58878 .16667 m
.58878 .16667 L
s
.60492 .16667 m
.60492 .21572 L
s
.62107 .16667 m
.62107 .25997 L
s
.63721 .16667 m
.63721 .29508 L
s
.65335 .16667 m
.65335 .31763 L
s
.66949 .16667 m
.66949 .3254 L
s
.68563 .16667 m
.68563 .31763 L
s
.70178 .16667 m
.70178 .29508 L
s
.71792 .16667 m
.71792 .25997 L
s
.73406 .16667 m
.73406 .21572 L
s
.7502 .16667 m
.7502 .16667 L
s
.76634 .16667 m
.76634 .11762 L
s
.78249 .16667 m
.78249 .07337 L
s
.79863 .16667 m
.79863 .03825 L
s
.81477 .16667 m
.81477 .01571 L
s
.83091 .16667 m
.83091 .00794 L
s
.84705 .16667 m
.84705 .01571 L
s
.8632 .16667 m
.8632 .03825 L
s
.87934 .16667 m
.87934 .07337 L
s
.89548 .16667 m
.89548 .11762 L
s
.91162 .16667 m
.91162 .16667 L
s
.92776 .16667 m
.92776 .21572 L
s
.94391 .16667 m
.94391 .25997 L
s
.96005 .16667 m
.96005 .29508 L
s
.97619 .16667 m
.97619 .31763 L
s
.005 w
.02381 .3254 Mdot
.03995 .31763 Mdot
.05609 .29508 Mdot
.07224 .25997 Mdot
.08838 .21572 Mdot
.10452 .16667 Mdot
.12066 .11762 Mdot
.1368 .07337 Mdot
.15295 .03825 Mdot
.16909 .01571 Mdot
.18523 .00794 Mdot
.20137 .01571 Mdot
.21751 .03825 Mdot
.23366 .07337 Mdot
.2498 .11762 Mdot
.26594 .16667 Mdot
.28208 .21572 Mdot
.29822 .25997 Mdot
.31437 .29508 Mdot
.33051 .31763 Mdot
.34665 .3254 Mdot
.36279 .31763 Mdot
.37893 .29508 Mdot
.39508 .25997 Mdot
.41122 .21572 Mdot
.42736 .16667 Mdot
.4435 .11762 Mdot
.45964 .07337 Mdot
.47579 .03825 Mdot
.49193 .01571 Mdot
.50807 .00794 Mdot
.52421 .01571 Mdot
.54036 .03825 Mdot
.5565 .07337 Mdot
.57264 .11762 Mdot
.58878 .16667 Mdot
.60492 .21572 Mdot
.62107 .25997 Mdot
.63721 .29508 Mdot
.65335 .31763 Mdot
.66949 .3254 Mdot
.68563 .31763 Mdot
.70178 .29508 Mdot
.71792 .25997 Mdot
.73406 .21572 Mdot
.7502 .16667 Mdot
.76634 .11762 Mdot
.78249 .07337 Mdot
.79863 .03825 Mdot
.81477 .01571 Mdot
.83091 .00794 Mdot
.84705 .01571 Mdot
.8632 .03825 Mdot
.87934 .07337 Mdot
.89548 .11762 Mdot
.91162 .16667 Mdot
.92776 .21572 Mdot
.94391 .25997 Mdot
.96005 .29508 Mdot
.97619 .31763 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 168},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000Z2000`400?l00000o`00003ooooooooi
ooooo`00;oooool2o`0004Cooooo0ol00004ooooo`;o0000?oooool5o`0000?ooooo0_l00010oooo
o`?o00001?ooool2o`0004;ooooo0ol00003ooooo`;o0000@?ooool3o`0000Cooooo0_l00010oooo
o`?o00001?ooool2o`0000cooooo000^ooooo`04o`000?ooooooooooo`0004Cooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool0000oooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo0000?_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo0000@_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0??ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000?_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00002oooool002kooooo00Co0000oooooooo
oooo0000A?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00043ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00012ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool0?Oooool5o`0000;ooooo00Co0000oooooooooooo0000@_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo03cooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000_ooooo000^ooooo`04o`000?ooooooooooo`0004Cooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00011ooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`0nooooo`;o00000oooool01?l0003oooooooooool0000ooooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo0000@_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo03cooooo1?l00003ooooo`04o`000?ooooooooooo`0000_o
oooo000^ooooo`04o`000?ooooooooooo`0004Cooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000nooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0012ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
o`000003ooooo`04o`000?ooooooooooo`0003kooooo1?l00003ooooo`04o`000?ooooooooooo`00
03kooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0000;ooooo`00;_ooool01?l0
003oooooooooool00013ooooo`;o00001?ooool01?l0003oooooooooool0000nooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool0000nooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00011ooooo`;o00000oooool01?l0003oooooooooool0
000nooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000?oooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`0000_ooooo000_ooooo`;o0000AOooool00ol0003ooooo
ooooo`03ooooo`;o0000@?ooool3o`0000Cooooo0_l00010ooooo`?o00001?ooool2o`0004?ooooo
00?o0000ooooooooool00_ooool2o`0003oooooo1Ol00003ooooo`;o0000@Oooool2o`0000Cooooo
0_l0000<ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00
oooooooiooooo`00oooooooiooooo`00oooooooiooooo`009Oooooooo`000<Wo00002oooool001_o
oooo0ol00007ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000;oooo
o`007?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`005?ooool5o`0000?ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo04Kooooo0_l00?m8ooooo`03o`000?oooooooooo04Ko
oooo0_l00?m8ooooo`03o`000?oooooooooo04Gooooo0_l00?m8ooooo`05o`000?oooooooooooooo
ool000002oooool001cooooo00?o0000ooooooooool01_ooool4o`00053ooooo0_l00?nAooooo`;o
003oT?ooool2o`00odWooooo1?l0000;ooooo`007?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo05;ooooo00?o003oooooooooool0Soooool00ol00?ooooooooooo`2@ooooo`03o`00
oooooooooooo04[ooooo00?o0000ooooooooool02Oooool001_ooooo0_l00008ooooo`03o`000?oo
oooooooo05;ooooo00?o003oooooooooool0Soooool00ol00?ooooooooooo`2@ooooo`03o`00oooo
oooooooo04[ooooo00?o0000ooooooooool02Oooool001cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1:ooooo`;o003o1_ooool00ol00?ooooooooooo`03ooooo`;o003oP_ooool2
o`00o`Kooooo00?o003oooooooooool01?ooool2o`00oh;ooooo0_l00?l6ooooo`03o`00oooooooo
oooo00Cooooo0_l00?m4ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo
04[ooooo0_l00?l6ooooo`03o`00oooooooooooo00?ooooo0_l00?n2ooooo`;o003o1_ooool00ol0
0?ooooooooooo`04ooooo`;o003oP_ooool2o`00o`Kooooo00?o003oooooooooool01?ooool2o`00
odCooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool0B_ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0POooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0POooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0@oooool00ol0003o
ooooooooo`09ooooo`009Oooool00ol0003oooooooooo`1:ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`21ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`21ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`13ooooo`03o`000?oooooooooo00Wooooo
000Uooooo`?o0000B_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool0POooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool0POooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool0@Oooool3o`0000_ooooo000Uooooo`03o`000?oooooooooo04[ooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo087ooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo087ooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo04?ooooo00?o0000
ooooooooool02Oooool002Gooooo00?o0000ooooooooool0B_ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool0POooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool0POooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool0@oooool00ol0003oooooooooo`09oooo
o`009Oooool00ol0003oooooooooo`1:ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`21ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`21ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`13ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`00
0?oooooooooo04[ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo087ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo087ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo04?ooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool0B_oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0POoo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0POoo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0@ooo
ool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`12ooooo`;o003o1_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool2
o`00og?ooooo0_l00?l6ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`03ooooo`;o003oM?ooool2o`00o`Kooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo0_l00?lmooooo`03o`000?oooooo
oooo00Wooooo000Uooooo`?o0000@_ooool2o`00o`Kooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo0_l00?mcooooo`;o003o1_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00oooool2o`00
ogCooooo0_l00?l6ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`04ooooo`;o003o>oooool3o`0000_ooooo000Uooooo`03o`000?oooooooooo04?o
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1cooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool0L_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo03_o
oooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool0@oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo07?ooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`1booooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0>oooool00ol0003ooooo
ooooo`09ooooo`009Oooool00ol0003oooooooooo`13ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool0Loooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo07;ooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0kooooo`03o`000?oooooooooo00Wooooo000U
ooooo`03o`000?oooooooooo04?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1c
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0L_ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo03_ooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000oooo
ooooool0@oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo07?ooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`1booooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool0>oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`13ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool0Loooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo07;ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0kooooo`03
o`000?oooooooooo00Wooooo000Uooooo`?o0000@oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo07?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1booooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool0>Oooool3o`0000_ooooo000Uooooo`03o`000?oo
oooooooo04?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1cooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool0L_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo03_ooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool0@oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo07?ooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`1booooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0>oooool0
0ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`13ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool0Loooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
07;ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0kooooo`03o`000?oooooooooo
00Wooooo000Uooooo`03o`000?oooooooooo04?ooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`1cooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0L_ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo03_ooooo00?o0000ooooooooool02Oooool002Gooooo
00?o0000ooooooooool0@oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo07?ooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`1booooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool0>oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003ooooooooo
o`13ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0Loooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo07;ooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`0kooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo04?ooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`1cooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool0L_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo03_ooooo00?o0000
ooooooooool02Oooool002Gooooo0ol0000kooooo`;o003o1_ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo0_l00?mUooooo`;o003o1_ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo0_l00?mTooooo`;o003o1_ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00?ooooo0_l00?ldooooo`?o00002oooool002Gooooo00?o0000oooooooo
ool0>oooool2o`00o`Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`;o
003oIOooool2o`00o`Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`;o
003oI?ooool2o`00o`Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`03ooooo`;o
003o=_ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`0looooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo06?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool0I?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0dooooo`03o`00
0?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo03cooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0Hooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`1Tooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo03Cooooo00?o0000ooooooooool02Ooo
ool0013ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00007ooooo`03o`000?oooooo
oooo03cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool0Hoooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Tooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo03Cooooo00?o0000ooooooooool02Oooool000oooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0??ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`1Sooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo06Cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0=?ooool00ol0003ooooooooo
o`09ooooo`002?ooool5o`0000;ooooo00Co0000oooooooooooo00002oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo03cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0Hoooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`1Tooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo03Cooooo00?o0000ooooooooool02Oooool000oooooo00Co0000
oooooooooooo00002oooool00ol0003oooooooooo`04ooooo`Co0000>oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`1Sooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo06Cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0<Oooool4o`0000_ooooo000?
ooooo`04o`000?ooooooooooo`0000Oooooo1?l00007ooooo`03o`000?oooooooooo03cooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool0Hoooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`1Tooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo03Cooooo00?o
0000ooooooooool02Oooool000oooooo00Co0000oooooooooooo00001oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo03cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0Hoooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`1Tooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo03Cooooo00?o0000ooooooooool02Oooool0013ooooo0_l00008
ooooo`Go00001_ooool00ol0003oooooooooo`0looooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo06?ooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool0I?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0dooooo`03o`000?oooooooooo00Wooooo000Uoooo
o`03o`000?oooooooooo03cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool0Hoooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Toooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo03Cooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000oooooooo
ool0??ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`1Sooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo06Cooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool0=?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`0looooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo06?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool0I?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0dooooo`03o`00
0?oooooooooo00Wooooo000Uooooo`?o0000??ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`1Sooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo06Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool0<_ooool3o`0000_ooooo000Uooooo`03o`000?oooooo
oooo03cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool0Hoooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Tooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo03Cooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool0??ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`1Sooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo06Cooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0=?ooool00ol0
003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`0looooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo06?o
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool0I?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0dooooo`03o`000?oooooooooo00Wo
oooo000Uooooo`03o`000?oooooooooo03cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0Hoooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`1Tooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo03Cooooo00?o0000ooooooooool02Oooool002Gooooo00?o
0000ooooooooool0??ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`1Sooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo06Cooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool0=?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`0d
ooooo`;o003o1_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`03ooooo`;o003oE_ooool2o`00o`Kooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool2o`00oeKooooo0_l00?l6ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo0_l00?l^
ooooo`03o`000?oooooooooo00Wooooo000Uooooo`?o0000=?ooool2o`00o`Kooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool00oooool2o`00oeKooooo0_l00?l6ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo0_l00?mFoooo
o`;o003o1_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`04ooooo`;o003o;?ooool3o`0000_ooooo000Uooooo`03
o`000?oooooooooo03Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo05Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo05Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo02gooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool0
=?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
EOooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
EOooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
;Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`0dooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Eooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`1Eooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0]ooooo`03o`000?oo
oooooooo00Wooooo000Uooooo`03o`000?oooooooooo03Cooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo05Gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo05Gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02gooooo00?o0000ooooooooool02Oooool0
02Gooooo00?o0000ooooooooool0=?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool0;Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003o
ooooooooo`0dooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`1Eooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`1Eooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`0]ooooo`03o`000?oooooooooo00Wooooo000Uooooo`?o0000=?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0EOooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0EOooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0:oooool3o`0000_ooooo
000Uooooo`03o`000?oooooooooo03Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo05Gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo05Gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo02gooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000
ooooooooool0=?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool0EOooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool0EOooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool0;Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`0doooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Eoooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`1Eoooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0]oooo
o`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo03Cooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo05Gooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo05Gooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02gooooo00?o0000oooooooo
ool02Oooool002Gooooo00?o0000ooooooooool0=?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool0;Oooool00ol0003oooooooooo`09ooooo`009Ooo
ool00ol0003oooooooooo`0dooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`0]ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooo
oooo03Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo05Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo05Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo02gooooo00?o0000ooooooooool02Oooool002Gooooo0ol0000dooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0[ooooo`?o00002oooool002Go
oooo00?o0000ooooooooool0=?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool0;Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003ooooo
ooooo`0dooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`1Eooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`1Eooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0]ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo03Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo05Gooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo05Gooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02gooooo00?o
0000ooooooooool02Oooool001cooooo0_l00007ooooo`03o`000?oooooooooo03Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo05Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo05Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02gooooo00?o0000
ooooooooool02Oooool001_ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0d
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1E
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`1E
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0]
ooooo`03o`000?oooooooooo00Wooooo000Kooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool0=?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool0EOooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool0EOooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool0;Oooool00ol0003oooooooooo`09ooooo`006oooool01?l0003oooooooooool00006
ooooo`_o000000?o003oo`000?l000001Ol000000ol00?oo0000o`000004o`000003o`00ool0003o
000000Co000000?o003oo`000?l000001Ol000000ol00?oo0000o`000003o`0000;o003o1_l00000
0ol00?oo0000o`000005o`000003o`00ool0003o000000Co000000?o003oo`000?l000001?l00000
0ol00?oo0000o`000005o`000003o`00ool0003o000000Co000000?o003oo`000?l000001?l00000
0ol00?oo0000o`000005o`000003o`00ool0003o000000Co000000?o003oo`000?l000001?l00002
o`00o`Ko000000?o003oo`000?l000001?l000000ol00?oo0000o`000004o`000003o`00ool0003o
000000Go000000?o003oo`000?l000001?l000000ol00?oo0000o`000004o`000003o`00ool0003o
000000Go000000?o003oo`000?l000001?l000000ol00?oo0000o`000004o`000003o`00ool0003o
000000Co00000_l00?l6o`000003o`00ool0003o000000Co000000?o003oo`000?l000001Ol00000
0ol00?oo0000o`000004o`000003o`00ool0003o000000Co000000?o003oo`000?l000001Ol00000
0ol00?oo0000o`000004o`000003o`00ool0003o000000Co000000?o003oo`000?l000001Ol00000
0ol00?oo0000o`000003o`0000;o003o1_l000000ol00?oo0000o`000005o`000003o`00ool0003o
000000Co000000?o003oo`000?l000001?l000000ol00?oo0000o`000005o`000003o`00ool0003o
000000Co000000?o003oo`000?l000001?l000000ol00?oo0000o`000005o`000003o`00ool0003o
000000Co000000?o003oo`000?l000001?l00002o`00o`Ko000000?o003oo`000?l000001?l00000
0ol00?oo0000o`000004o`000003o`00ool0003o000000Go000000?o003oo`000?l000001?l00000
0ol00?oo0000o`000004o`000003o`00ool0003o000000Go000000?o003oo`000?l000001?l00000
0ol00?oo0000o`000004o`000003o`00ool0003o000000Co00000_l00?l6o`000003o`00ool0003o
000000Co000000?o003oo`000?l000001Ol000000ol00?oo0000o`000004o`000003o`00ool0003o
000000Wo00002oooool001_ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`08
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00oooool2o`00odSooooo0_l00?l6
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04
ooooo`;o003oAoooool2o`00o`Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Cooooo0_l00?m7ooooo`;o003o1_ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08
ooooo`03o`000?oooooooooo00Wooooo000Kooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo05Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo05Gooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo05Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool02?ooool00ol0003oooooooooo`09ooooo`007?ooool2o`0000Oooooo00?o0000oooo
ooooool02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo05Gooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo05Gooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo05Gooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool02?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`08ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03
o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool0
2Oooool002Gooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo05Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo05Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo05Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`09ooooo`009Oooool3
o`0000Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Kooooo0ol0000;ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo
00Wooooo000Uooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`1Eooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`1Eooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`1Eooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02Oooool002Gooooo
00?o0000ooooooooool02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo05Gooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo05Gooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo05Gooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool02?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003ooooooooo
o`08ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0EOooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0EOooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0EOooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`08ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00Sooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o0000
ooooooooool02Oooool002Gooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo05Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo05Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo05Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`09oooo
o`009Oooool3o`0000Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`1Eooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Eooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Eooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Kooooo0ol0000;ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02Ooo
ool002Gooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo05Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo05Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo05Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0
003oooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0EOooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0EOooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0EOooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`08ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00So
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00So
oooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool02?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo05Gooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo05Gooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo05Gooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02?ooool00ol0003ooooo
ooooo`09ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool0EOooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool0EOooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool0EOooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Wooooo000U
ooooo`?o00002?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`;o003oE_ooool2o`00o`Kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool2o`00oeKooooo0_l00?l6ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00?ooooo0_l00?mF
ooooo`;o003o1_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01_ooool3o`0000_ooooo000Uooooo`03o`000?oooooooooo00Sooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool01?ooool2o`00oeKooooo0_l00?l6ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo0_l00?mFoooo
o`;o003o1_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`03ooooo`;o003oE_ooool2o`00o`Kooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o0000oooo
ooooool02Oooool002Gooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Tooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo06Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool0Hoooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`09ooooo`00
9Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo06Cooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
I?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`1Sooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oo
oooooooo00Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool0I?ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Tooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo06?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Sooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool02?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`1Tooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo06Cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0Hoooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02?ooool0
0ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
06Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool0I?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`1Sooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo
00Wooooo000Uooooo`?o00002?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Tooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo06Co
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool0Hoooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01_ooool3o`0000_ooooo000Uooooo`03o`000?oooooooooo00Sooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool0I?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Tooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo06?ooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo
00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool02?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`1Tooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo06Cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0Hoooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02?ooool00ol0003ooooooooo
o`09ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo06Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool0I?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`1Sooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Wooooo000@oooo
o`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001oooool00ol0003oooooooooo`08oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo06Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool0I?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`1Soooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08oooo
o`03o`000?oooooooooo00Wooooo000?ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0I?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`1Tooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo06?ooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02Oooool0
00oooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool0I?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Tooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo06?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Sooooo00?o0000ooooooooool02Oooool000oooooo00Co0000oooooooooooo00002oooool0
0ol0003oooooooooo`04ooooo`Co00001oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Tooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo06Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool0Hoooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01Oooool4o`0000_ooooo000?ooooo`04o`000?oooooooooo
o`0000Oooooo1?l00007ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0I?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`1Tooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo06?ooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02Oooool0
00oooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool0I?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Tooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo06?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Sooooo00?o0000ooooooooool02Oooool0013ooooo0_l00008ooooo`Go00001_ooool00ol0
003oooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo06Cooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0I?ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`1Sooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`08ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00So
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool0I?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Tooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo06?o
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00So
oooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool02?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`1Tooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo06Cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0Hoooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02?ooool00ol0003ooooo
ooooo`09ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`;o003oI?ooool2o`00o`Kooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`03ooooo`;o003oIOooool2o`00o`Kooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`;o003oIOooool2o`00o`Kooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Wooooo000U
ooooo`?o00002?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool2o`00ofCooooo0_l00?l6ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool00oooool2o`00ofGooooo0_l00?l6ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool2o`00ofGooooo0_l00?l6ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01_ooool3o`0000_ooooo000Uooooo`03o`000?oooooooooo00Sooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo07;ooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`1booooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool0Loooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o0000oooo
ooooool02Oooool002Gooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool0L_ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo07;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1cooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`09ooooo`00
9Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`1booooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
L_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo07?ooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oo
oooooooo00Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo07;ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`1booooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool0Loooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Sooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool02?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0L_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo07;ooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`1cooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02?ooool0
0ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1booooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool0L_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
07?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo
00Wooooo000Uooooo`?o00002?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool0L_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo07;o
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1cooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01_ooool3o`0000_ooooo000Uooooo`03o`000?oooooooooo00Sooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo07;ooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`1booooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool0Loooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo
00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool02?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0L_ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo07;ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`1cooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02?ooool00ol0003ooooooooo
o`09ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`1booooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool0L_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo07?ooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Wooooo000Uoooo
o`03o`000?oooooooooo00Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo07;ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`1boooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool0Loooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000oooooooo
ool02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool0L_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo07;ooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`1cooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool02?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1booooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool0L_ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo07?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo07;ooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`1booooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0Looo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02Ooo
ool002Gooooo0ol00008ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00oooool2
o`00ogCooooo0_l00?l6ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`04ooooo`;o003oLoooool2o`00o`Kooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo0_l00?mcooooo`;o003o1_ooool0
0ol00?ooooooooooo`06ooooo`?o00002oooool002Gooooo00?o0000ooooooooool02?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00?ooooo0_l00?mdooooo`;o003o1_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool2o`00
og?ooooo0_l00?l6ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`04ooooo`;o003oLoooool2o`00o`Kooooo00?o003oooooooooool02?ooool00ol0
003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool0POooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool0POooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool0POooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Wo
oooo000Uooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`21ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`21ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`21ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02Oooool002Gooooo00?o
0000ooooooooool02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo087ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo087ooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo087ooooo00?o
003oooooooooool02?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`08
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0POooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0POooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0POooool00ol00?ooooooooooo`08
ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00Sooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`21ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`21ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`21ooooo`03o`00oooooooooooo00Sooooo00?o0000oooo
ooooool02Oooool002Gooooo0ol00008ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool0POooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool0POooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool0POooool00ol00?ooooooooooo`06ooooo`?o00002oooool002Gooooo00?o0000ooooooooool0
2?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo087ooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo087ooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo087ooooo00?o003oooooooooool0
2?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool0POooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool0POooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool0POooool00ol00?ooooooooooo`08ooooo`03o`000?oo
oooooooo00Wooooo000Uooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01?ooool2
o`00oh;ooooo0_l00?l6ooooo`03o`00oooooooooooo00Cooooo0_l00?n2ooooo`;o003o1_ooool0
0ol00?ooooooooooo`03ooooo`;o003oP_ooool2o`00o`[ooooo00?o0000ooooooooool02Oooool0
01_ooooo0ol00007ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01?ooool2o`00
oh;ooooo0_l00?l6ooooo`03o`00oooooooooooo00Cooooo0_l00?n2ooooo`;o003o1_ooool00ol0
0?ooooooooooo`03ooooo`;o003oP_ooool2o`00o`[ooooo00?o0000ooooooooool02Oooool001co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo093o
oooo00?o003oooooooooool0T?ooool00ol00?ooooooooooo`2Cooooo`03o`000?oooooooooo00Wo
oooo000Looooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol00?oooooo
ooooo`2@ooooo`03o`00oooooooooooo093ooooo00?o003oooooooooool0Toooool00ol0003ooooo
ooooo`09ooooo`007?ooool00ol0003oooooooooo`06ooooo`Co00001oooool2o`00oi3ooooo0_l0
0?nAooooo`;o003oT_ooool4o`0000_ooooo000Looooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02?ooool2o`00odSooooo00?o0000ooooooooool0AOooool2o`00odSooooo00?o0000
ooooooooool0A_ooool2o`00odSooooo00?o0000ooooooooool0A_ooool01Ol0003ooooooooooooo
oooo000000_ooooo000Kooooo`;o00002?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`05o`000?oooooo
ooooooooool000002oooool001cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`05o`000?ooooooooooooooool000002oooool002Goooooool00039o`0000_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 503}, {167, 0}} -> {-6.64967, -1.25358, 0.136372, \
0.0138684}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Magnitude plot of DTFT as a function of frequency", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(X\[Theta]\  = DTFT[xd, \[Theta]]\  // \ Simplify; 
    g1 = Plot[
        Abs[X\[Theta]\  /. \ \[Theta] \[Rule] \ 2  \[Pi]\ f/fs], {f, \(-fs\)/
            2, fs/2}, \ PlotStyle \[Rule] {Blue, \ Dashing[{ .01}]}, \ 
        PlotRange \[Rule] All, PlotPoints \[Rule] 200];\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.0147151 0.0195446 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11244 -6 -4.5 ]
[-0.0125 .11244 0 4.5 ]
[-0.0125 .21016 -12 -4.5 ]
[-0.0125 .21016 0 4.5 ]
[-0.0125 .30788 -12 -4.5 ]
[-0.0125 .30788 0 4.5 ]
[-0.0125 .40561 -12 -4.5 ]
[-0.0125 .40561 0 4.5 ]
[-0.0125 .50333 -12 -4.5 ]
[-0.0125 .50333 0 4.5 ]
[-0.0125 .60105 -12 -4.5 ]
[-0.0125 .60105 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11244 m
.00625 .11244 L
s
[(5)] -0.0125 .11244 1 0 Mshowa
0 .21016 m
.00625 .21016 L
s
[(10)] -0.0125 .21016 1 0 Mshowa
0 .30788 m
.00625 .30788 L
s
[(15)] -0.0125 .30788 1 0 Mshowa
0 .40561 m
.00625 .40561 L
s
[(20)] -0.0125 .40561 1 0 Mshowa
0 .50333 m
.00625 .50333 L
s
[(25)] -0.0125 .50333 1 0 Mshowa
0 .60105 m
.00625 .60105 L
s
[(30)] -0.0125 .60105 1 0 Mshowa
.125 Mabswid
0 .03426 m
.00375 .03426 L
s
0 .0538 m
.00375 .0538 L
s
0 .07335 m
.00375 .07335 L
s
0 .09289 m
.00375 .09289 L
s
0 .13198 m
.00375 .13198 L
s
0 .15153 m
.00375 .15153 L
s
0 .17107 m
.00375 .17107 L
s
0 .19062 m
.00375 .19062 L
s
0 .22971 m
.00375 .22971 L
s
0 .24925 m
.00375 .24925 L
s
0 .2688 m
.00375 .2688 L
s
0 .28834 m
.00375 .28834 L
s
0 .32743 m
.00375 .32743 L
s
0 .34697 m
.00375 .34697 L
s
0 .36652 m
.00375 .36652 L
s
0 .38606 m
.00375 .38606 L
s
0 .42515 m
.00375 .42515 L
s
0 .4447 m
.00375 .4447 L
s
0 .46424 m
.00375 .46424 L
s
0 .48379 m
.00375 .48379 L
s
0 .52287 m
.00375 .52287 L
s
0 .54242 m
.00375 .54242 L
s
0 .56196 m
.00375 .56196 L
s
0 .58151 m
.00375 .58151 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11244 m
1 .11244 L
s
.99375 .21016 m
1 .21016 L
s
.99375 .30788 m
1 .30788 L
s
.99375 .40561 m
1 .40561 L
s
.99375 .50333 m
1 .50333 L
s
.99375 .60105 m
1 .60105 L
s
.125 Mabswid
.99625 .03426 m
1 .03426 L
s
.99625 .0538 m
1 .0538 L
s
.99625 .07335 m
1 .07335 L
s
.99625 .09289 m
1 .09289 L
s
.99625 .13198 m
1 .13198 L
s
.99625 .15153 m
1 .15153 L
s
.99625 .17107 m
1 .17107 L
s
.99625 .19062 m
1 .19062 L
s
.99625 .22971 m
1 .22971 L
s
.99625 .24925 m
1 .24925 L
s
.99625 .2688 m
1 .2688 L
s
.99625 .28834 m
1 .28834 L
s
.99625 .32743 m
1 .32743 L
s
.99625 .34697 m
1 .34697 L
s
.99625 .36652 m
1 .36652 L
s
.99625 .38606 m
1 .38606 L
s
.99625 .42515 m
1 .42515 L
s
.99625 .4447 m
1 .4447 L
s
.99625 .46424 m
1 .46424 L
s
.99625 .48379 m
1 .48379 L
s
.99625 .52287 m
1 .52287 L
s
.99625 .54242 m
1 .54242 L
s
.99625 .56196 m
1 .56196 L
s
.99625 .58151 m
1 .58151 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .01472 m
.02608 .0232 L
.02723 .02697 L
.02847 .03029 L
.02913 .03169 L
.02972 .03272 L
.03001 .03313 L
.03033 .0335 L
.03062 .03378 L
.03089 .03399 L
.03105 .03408 L
.03121 .03416 L
.03131 .03419 L
.0314 .03422 L
.03148 .03424 L
.03156 .03425 L
.03166 .03426 L
.03174 .03427 L
.03184 .03426 L
.03193 .03425 L
.03202 .03424 L
.0321 .03422 L
.03228 .03416 L
.03243 .03409 L
.03257 .03401 L
.0329 .03377 L
.03321 .03345 L
.03355 .03304 L
.03419 .03203 L
.03478 .03086 L
.03611 .02742 L
.03736 .02338 L
.03854 .01911 L
.03907 .01709 L
.03935 .01599 L
.03949 .01544 L
.03962 .01495 L
.03976 .01503 L
.03991 .01561 L
.04023 .01684 L
.04079 .01897 L
.04208 .02367 L
.04327 .0275 L
.04438 .03041 L
.04496 .03166 L
.04559 .03275 L
.04592 .03321 L
.04622 .03357 L
.04652 .03386 L
.04681 .03407 L
Mistroke
.04696 .03415 L
.04712 .03423 L
.04722 .03426 L
.0473 .03428 L
.04738 .0343 L
.04747 .03431 L
.04763 .03432 L
.04771 .03432 L
.0478 .03431 L
.04795 .03428 L
.0481 .03424 L
.04825 .03417 L
.04841 .03409 L
.0487 .03388 L
.04902 .03359 L
.04936 .03318 L
.04998 .03224 L
.05056 .03112 L
.05163 .02847 L
.0528 .02492 L
.05405 .02048 L
.05466 .01817 L
.05522 .01603 L
.05536 .01547 L
.05552 .01485 L
.05567 .01516 L
.05581 .01569 L
.05643 .01812 L
.05776 .02304 L
.05886 .02668 L
.06003 .02996 L
.0607 .03149 L
.06132 .03262 L
.06161 .03307 L
.06194 .0335 L
.06222 .0338 L
.06252 .03407 L
.06267 .03417 L
.06283 .03426 L
.06297 .03433 L
.06311 .03438 L
.06323 .03441 L
.06337 .03443 L
.06352 .03444 L
.06365 .03443 L
.06373 .03442 L
.06381 .0344 L
.06396 .03436 L
.06412 .03429 L
.0643 .03419 L
Mistroke
.06461 .03397 L
.0649 .03368 L
.06554 .03285 L
.06612 .03184 L
.06744 .02875 L
.06864 .02508 L
.06992 .02053 L
.07054 .01816 L
.07085 .01698 L
.07113 .01588 L
.07126 .01536 L
.07139 .01488 L
.07152 .01506 L
.07166 .01561 L
.07223 .01783 L
.07459 .02635 L
.07576 .02972 L
.07684 .03214 L
.07741 .03311 L
.07801 .03389 L
.07833 .03418 L
.07862 .03439 L
.07879 .03447 L
.07894 .03454 L
.07903 .03456 L
.07911 .03458 L
.07921 .0346 L
.07929 .03461 L
.07943 .03461 L
.07958 .03459 L
.07973 .03456 L
.07986 .03452 L
.07998 .03447 L
.08011 .0344 L
.08038 .03423 L
.08066 .03397 L
.08097 .03363 L
.08153 .03284 L
.08217 .03166 L
.08275 .03033 L
.08409 .02657 L
.08525 .0226 L
.08651 .01783 L
.08684 .01656 L
.08701 .01586 L
.08718 .0152 L
.08732 .01479 L
.08747 .01538 L
.08779 .01665 L
.08899 .0213 L
Mistroke
.09124 .02882 L
.09247 .03186 L
.09317 .03314 L
.0935 .03363 L
.09381 .03402 L
.0941 .03432 L
.09437 .03453 L
.09451 .03462 L
.09467 .03471 L
.09475 .03474 L
.09483 .03477 L
.09499 .03482 L
.09506 .03483 L
.09515 .03484 L
.0953 .03484 L
.09545 .03483 L
.09559 .0348 L
.09574 .03475 L
.0959 .03468 L
.09608 .03458 L
.09624 .03447 L
.09684 .03387 L
.09718 .03341 L
.0975 .0329 L
.09869 .03037 L
.09977 .02731 L
.10093 .02342 L
.10206 .01916 L
.10265 .01682 L
.10295 .01562 L
.10303 .0153 L
.10312 .01495 L
.10327 .01512 L
.10342 .01571 L
.10358 .01636 L
.10388 .01753 L
.10442 .01968 L
.10548 .02366 L
.10672 .02783 L
.10787 .03104 L
.10851 .03244 L
.10908 .03348 L
.10972 .03435 L
.11008 .0347 L
.11024 .03482 L
.11041 .03493 L
.11058 .03502 L
.11073 .03508 L
.11087 .03512 L
.11102 .03514 L
Mistroke
.11116 .03514 L
.11128 .03514 L
.11142 .03511 L
.11157 .03507 L
.11173 .035 L
.1119 .03491 L
.11222 .03468 L
.11252 .03438 L
.1128 .03404 L
.11388 .0322 L
.11442 .03096 L
.11502 .02938 L
.11626 .02549 L
.11756 .0207 L
.11809 .01858 L
.11866 .01627 L
.11883 .01558 L
.11892 .01525 L
.11899 .01493 L
.11914 .01508 L
.11929 .01572 L
.11988 .01808 L
.12229 .0271 L
.12347 .03062 L
.12455 .03309 L
.12511 .03405 L
.12564 .03475 L
.12593 .03504 L
.1262 .03525 L
.12634 .03533 L
.1265 .03541 L
.12658 .03544 L
.12666 .03546 L
.12681 .0355 L
.12697 .03551 L
.12712 .03551 L
.1272 .0355 L
.12728 .03549 L
.12736 .03547 L
.12745 .03544 L
.12761 .03537 L
.12777 .03529 L
.12811 .03503 L
.12839 .03475 L
.12869 .03438 L
.1293 .03341 L
.13053 .03068 L
.13165 .02735 L
.13295 .02268 L
.13359 .02019 L
Mistroke
.13416 .01785 L
.13444 .01672 L
.13458 .01612 L
.13473 .01549 L
.13487 .01493 L
.13501 .01511 L
.13515 .01566 L
.13527 .01618 L
.13645 .02101 L
.13774 .02588 L
.13895 .02985 L
.14013 .03287 L
.14079 .03416 L
.14111 .03466 L
.14141 .03505 L
.14168 .03535 L
.14192 .03557 L
.1422 .03576 L
.14234 .03584 L
.14249 .0359 L
.14263 .03593 L
.14278 .03596 L
.14292 .03596 L
.14304 .03595 L
.14319 .03593 L
.14328 .0359 L
.14335 .03587 L
.1435 .03581 L
.14365 .03573 L
.14395 .0355 L
.14424 .03521 L
.14479 .03449 L
.14537 .03346 L
.14601 .03204 L
.14822 .02517 L
.14944 .02038 L
.15004 .01789 L
.15031 .01678 L
.1506 .01556 L
.15067 .01523 L
.15076 .01487 L
.15091 .01519 L
.15099 .01557 L
.15108 .01592 L
.15123 .01659 L
.15192 .01949 L
.15313 .02433 L
.15429 .02853 L
.15553 .03219 L
.15659 .0345 L
Mistroke
.15688 .03499 L
.15719 .03544 L
.15749 .0358 L
.15776 .03606 L
.15806 .03628 L
.15823 .03637 L
.15839 .03643 L
.15853 .03647 L
.15867 .03649 L
.15882 .03649 L
.15897 .03648 L
.15913 .03644 L
.15922 .03641 L
.1593 .03638 L
.15961 .0362 L
.15978 .03607 L
.15996 .03589 L
.1603 .0355 L
.16091 .03457 L
.16156 .03325 L
.16273 .03014 L
.16388 .02623 L
.1651 .02144 L
.16614 .01702 L
.16642 .01578 L
.16658 .01509 L
.16673 .01498 L
.16686 .01557 L
.16701 .01621 L
.16728 .01737 L
.16961 .02691 L
.1708 .03096 L
.17144 .03276 L
.17212 .03438 L
.17277 .03559 L
.17336 .03639 L
.17364 .03668 L
.17379 .0368 L
.17395 .03691 L
.17411 .03699 L
.17424 .03705 L
.17438 .03709 L
.17452 .03712 L
.17466 .03712 L
.17475 .03712 L
.17482 .03711 L
.17498 .03708 L
.17507 .03705 L
.17515 .03701 L
.17529 .03694 L
Mistroke
.17545 .03684 L
.17573 .03661 L
.17607 .03625 L
.17642 .03576 L
.17705 .03463 L
.17818 .03184 L
.1794 .02787 L
.18055 .02343 L
.18161 .01888 L
.18217 .01639 L
.18233 .01566 L
.18248 .01498 L
.18262 .01506 L
.18276 .01573 L
.18403 .02134 L
.18524 .02638 L
.18657 .03115 L
.18717 .03295 L
.18781 .03461 L
.18837 .03578 L
.18897 .03677 L
.18933 .03721 L
.1895 .03738 L
.18965 .03751 L
.1898 .03762 L
.18997 .03772 L
.19006 .03776 L
.19014 .03779 L
.19022 .03781 L
.1903 .03784 L
.19045 .03786 L
.19058 .03786 L
.19066 .03785 L
.19074 .03784 L
.19089 .0378 L
.19105 .03774 L
.19119 .03766 L
.19151 .03742 L
.19181 .03713 L
.19207 .03679 L
.19268 .0358 L
.19324 .03461 L
.19377 .03325 L
.19626 .02441 L
.19741 .01933 L
.19775 .01781 L
.19806 .01636 L
.1982 .01572 L
.19834 .01505 L
.1985 .01512 L
Mistroke
.19865 .0158 L
.20086 .02576 L
.20201 .03022 L
.20323 .03414 L
.20382 .03566 L
.20439 .03683 L
.20489 .03765 L
.20518 .03801 L
.20544 .03828 L
.20572 .0385 L
.20587 .03858 L
.20603 .03865 L
.20616 .03869 L
.20629 .03871 L
.20643 .03872 L
.20658 .03871 L
.20666 .03869 L
.20674 .03867 L
.20682 .03864 L
.20691 .0386 L
.20706 .03852 L
.20723 .03841 L
.20754 .03812 L
.20783 .03778 L
.20846 .03676 L
.20905 .03551 L
.21036 .03171 L
.21156 .02719 L
.21285 .02157 L
.21347 .01864 L
.21378 .01717 L
.21406 .01582 L
.21419 .01517 L
.21431 .01485 L
.21444 .01548 L
.21459 .01617 L
.21515 .01891 L
.21752 .02948 L
.21869 .03367 L
.21977 .03668 L
.22034 .03789 L
.22094 .03885 L
.22126 .03921 L
.22155 .03946 L
.22172 .03957 L
.22188 .03964 L
.22196 .03967 L
.22205 .0397 L
.22214 .03972 L
.22223 .03972 L
Mistroke
.22237 .03972 L
.22252 .0397 L
.22266 .03966 L
.22279 .0396 L
.22291 .03954 L
.22304 .03945 L
.22331 .03922 L
.2236 .0389 L
.22391 .03846 L
.22446 .03744 L
.2251 .03594 L
.22569 .03425 L
.22702 .02946 L
.22827 .02399 L
.22889 .02107 L
.22945 .01829 L
.22972 .01693 L
.22997 .01565 L
.2301 .015 L
.23024 .01512 L
.23039 .01589 L
.23053 .01659 L
.2317 .02241 L
.23299 .02841 L
.23418 .0332 L
.2353 .03681 L
.23587 .03824 L
.23649 .03947 L
.23682 .03997 L
.23711 .04033 L
.23728 .0405 L
.23746 .04064 L
.23763 .04075 L
.23778 .04083 L
.23794 .04088 L
.23809 .0409 L
.23823 .0409 L
.23837 .04089 L
.23853 .04084 L
.23861 .04081 L
.2387 .04077 L
.239 .04056 L
.23915 .04041 L
.2393 .04026 L
.23963 .03982 L
.24023 .03876 L
.24077 .0375 L
.24135 .03586 L
.24387 .02576 L
.24501 .02012 L
Mistroke
.2456 .01701 L
.24574 .01625 L
.2459 .01543 L
.24599 .01496 L
.24607 .0149 L
.24622 .01574 L
.24737 .0218 L
.24843 .02708 L
.24955 .03215 L
.25074 .03662 L
.25137 .0385 L
.25205 .04016 L
.25235 .04074 L
.25267 .04127 L
.25298 .04167 L
.25325 .04195 L
.25341 .04207 L
.25356 .04216 L
.25372 .04223 L
.25381 .04226 L
.25389 .04228 L
.25402 .04229 L
.25417 .04229 L
.25433 .04225 L
.25448 .0422 L
.25456 .04216 L
.25465 .0421 L
.25481 .04199 L
.25512 .04168 L
.25548 .04121 L
.25581 .04065 L
.25637 .03944 L
.25698 .03776 L
.25823 .03331 L
.26057 .02207 L
.26125 .0184 L
.26158 .01655 L
.26174 .01564 L
.26189 .01482 L
.26203 .01542 L
.26216 .01617 L
.26246 .01784 L
.26309 .02133 L
.2653 .03261 L
.26656 .0377 L
.26718 .03971 L
.26774 .04122 L
.26833 .04248 L
.26861 .04293 L
.2689 .04332 L
Mistroke
.26904 .04348 L
.26921 .04363 L
.26935 .04374 L
.26949 .04382 L
.26957 .04386 L
.26965 .04389 L
.26974 .04391 L
.26983 .04393 L
.2699 .04394 L
.26999 .04394 L
.27014 .04391 L
.27022 .04389 L
.27031 .04386 L
.27047 .04378 L
.27064 .04366 L
.27082 .04349 L
.27116 .04309 L
.27147 .0426 L
.27205 .04141 L
.27268 .03972 L
.2739 .03532 L
.27523 .02913 L
.2765 .0222 L
.2771 .01871 L
.27737 .01716 L
.27752 .01627 L
.27766 .01544 L
.27779 .01481 L
.27794 .01569 L
.27824 .0175 L
.27888 .02127 L
.28003 .02784 L
.28135 .03458 L
.28256 .03968 L
.28315 .04165 L
.28379 .04342 L
.28444 .04474 L
.28479 .04526 L
.28495 .04544 L
.28513 .04561 L
.28528 .04572 L
.28542 .0458 L
.28558 .04586 L
.28566 .04589 L
.28574 .0459 L
.28587 .0459 L
.28602 .04588 L
.28617 .04583 L
.2863 .04577 L
.28645 .04567 L
Mistroke
.28659 .04555 L
.28691 .04519 L
.28722 .04472 L
.28755 .04408 L
.28819 .04253 L
.28878 .04068 L
.29011 .03521 L
.29136 .02871 L
.29254 .02175 L
.29306 .01846 L
.29335 .01664 L
.29349 .01574 L
.29362 .01493 L
.29376 .0154 L
.29391 .01636 L
.29423 .01839 L
.29478 .02193 L
.29607 .02979 L
.29727 .03627 L
.29837 .04126 L
.29895 .04342 L
.29958 .04534 L
.2999 .04616 L
.3002 .0468 L
.30051 .04733 L
.30079 .04772 L
.30096 .04791 L
.30111 .04804 L
.30128 .04815 L
.30137 .0482 L
.30145 .04823 L
.30161 .04827 L
.30176 .04828 L
.30191 .04825 L
.30199 .04823 L
.30208 .04819 L
.30224 .0481 L
.30239 .04798 L
.30271 .04762 L
.303 .04718 L
.30331 .0466 L
.30385 .04531 L
.30444 .04348 L
.30574 .03805 L
.30696 .03148 L
.30814 .02407 L
.30879 .01975 L
.30911 .01759 L
.30924 .01665 L
.30939 .01562 L
Mistroke
.30953 .01476 L
.30966 .01564 L
.30991 .01737 L
.31046 .02117 L
.31162 .02898 L
.31389 .0419 L
.31451 .04464 L
.31517 .0471 L
.3158 .04892 L
.31638 .05013 L
.31668 .05059 L
.31695 .05089 L
.31711 .05102 L
.31719 .05107 L
.31727 .05112 L
.31742 .05117 L
.31757 .05119 L
.3177 .05119 L
.31784 .05116 L
.31797 .0511 L
.31809 .05102 L
.31824 .05091 L
.31839 .05075 L
.31867 .05038 L
.31897 .04986 L
.3193 .04914 L
.31997 .04723 L
.32117 .04235 L
.32241 .03563 L
.32371 .02712 L
.32482 .01908 L
.32512 .0168 L
.3252 .0162 L
.32529 .01555 L
.32544 .01507 L
.3256 .01628 L
.32575 .01739 L
.32603 .01949 L
.32844 .03677 L
.32962 .0438 L
.3307 .04893 L
.33122 .0509 L
.33179 .05261 L
.33211 .05335 L
.3324 .05391 L
.33267 .05432 L
.33283 .0545 L
.33297 .05463 L
.33311 .05474 L
.33326 .05481 L
Mistroke
.33341 .05485 L
.3335 .05485 L
.33358 .05485 L
.33372 .05481 L
.33386 .05475 L
.33401 .05465 L
.33415 .05452 L
.33448 .0541 L
.33478 .05357 L
.33511 .05282 L
.33546 .05185 L
.3366 .04745 L
.33782 .04081 L
.34002 .02495 L
.34062 .02016 L
.34094 .01747 L
.3411 .01615 L
.34124 .01493 L
.34133 .01521 L
.34142 .01596 L
.34161 .01754 L
.34194 .0203 L
.34258 .02563 L
.34375 .03498 L
.345 .04395 L
.34624 .05121 L
.34683 .05395 L
.34737 .05603 L
.34791 .05766 L
.3482 .05832 L
.34851 .05887 L
.34863 .05905 L
.34877 .05922 L
.34889 .05934 L
.34902 .05944 L
.34916 .05952 L
.34931 .05956 L
.34945 .05956 L
.34958 .05954 L
.34974 .05947 L
.34981 .05942 L
.3499 .05935 L
.35019 .05901 L
.35036 .05876 L
.35053 .05844 L
.35085 .05771 L
.35148 .05578 L
.35205 .05345 L
.3532 .04722 L
.35429 .03964 L
Mistroke
.35545 .03016 L
.35609 .0245 L
.3564 .02164 L
.35669 .01898 L
.35696 .01643 L
.3571 .01513 L
.35725 .01572 L
.3574 .01715 L
.35756 .01868 L
.35785 .02145 L
.35891 .03129 L
.36014 .04206 L
.36148 .05215 L
.36209 .05601 L
.36274 .05949 L
.36335 .0621 L
.36391 .06392 L
.36418 .06461 L
.36433 .06491 L
.36449 .06519 L
.36464 .06541 L
.36477 .06558 L
.36491 .0657 L
.36504 .06579 L
.36519 .06585 L
.36535 .06586 L
.36548 .06584 L
.36563 .06576 L
.36578 .06564 L
.36595 .06545 L
.36611 .06522 L
.36626 .06496 L
.3668 .06363 L
.36711 .06262 L
.36739 .06153 L
.36847 .05602 L
.36963 .04784 L
.37072 .03838 L
.37193 .02636 L
.37225 .02301 L
.37259 .01936 L
.37275 .01757 L
.37291 .01587 L
.37305 .01509 L
.3732 .01675 L
.37436 .02944 L
.37564 .04276 L
.37679 .05361 L
.37787 .06218 L
.37901 .06908 L
Mistroke
.37961 .0717 L
.37995 .07282 L
.38026 .07363 L
.38042 .07396 L
.38059 .07424 L
.38074 .07445 L
.38089 .07459 L
.38097 .07466 L
.38105 .0747 L
.38114 .07473 L
.38124 .07474 L
.38139 .07471 L
.38148 .07467 L
.38156 .07461 L
.38164 .07455 L
.38173 .07446 L
.38188 .07426 L
.38216 .07374 L
.38249 .07288 L
.3828 .07186 L
.38336 .06944 L
.38396 .06605 L
.38506 .05795 L
.38624 .04659 L
.38754 .03178 L
.38815 .02425 L
.38848 .01999 L
.38865 .01788 L
.3888 .01592 L
.38894 .01536 L
.38909 .01734 L
.38941 .02151 L
.38996 .02879 L
.39251 .06006 L
.39365 .07144 L
.39428 .07666 L
.39487 .0808 L
.39543 .08388 L
.39572 .0852 L
.39603 .08635 L
.39629 .08711 L
.39643 .08744 L
.39658 .08773 L
.39671 .08795 L
.39684 .0881 L
.39696 .08821 L
.39708 .08827 L
.39723 .08829 L
.39731 .08827 L
.39739 .08824 L
Mistroke
.39753 .08813 L
.39768 .08795 L
.39782 .08774 L
.39794 .08749 L
.39823 .08675 L
.39854 .08569 L
.39882 .08448 L
.39946 .0809 L
.4 .07697 L
.40059 .07177 L
.40167 .06007 L
.4029 .04382 L
.40405 .0263 L
.40436 .02133 L
.40453 .01857 L
.40468 .01599 L
.40477 .0148 L
.40486 .01626 L
.40504 .01938 L
.40537 .02488 L
.40658 .04491 L
.40897 .0811 L
.40962 .08929 L
.41032 .09682 L
.41092 .10225 L
.41123 .10465 L
.41157 .10683 L
.41186 .10846 L
.41218 .10989 L
.41232 .11041 L
.41247 .11088 L
.41261 .11124 L
.41275 .11152 L
.41289 .11174 L
.41304 .1119 L
.41318 .11197 L
.41332 .11196 L
.41345 .11189 L
.41358 .11176 L
.41371 .11155 L
.41385 .11126 L
.41402 .11081 L
.41417 .11029 L
.41453 .10878 L
.41484 .10704 L
.41517 .10478 L
.4158 .0993 L
.41637 .09305 L
.4176 .07572 L
.4189 .05233 L
Mistroke
.42 .02906 L
.4203 .02228 L
.42047 .01849 L
.42063 .01487 L
.42077 .01796 L
.42093 .02167 L
.42121 .02823 L
.42343 .0809 L
.42469 .10883 L
.42587 .13163 L
.42702 .14928 L
.42767 .15675 L
.42826 .16182 L
.42858 .16382 L
.42888 .16518 L
.42905 .16573 L
.42921 .16609 L
.4293 .16623 L
.42939 .16633 L
.42948 .16638 L
.42956 .16639 L
.42971 .16629 L
.42985 .16609 L
.43 .16573 L
.43016 .1652 L
.43033 .16446 L
.43049 .16359 L
.4308 .16153 L
.43135 .15627 L
.43196 .14818 L
.4326 .13716 L
.43319 .12442 L
.43542 .05774 L
.43603 .03433 L
.43618 .02815 L
.43633 .02221 L
.43646 .01679 L
.4366 .01862 L
.43675 .02504 L
.43689 .03106 L
.4372 .04477 L
.43785 .07508 L
.44008 .1886 L
.44253 .3198 L
.44483 .43383 L
.44703 .52237 L
.44827 .55939 L
.4494 .58381 L
.44997 .59257 L
.45029 .59635 L
Mistroke
.45058 .59907 L
.45086 .60101 L
.45101 .60185 L
.45115 .60245 L
.45128 .60285 L
.45141 .60315 L
.45155 .6033 L
.45169 .6033 L
.45184 .60313 L
.45193 .60294 L
.45201 .60272 L
.45216 .60217 L
.45232 .60141 L
.45259 .59962 L
.45289 .59698 L
.45356 .58869 L
.45419 .57793 L
.45538 .55004 L
.45662 .51118 L
.45886 .42247 L
.46346 .20488 L
.46602 .09277 L
.46724 .04765 L
.46777 .02984 L
.46791 .02519 L
.46807 .02031 L
.46822 .01581 L
.46835 .01764 L
.46849 .02168 L
.46864 .02599 L
.46892 .03352 L
.46952 .0486 L
.47013 .06212 L
.47078 .07442 L
.4714 .0842 L
.47196 .09139 L
.47253 .09705 L
.47307 .10098 L
.47336 .10259 L
.47363 .10375 L
.47378 .10427 L
.47393 .10466 L
.47401 .10484 L
.4741 .10501 L
.47425 .10522 L
.4744 .10534 L
.47448 .10537 L
.47456 .10537 L
.47465 .10535 L
.47472 .1053 L
Mistroke
.47481 .10522 L
.4749 .10512 L
.47504 .10487 L
.47518 .10457 L
.47549 .10365 L
.47579 .10249 L
.47606 .10115 L
.47657 .09805 L
.47772 .08867 L
.48015 .06163 L
.48237 .03417 L
.48294 .02754 L
.48355 .02077 L
.48384 .01764 L
.48399 .01614 L
.48412 .01478 L
.48424 .01587 L
.48437 .01713 L
.48464 .01973 L
.48584 .02981 L
.48647 .03414 L
.48714 .03796 L
.48772 .04068 L
.48836 .04296 L
.48864 .04375 L
.48894 .04444 L
.48923 .04495 L
.48948 .04531 L
.48962 .04546 L
.48977 .04558 L
.48989 .04566 L
.49003 .04573 L
.49017 .04576 L
.49033 .04577 L
.49048 .04575 L
.49062 .0457 L
.49075 .04562 L
.49088 .04553 L
.49117 .04525 L
.49142 .04492 L
.49169 .0445 L
.49234 .04316 L
.49293 .0416 L
.49428 .0372 L
.49671 .02769 L
.49781 .02328 L
.49898 .01866 L
.49933 .01731 L
.49966 .01603 L
.4998 .01548 L
Mistroke
.49995 .01489 L
.50003 .01484 L
.50012 .01518 L
.50027 .01578 L
.50148 .02046 L
.50401 .03059 L
.50512 .03495 L
.50633 .03931 L
.5069 .04112 L
.50751 .04279 L
.50804 .04398 L
.50861 .04497 L
.50877 .04518 L
.50895 .04537 L
.50911 .04552 L
.50926 .04563 L
.5094 .0457 L
.50955 .04575 L
.50963 .04577 L
.50971 .04577 L
.50986 .04576 L
.51 .04572 L
.51015 .04564 L
.51027 .04555 L
.51041 .04543 L
.51072 .04504 L
.511 .04454 L
.51157 .04317 L
.51219 .04105 L
.51283 .03811 L
.51344 .03472 L
.51451 .02706 L
.51507 .02232 L
.51538 .01952 L
.51567 .01677 L
.51581 .01532 L
.51597 .01571 L
.51606 .01663 L
.51615 .01752 L
.51631 .01921 L
.5169 .02571 L
.51824 .04157 L
.52067 .07142 L
.52182 .08422 L
.52246 .09036 L
.52306 .09538 L
.52362 .09928 L
.52391 .10099 L
.52422 .10251 L
.52448 .10356 L
Mistroke
.52462 .10403 L
.52477 .10445 L
.52491 .10477 L
.52503 .105 L
.52516 .10518 L
.52527 .1053 L
.52541 .10537 L
.52556 .10536 L
.5257 .10527 L
.52583 .10512 L
.52597 .10488 L
.52613 .10452 L
.52629 .10404 L
.52644 .10349 L
.52675 .10203 L
.52704 .10032 L
.52768 .09513 L
.52823 .08913 L
.52882 .08095 L
.5299 .06156 L
.53104 .03458 L
.53136 .02604 L
.53153 .02114 L
.53161 .01866 L
.53169 .01634 L
.53184 .01765 L
.53192 .0201 L
.53201 .02274 L
.5323 .03198 L
.53484 .12817 L
.53986 .36387 L
.54238 .47439 L
.54349 .51509 L
.5447 .55211 L
.54527 .56631 L
.54587 .57912 L
.5464 .58809 L
.54697 .59554 L
.5473 .59878 L
.54745 .59993 L
.54761 .60101 L
.54775 .60178 L
.54791 .60244 L
.54799 .60273 L
.54807 .60294 L
.54822 .60322 L
.54836 .60332 L
.5485 .60326 L
.54865 .60304 L
.5488 .60261 L
Mistroke
.54895 .60201 L
.54909 .60129 L
.54936 .59952 L
.54965 .59695 L
.54992 .59395 L
.55054 .58501 L
.55114 .57352 L
.55178 .55825 L
.55401 .48394 L
.55657 .36639 L
.55899 .23832 L
.56119 .12256 L
.56244 .06152 L
.56274 .04778 L
.56305 .0337 L
.56332 .02202 L
.56347 .01555 L
.56361 .01981 L
.56476 .0641 L
.566 .10362 L
.56722 .13353 L
.56791 .14608 L
.56853 .15485 L
.56911 .16081 L
.56941 .16299 L
.56958 .16399 L
.56973 .16476 L
.56987 .16529 L
.57001 .16575 L
.57016 .16611 L
.57031 .16631 L
.57044 .16639 L
.57058 .16635 L
.57072 .16621 L
.57084 .16599 L
.571 .16558 L
.57117 .16499 L
.57146 .16357 L
.57178 .1615 L
.57213 .15863 L
.57276 .15197 L
.57335 .14415 L
.57581 .09816 L
.57805 .04586 L
.57863 .03198 L
.57895 .02445 L
.5791 .0208 L
.57925 .01748 L
.57937 .01481 L
.5795 .0178 L
Mistroke
.57977 .024 L
.58035 .03679 L
.58156 .06118 L
.58286 .08279 L
.5835 .09151 L
.58411 .09839 L
.5847 .10376 L
.58496 .1057 L
.58524 .10753 L
.58549 .10887 L
.58576 .11005 L
.58591 .11058 L
.58604 .11098 L
.58617 .11131 L
.58631 .11158 L
.58645 .11179 L
.58659 .11192 L
.58674 .11197 L
.58682 .11197 L
.5869 .11194 L
.58704 .11183 L
.58717 .11166 L
.58731 .11141 L
.58746 .11106 L
.58777 .11009 L
.58806 .10885 L
.58861 .10574 L
.5892 .1013 L
.58984 .09528 L
.59205 .06669 L
.59328 .04719 L
.59444 .02795 L
.59474 .02297 L
.59502 .01826 L
.59518 .01568 L
.59527 .01521 L
.59535 .01656 L
.59565 .02143 L
.59698 .042 L
.59825 .05918 L
.59945 .07223 L
.60053 .08085 L
.60114 .0843 L
.60143 .08556 L
.6017 .08653 L
.60184 .08696 L
.60199 .08735 L
.60212 .08763 L
.60227 .08788 L
.60242 .08808 L
Mistroke
.6025 .08816 L
.60258 .08822 L
.60272 .08828 L
.60287 .08828 L
.60301 .08823 L
.60315 .08812 L
.6033 .08793 L
.60344 .0877 L
.6037 .08714 L
.60397 .08636 L
.60429 .08516 L
.60464 .08355 L
.60527 .07985 L
.60646 .07045 L
.60881 .04454 L
.61006 .02853 L
.61042 .02382 L
.61076 .01934 L
.61091 .0174 L
.61106 .01534 L
.61115 .01528 L
.61124 .01635 L
.6114 .01842 L
.61266 .03424 L
.61385 .04759 L
.61495 .05798 L
.61557 .06289 L
.61615 .06675 L
.61677 .07006 L
.61733 .07233 L
.61764 .07326 L
.61793 .07393 L
.61809 .07421 L
.61824 .07442 L
.6184 .07459 L
.61849 .07465 L
.61858 .0747 L
.61872 .07474 L
.61887 .07473 L
.61899 .07468 L
.61913 .07458 L
.61928 .07442 L
.61944 .0742 L
.61973 .07365 L
.62002 .07291 L
.62029 .07204 L
.62081 .06997 L
.62198 .06323 L
.62322 .0535 L
.62545 .03143 L
Mistroke
.62604 .02507 L
.62659 .01899 L
.62674 .01736 L
.6269 .01563 L
.62698 .01473 L
.62707 .01569 L
.62723 .01743 L
.62782 .02369 L
.63003 .04502 L
.63124 .05419 L
.63236 .06045 L
.63294 .06281 L
.63328 .06387 L
.63358 .06464 L
.63391 .06525 L
.63408 .0655 L
.63417 .06559 L
.63425 .06567 L
.63441 .06578 L
.63455 .06584 L
.6347 .06586 L
.63479 .06585 L
.63487 .06583 L
.63502 .06575 L
.63511 .06569 L
.63518 .06562 L
.63547 .06525 L
.63564 .06498 L
.63581 .06462 L
.63613 .06383 L
.63675 .06173 L
.63732 .0592 L
.63841 .05294 L
.63955 .04456 L
.6407 .03485 L
.64133 .02912 L
.64192 .02355 L
.64248 .0183 L
.64263 .01686 L
.64271 .01607 L
.64279 .01534 L
.64293 .01539 L
.64308 .01682 L
.64414 .02654 L
.64532 .03664 L
.64657 .04577 L
.64764 .05197 L
.6482 .05453 L
.6488 .05674 L
.64914 .05768 L
Mistroke
.64944 .05839 L
.64974 .05891 L
.64988 .05911 L
.65005 .05929 L
.65019 .05942 L
.65033 .0595 L
.65048 .05955 L
.65063 .05956 L
.65076 .05954 L
.65089 .05949 L
.65103 .05941 L
.65117 .05928 L
.65134 .05908 L
.6515 .05886 L
.65186 .0582 L
.65217 .05744 L
.6525 .05647 L
.6537 .05152 L
.65485 .04495 L
.65607 .03634 L
.65723 .02726 L
.65773 .02308 L
.65829 .01842 L
.65844 .01717 L
.6586 .01583 L
.65875 .01486 L
.65889 .01602 L
.65952 .02127 L
.66086 .03175 L
.66212 .04039 L
.66329 .04689 L
.66386 .04942 L
.66439 .05138 L
.66469 .05229 L
.66501 .05311 L
.6653 .05373 L
.66558 .05418 L
.66573 .05439 L
.66588 .05455 L
.66604 .05468 L
.66612 .05474 L
.66621 .05479 L
.66629 .05482 L
.66637 .05484 L
.66653 .05485 L
.66661 .05484 L
.66669 .05482 L
.66678 .05479 L
.66688 .05474 L
.66702 .05464 L
Mistroke
.66718 .05449 L
.6675 .05407 L
.6678 .05355 L
.66807 .05294 L
.66868 .05121 L
.66934 .04875 L
.67054 .04291 L
.67278 .02833 L
.67392 .01986 L
.67424 .01749 L
.67441 .01619 L
.67449 .01555 L
.67457 .01495 L
.67472 .01562 L
.6748 .01623 L
.67489 .01687 L
.67518 .01904 L
.67772 .03638 L
.67896 .04297 L
.67961 .04574 L
.6803 .04809 L
.68091 .04962 L
.68125 .05026 L
.68142 .05051 L
.68157 .05071 L
.68171 .05086 L
.68187 .05099 L
.68201 .05109 L
.68213 .05115 L
.68227 .05118 L
.68243 .05119 L
.6825 .05119 L
.68259 .05117 L
.68274 .05111 L
.68289 .05102 L
.68303 .05091 L
.68334 .05057 L
.68362 .05013 L
.68389 .04961 L
.6845 .0481 L
.68516 .04594 L
.68648 .04007 L
.6877 .0332 L
.6888 .02621 L
.6894 .02214 L
.68997 .01821 L
.69029 .01598 L
.69038 .01537 L
.69048 .01472 L
.69056 .01526 L
Mistroke
.69064 .01587 L
.69126 .02008 L
.69246 .02795 L
.6936 .03462 L
.69479 .04047 L
.69542 .04296 L
.6961 .04517 L
.6964 .04596 L
.69673 .04668 L
.697 .04719 L
.69731 .04764 L
.69762 .04798 L
.69779 .04811 L
.69787 .04816 L
.69795 .0482 L
.6981 .04825 L
.69823 .04828 L
.69838 .04827 L
.69846 .04826 L
.69854 .04824 L
.69862 .0482 L
.69871 .04816 L
.69888 .04805 L
.69904 .04791 L
.69919 .04775 L
.69952 .04728 L
.69988 .04664 L
.70048 .0452 L
.70103 .04348 L
.70231 .03834 L
.70455 .02605 L
.70517 .02222 L
.70582 .01807 L
.70609 .01635 L
.70623 .01545 L
.70638 .01493 L
.70646 .01544 L
.70655 .01599 L
.7067 .01696 L
.707 .01885 L
.70833 .02693 L
.70956 .03363 L
.71073 .03885 L
.71134 .04109 L
.71199 .04301 L
.7123 .04378 L
.71265 .04449 L
.71297 .04502 L
.71326 .04539 L
.7134 .04554 L
Mistroke
.71356 .04567 L
.71364 .04573 L
.71372 .04578 L
.71388 .04585 L
.71403 .04589 L
.71416 .0459 L
.71431 .04589 L
.71446 .04585 L
.71459 .0458 L
.71473 .04571 L
.71488 .0456 L
.71502 .04547 L
.71554 .04478 L
.71583 .04425 L
.7161 .04368 L
.7167 .04212 L
.7179 .03789 L
.71901 .03287 L
.7203 .02599 L
.72093 .02236 L
.72151 .01894 L
.72178 .01736 L
.72192 .01652 L
.72207 .01562 L
.72221 .01476 L
.72235 .01545 L
.7226 .01697 L
.72377 .02375 L
.72507 .03062 L
.72626 .03597 L
.72738 .03991 L
.72795 .04142 L
.72858 .04268 L
.7289 .04317 L
.7292 .04352 L
.72937 .04366 L
.72955 .04379 L
.72963 .04383 L
.72972 .04387 L
.72987 .04392 L
.73002 .04394 L
.73017 .04393 L
.73032 .0439 L
.73045 .04385 L
.7306 .04377 L
.73076 .04366 L
.73109 .04334 L
.73139 .04293 L
.73172 .04238 L
.73233 .04107 L
Mistroke
.73345 .03766 L
.73476 .0323 L
.73598 .02635 L
.73707 .02047 L
.73735 .01887 L
.73767 .01712 L
.73781 .01631 L
.73796 .01546 L
.73811 .01478 L
.73824 .01552 L
.73891 .01925 L
.73952 .02258 L
.74073 .02869 L
.74186 .03368 L
.74305 .03787 L
.74367 .03955 L
.74401 .04028 L
.74436 .04094 L
.74469 .04144 L
.74498 .04179 L
.74512 .04193 L
.74528 .04206 L
.74543 .04215 L
.74556 .04222 L
.7457 .04226 L
.74584 .04229 L
.74599 .04229 L
.74615 .04227 L
.74629 .04223 L
.74643 .04216 L
.74657 .04208 L
.7467 .04199 L
.74701 .04169 L
.74734 .04125 L
.74795 .04016 L
.74859 .03862 L
.74927 .03658 L
.75049 .03199 L
.75163 .02682 L
.75285 .02064 L
.75344 .01751 L
.75373 .01596 L
.75386 .01528 L
.754 .0149 L
.75413 .01557 L
.75425 .0162 L
.75451 .01758 L
.75506 .02044 L
.75728 .03092 L
.75854 .03553 L
Mistroke
.75916 .03732 L
.75972 .03865 L
.76001 .03922 L
.76032 .03974 L
.76059 .04012 L
.76088 .04045 L
.76104 .04059 L
.7612 .0407 L
.76129 .04076 L
.76137 .0408 L
.76145 .04084 L
.76153 .04086 L
.76168 .0409 L
.76176 .0409 L
.76184 .04091 L
.76199 .04089 L
.76213 .04086 L
.76229 .0408 L
.76237 .04075 L
.76246 .0407 L
.76276 .04046 L
.76311 .04007 L
.76344 .03959 L
.76404 .03845 L
.76467 .03688 L
.7659 .03291 L
.76724 .02743 L
.76839 .022 L
.769 .01896 L
.76932 .01734 L
.7695 .01645 L
.76966 .01562 L
.76981 .01487 L
.76997 .01536 L
.77006 .01581 L
.77014 .01625 L
.7703 .01705 L
.77089 .01998 L
.77205 .02546 L
.77328 .03064 L
.77458 .03506 L
.77513 .03654 L
.77573 .03783 L
.77607 .03842 L
.77638 .03887 L
.7767 .03923 L
.77685 .03937 L
.77699 .03948 L
.77712 .03956 L
.77726 .03963 L
Mistroke
.77741 .03968 L
.77755 .03971 L
.77768 .03973 L
.77781 .03972 L
.77793 .0397 L
.77806 .03967 L
.77821 .0396 L
.77835 .03953 L
.77866 .03929 L
.77895 .03898 L
.77922 .03862 L
.77978 .03767 L
.78039 .03631 L
.78163 .03263 L
.78385 .02359 L
.78444 .02083 L
.78507 .01784 L
.78533 .01659 L
.78547 .0159 L
.7856 .01525 L
.78576 .01495 L
.78591 .01564 L
.78619 .017 L
.7887 .02827 L
.78988 .0325 L
.79052 .03441 L
.79112 .03591 L
.79168 .03702 L
.79218 .0378 L
.79247 .03814 L
.79275 .03839 L
.79289 .03849 L
.79303 .03858 L
.79311 .03861 L
.7932 .03865 L
.79335 .03869 L
.7935 .03872 L
.79363 .03872 L
.79378 .0387 L
.79387 .03868 L
.79394 .03866 L
.7941 .0386 L
.79426 .03851 L
.79456 .03827 L
.79485 .03798 L
.79514 .03759 L
.79568 .0367 L
.7963 .03537 L
.79688 .03384 L
.79819 .02949 L
Mistroke
.79945 .02444 L
.80064 .01912 L
.80116 .01673 L
.8013 .01603 L
.80144 .01538 L
.80157 .01479 L
.80171 .01527 L
.80231 .01808 L
.80287 .02063 L
.80523 .03014 L
.80588 .03223 L
.80657 .03414 L
.80722 .0356 L
.80782 .03664 L
.80812 .03704 L
.80843 .03738 L
.80875 .03763 L
.80893 .03773 L
.80901 .03777 L
.8091 .0378 L
.80925 .03784 L
.80941 .03786 L
.80955 .03786 L
.80968 .03784 L
.80984 .0378 L
.80999 .03774 L
.81016 .03765 L
.81031 .03754 L
.81059 .03729 L
.81088 .03696 L
.8114 .03619 L
.81197 .0351 L
.81259 .03361 L
.81493 .02569 L
.81624 .02017 L
.81688 .01734 L
.81715 .01609 L
.8173 .01544 L
.81745 .01475 L
.81761 .0154 L
.81776 .01606 L
.81805 .01734 L
.81868 .02013 L
.82001 .02566 L
.82118 .02989 L
.82182 .03187 L
.82243 .03349 L
.82303 .0348 L
.82334 .03538 L
.82368 .03591 L
Mistroke
.82396 .03628 L
.82427 .03661 L
.82455 .03684 L
.82468 .03693 L
.82481 .037 L
.82495 .03705 L
.82509 .0371 L
.82523 .03712 L
.82537 .03712 L
.8255 .03711 L
.82563 .03709 L
.82575 .03705 L
.82587 .037 L
.82601 .03693 L
.82617 .03683 L
.82647 .03657 L
.82676 .03626 L
.82702 .03591 L
.82763 .03489 L
.82828 .03347 L
.82948 .03009 L
.83171 .0217 L
.83226 .01939 L
.83285 .01684 L
.83301 .01613 L
.83318 .01537 L
.83333 .01473 L
.83341 .01507 L
.83349 .0154 L
.8341 .01804 L
.8354 .02346 L
.83663 .02804 L
.83781 .03169 L
.83844 .03325 L
.8391 .03458 L
.83965 .03544 L
.83997 .03582 L
.84026 .0361 L
.8404 .03621 L
.84053 .03629 L
.84065 .03636 L
.84078 .03641 L
.84092 .03646 L
.84105 .03648 L
.8412 .0365 L
.84134 .03649 L
.84148 .03647 L
.84162 .03643 L
.84177 .03637 L
.84193 .03629 L
Mistroke
.84225 .03605 L
.84255 .03576 L
.84312 .03499 L
.84366 .03402 L
.84487 .03111 L
.84617 .02691 L
.84741 .02223 L
.84856 .01745 L
.84885 .01625 L
.849 .01559 L
.84914 .01498 L
.8493 .01511 L
.84938 .01546 L
.84947 .01584 L
.84977 .0171 L
.8511 .02256 L
.85234 .02714 L
.85368 .03124 L
.85429 .03274 L
.85494 .03404 L
.8555 .03489 L
.85581 .03527 L
.85611 .03555 L
.85626 .03567 L
.85642 .03577 L
.85656 .03584 L
.85671 .0359 L
.85679 .03592 L
.85687 .03594 L
.85702 .03596 L
.8571 .03596 L
.85719 .03596 L
.85728 .03595 L
.85737 .03594 L
.85752 .03589 L
.85767 .03583 L
.8578 .03576 L
.85794 .03567 L
.85826 .03541 L
.85856 .03509 L
.85908 .03437 L
.85964 .03334 L
.8608 .03057 L
.8621 .02646 L
.86333 .02185 L
.86444 .01735 L
.86475 .01609 L
.86491 .0154 L
.86507 .01475 L
.86522 .0153 L
Mistroke
.86538 .01596 L
.86566 .0171 L
.86789 .02575 L
.86915 .02979 L
.86977 .03143 L
.87033 .03271 L
.87089 .03375 L
.87149 .03462 L
.87183 .03497 L
.87197 .0351 L
.87213 .03522 L
.87227 .03531 L
.87243 .03539 L
.87251 .03542 L
.87259 .03545 L
.87274 .03549 L
.87289 .03551 L
.87304 .03551 L
.87319 .0355 L
.87333 .03547 L
.87341 .03544 L
.87349 .03541 L
.87366 .03533 L
.87398 .03512 L
.87428 .03484 L
.87461 .03445 L
.87528 .03341 L
.87591 .03214 L
.8765 .03068 L
.87762 .02738 L
.87885 .02308 L
.87951 .02051 L
.88014 .018 L
.88044 .01681 L
.88075 .01555 L
.88083 .01523 L
.88091 .01488 L
.881 .01492 L
.88109 .01527 L
.8814 .01654 L
.88254 .02107 L
.88476 .02875 L
.88599 .03192 L
.88668 .03327 L
.88701 .03379 L
.88733 .03421 L
.88762 .03453 L
.88789 .03476 L
.88818 .03496 L
.88835 .03504 L
Mistroke
.8885 .03509 L
.88865 .03513 L
.88874 .03514 L
.88881 .03514 L
.88896 .03514 L
.8891 .03512 L
.88918 .0351 L
.88926 .03508 L
.88941 .03502 L
.88958 .03494 L
.88975 .03483 L
.89006 .03458 L
.89038 .03423 L
.89098 .03338 L
.89157 .0323 L
.8921 .03109 L
.89463 .02328 L
.89571 .01917 L
.89628 .01691 L
.89643 .01632 L
.89659 .01567 L
.89674 .01507 L
.89688 .01491 L
.89695 .01523 L
.89704 .01557 L
.89719 .01619 L
.89754 .01758 L
.89816 .01998 L
.89936 .02444 L
.9006 .02843 L
.90175 .03142 L
.90234 .03261 L
.90296 .03361 L
.90332 .03405 L
.90366 .03438 L
.90396 .0346 L
.90413 .0347 L
.90429 .03477 L
.90445 .03481 L
.90452 .03483 L
.90461 .03484 L
.90476 .03484 L
.9049 .03483 L
.90499 .03482 L
.90507 .0348 L
.90522 .03475 L
.90539 .03468 L
.90557 .03458 L
.90587 .03434 L
.90619 .03402 L
Mistroke
.90677 .03325 L
.90732 .03228 L
.90784 .03119 L
.90901 .02808 L
.91124 .0204 L
.91186 .01804 L
.91219 .01672 L
.91236 .01607 L
.91251 .01547 L
.91265 .0149 L
.9128 .01513 L
.91296 .01573 L
.91312 .0164 L
.91368 .01859 L
.9161 .02717 L
.91742 .03075 L
.91806 .0321 L
.91865 .03312 L
.91925 .03388 L
.91957 .03418 L
.91973 .0343 L
.9199 .03441 L
.92007 .03449 L
.92023 .03455 L
.92038 .03459 L
.92053 .03461 L
.92067 .03461 L
.9208 .0346 L
.92094 .03457 L
.9211 .03452 L
.92125 .03446 L
.92139 .03438 L
.9217 .03416 L
.92198 .0339 L
.92227 .03356 L
.92278 .03283 L
.92333 .03181 L
.92456 .02888 L
.92567 .02548 L
.92698 .02086 L
.92762 .01844 L
.92789 .01737 L
.92819 .0162 L
.92834 .01564 L
.92849 .01504 L
.92862 .0149 L
.92876 .01546 L
.9293 .01756 L
.93048 .02202 L
.93179 .02647 L
Mistroke
.93298 .02985 L
.93356 .0312 L
.93419 .03241 L
.93478 .03331 L
.93533 .03392 L
.93563 .03415 L
.93577 .03423 L
.93591 .03431 L
.93599 .03434 L
.93608 .03437 L
.93622 .03441 L
.93631 .03442 L
.9364 .03443 L
.93648 .03444 L
.93656 .03444 L
.93664 .03443 L
.93672 .03442 L
.93688 .03438 L
.93696 .03435 L
.93704 .03432 L
.93722 .03423 L
.93753 .03403 L
.93786 .03373 L
.93849 .03292 L
.93908 .03192 L
.94041 .02882 L
.94283 .02088 L
.94345 .01857 L
.94377 .01733 L
.94411 .01601 L
.94425 .01545 L
.94441 .01485 L
.9445 .01492 L
.94458 .01524 L
.94474 .01585 L
.94531 .01808 L
.94756 .02606 L
.94868 .0293 L
.94986 .03195 L
.95048 .03297 L
.95081 .03339 L
.95117 .03377 L
.95149 .03402 L
.95163 .03411 L
.95179 .03419 L
.95193 .03425 L
.95207 .03429 L
.95222 .03431 L
.95237 .03432 L
.95252 .03432 L
Mistroke
.9526 .0343 L
.95268 .03429 L
.95277 .03426 L
.95284 .03424 L
.95301 .03417 L
.95316 .03409 L
.95332 .03398 L
.95361 .03374 L
.95395 .03338 L
.9543 .03291 L
.95495 .03183 L
.9561 .02922 L
.95738 .02547 L
.95851 .02155 L
.95971 .01706 L
.96001 .0159 L
.96018 .01525 L
.96034 .01479 L
.96043 .01513 L
.96052 .01551 L
.96069 .01616 L
.96102 .01743 L
.96222 .02193 L
.96346 .02611 L
.96462 .02943 L
.96583 .03206 L
.96647 .03306 L
.96683 .03349 L
.96715 .03381 L
.96731 .03393 L
.96746 .03403 L
.96759 .0341 L
.96773 .03416 L
.96788 .03421 L
.96802 .03425 L
.96818 .03426 L
.96826 .03427 L
.96834 .03426 L
.96849 .03425 L
.96862 .03421 L
.96874 .03417 L
.96888 .03412 L
.96917 .03394 L
.96945 .03372 L
.97002 .03308 L
.97066 .03209 L
.97195 .02927 L
.97399 .02296 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005_ooool3o`0000Cooooo0_l0000iooooo`?o0000>oooool2o`0003cooooo0ol0000ioooo
o`?o00001?ooool2o`0000Oooooo000Gooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000=oooool01Ol0003ooooooooooooooooo000003Wooooo00Co0000oooooooooooo0000>_oo
ool01Ol0003ooooooooooooooooo000003Wooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00006ooooo`003oooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000aooooo`Go00001Oooool00ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`00
03kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Kooooo000Gooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000>oooool0
0ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`0003kooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo000Gooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000=oooool4o`0003[ooooo00Co0000oooooooooooo
0000>_ooool4o`0003[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006oooo
o`005_ooool2o`0000Cooooo00Co0000oooooooooooo0000=oooool00ol0003oooooooooo`0koooo
o`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool0>_ooool2o`0000Cooooo00Co0000
oooooooooooo00001_ooool001Oooooo00?o0000ooooooooool00oooool2o`0003Sooooo1Ol0000j
ooooo`;o0000>oooool5o`0003Wooooo00?o0000ooooooooool00oooool2o`0000Oooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Aoooooooo00003Ol00003
ooooo`002_ooool2o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`01oooo
o`002Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo007ooooo0009ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo007ooooo0009ooooo`04o`000?ooooooooooo`0000Cooooo0ol00004oooo
o`05o`00ooooooooooooooooool00?l01oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`Oooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool04_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool01_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o00Oooooo00Co003ooooooooooooooooo0_l00?l3ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01_ooool01Ol00?oooooooooooooooooo003o00_ooooo00?o
003oooooooooool02_ooool01Ol00?oooooooooooooooooo003o00Cooooo0ol00003ooooo`002Ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o0_ooool2o`00o`?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`;o003o0_ooool01?l00?ooooooooooooooool2o`00o`?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o0oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00Oooooo00Co003ooooo
oooooooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`06ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool2o`00o`;ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool2
o`00o`;ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo007ooooo0009ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`02ooooo`;o003o
0oooool00ol00?ooooooooooo`02o`00o`;ooooo00?o003oooooool00?l00_ooool01?l00?oooooo
ooooooooool2o`00o`;ooooo00Co003ooooooooooooooooo0_l00?l7ooooo`;o003o0_ooool2o`00
o`Oooooo00Co003ooooooooooooooooo0_l00?l2ooooo`04o`00ooooooooooooooooo`;o003o0ooo
ool01Ol00?oooooooooooooooooo003o00Oooooo0_l00?l3ooooo`05o`00ooooooooooooooooool0
0?l00oooool01?l00?ooooooooooooooool2o`00o`?ooooo00?o003oooooooooool01Oooool01?l0
0?ooooooooooooooool2o`00o`;ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l02?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o
003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?l3
ooooo`03o`00oooooooooooo00;o003o0oooool01?l00?ooooooooooooooool2o`00o`?ooooo00?o
003oooooooooool00_l00?l2ooooo`;o003o0oooool01?l00?ooooooooooooooool2o`00o`?ooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooooooool2o`00o`;ooooo0_l00?l2oooo
o`;o003o0_ooool2o`00o`Oooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`01oooo
o`002_ooool2o`0000Gooooo00?o0000ooooooooool02Oooool01ol00?ooooooo`00oooooooo003o
ooooool00?l01Oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Gooooo0_l0
0?l01?oooooo003oooooool00?l6ooooo`04o`00ooooooooooooooooo`;o003o1_ooool00ol00?oo
ooooo`00o`02ooooo`;o003o0oooool00ol00?ooooooooooo`02o`00o`;ooooo0_l00?l3ooooo`03
o`00oooooooooooo00Gooooo0_l00?l2ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o
00?ooooo0_l00?l3ooooo`03o`00oooooooooooo00Wooooo0_l00?l2ooooo`;o003o0_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo0_l00?l3ooooo`05o`00oooooooooooo
ooooool00?l00oooool01?l00?ooooooooooooooool2o`00o`;ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o0oooool2o`00o`;o
oooo0_l00?l3ooooo`;o003o0_ooool01?l00?ooooooooooooooool2o`00o`;ooooo0_l00?l2oooo
o`03o`00oooooooooooo00;ooooo0_l00?l2ooooo`03o`00oooooooooooo00?ooooo00Co003ooooo
ool00?oo003o0oooool2o`00o`;ooooo0_l00?l2ooooo`07o`00oooooooo003oooooool00?oooooo
o`00o`03ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool01Oooool2o`00o`;ooooo00Co003ooooooooooooooooo0ol00?l2ooooo`;o003o
0_ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooo003o00Cooooo00oo003ooooooooooooo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l01Oooool02?l00?oo
ooooooooool00?ooooooo`00oooooooo003o0oooool00ol00?ooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;o003o
0oooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooooooo0_l00?l2
ooooo`04o`00ool0003oooooooooo`;o003o0oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`?o
oooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooooooo00;o003o0_ooool00ol0
0?ooooooooooo`03ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool0
0?l3ooooo`03o`00oooooooooooo00?ooooo00Oo003oooooool00?ooooooo`00oooooooo003o00?o
oooo00Co003ooooooooooooo003o0oooool01ol00?oooooooooooooooooo003oooooool00?l01_oo
ool01ol00?ooooooo`00oooooooo003oooooool00?l00oooool01?l00?ooooooo`00ool00?l8oooo
o`03o`000?oooooooooo007ooooo000Aooooo`;o00001_ooool2o`00o`?ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02o`00o`?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`04o`00ooooooooooooooooo`;o003o0_ooool00ol00?ooooooooooo`02ooooo`;o003o00?ooooo
o`00ool00?l00_ooool2o`00o`?ooooo0ol00?l01?oooooo003oooooool00?l7ooooo`03o`00oooo
oooo003o00;ooooo0_l00?l2ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00_l0
0?l3ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00Go003oooooool0003o003oooooo`02o`00o`?ooooo
00?o003oooooooooool01Oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`04ooooo`03
o`00oooooooooooo00Cooooo0_l00?l2ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02
ooooo`;o003o0_ooool2o`00o`cooooo00Co003oooooool00?oooooo0_l00?l01_oooooo003ooooo
ool00?ooooooo`00o`?ooooo00Co003oooooool00?oo003o1?ooool00ol00?ooooooooooo`02o`00
o`;ooooo0_l00?l8ooooo`04o`00ooooooooooooo`00o`Sooooo0_l00?l2ooooo`;o003o1_ooool2
o`0000?ooooo000Aooooo`03o`000?oooooooooo02cooooo00Go003oooooooooooooooooo`00o`03
ooooo`;o003o0oooool01?l00?ooooooooooool00?l3ooooo`04o`00oooooooo003oooooo`?o003o
1?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00?ooooo00?o003oooooool00?l0
0_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool01Oooool01Ol00?oooooooooooooooooo
003o00Cooooo00?o0000o`00ooooool00_l00?l3ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool00_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`;ooooo0_l0
0?l4ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00oooool00ol00?ooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00_ooool2o`00o`;ooooo00Co003ooooooooooooo
oooo0_l00?l3ooooo`;o003o0_ooool01?l00?ooooooooooooooool2o`00obWooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool0@Oooool2o`00o`;ooooo0_l00?l3ooooo`03
o`00oooooooooooo00Cooooo00Oo003oooooool00?ooooooo`00oooooooo003o00Cooooo0_l00?l2
ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l01ooo
ool01?l00?ooooooooooooooool4o`00o`06ooooool0003o003oo`00oooooooo003o0oooool00ol0
0?ooooooooooo`06ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`02
ooooo`;o003o0_ooool2o`00o`Cooooo00Oo003oooooooooooooooooo`00oooooooo003o00?ooooo
00?o003oooooooooool01?ooool2o`00o`;ooooo0_l00?l3ooooo`;o003o@_ooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`16ooooo`03o`00oooooooooooo00;o003o0_oo
ool2o`00o`;ooooo00Go003oooooool00?ooooooo`00o`06ooooo`;o003o0_ooool2o`00o`;ooooo
00?o003oooooool00?l00_ooool2o`00o`;ooooo0_l00?l3ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooool00?l00_ooool00ol0003oooooo`00o`05ooooo`03o`00oooooooooooo00Gooooo
0_l00?l3ooooo`03o`00oooooooooooo00;o003o0oooool2o`00o`;ooooo0_l00?l2ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooo`00o`04ooooo`;o003o0_ooool2o`00o`?o
oooo00?o003oooooooooool0AOooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`1>ooooo`04o`00ooooooooooooo`00o`Cooooo0_l00?l2ooooo`0=o`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`02ooooo`;o003o0_ooool01Ol00?oo
oooooooooooooooo003o00Sooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`000?oooooo
oooo00Gooooo00?o003oooooooooool01Oooool01?l00?ooooooooooooooool2o`00o`?ooooo00?o
003oooooooooool00_ooool01?l00?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool0
0?l01_ooool2o`00o`;ooooo0_l00?m?ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000
Eoooool2o`00o`;ooooo0_l00?l2ooooo`03o`00oooooooo003o00cooooo00Go003ooooooooooooo
ooooo`00o`08ooooo`;o003o1oooool00ol0003oooooooooo`02ooooo`04o`00ooooooooooooo`00
o`Oooooo00Go003oooooooooooooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l01Ooo
ool01_l00?ooooooooooool00?ooooooo`00o`;ooooo00Go003oooooooooooooooooo`00o`1Coooo
o`;o00000oooool0017ooooo00?o0000ooooooooool0F_ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Sooooo0_l00?l2ooooo`;o003o1oooool2o`00o`Oooooo00?o0000oooooooo
ool00_ooool01?l00?ooooooooooool00?l7ooooo`;o003o0_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`02ooooo`;o003o0_ooool2o`00oecooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0G_ooool3o`00o`0:ooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00o`;ooooo0_l00?l3ooooo`03o`00oooooooooooo
00Gooooo0_l00?l00ooooooo003oooooo`04ooooo`03o`000?oooooooooo00;ooooo00Co003ooooo
oooooooo003o2?ooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003ooooooooooooooooo
o`00o`02ooooo`;o003o0_ooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo05kooooo0_l00?l2ooooo`09o`00oooooooo003oooooool00?oo
ooooo`00oooooooo003o00;ooooo0_l00?l3ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ool00?l01Oooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00Gooooo0_l00?l3oooo
o`0<o`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o0_ooool2o`00
of3ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0H_ooool02Ol00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00o`02ooooo`05o`00ooooooooooooooooool00?l0
2?ooool01?l00?ooooooooooool00?l5ooooo`03o`000?oooooooooo00Cooooo0_l00?l7ooooo`04
o`00ooooooooooooooooo`;o003o1?ooool00ol00?ooooooo`00o`02ooooo`;o003oI?ooool00ol0
003oooooooooo`01ooooo`004Oooool2o`0006?ooooo0_l00?l4ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool01_ooool2o`00o`Oooooo00?o0000ooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00Kooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool0H_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo
06gooooo0_l00?l2ooooo`;o003o1oooool2o`00o`Oooooo00?o0000ooooooooool00_ooool01Ol0
0?ooooooo`00oooooooo003o00Kooooo0_l00?l2ooooo`09o`00ooooooooooooooooool00?oooooo
o`00oooooooo003o06Sooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
Ioooool2o`00o`04ooooool00?ooooooooooo`;o003o0_ooool2o`00o`Oooooo0_l00?l00ooooooo
003oooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o003oooooool00?l02Oooool02?l00?oo
ooooooooool00?ooooooo`00oooooooo003o0oooool00ol00?ooooooooooo`1Vooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo06Oooooo0_l00?l01_oooooo003oooooool0
0?ooooooo`00o`?ooooo00?o003oooooooooool01_ooool00ol00?ooooooo`00o`05ooooo`03o`00
0?oooooooooo00;ooooo00?o003oooooool00?l02Oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooo003o00;ooooo00?o003oooooooooool0Ioooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`1Wooooo`;o003o00Koooooo`00oooooooo003oooooool00?l2ooooo`;o
003o1oooool01?l00?ooooooooooool00?l5ooooo`03o`000?oooooooooo00Cooooo00?o003ooooo
ool00?l01_ooool2o`00o`;ooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo
oooo06Oooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0J_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooooooo003o1Oooool0
0ol0003oooooooooo`03ooooo`04o`00ooooooooooooo`00o`Kooooo00Oo003ooooooooooooooooo
o`00oooooooo003o06kooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001_ooooo`03o`00
oooooooooooo00;o003o1oooool2o`00o`Oooooo00?o0000ooooooooool00oooool01?l00?oooooo
ooooool00?l6ooooo`;o003o0_ooool01?l00?ooooooooooool00?m/ooooo`;o00000oooool0017o
oooo00?o0000ooooooooool0Joooool2o`00o`04ooooool00?ooooooooooo`;o003o1_ooool01?l0
0?ooooooo`00ool00?l6ooooo`03o`000?oooooooooo00?ooooo0_l00?l9ooooo`05o`00oooooooo
ooooo`00ooooool00_l00?m]ooooo`03o`000?oooooooooo007ooooo0009ooooo`?o00001Oooool0
0ol0003oooooooooo`1[ooooo`;o003o00?oooooo`00ooooool00_ooool00ol00?ooooooooooo`06
ooooo`;o003o1_ooool00ol0003oooooooooo`03ooooo`;o003o2Oooool00ol00?ooooooooooo`02
ooooo`;o003oKOooool00ol0003oooooooooo`01ooooo`002?ooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool0Joooool2o`00o`03ooooool00?oooooo00;ooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0_l00?l0
0ooooooo003oooooo`05ooooo`;o003o1?ooool2o`00ofgooooo00?o0000ooooooooool00Oooool0
00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1[ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo
00Kooooo00?o003oooooooooool01?ooool01ol00?oooooooooooooooooo003oooooool00?l0K_oo
ool00ol0003oooooooooo`01ooooo`003?ooool00ol0003oooooooooo`02ooooo`?o0000LOooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool01_ooool0
0ol00?ooooooooooo`04ooooo`05o`00ooooooooooooooooool00?l0K_ooool3o`0000?ooooo0008
ooooo`Co00001Oooool00ol0003oooooooooo`1_ooooo`04o`00oooooooo003oo`00o`Kooooo00?o
003oooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00Cooooo0_l0
0?l00ooooooo003oooooo`1`ooooo`03o`000?oooooooooo007ooooo0008ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0Koooool01?l00?ooooooooooool00?l@ooooo`03o`000?oo
oooooooo00kooooo00?o003oooooooooool0LOooool00ol0003oooooooooo`01ooooo`002?ooool5
o`0000Cooooo00?o0000ooooooooool0Koooool01?l00?ooooooooooool00?l@ooooo`03o`000?oo
oooooooo00Kooooo00?o003oooooooooool01?ooool2o`00og?ooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0LOooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`04ooooo`04o`00oooooooo
ooooo`00og7ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001booooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`00oooooooo
oooo00Cooooo00Co003ooooooooooooo003oL?ooool2o`0000?ooooo000Aooooo`03o`000?oooooo
oooo06oooooo00Co003oooooool00?oo003o1_ooool00ol00?ooooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo00?o003oooooooooool01?ooool01?l00?ooooooo`00ool00?maooooo`03o`00
0?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06oooooo00Co003oooooool00?oo003o
1_ooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo00oooooo0_l00?maooooo`03o`00
0?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06oooooo00Co003ooooooooooooo003o
4?ooool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo073ooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool0Koooool4o`00o`Kooooo00?o003oooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00Cooooo00Co003oooooool00?oo003o
LOooool00ol0003oooooooooo`01ooooo`004Oooool2o`00077ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool01?oo
ool01?l00?ooooooooooool00?m`ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0Kooo
ool2o`00o`03ooooool00?oooooo00Gooooo00?o003oooooooooool01oooool00ol0003ooooooooo
o`06ooooo`03o`00oooooooooooo00Cooooo00Co003oooooool00?oo003oLOooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`1_ooooo`;o003o00?oooooo`00ooooool01Ooo
ool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo00oooooo0_l00?maooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo06oooooo00Co003ooooooooooooo003o4?oo
ool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo073ooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0L?ooool00ol00?ooooooo`00o`0@ooooo`03o`000?oooooo
oooo00Kooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`1booooo`03o`000?oooooo
oooo007ooooo000Aooooo`;o0000N_ooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo
00Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1aooooo`;o00000oooool0017o
oooo00?o0000ooooooooool0NOooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo00Ko
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1booooo`03o`000?oooooooooo007o
oooo000Aooooo`03o`000?oooooooooo07?ooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`1booooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07?ooooo00?o
003oooooooooool03Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo07?ooooo00?o003oooooooooool03Oooool00ol0003oooooooooo`06
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0L_ooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`1iooooo`03o`00oooooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo07;ooooo00?o0000oooo
ooooool00Oooool0017ooooo0_l0001jooooo`03o`00oooooooooooo00Oooooo00?o0000oooooooo
ool01_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo077ooooo0_l00003ooooo`00
4Oooool00ol0003oooooooooo`1cooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
1oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
L_ooool00ol0003oooooooooo`01ooooo`000oooool3o`0000Cooooo0_l00005ooooo`03o`000?oo
oooooooo07?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`07ooooo`03o`000?oo
oooooooo08;ooooo00?o0000ooooooooool00Oooool000Cooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo07?ooooo00?o003oooooooooool03Ooo
ool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo007ooooo0004ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1cooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool0Loooool00ol0003oooooooooo`01ooooo`001?ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo0ol0001iooooo`03o`00oooo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo077ooooo0ol00003ooooo`001?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0Loooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo07?ooooo00?o0000ooooooooool00Oooool000?ooooo0_l00004ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0Loooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00Oooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`01ooooo`001?ooool0
0ol0003oooooooooo`03ooooo`;o00001Oooool00ol0003oooooooooo`1cooooo`03o`00oooooooo
oooo00gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`1cooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool01_ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo07?ooooo00?o0000ooooooooool00Oooool0017o
oooo0_l0001jooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo07;ooooo0_l00003ooooo`004Oooool00ol0003ooooo
ooooo`1iooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo07?ooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool0Loooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo07?ooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Loooool00ol00?ooooooooooo`0=
ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool0Loooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo007ooooo000Aooooo`;o
0000N_ooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`1booooo`;o00000oooool0017ooooo00?o0000ooooooooool0
NOooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo07?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1cooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo07?ooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`07ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool0Loooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo
08;ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001dooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool0L_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo07Sooooo
00?o003oooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool0Loooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`1cooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Loooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`1cooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool02?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo07?ooooo00?o003oooooooooool03Oooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07?ooooo00?o003ooooooooo
ool03Oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool0Loooool00ol0003oooooooooo`01ooooo`004Oooool2o`0007Wooooo00?o003oooooooooool0
2?ooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
L_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo07Sooooo00?o003oooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Looo
ool00ol0003oooooooooo`01ooooo`000oooool3o`0000?ooooo0ol00005ooooo`03o`000?oooooo
oooo07?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1cooooo`03o`000?oooooo
oooo007ooooo0004ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo07?ooooo00?o003oooooooooool03Oooool00ol0003oooooooooo`22
ooooo`03o`000?oooooooooo007ooooo0004ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1cooooo`03o`00oooooooooooo00gooooo00?o0000oooo
ooooool01oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo07?ooooo00?o0000oooo
ooooool00Oooool000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`?o
0000N?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`1aooooo`?o00000oooool000Cooooo00Co0000oooooooooooo
oooo1?l00005ooooo`03o`000?oooooooooo07Sooooo00?o003oooooooooool02?ooool00ol0003o
ooooooooo`07ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Loooool00ol0003o
ooooooooo`01ooooo`000oooool2o`0000?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`1cooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Loooool00ol0003ooooo
ooooo`01ooooo`001?ooool01?l0003oooooooooooooool5o`0000Cooooo00?o0000ooooooooool0
Loooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool0
P_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1cooooo`03o`00oooo
oooooooo00gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`01ooooo`004Oooool2
o`0007Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1booooo`;o00000oooool0
017ooooo00?o0000ooooooooool0N?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo07?ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`1cooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07?ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo08;ooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Loooool00ol00?oooooooooo
o`0=ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001d
ooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo07;ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1hoooo
o`03o`00oooooooooooo00Sooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo07?ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0N?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo07?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`08ooooo`03o`00
0?oooooooooo00Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1cooooo`03o`00
0?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07?ooooo00?o003oooooooooool03Ooo
ool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo07Cooooo00?o003oooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool0Loooool00ol0003oooooooooo`01ooooo`004Oooool2o`00
07Wooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool0L_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo07So
oooo00?o003oooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool0Loooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`1dooooo`05o`00ooooooooooooooooool00?l02_ooool00ol0003oooooooooo`07ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool0Loooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`1dooooo`05o`00ooooooooooooooooool00?l02_ooool00ol0003o
ooooooooo`22ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07Cooooo
00?o003oooooooooool03?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo007ooooo
000Aooooo`;o0000MOooool01Ol00?oooooooooooooooooo003o00[ooooo00?o0000ooooooooool0
1oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo07;ooooo0_l00003ooooo`004Ooo
ool00ol0003oooooooooo`1hooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo07?ooooo00?o0000ooooooooool00Ooo
ool000;ooooo1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`1dooooo`05o`00oooooooo
ooooooooool00?l02_ooool00ol0003oooooooooo`07ooooo`05o`00ooooooooooooooooool00?l0
M_ooool00ol0003oooooooooo`01ooooo`000oooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0M?ooool01Ol00?oooooooooooooooooo003o
00[ooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`01ooooo`001?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0M?ooool00ol0
0?ooooooooooo`0<ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool00Oooool000Go
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo0ol0001doooo
o`03o`00oooooooooooo00cooooo00?o0000ooooooooool01oooool01Ol00?oooooooooooooooooo
003o07Cooooo0ol00003ooooo`000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`1hooooo`03o`00oooooooooooo00Sooooo00?o
0000ooooooooool01oooool01Ol00?oooooooooooooooooo003o07Kooooo00?o0000ooooooooool0
0Oooool000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0N?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00So
oooo00Co003ooooooooooooo003oM_ooool00ol0003oooooooooo`01ooooo`000oooool3o`0000Co
oooo0_l00005ooooo`03o`000?oooooooooo07Cooooo00Go003oooooooooooooooooo`00o`0:oooo
o`03o`000?oooooooooo00Sooooo00Co003ooooooooooooo003oM_ooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`1dooooo`03o`00oooooooooooo00cooooo00?o0000oooo
ooooool0P_ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0007Gooooo00?o003ooooooooo
ool03?ooool00ol0003oooooooooo`08ooooo`04o`00ooooooooooooo`00ogGooooo0_l00003oooo
o`004Oooool00ol0003oooooooooo`1hooooo`03o`00oooooooooooo00Sooooo00?o0000oooooooo
ool02?ooool01?l00?ooooooooooool00?mfooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo07Sooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`08ooooo`04
o`00ooooooooooooo`00ogKooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0M?ooool01Ol00?oooooooooooooooooo003o00[ooooo00?o0000ooooooooool02?ooool01?l0
0?ooooooooooool00?mfooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
07Cooooo00Go003oooooooooooooooooo`00o`0:ooooo`03o`000?oooooooooo08;ooooo00?o0000
ooooooooool00Oooool0017ooooo0_l0001eooooo`03o`00oooooooooooo00cooooo00?o0000oooo
ooooool0POooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo07Cooooo00Co003ooooooooo
oooo003o2oooool00ol0003oooooooooo`08ooooo`04o`00ooooooooooooo`00ogKooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Moooool00ol00?ooooooooooo`09oooo
o`03o`000?oooooooooo00Sooooo00Co003ooooooooooooo003oM_ooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`1dooooo`04o`00ooooooooooooo`00o`_ooooo00?o0000
ooooooooool02?ooool01?l00?ooooooooooool00?mfooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo07Cooooo00Co003ooooooooooooo003o2oooool00ol0003ooooooooo
o`22ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07Cooooo00?o003o
ooooooooool03?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`;o0000MOooool00ol00?ooooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00Co003ooooo
oooooooo003oMOooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo07Oooooo00?o003ooooo
ooooool02Oooool00ol0003oooooooooo`08ooooo`04o`00ooooooooooooo`00ogKooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0M?ooool01?l00?ooooooooooool00?l;
ooooo`03o`000?oooooooooo00Sooooo00Co003ooooooooooooo003oM_ooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`1dooooo`04o`00ooooooooooooo`00o`_ooooo00?o
0000ooooooooool02?ooool01?l00?ooooooooooool00?mfooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo07Cooooo00?o003oooooooooool03?ooool00ol0003ooooooooo
o`22ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000MOooool00ol00?ooooooooooo`0<
ooooo`03o`000?oooooooooo00Sooooo00Co003ooooooooooooo003oMOooool2o`0000?ooooo000A
ooooo`03o`000?oooooooooo07Oooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`08
ooooo`04o`00ooooooooooooo`00ogKooooo00?o0000ooooooooool00Oooool000;ooooo1Ol00002
ooooo`?o00001Oooool00ol0003oooooooooo`1gooooo`03o`00oooooooooooo00Wooooo00?o0000
ooooooooool02?ooool01?l00?ooooooooooool00?mfooooo`03o`000?oooooooooo007ooooo0003
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo07Cooooo00Co003ooooooooooooo003o2oooool00ol0003oooooooooo`08ooooo`04
o`00ooooooooooooo`00ogKooooo00?o0000ooooooooool00Oooool000Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07Cooooo00Co003ooooooooo
oooo003o2oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo007ooooo0005ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool3o`0007Cooooo00?o003ooooooooo
ool03?ooool00ol0003oooooooooo`20ooooo`?o00000oooool000;ooooo00Ko0000oooooooooooo
ooooo`000?ooool4o`0000Gooooo00?o0000ooooooooool0Moooool00ol00?ooooooooooo`09oooo
o`03o`000?oooooooooo00Sooooo00Co003ooooooooooooo003oM_ooool00ol0003oooooooooo`01
ooooo`000_ooool01ol0003ooooooooooooooooo0000ooooool000002?ooool00ol0003ooooooooo
o`1gooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool02?ooool01?l00?oooooooooo
ool00?mfooooo`03o`000?oooooooooo007ooooo0003ooooo`?o00000_ooool5o`0000Cooooo00?o
0000ooooooooool0M?ooool01?l00?ooooooooooool00?l;ooooo`03o`000?oooooooooo00Sooooo
00Co003ooooooooooooo003oM_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`1dooooo`04o`00ooooooooooooo`00o`_ooooo00?o0000ooooooooool0P_ooool00ol0003o
ooooooooo`01ooooo`004Oooool2o`0007Gooooo00?o003oooooooooool03?ooool00ol0003ooooo
ooooo`21ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0M?ooool00ol00?oooooooooo
o`0<ooooo`03o`000?oooooooooo00Sooooo00Co003ooooooooooooo003oM_ooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`1gooooo`03o`00oooooooooooo00Wooooo00?o
0000ooooooooool02?ooool01?l00?ooooooooooool00?mfooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo07Gooooo00?o003oooooool00?l02oooool00ol0003ooooooooo
o`08ooooo`04o`00ooooooooooooo`00ogKooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool0MOooool00ol00?ooooooo`00o`0;ooooo`03o`000?oooooooooo00Sooooo00Co
003ooooooooooooo003oM_ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0007Kooooo00?o
003oooooooooool02oooool00ol0003oooooooooo`21ooooo`;o00000oooool0017ooooo00?o0000
ooooooooool0MOooool00ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o003o
ooooool00?l0Moooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1goooo
o`03o`00oooooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol00?ooooooo`00o`1goooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07Oooooo00?o003ooooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`;o003oMoooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`1eooooo`03o`00oooooooo003o00_ooooo00?o0000ooooooooool0
2Oooool2o`00ogOooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0MOoo
ool00ol00?ooooooo`00o`0;ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool00Ooo
ool0017ooooo0_l0001fooooo`03o`00oooooooooooo00_ooooo00?o0000ooooooooool02_ooool0
0ol00?ooooooooooo`1dooooo`;o00000oooool0017ooooo00?o0000ooooooooool0M_ooool00ol0
0?ooooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0_l00?mgooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo07Kooooo00?o003oooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`;o003oMoooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`1eooooo`;o003o3?ooool00ol0003oooooooooo`09ooooo`;o003oMoooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`1eooooo`;o003o3?ooool00ol0003ooooooooo
o`22ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000M_ooool00ol00?ooooooooooo`0;
ooooo`03o`000?oooooooooo087ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1eoooo
o`03o`00oooooooooooo00_ooooo00?o0000ooooooooool02Oooool2o`00ogOooooo00?o0000oooo
ooooool00Oooool000?ooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`1fooooo`03
o`00oooooooooooo00[ooooo00?o0000ooooooooool02Oooool2o`00ogOooooo00?o0000oooooooo
ool00Oooool000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0MOooool2o`00o`cooooo00?o0000ooooooooool02Oooool2o`00
ogOooooo00?o0000ooooooooool00Oooool000Kooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo07Gooooo0_l00?l<ooooo`03o`000?oooooooooo
00Wooooo00?o003oooooooooool0M_ooool00ol0003oooooooooo`01ooooo`001?ooool2o`0000?o
oooo00Co0000oooooooooooo00001?ooool3o`0008?ooooo00?o0000ooooooooool0P?ooool3o`00
00?ooooo0006ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`23ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool00Oooool000;o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool0Poooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo007ooooo0003oooo
o`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`01oooo
o`004Oooooooo`0000go00000oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-11.9139, -3.12156, \
0.0788464, 0.192104}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Phase plot of DTFT as a function of index k", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(g2 = 
        Plot[Arg[
            X\[Theta]\  /. \ \[Theta] \[Rule] \ 2  \[Pi]\ f/fs], {f, \(-fs\)/
              2, fs/2}, \ PlotStyle \[Rule] {Blue, \ Dashing[{ .01}]}, \ 
          PlotRange \[Rule] All, PlotPoints \[Rule] 200];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.309471 0.0971556 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .018 -12 -4.5 ]
[-0.0125 .018 0 4.5 ]
[-0.0125 .11516 -12 -4.5 ]
[-0.0125 .11516 0 4.5 ]
[-0.0125 .21232 -12 -4.5 ]
[-0.0125 .21232 0 4.5 ]
[-0.0125 .30947 -6 -4.5 ]
[-0.0125 .30947 0 4.5 ]
[-0.0125 .40663 -6 -4.5 ]
[-0.0125 .40663 0 4.5 ]
[-0.0125 .50378 -6 -4.5 ]
[-0.0125 .50378 0 4.5 ]
[-0.0125 .60094 -6 -4.5 ]
[-0.0125 .60094 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .018 m
.00625 .018 L
s
[(-3)] -0.0125 .018 1 0 Mshowa
0 .11516 m
.00625 .11516 L
s
[(-2)] -0.0125 .11516 1 0 Mshowa
0 .21232 m
.00625 .21232 L
s
[(-1)] -0.0125 .21232 1 0 Mshowa
0 .30947 m
.00625 .30947 L
s
[(0)] -0.0125 .30947 1 0 Mshowa
0 .40663 m
.00625 .40663 L
s
[(1)] -0.0125 .40663 1 0 Mshowa
0 .50378 m
.00625 .50378 L
s
[(2)] -0.0125 .50378 1 0 Mshowa
0 .60094 m
.00625 .60094 L
s
[(3)] -0.0125 .60094 1 0 Mshowa
.125 Mabswid
0 .03744 m
.00375 .03744 L
s
0 .05687 m
.00375 .05687 L
s
0 .0763 m
.00375 .0763 L
s
0 .09573 m
.00375 .09573 L
s
0 .13459 m
.00375 .13459 L
s
0 .15402 m
.00375 .15402 L
s
0 .17345 m
.00375 .17345 L
s
0 .19288 m
.00375 .19288 L
s
0 .23175 m
.00375 .23175 L
s
0 .25118 m
.00375 .25118 L
s
0 .27061 m
.00375 .27061 L
s
0 .29004 m
.00375 .29004 L
s
0 .3289 m
.00375 .3289 L
s
0 .34833 m
.00375 .34833 L
s
0 .36776 m
.00375 .36776 L
s
0 .3872 m
.00375 .3872 L
s
0 .42606 m
.00375 .42606 L
s
0 .44549 m
.00375 .44549 L
s
0 .46492 m
.00375 .46492 L
s
0 .48435 m
.00375 .48435 L
s
0 .52321 m
.00375 .52321 L
s
0 .54264 m
.00375 .54264 L
s
0 .56208 m
.00375 .56208 L
s
0 .58151 m
.00375 .58151 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .018 m
1 .018 L
s
.99375 .11516 m
1 .11516 L
s
.99375 .21232 m
1 .21232 L
s
.99375 .30947 m
1 .30947 L
s
.99375 .40663 m
1 .40663 L
s
.99375 .50378 m
1 .50378 L
s
.99375 .60094 m
1 .60094 L
s
.125 Mabswid
.99625 .03744 m
1 .03744 L
s
.99625 .05687 m
1 .05687 L
s
.99625 .0763 m
1 .0763 L
s
.99625 .09573 m
1 .09573 L
s
.99625 .13459 m
1 .13459 L
s
.99625 .15402 m
1 .15402 L
s
.99625 .17345 m
1 .17345 L
s
.99625 .19288 m
1 .19288 L
s
.99625 .23175 m
1 .23175 L
s
.99625 .25118 m
1 .25118 L
s
.99625 .27061 m
1 .27061 L
s
.99625 .29004 m
1 .29004 L
s
.99625 .3289 m
1 .3289 L
s
.99625 .34833 m
1 .34833 L
s
.99625 .36776 m
1 .36776 L
s
.99625 .3872 m
1 .3872 L
s
.99625 .42606 m
1 .42606 L
s
.99625 .44549 m
1 .44549 L
s
.99625 .46492 m
1 .46492 L
s
.99625 .48435 m
1 .48435 L
s
.99625 .52321 m
1 .52321 L
s
.99625 .54264 m
1 .54264 L
s
.99625 .56208 m
1 .56208 L
s
.99625 .58151 m
1 .58151 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30947 m
1 .30947 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .46208 m
.02847 .37402 L
.03355 .27797 L
.03602 .23127 L
.03723 .20849 L
.03832 .18777 L
.03887 .17744 L
.03916 .17199 L
.03932 .16901 L
.03946 .16622 L
.03959 .16379 L
.03973 .46641 L
.03988 .46351 L
.04002 .46086 L
.04054 .45108 L
.04291 .40624 L
.0477 .31573 L
.05231 .22867 L
.05353 .20558 L
.05468 .18383 L
.05499 .17797 L
.05532 .17178 L
.0554 .17022 L
.05549 .16855 L
.05559 .47193 L
.05568 .47022 L
.05601 .46398 L
.05721 .44124 L
.0622 .34696 L
.06469 .29979 L
.067 .25614 L
.06925 .21377 L
.07038 .19238 L
.07069 .18652 L
.07102 .1802 L
.07118 .1773 L
.07126 .17571 L
.07134 .17424 L
.07148 .47685 L
.07163 .47399 L
.07634 .38499 L
.08134 .2904 L
.08385 .24298 L
.08495 .22216 L
.08553 .21112 L
.08616 .19926 L
.08647 .19337 L
.08677 .18777 L
.08704 .18274 L
.08719 .1799 L
Mistroke
.08733 .48248 L
.08747 .47979 L
.0876 .47725 L
.08785 .47251 L
.08842 .4619 L
.0908 .41681 L
.09546 .32881 L
.09782 .28417 L
.10041 .23523 L
.1016 .21271 L
.10226 .20032 L
.10258 .19422 L
.10288 .18859 L
.10302 .18586 L
.10316 .1833 L
.1033 .48585 L
.10345 .48291 L
.10408 .47105 L
.10518 .45033 L
.10985 .36203 L
.11222 .31715 L
.11482 .26813 L
.11602 .24545 L
.1173 .22126 L
.11792 .2095 L
.11851 .19842 L
.11876 .19358 L
.1189 .19094 L
.11903 .18847 L
.11917 .49102 L
.11933 .48808 L
.1196 .48292 L
.12429 .39431 L
.12927 .30011 L
.13177 .25299 L
.13286 .23226 L
.13345 .22124 L
.13408 .20936 L
.13437 .20382 L
.13453 .2008 L
.13468 .19798 L
.13481 .19558 L
.13494 .49822 L
.13509 .49537 L
.13523 .49277 L
.13632 .47227 L
.1387 .42729 L
.14351 .33623 L
.14815 .24863 L
.14939 .22526 L
Mistroke
.14999 .21383 L
.15025 .20884 L
.15054 .20338 L
.1507 .20046 L
.15084 .50297 L
.15098 .50037 L
.15112 .49761 L
.15175 .48579 L
.15308 .46066 L
.1581 .36584 L
.16062 .31824 L
.16293 .27447 L
.16519 .23171 L
.16574 .22132 L
.16605 .2156 L
.16633 .21018 L
.1665 .20712 L
.16659 .20539 L
.16667 .50901 L
.16682 .50619 L
.16698 .50319 L
.16758 .49179 L
.17214 .4057 L
.17699 .31402 L
.17922 .27188 L
.18048 .24801 L
.1811 .23637 L
.18166 .2258 L
.18195 .22035 L
.1821 .21747 L
.18226 .21443 L
.1824 .21177 L
.18256 .51407 L
.1827 .51141 L
.18283 .50892 L
.18408 .48532 L
.18662 .43722 L
.19131 .34869 L
.19369 .30365 L
.19495 .27987 L
.19629 .25457 L
.19696 .24184 L
.19759 .22987 L
.19787 .22464 L
.19816 .21912 L
.19832 .21623 L
.1984 .2146 L
.19848 .5183 L
.19863 .51561 L
.19878 .51274 L
Mistroke
.20108 .46913 L
.20608 .37471 L
.20858 .32741 L
.2109 .28373 L
.21314 .24126 L
.21369 .23094 L
.21399 .22524 L
.21414 .22244 L
.21428 .21983 L
.21436 .52358 L
.21444 .52201 L
.21461 .51869 L
.21492 .51286 L
.21553 .50144 L
.22054 .40671 L
.22537 .31543 L
.22759 .27357 L
.22884 .2498 L
.22946 .23819 L
.22975 .23269 L
.23002 .2276 L
.23016 .22499 L
.2303 .52744 L
.23045 .52465 L
.23061 .52158 L
.23118 .51091 L
.23242 .48741 L
.23496 .43942 L
.23981 .34783 L
.24204 .30575 L
.2433 .2819 L
.24447 .2597 L
.24507 .24835 L
.24564 .23764 L
.24579 .23476 L
.24588 .23318 L
.24596 .23171 L
.24604 .53534 L
.24613 .53359 L
.2463 .53051 L
.24689 .51928 L
.24943 .47121 L
.25412 .38277 L
.2565 .33779 L
.25909 .28875 L
.2603 .26599 L
.26096 .25351 L
.26128 .24739 L
.26158 .24176 L
.26173 .23899 L
Mistroke
.26186 .23641 L
.262 .53895 L
.26216 .53599 L
.26279 .52412 L
.26389 .50341 L
.26858 .41466 L
.27098 .36946 L
.27358 .32034 L
.27479 .29743 L
.27608 .27311 L
.2766 .26312 L
.27717 .25236 L
.27733 .24935 L
.2775 .24619 L
.27764 .24349 L
.2778 .54577 L
.27795 .54299 L
.2781 .54003 L
.27839 .53469 L
.2834 .44006 L
.28822 .34888 L
.29043 .30709 L
.29169 .28335 L
.29231 .27175 L
.29287 .26117 L
.29315 .25579 L
.2933 .25296 L
.29346 .24994 L
.2936 .24731 L
.29375 .54964 L
.29389 .547 L
.29402 .54452 L
.29527 .52104 L
.29781 .47309 L
.30247 .38506 L
.30483 .34039 L
.30608 .31674 L
.30742 .29146 L
.30809 .27889 L
.30872 .26702 L
.30899 .26184 L
.30928 .25636 L
.30943 .25349 L
.30952 .25186 L
.3096 .55556 L
.30974 .55289 L
.30989 .55001 L
.3122 .50654 L
.31717 .41263 L
.31965 .36572 L
Mistroke
.32196 .32218 L
.32311 .3005 L
.32419 .28007 L
.32479 .26876 L
.32495 .26566 L
.32513 .26239 L
.32527 .2596 L
.32536 .25801 L
.32544 .56175 L
.32558 .55899 L
.32572 .55637 L
.32598 .55145 L
.32657 .54041 L
.33119 .45312 L
.33611 .36025 L
.33855 .31412 L
.33975 .29154 L
.34027 .28165 L
.34055 .27642 L
.34085 .27083 L
.34099 .26802 L
.34114 .26536 L
.34126 .26298 L
.3414 .56561 L
.34153 .56316 L
.34167 .56056 L
.34191 .5559 L
.34304 .53469 L
.3454 .4901 L
.34997 .40384 L
.35251 .35585 L
.35484 .31201 L
.35599 .29031 L
.3563 .28437 L
.35664 .27804 L
.3568 .27497 L
.35695 .27207 L
.35709 .26948 L
.35724 .57189 L
.35738 .5692 L
.35751 .56669 L
.35782 .56098 L
.35843 .54947 L
.35952 .52886 L
.36422 .44019 L
.36661 .39502 L
.36921 .34596 L
.37043 .32306 L
.37172 .29877 L
.37224 .28878 L
Mistroke
.37254 .28327 L
.37281 .27804 L
.37297 .27509 L
.37306 .57865 L
.37314 .5771 L
.37344 .57146 L
.37403 .56041 L
.37874 .47147 L
.38375 .37698 L
.38627 .32958 L
.38737 .30879 L
.38796 .29777 L
.38828 .2917 L
.38858 .28595 L
.38873 .28328 L
.38888 .28044 L
.38895 .58418 L
.38904 .58255 L
.38919 .57967 L
.38975 .56917 L
.39084 .54861 L
.39323 .50362 L
.39808 .41234 L
.4003 .37041 L
.40156 .34665 L
.40274 .32453 L
.40391 .30255 L
.40424 .29623 L
.40441 .29312 L
.40456 .29025 L
.4047 .28765 L
.40484 .59011 L
.40499 .58734 L
.40515 .58429 L
.4077 .53641 L
.41256 .44493 L
.41724 .35693 L
.41846 .334 L
.4191 .32188 L
.41979 .30898 L
.42013 .30259 L
.4203 .29946 L
.42045 .29658 L
.42059 .29396 L
.42074 .59641 L
.42089 .59363 L
.42105 .59058 L
.42221 .56867 L
.42709 .47706 L
.43179 .38897 L
Mistroke
.43302 .36594 L
.43435 .34091 L
.43496 .32945 L
.43561 .31728 L
.43617 .3069 L
.43632 .30405 L
.4364 .30256 L
.43648 .30099 L
.43664 .60332 L
.43678 .60067 L
.44138 .51462 L
.44627 .4232 L
.45099 .3354 L
.45599 .24239 L
.46082 .15317 L
.46546 .06783 L
.4667 .04514 L
.46731 .03407 L
.46786 .02398 L
.46801 .02137 L
.46816 .01853 L
.46831 .32106 L
.46845 .31858 L
.46907 .30719 L
.4704 .28307 L
.47513 .19806 L
.47755 .15528 L
.48015 .10979 L
.48138 .08869 L
.48268 .06671 L
.48321 .05774 L
.48378 .04821 L
.48395 .04541 L
.48404 .04404 L
.48411 .04277 L
.48426 .34563 L
.48441 .34307 L
.485 .3335 L
.48974 .26019 L
.4943 .20211 L
.49664 .17994 L
.49795 .17004 L
.49916 .16204 L
.49947 .16015 L
.49975 .15839 L
.49991 .15741 L
.5 .15687 L
.50008 .46159 L
.50023 .46069 L
.50038 .45975 L
Mistroke
.50171 .45124 L
.50413 .4323 L
.5065 .40789 L
.50871 .38026 L
.51096 .34856 L
.5134 .31114 L
.51405 .30088 L
.51473 .28983 L
.51532 .2803 L
.51548 .27767 L
.51565 .27483 L
.51573 .27352 L
.51582 .27214 L
.51596 .57489 L
.51612 .57237 L
.51626 .57008 L
.51657 .56492 L
.51712 .55557 L
.51839 .53411 L
.52321 .45029 L
.52785 .36746 L
.53025 .32412 L
.53083 .31354 L
.53115 .3077 L
.53146 .30216 L
.53163 .29903 L
.53173 .29726 L
.53182 .60085 L
.53197 .59795 L
.53214 .59487 L
.53279 .58315 L
.53781 .49109 L
.54264 .40176 L
.5473 .31541 L
.55225 .22326 L
.55702 .13428 L
.55942 .08942 L
.5616 .04854 L
.56218 .03767 L
.56281 .02587 L
.5631 .02046 L
.56326 .01749 L
.56341 .01472 L
.56354 .31758 L
.56367 .31504 L
.56396 .30963 L
.56648 .26235 L
.57145 .1692 L
.57393 .12266 L
.57624 .07939 L
Mistroke
.57738 .05787 L
.57846 .03757 L
.57875 .03211 L
.57906 .02634 L
.57922 .02332 L
.57931 .02161 L
.5794 .32523 L
.57955 .32241 L
.57971 .3194 L
.58084 .29816 L
.58582 .20446 L
.58831 .15758 L
.59062 .11415 L
.59286 .07203 L
.59399 .05074 L
.5943 .04491 L
.59464 .03862 L
.59479 .03573 L
.59495 .03268 L
.59509 .03008 L
.59524 .33245 L
.5954 .32947 L
.59555 .32671 L
.59588 .32048 L
.59648 .30917 L
.5976 .28799 L
.60013 .24043 L
.60488 .151 L
.60726 .10608 L
.60944 .06499 L
.61002 .05417 L
.61032 .04845 L
.61064 .04236 L
.6108 .03935 L
.61095 .03651 L
.61109 .03396 L
.61123 .33643 L
.61137 .33381 L
.61152 .33104 L
.61178 .32608 L
.6143 .27861 L
.61888 .19224 L
.62143 .14413 L
.62376 .10028 L
.62492 .0785 L
.62552 .06701 L
.62617 .05481 L
.62644 .04969 L
.62674 .04417 L
.62682 .04263 L
Mistroke
.6269 .04101 L
.62706 .34334 L
.6272 .34063 L
.62736 .33766 L
.62845 .31697 L
.63335 .22466 L
.63806 .13579 L
.63929 .11247 L
.64063 .08719 L
.64125 .07559 L
.6419 .06332 L
.64245 .05284 L
.64261 .04997 L
.64269 .04839 L
.64277 .04689 L
.64292 .3492 L
.64307 .34655 L
.64768 .25947 L
.65259 .1668 L
.65486 .1239 L
.65732 .07757 L
.65797 .06518 L
.65833 .05841 L
.65851 .05511 L
.65867 .0521 L
.65881 .35456 L
.65895 .35194 L
.65926 .34617 L
.65991 .33393 L
.66234 .28798 L
.66697 .20055 L
.66931 .1563 L
.6719 .10754 L
.67308 .08527 L
.67373 .07299 L
.67405 .06693 L
.6742 .06398 L
.67435 .06131 L
.67449 .05861 L
.67462 .3613 L
.67477 .35861 L
.67492 .35571 L
.67554 .3439 L
.67664 .32319 L
.68158 .22986 L
.68405 .18338 L
.68634 .13996 L
.68855 .09825 L
.68919 .08624 L
.68979 .07486 L
Mistroke
.69005 .06991 L
.6902 .06719 L
.69033 .06464 L
.69048 .36712 L
.69056 .36566 L
.69064 .36409 L
.69092 .35874 L
.69588 .26508 L
.70066 .17486 L
.70306 .12941 L
.70411 .10959 L
.70525 .08809 L
.70556 .08229 L
.70588 .07615 L
.70616 .0709 L
.70632 .06792 L
.70647 .37035 L
.70662 .36755 L
.70676 .36489 L
.70702 .3599 L
.70762 .34867 L
.71014 .30095 L
.71475 .21387 L
.71733 .16524 L
.71966 .12119 L
.72083 .0991 L
.72144 .08748 L
.72178 .08114 L
.72194 .07804 L
.72209 .07522 L
.72223 .37778 L
.72237 .37526 L
.72266 .3697 L
.72329 .35791 L
.72438 .33718 L
.72901 .24978 L
.73135 .20555 L
.73393 .15678 L
.73511 .13453 L
.73638 .11057 L
.73696 .09955 L
.73728 .09354 L
.73757 .08795 L
.73783 .08316 L
.73797 .08048 L
.7381 .38327 L
.73824 .3806 L
.73839 .37771 L
.73867 .37245 L
.74361 .27914 L
Mistroke
.74837 .18928 L
.75076 .1441 L
.7518 .12436 L
.75294 .10286 L
.75324 .09714 L
.75357 .09104 L
.7537 .08854 L
.75384 .08584 L
.754 .3881 L
.75415 .38531 L
.75529 .36371 L
.75781 .31608 L
.76277 .22245 L
.76524 .17576 L
.76754 .13227 L
.76868 .11072 L
.76924 .10014 L
.76949 .09548 L
.76962 .09302 L
.76976 .09036 L
.76991 .39276 L
.77005 .39012 L
.77035 .38433 L
.771 .37211 L
.77213 .35076 L
.7771 .25681 L
.77958 .20988 L
.78189 .16631 L
.78412 .12418 L
.78476 .11205 L
.78508 .1061 L
.78537 .10062 L
.7855 .09804 L
.78563 .09563 L
.78576 .39834 L
.78591 .39558 L
.7865 .38449 L
.79119 .29581 L
.79618 .20154 L
.79867 .15437 L
.79977 .13362 L
.80036 .1226 L
.80098 .11072 L
.80128 .10517 L
.80144 .10214 L
.80159 .09933 L
.80171 .40214 L
.80185 .39956 L
.80214 .3941 L
.80323 .37359 L
Mistroke
.80561 .32859 L
.81061 .234 L
.81312 .18659 L
.81422 .16577 L
.81543 .14287 L
.816 .13226 L
.8166 .12087 L
.81689 .11535 L
.81717 .11011 L
.81729 .10783 L
.81742 .10541 L
.81756 .40797 L
.81769 .40551 L
.82007 .36042 L
.8251 .26552 L
.82762 .21786 L
.82993 .17408 L
.83111 .15192 L
.8322 .13126 L
.83275 .12085 L
.83291 .11785 L
.83306 .11502 L
.83319 .11247 L
.83334 .41493 L
.83349 .4121 L
.83366 .40897 L
.83399 .40265 L
.83459 .39131 L
.83945 .29955 L
.84412 .21125 L
.84649 .16637 L
.84775 .14266 L
.84844 .12963 L
.84877 .12324 L
.84892 .12043 L
.849 .11895 L
.84909 .11735 L
.84924 .41961 L
.84939 .41684 L
.84971 .41077 L
.85039 .398 L
.85157 .37569 L
.85387 .33214 L
.85886 .23793 L
.86135 .19081 L
.86245 .17008 L
.86366 .14718 L
.86421 .13668 L
.86451 .13117 L
.86466 .12816 L
Mistroke
.86481 .12536 L
.86494 .12289 L
.86508 .42548 L
.86524 .42255 L
.86538 .41989 L
.8659 .41009 L
.86828 .3651 L
.8731 .27404 L
.87773 .18642 L
.87897 .16305 L
.88013 .14117 L
.88042 .13553 L
.88071 .13017 L
.88086 .12722 L
.88095 .12555 L
.88103 .42922 L
.88118 .42648 L
.88133 .42357 L
.88266 .39845 L
.88768 .30361 L
.8902 .25601 L
.89252 .21223 L
.89478 .16947 L
.89592 .14793 L
.89623 .14203 L
.8964 .13879 L
.89656 .13571 L
.89672 .13285 L
.8968 .13124 L
.89688 .43497 L
.89702 .43233 L
.89717 .42953 L
.90172 .34343 L
.90657 .25174 L
.9088 .20959 L
.91007 .18571 L
.91124 .1635 L
.91184 .15213 L
.91214 .14654 L
.91241 .14139 L
.91257 .13851 L
.91264 .13705 L
.91273 .44068 L
.91281 .43907 L
.9129 .43735 L
.91307 .43424 L
.91366 .42301 L
.91621 .3749 L
.92119 .28076 L
.92368 .23369 L
Mistroke
.92599 .19008 L
.92714 .1683 L
.9277 .15762 L
.92822 .14782 L
.92837 .14496 L
.92851 .14229 L
.92866 .44473 L
.92874 .44326 L
.92882 .44169 L
.92947 .42943 L
.9306 .40807 L
.9356 .31362 L
.9381 .26631 L
.94041 .22262 L
.94266 .18014 L
.9438 .1587 L
.94411 .15283 L
.94428 .14959 L
.94436 .14799 L
.94444 .14651 L
.94459 .44888 L
.94467 .44737 L
.94476 .44576 L
.94504 .44031 L
.95006 .34554 L
.95489 .25423 L
.95711 .21236 L
.95836 .18858 L
.95898 .17697 L
.95954 .16638 L
.95982 .16099 L
.95997 .15814 L
.96013 .15512 L
.96027 .15249 L
.96043 .45481 L
.96057 .45216 L
.9607 .44968 L
.96194 .42617 L
.96448 .37816 L
.96915 .28999 L
.97411 .19624 L
.97619 .15686 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005_ooool3o`0000Cooooo0_l0000iooooo`?o0000>oooool2o`0003cooooo0ol0000ioooo
o`?o00001?ooool2o`0000Oooooo000Gooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000=oooool01Ol0003ooooooooooooooooo000003Wooooo00Co0000oooooooooooo0000>_oo
ool01Ol0003ooooooooooooooooo000003Wooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00006ooooo`003oooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000aooooo`Go00001Oooool00ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`00
03kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Kooooo000Gooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000>oooool0
0ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`0003kooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo000Gooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000=oooool4o`0003[ooooo00Co0000oooooooooooo
0000>_ooool4o`0003[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006oooo
o`005_ooool2o`0000Cooooo00Co0000oooooooooooo0000=oooool00ol0003oooooooooo`0koooo
o`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool0>_ooool2o`0000Cooooo00Co0000
oooooooooooo00001_ooool001Oooooo00?o0000ooooooooool00oooool2o`0003Sooooo1Ol0000j
ooooo`;o0000>oooool5o`0003Wooooo00?o0000ooooooooool00oooool2o`0000Oooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Aoooooooo00003Ol00003
ooooo`004Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo007ooooo0009ooooo`?o
00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool0?Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`01ooooo`002?ooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo007o
oooo0002ooooo`Go00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08?ooooo
00?o0000ooooooooool03Oooool00ol00?ooooooooooo`1booooo`03o`000?oooooooooo007ooooo
000:ooooo`;o00001Oooool3o`0007[ooooo00?o003oooooooooool01_ooool00ol0003ooooooooo
o`0=ooooo`03o`00oooooooooooo073ooooo0ol00003ooooo`003?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo07[ooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`0=
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0KOooool00ol0003oooooooooo`01
ooooo`002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0N_ooool0
0ol00?ooooooooooo`06ooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`1]ooooo`03o`000?oooooooooo007ooooo0009ooooo`?o00001Oooool00ol0
003oooooooooo`1jooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0Joooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`1jooooo`03o`00oooooooooooo00Kooooo00?o0000oooo
ooooool03Oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`1Uooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000Noooool00ol0
0?ooooooooooo`06ooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0I?ooool2o`0000?ooooo000Aoooo
o`03o`000?oooooooooo07[ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`000?oooooo
oooo00gooooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l0
Ioooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1jooooo`05o`00oooo
ooooooooooooool00?l01?ooool00ol0003oooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo06Gooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool0N_ooool01Ol00?oooooooooooooooooo003o00Co
oooo00?o0000ooooooooool03Oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0G?ooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1jooooo`03o`00oooooooooooo
00Kooooo00?o0000ooooooooool03Oooool01?l00?ooooooooooooooool2o`00o`?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`1Jooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000N_ooool2o`00o`?ooooo00?o
003oooooooooool00_ooool00ol0003oooooooooo`0=ooooo`05o`00ooooooooooooooooool00?l0
1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?l3oooo
o`03o`00oooooooooooo05Oooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1iooooo`;o
003o0oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00gooooo00Co003ooooooooo
oooooooo0_l00?l2ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo05Cooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0N_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o
0000ooooooooool04_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00Kooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0D_ooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1jooooo`05o`00oooooooooooooooo
ool00?l01?ooool00ol0003oooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo00Co003ooooo
oooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`1;ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07Wooooo00?o
003oooooooooool01oooool00ol0003oooooooooo`0=ooooo`04o`00ooooooooooooooooo`;o003o
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo04_ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001jooooo`;o003o0oooool00ol0
0?ooooooooooo`02ooooo`03o`000?oooooooooo00gooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00o`?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`18ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0NOooool2o`00o`?o
oooo00?o003oooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00;o
oooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool2
o`00o`?ooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`15ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo07[ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`000?oooooooooo00cooooo
00?o003oooooooooool00_ooool2o`00o`;ooooo00Co003ooooooooooooooooo0_l00?l8ooooo`03
o`00oooooooooooo00;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o04Gooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool0N_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o0000
ooooooooool03Oooool01?l00?ooooooooooooooool2o`00o`;ooooo00Go003ooooooooooooooooo
o`00o`08ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooo
oooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0o
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07Wooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00cooooo0_l00?l4oooo
o`03o`00oooooooooooo00;o003o0_ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo
0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
03gooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001jooooo`03o`00oooooooooooo00Oo
oooo00?o0000ooooooooool03?ooool2o`00o`Sooooo00?o003oooooooooool00_l00?l3ooooo`04
o`00ooooooooooooooooo`;o003o0_ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l01?ooool00ol00?ooooooooooo`02o`00o`?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0=Oooool2o`0000?ooooo000A
ooooo`03o`000?oooooooooo07Wooooo0_l00?l3ooooo`03o`00oooooooooooo00;ooooo00?o0000
ooooooooool03?ooool2o`00o`?ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00oooo
ooooooooooooool00?l00oooool2o`00o`;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`05ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`03o`00oooooooooooo03Kooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool0NOooool2o`00o`?ooooo00?o003oooooooooool00_ooool00ol0003o
ooooooooo`0<ooooo`03o`00oooooooooooo00;ooooo0_l00?l2ooooo`;o003o0oooool01Ol00?oo
oooooooooooooooo003o00Cooooo00?o003oooooooooool00_l00?l3ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0=?ooool00ol0003ooooo
ooooo`01ooooo`002?ooool5o`0000Cooooo00?o0000ooooooooool0N_ooool00ol00?oooooooooo
o`02o`00o`Cooooo00?o0000ooooooooool03Oooool01_l00?ooooooooooool00?ooooooo`00o`;o
oooo00Go003oooooooooooooooooo`00o`09ooooo`05o`00ooooooooooooooooool00?l00_ooool0
0ol00?ooooooooooo`02ooooo`04o`00ooooooooooooooooo`;o003o0_ooool2o`00o`?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo02kooooo00?o0000ooooooooool00Oooool000Wooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1iooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol0003oooooooooo`0=ooooo`06o`00ooooooooooooo`00
oooooooo003o0_ooool2o`00o`;ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_l00?l3ooooo`04o`00ooooooooooooooooo`;o003o
0_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0^oooo
o`03o`000?oooooooooo007ooooo0002ooooo`Go00000oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo07Wooooo00?o003oooooooooool01oooool00ol0003oooooooooo`0<ooooo`;o
003o1?ooool01Ol00?oooooooooooooooooo003o00;ooooo0_l00?l2ooooo`;o003o0oooool01?l0
0?ooooooooooooooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooooooooooooooo
o`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0:_ooool0
0ol0003oooooooooo`01ooooo`002oooool00ol0003oooooooooo`03ooooo`?o0000NOooool2o`00
o`;ooooo00?o003oooooooooool00oooool00ol0003oooooooooo`0<ooooo`;o003o0_ooool00ol0
0?ooooooooooo`03ooooo`05o`00ooooooooooooooooool00?l00_ooool2o`00o`?ooooo0_l00?l2
ooooo`04o`00ooooooooooooooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool2o`00o`?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo02?ooooo0ol00003ooooo`002?ooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool0NOooool2o`00o`;ooooo0_l00?l4ooooo`03o`000?oooooooooo00co
oooo00Oo003oooooooooooooooooo`00oooooooo003o00;ooooo0_l00?l3ooooo`03o`00oooooooo
oooo00;o003o1?ooool00ol00?ooooooooooo`02o`00o`;ooooo0_l00?l7ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_l00?l3ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01oooool2o`00obOooooo
00?o0000ooooooooool00Oooool000Sooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo07[ooooo00?o003oooooooooool00_l00?l4ooooo`03o`000?oooooooooo013ooooo
00?o003oooooool00?l00_ooool01?l00?ooooooooooooooool2o`00o`Sooooo00?o003ooooooooo
ool00_l00?l2ooooo`04o`00ooooooooooooooooo`;o003o0oooool01?l00?ooooooooooooooool2
o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
1?ooool01Ol00?oooooooooooooooooo003o00Sooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo01gooooo00?o0000ooooooooool00Oooool000Wooooo0ol00005ooooo`03
o`000?oooooooooo07[ooooo00?o003oooooooooool00_l00?l4ooooo`03o`000?oooooooooo00go
oooo00So003ooooooooooooo003oooooool00?ooooooo`00o`Cooooo00?o003oooooooooool00_oo
ool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00o`?ooooo
0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l02?ooool01Ol00?oooooooooooooooooo003o01oooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0N?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooo
oooo00cooooo0_l00?l4ooooo`05o`00ooooooooooooooooool00?l00_ooool2o`00o`;ooooo0_l0
0?l2ooooo`03o`00oooooooooooo00;ooooo0_l00?l3ooooo`03o`00oooooooooooo00;o003o1?oo
ool01?l00?ooooooooooool00?l3ooooo`;o003o0_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_l00?l3ooooo`05o`00ooooooooooooooooool0
0?l00oooool2o`00o`Oooooo00Go003oooooooooooooooooo`00o`0Kooooo`03o`000?oooooooooo
007ooooo000Aooooo`;o0000NOooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00?o
oooo00?o0000ooooooooool03?ooool2o`00o`Sooooo00?o003oooooooooool00_l00?l2ooooo`;o
003o0_ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_l00?l4ooooo`03o`00oooooooooooo00;o003o0_ooool01?l00?ooooooooooooooool2o`00
o`?ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`03o`00oooooooooooo00Gooooo00Co003o
oooooooooooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`0Hooooo`;o00000oooool0017ooooo00?o0000ooooooooool0N?ooool00ol00?ooooooo`00
o`02ooooo`;o003o1?ooool00ol0003oooooooooo`0<ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00;o003o0_ooool00ol00?oooooo
o`00o`02ooooo`04o`00ooooooooooooooooo`;o003o1_ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooo
oooooooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l05oooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1jooooo`03o`00oooooooooooo00;o003o
1?ooool00ol0003oooooooooo`0<ooooo`09o`00ooooooooooooooooool00?ooooooo`00oooooooo
003o00Cooooo0_l00?l8ooooo`03o`00oooooooooooo00;o003o0_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool2o`00o`?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00Gooooo0_l00?l2ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o
00?ooooo0_l00?l3ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool0N_ooool00ol00?ooooooooooo`02o`00o`Cooooo00?o0000oooooooo
ool03Oooool02?l00?ooooooooooool00?ooooooo`00oooooooo003o1?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool2o`00o`;ooooo
00?o003oooooool00?l00_ooool2o`00o`?ooooo00?o003oooooooooool00_l00?l3ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_l00?l3ooooo`05o`00ooooooooooooooooool0
0?l01oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0oooool00ol0
0?ooooooooooo`0@ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07So
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00co
oooo0_l00?l4ooooo`05o`00oooooooo003oooooool00?l00_ooool01?l00?ooooooooooooooool2
o`00o`;ooooo00?o003oooooooooool00oooool01Ol00?oooooooooooooooooo003o00;ooooo0_l0
0?l2ooooo`03o`00oooooooo003o00;ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02o`00o`;ooooo
0_l00?l3ooooo`05o`00ooooooooooooooooool00?l02?ooool01Ol00?oooooooooooooooooo003o
00?ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l03_ooool00ol0003oooooooooo`01
ooooo`004Oooool2o`0007Wooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0<oooo
o`;o003o2?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo0_l00?l2ooooo`05o`00oooooooo
003oooooool00?l01Oooool00ol00?ooooooooooo`02o`00o`Cooooo00?o003oooooooooool00_l0
0?l2ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooooooool2o`00o`?o
oooo00?o003oooooooooool01Oooool01?l00?ooooooooooooooool2o`00o`Oooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Wooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1hooooo`03o`00oooo
oooo003o00;ooooo0_l00?l4ooooo`03o`000?oooooooooo00_ooooo00?o003oooooool00?l00_oo
ool01ol00?oooooooooooooooooo003oooooool00?l00oooool00ol00?ooooooooooo`02o`00o`;o
oooo00Go003oooooool00?ooooooo`00o`04ooooo`;o003o1_ooool00ol00?ooooooo`00o`03oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool2o`00o`?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o0_ooool2o`00o`?o
oooo00Go003oooooooooooooooooo`00o`08ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`08ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
07Sooooo00?o003oooooool00?l00_ooool2o`00o`?ooooo0_l00?l=ooooo`03o`00oooooooooooo
00;ooooo00Oo003oooooool00?ooooooo`00oooooooo003o00?ooooo00?o003oooooooooool01_oo
ool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00;o003o0oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o1oooool2o`00o`;ooooo0_l00?l3oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Kooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`1_ooooo`05o`00oooo
oooo003oooooool00?l00oooool2o`00o`oooooo00So003ooooooooooooo003oooooool00?oooooo
o`00o`?ooooo00?o003oooooooooool02?ooool01Ol00?oooooooooooooooooo003o00;ooooo00Co
003ooooooooooooooooo0_l00?l2ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`03oooo
o`03o`00oooooooooooo00;o003o0oooool01?l00?ooooooooooooooool2o`00o`;ooooo00Co003o
oooooooooooooooo0_l00?l3ooooo`03o`00oooooooooooo00Gooooo0_l00?l2ooooo`;o003o0ooo
ool01?l00?ooooooooooooooool2o`00o`;ooooo00?o003oooooooooool01_ooool01Ol00?oooooo
oooooooooooo003o00Kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
2?ooool01Ol00?oooooooooooooooooo003o06_ooooo00?o003oooooooooool00oooool01?l00?oo
ooooooooooooool2o`00o`oooooo00co003ooooooooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?l4ooooo`;o003o0_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00;o003o0_ooool2o`00o`;ooooo00Go003oooooool00?ooooooo`00o`04ooooo`;o003o0_ooool0
1?l00?ooooooooooooooool2o`00o`Cooooo00?o003oooooooooool00_l00?l2ooooo`;o003o0ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooooooo
0_l00?l2ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool01?ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000Wooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool01oooool00ol00?oo
0000ooooo`0<ooooo`03o`00oooooooo003o00Cooooo00Wo003oooooooooooooooooo`00oooooooo
003oooooool00?l00_ooool2o`00o`;ooooo00Oo003oooooooooooooooooo`00oooooooo003o00?o
oooo00?o003oooooooooool00_l00?l4ooooo`03o`00oooooooo003o00Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo0_l00?l3ooooo`03o`00oooooooooooo
00Cooooo0_l00?l3ooooo`;o003o1_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_l00?l3ooooo`03o`00oooooooooooo00_ooooo0_l00003oooo
o`004Oooool00ol0003oooooooooo`08ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`1Uooooo`05o`00oooooooo003oooooool00?l01_ooool00ol0003oooooooooo`0;
ooooo`05o`00oooooooo003oooooool00?l01_ooool02Ol00?oooooooooooooooooo003oooooool0
0?ooooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l00oooool00ol00?ooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooo
oooooooo00;ooooo00Co003ooooooooooooo003o1?ooool2o`00o`?ooooo00?o003oooooooooool0
1?ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00So
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Sooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool02?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Pooooo`07o`00oooooooo003o
ooooool00?ooooooo`00o`04ooooo`03o`00oooooooooooo00_ooooo00Go003ooooooooooooooooo
o`00o`02ooooo`05o`00oooooooo003oooooool00?l00oooool01Ol00?ooooooo`00oooooooo003o
00Cooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l01_ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00;o003o0oooool00ol00?ooooooooooo`02o`00o`;ooooo
00?o003oooooooooool00_ooool01?l00?ooooooooooooooool2o`00o`Oooooo0_l00?l2ooooo`;o
003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`06ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo00Sooooo00Go003oooooooooooooooooo`00
o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`1Nooooo`05o`00
oooooooo003oooooool00?l00oooool2o`00oa7ooooo00Ko003ooooooooooooo003oooooool00?l3
ooooo`03o`00oooooooo003o00Sooooo00Oo003oooooool00?ooooooo`00oooooooo003o00Cooooo
0_l00?l2ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`03ooooo`03o`00oooooooooooo
00;o003o0oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooooooo`;o003o2?oo
ool00ol00?ooooooooooo`02o`00o`;ooooo0_l00?l3ooooo`04o`00ooooooooooooooooo`;o003o
0_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`04ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Sooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo05[ooooo00Go003oooooool00?ooooooo`00o`03
ooooo`;o003o3oooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo003o00?ooooo00Oo003o
ooooooooooooooooo`00oooooooo003o00;ooooo00?o003oooooooooool00oooool01Ol00?oooooo
o`00oooooooo003o00;ooooo0_l00?l2ooooo`05o`00oooooooo003oooooool00?l01Oooool00ol0
0?ooooooooooo`02o`00o`;ooooo0_l00?l4ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00
o`;ooooo0_l00?l7ooooo`;o003o0_ooool2o`00o`?ooooo00Co003ooooooooooooooooo0_l00?l2
ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00Kooooo
00?o0000ooooooooool00Oooool0017ooooo0_l00009ooooo`05o`00ooooooooooooooooool00?l0
0oooool01?l00?ooooooooooooooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`1Joooo
o`03o`00oooooooooooo00Kooooo00?o003oooooool00?l03Oooool00ol00?ooooooo`00o`04oooo
o`0=o`00ooooooooooooooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`02oooo
o`07o`00ooooooooooooooooool00?ooooooo`00o`03ooooo`05o`00oooooooo003oooooool00?l0
1?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooo003o00;ooooo00Co003ooooooooooooo
oooo0_l00?l4ooooo`03o`00oooooooooooo00;o003o0_ooool01?l00?ooooooooooooooool2o`00
o`?ooooo0_l00?l6ooooo`04o`00ooooooooooooooooo`;o003o0oooool2o`00o`;ooooo0_l00?l2
ooooo`;o003o1oooool00ol00?ooooooooooo`03ooooo`;o00000oooool0017ooooo00?o0000oooo
ooooool02?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`1Dooooo`05o`00
oooooooo003oooooool00?l01_ooool00ol0003oooooooooo`0;ooooo`03o`00oooooooo003o00So
oooo00_o003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00
oooooooo003o00Gooooo00Go003oooooool00?ooooooo`00o`04ooooo`07o`00oooooooo003ooooo
ool00?ooooooo`00o`04ooooo`;o003o0_ooool01ol00?oooooooooooooooooo003oooooool00?l0
0oooool00ol00?ooooooooooo`04ooooo`;o003o0oooool2o`00o`;ooooo0_l00?l2ooooo`;o003o
0_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00o`?ooooo
00?o003oooooooooool02?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`08ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool0C_ooool02?l00?ooooooooooool00?ooooooo`00oooooooo003o1?ooool00ol00?oooooo
ooooo`0;ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooo`00o`03ooooo`07
o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00?ooooo00?o003o
ooooool00?l01_ooool00ol00?ooooooooooo`03ooooo`05o`00oooooooo003oooooool00?l00ooo
ool00ol00?ooooooooooo`02o`00o`;ooooo00Oo003oooooooooooooooooo`00oooooooo003o00;o
oooo0_l00?l3ooooo`06o`00ooooooooooooo`00oooooooo003o0_ooool2o`00o`?ooooo00?o003o
ooooooooool00_l00?l3ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?l3
ooooo`05o`00ooooooooooooooooool00?l01_ooool00ol0003oooooooooo`01ooooo`002Oooool3
o`0000Gooooo00?o0000ooooooooool01oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`1Aooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?oo
ooooo`00o`0=ooooo`05o`00ooooooooooooooooool00?l00_ooool2o`00o`Cooooo00?o003ooooo
ool00?l02?ooool01ol00?ooooooo`00oooooooo003oooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`03ooooo`03o`00oooooooooooo00;o
003o0oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00;ooooo0_l00?l6oooo
o`03o`00oooooooo003o00;ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l2oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?l3ooooo`03o`00oooooooooooo
00Cooooo00?o0000ooooooooool00Oooool000[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`08ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`1?ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?oo
ooooo`00o`0?ooooo`03o`00oooooooo003o00;ooooo0_l00?l4ooooo`03o`00oooooooooooo00Go
oooo00Co003ooooooooooooo003o0oooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooo003o
00;ooooo00Oo003oooooool00?ooooooo`00oooooooo003o00?ooooo00?o003oooooooooool00_l0
0?l3ooooo`03o`00oooooooooooo00;ooooo00Go003oooooool00?ooooooo`00o`02ooooo`;o003o
0_ooool2o`00o`Oooooo0_l00?l2ooooo`;o003o0oooool01_l00?ooooooooooool00?ooooooo`00
o`;ooooo00?o003oooooooooool01Oooool2o`00o`?ooooo00?o003oooooooooool01?ooool00ol0
003oooooooooo`01ooooo`000_ooool5o`0000?ooooo00?o0000ooooooooool01?ooool3o`0000So
oooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o0oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00
ooooooooooooooooool00?l0B?ooool00ol00?ooooooooooo`04ooooo`06o`00ooooooooooooo`00
oooooooo003o3Oooool00ol00?ooooooo`00o`04ooooo`;o003o0_ooool00ol00?ooooooo`00o`03
ooooo`05o`00oooooooo003oooooool00?l01_ooool02Ol00?oooooooooooooooooo003oooooool0
0?ooooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l00oooool01Ol00?ooooooo`00oooo
oooo003o00Cooooo0_l00?l4ooooo`05o`00oooooooo003oooooool00?l00_ooool2o`00o`;ooooo
0_l00?l2ooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooooooooooo0_l00?l2ooooo`03
o`00oooooooo003o00;ooooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`?o00000oooool000[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`07ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooo
oooooooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`12ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00000=ooooo`03o`00
oooooooo003o00Sooooo00_o003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
o`02ooooo`03o`00oooooooo003o00Gooooo00Go003oooooool00?ooooooo`00o`04ooooo`07o`00
oooooooo003oooooool00?ooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Oo003ooooo
ooooooooooooo`00oooooooo003o00?ooooo00?o003oooooooooool01?ooool2o`00o`;ooooo00?o
003oooooool00?l01_ooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooooooool0
0_l00?l2ooooo`;o003o0_ooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo007ooooo
000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool01?l00?oooooooooo
ooooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0oooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0mooooo`08o`00oooooooo
ooooo`00oooooooo003oooooool00?l4ooooo`03o`000?oooooooooo00_ooooo00Go003oooooool0
0?ooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00Oo003oooooool00?ooooooo`00
oooooooo003o00;ooooo00?o003oooooool00?l00oooool00ol00?ooooooo`00o`05ooooo`04o`00
ooooooooooooo`00o`?ooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l3oooo
o`03o`00oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`02ooooo`;o003o0_ooool0
1ol00?ooooooo`00oooooooo003oooooool00?l00oooool01?l00?ooooooooooool00?l9ooooo`03
o`00oooooooooooo00;o003o0_ooool2o`00o`[ooooo00?o0000ooooooooool00Oooool000Wooooo
0_l00006ooooo`03o`000?oooooooooo00Oooooo00Go003oooooooooooooooooo`00o`04ooooo`04
o`00ooooooooooooooooo`;o003o0_ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`;o003o0oooool00ol00?ooooooooooo`09ooooo`;o003o?oooool02?l00?ooooooooooool0
0?ooooooo`00oooooooo003o0_ooool00ol00?ooooooo`00o`0=ooooo`05o`00oooooooooooooooo
ool00?l00_ooool2o`00o`;ooooo00Go003oooooooooooooooooo`00o`08ooooo`;o003o0_ooool0
0ol00?ooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01_ooool01Ol00?ooooooo`00
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`02ooooo`05o`00oooooooooooooooo
ool00?l01?ooool2o`00o`Kooooo00Oo003oooooool00?ooooooo`00oooooooo003o00?ooooo00?o
003oooooooooool00_l00?l2ooooo`03o`00oooooooooooo00?ooooo00Go003ooooooooooooooooo
o`00o`02ooooo`;o003o0oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo007ooooo
000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool01?l00?oooooooooo
ool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?l3ooooo`05o`00
ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02o`00o`?ooooo00?o003ooooooooo
ool01Oooool2o`00o`?ooooo00?o003oooooooooool0??ooool01Ol00?ooooooo`00oooooooo003o
00;ooooo00?o003oooooool00?l03oooool00ol00?ooooooo`00o`02ooooo`;o003o0oooool00ol0
0?ooooooooooo`09ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`03ooooo`05o`00oooo
oooo003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo003o00?ooooo00Go003oooooool0
0?ooooooo`00o`03ooooo`08o`00ooooooooooooo`00oooooooo003oooooool00?l4ooooo`;o003o
0_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo003o00;ooooo0_l00?l3ooooo`06o`00
ooooooooooooo`00oooooooo003o0_ooool00ol00?ooooooooooo`05ooooo`;o003o0oooool00ol0
0?ooooooooooo`04ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00So
oooo00?o003oooooooooool00_l00?l3ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0>Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooo`00o`02ooooo`;o003o0_ooool2o`00o`Cooooo00Go003oooooool00?oooooo
o`00o`06ooooo`0;o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l00_oo
ool00ol00?ooooooo`00o`03ooooo`05o`00oooooooo003oooooool00?l00oooool00ol00?oooooo
o`00o`04ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00;ooooo0_l00?l;
ooooo`03o`00oooooooooooo00;ooooo00Ko003ooooooooooooo003oooooool00?l2ooooo`;o003o
0_ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Oooooo00?o0000oooooooo
ool00Oooool0017ooooo0_l00008ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?o
oooo0_l00?l2ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`04ooooo`05o`00ooooooooooooooooool00?l0=oooool00ol00?ooooooooooo`06ooooo`04o`00
ooooooooooooo`0000cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooooooool2
o`00o`;ooooo00Oo003oooooool00?ooooooo`00oooooooo003o00?ooooo00?o003oooooooooool0
1?ooool01Ol00?ooooooo`00oooooooo003o00Cooooo0_l00?l4ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00?ooooo00?o003ooooo
ooooool01?ooool2o`00o`;ooooo00?o003oooooool00?l01_ooool01Ol00?oooooooooooooooooo
003o00Gooooo00Go003oooooool00?ooooooo`00o`02ooooo`;o003o3Oooool2o`0000?ooooo000A
ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03
ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0<Ooo
ool00ol00?ooooooooooo`02o`00o`Oooooo00?o0000ooooooooool02_ooool01_l00?oooooooooo
ool00?ooooooo`00o`Kooooo00_o003oooooooooooooooooo`00oooooooo003oooooool00?oooooo
o`00o`02ooooo`;o003o1?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Oo003oooooooooooooooooo`00oooooooo003o00Gooooo00?o003oooooool00?l01?ooool00ol0
0?ooooooo`00o`03ooooo`03o`00oooooooooooo00Cooooo0_l00?l2ooooo`07o`00oooooooo003o
ooooool00?ooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`Oooooo00?o003oooooool00?l0
0_ooool2o`00o`;ooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`07ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?oooooo
ooooooooool2o`00o`;ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooooooooooo
ooooo`;o003o0_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool2o`00o`;ooooo0_l00?l7ooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool00_l0
0?l2ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;o003o0_ooool02Ol00?oooooooooooooooooo003oooooool0
0?ooooooo`00o`04ooooo`;o003o0_ooool01Ol00?ooooooo`00oooooooo003o00Gooooo00?o003o
ooooooooool01?ooool01Ol00?ooooooo`00oooooooo003o00?ooooo00Go003oooooool00?oooooo
o`00o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooo`00o`06ooooo`07
o`00oooooooo003oooooool00?ooooooo`00o`03ooooo`03o`00oooooooooooo00;o003o0_ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00o`;ooooo00?o003o
ooooooooool01Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`07oooo
o`;o003o0_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00;o003o0_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?l3oooo
o`03o`00oooooooooooo00Gooooo0_l00?l2ooooo`;o003o1oooool01Ol00?oooooooooooooooooo
003o03;ooooo0_l00?l2ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool03_ooool0
1?l00?ooooooooooooooool2o`00o`?ooooo00Co003ooooooooooooo003o2?ooool2o`00o`;ooooo
0_l00?l4ooooo`05o`00oooooooo003oooooool00?l00oooool01?l00?ooooooooooool00?l3oooo
o`05o`00oooooooo003oooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`07o`00oooo
ooooooooooooool00?ooooooo`00o`08ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooo
oooo003o00?ooooo00Ko003ooooooooooooo003oooooool00?l7ooooo`03o`00oooooooooooo00;o
003o0_ooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo00Sooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooooooo00?ooooo
00Go003oooooooooooooooooo`00o`02ooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;o003o0oooool01Ol00?oooooooooooooooooo003o00Oooooo0_l00?l3oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo02oooooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0=ooooo`;o003o0oooool2
o`00o`?ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooo003o00Kooooo0_l0
0?l2ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`;o003o1_ooool02Ol00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00o`04ooooo`0=o`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00o`06ooooo`07o`00oooooooo003oooooool00?oo
ooooo`00o`03ooooo`08o`00ooooooooooooo`00oooooooo003oooooool00?l3ooooo`03o`00oooo
oooooooo00?ooooo00Co003ooooooooooooo003o1oooool00ol0003oooooooooo`01ooooo`004Ooo
ool2o`0000Sooooo0_l00?l3ooooo`03o`00oooooooooooo00;o003o0oooool2o`00o`;ooooo0_l0
0?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`0Vooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooooooo003o3?oo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooooooo`;o003o0_ooool2o`00o`;o
oooo00?o003oooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`05o`00oooooooo003o
ooooool00?l01?ooool2o`00o`Cooooo00Go003oooooool00?ooooooo`00o`03ooooo`03o`00oooo
oooo003o00Cooooo00Oo003oooooool00?ooooooo`00oooooooo003o00?ooooo00?o003oooooool0
0?l00_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00;ooooo0_l00?l4ooooo`09
o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00Kooooo00?o003oooooooooool01?oo
ool2o`0000?ooooo000Aooooo`03o`000?oooooooooo00Oooooo0_l00?l3ooooo`03o`00oooooooo
oooo00;o003o0oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_l0
0?l3ooooo`04o`00ooooooooooooooooo`;o003o0_ooool2o`00o`?ooooo00Co003ooooooooooooo
oooo0_l00?l7ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2
o`00o`?ooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`02o`00o`Oooooo00?o0000
ooooooooool02_ooool01?l00?ooooooooooool00?l8ooooo`;o003o0_ooool2o`00o`;ooooo00?o
003oooooool00?l00_ooool2o`00o`Kooooo00Go003oooooooooooooooooo`00o`04ooooo`;o003o
0_ooool00ol00?ooooooo`00o`03ooooo`05o`00oooooooo003oooooool00?l00oooool01?l00?oo
ooooooooool00?l3ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l00_ooool02ol0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003ooooooooo
ool00oooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooo
oooooooo00Wooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01oooool0
1?l00?ooooooooooooooool2o`00o`?ooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooooooool2o`00o`?ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0oooool00ol00?ooooooooooo`05
ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool08?ooool00ol00?ooooooooooo`02o`00o`;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0:ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?oo
ooooooooool00?l3ooooo`;o003o0_ooool00ol00?ooooooo`00o`02ooooo`;o003o0_ooool2o`00
o`;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`;o003o0_ooool02ol0
0?oooooooooooooooooo003oooooool00?ooooooo`00oooooooo003o00Cooooo00Oo003oooooool0
0?ooooooo`00oooooooo003o00?ooooo00[o003ooooooooooooo003oooooool00?ooooooo`00oooo
oooo003o0oooool00ol00?ooooooooooo`02o`00o`;ooooo00_o003oooooooooooooooooo`00oooo
oooo003oooooool00?ooooooo`00o`02ooooo`;o003o0_ooool00ol00?ooooooooooo`05ooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Oooooo0_l00?l2ooooo`03o`00
oooooooooooo00;ooooo00Ko003ooooooooooooo003oooooool00?l2ooooo`;o003o0_ooool01?l0
0?ooooooooooooooool2o`00o`Cooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooo
oooo00Kooooo0_l00?l2ooooo`;o003o1oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo02?ooooo0_l00?l2ooooo`03o`00
oooooooo003o00;ooooo00?o003oooooooooool02_ooool01Ol00?oooooooooooooooooo003o00?o
oooo0_l00?l3ooooo`04o`00ooooooooooooo`00o`Sooooo0_l00?l2ooooo`;o003o0oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00_ooool02Ol00?oooooooooooooo
oooo003oooooool00?ooooooo`00o`03ooooo`03o`00oooooooo003o00Cooooo00Oo003ooooooooo
ooooooooo`00oooooooo003o00Kooooo00oo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`07ooooo`03o`00oooo
oooooooo00;o003o0_ooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooo
oooo00?ooooo00Go003oooooooooooooooooo`00o`02ooooo`;o003o0_ooool2o`00o`Cooooo00?o
003oooooooooool00_l00?l2ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool00_l0
0?l2ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l3ooooo`05o`00
ooooooooooooooooool00?l00oooool2o`00ob3ooooo0_l00?l2ooooo`03o`00oooooooo003o00;o
oooo00?o003oooooooooool03Oooool2o`00o`?ooooo0_l00?l3ooooo`03o`00oooooooooooo00Go
oooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0oooool01_l00?ooooooooooool00?oo
ooooo`00o`;ooooo0_l00?l2ooooo`09o`00ooooooooooooooooool00?ooooooo`00oooooooo003o
00?ooooo00?o003oooooooooool00_ooool2o`00o`;ooooo00Wo003oooooool00?ooooooo`00oooo
oooo003oooooool00?l01_ooool01ol00?ooooooo`00oooooooo003oooooool00?l00oooool02?l0
0?ooooooooooool00?ooooooo`00oooooooo003o2?ooool2o`00o`;ooooo00?o003oooooooooool0
1Oooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000Wooooo00?o003oooooooooool00_l0
0?l2ooooo`;o003o0_ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00;o003o0_oo
ool00ol00?ooooooooooo`02ooooo`;o003o0oooool00ol00?ooooooooooo`02o`00o`;ooooo0_l0
0?l7ooooo`04o`00ooooooooooooooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool06oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo003o00;ooooo00?o003ooooo
ooooool02_ooool01?l00?ooooooooooool00?l4ooooo`;o003o0_ooool2o`00o`?ooooo00?o003o
ooooooooool00_l00?l7ooooo`04o`00ooooooooooooooooo`;o003o0_ooool00ol00?ooooooo`00
o`02ooooo`;o003o0oooool01_l00?ooooooooooool00?ooooooo`00o`?ooooo00?o003oooooool0
0?l01?ooool2o`00o`;ooooo00_o003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00o`08ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`02ooooo`09o`00oooooooo003o
ooooool00?ooooooo`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1_ooool2o`0000?o
oooo000Aooooo`03o`000?oooooooooo00Kooooo00?o003oooooool00?l00oooool00ol00?oooooo
ooooo`02o`00o`;ooooo00?o003oooooooooool00_ooool2o`00o`?ooooo00Co003ooooooooooooo
003o1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00o`?o
oooo0_l00?l6ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l0
0?l3ooooo`03o`00oooooooooooo01;ooooo00Co003ooooooooooooooooo0_l00?l7ooooo`05o`00
0?ooooooooooooooool00?l02?ooool01?l00?ooooooooooool00?l8ooooo`;o003o0_ooool2o`00
o`;ooooo0_l00?l3ooooo`;o003o1_ooool2o`00o`;ooooo00?o003oooooooooool00_ooool2o`00
o`;ooooo0_l00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool0
0?l3ooooo`03o`00oooooooooooo00?ooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00
oooooooooooo00?ooooo00Go003oooooooooooooooooo`00o`06ooooo`0;o`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?l03?ooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00;ooooo0_l00?l2ooooo`;o003o0_oo
ool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooooooo`;o003o0oooool01_l00?oooooo
ooooool00?ooooooo`00o`;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02o`00
o`?ooooo0_l00?l3ooooo`03o`00oooooooooooo00;o003o0oooool01Ol00?oooooooooooooooooo
003o00?ooooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`;o003o0oooool00ol00?ooooooooooo`0Booooo`04o`00ooooooooooooooooo`;o003o
0_ooool00ol00?ooooooooooo`02ooooo`05o`000?ooooooooooooooool00?l02?ooool00ol00?oo
ooooooooo`02o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0_ooool2o`00
o`?ooooo0_l00?l3ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o0ooo
ool2o`00o`?ooooo00Ko003ooooooooooooo003oooooool00?l3ooooo`04o`00ooooooooooooo`00
o`?ooooo00_o003oooooooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`02ooooo`05
o`00oooooooo003oooooool00?l00oooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00_o003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03
o`00oooooooooooo00Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
1_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00[o003ooooooooooooo
003oooooool00?ooooooo`00oooooooo003o0_ooool00ol00?ooooooooooo`02ooooo`06o`00oooo
ooooooooo`00oooooooo003o0_ooool00ol00?ooooooooooo`0:ooooo`;o003o0_ooool2o`00o`Ko
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
003o0oooool00ol00?ooooooooooo`05ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o
013ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`;o003o0oooool01Ol00?oooooooooooooo
oooo003o00Sooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`06ooooo`;o003o0_ooool2o`00o`?ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`04ooooo`;o003o0_ooool2o`00o`;ooooo00Oo003ooooooooo
ooooooooo`00oooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`05
ooooo`08o`00ooooooooooooo`00oooooooo003oooooool00?l3ooooo`07o`00oooooooo003ooooo
ool00?ooooooo`00o`06ooooo`09o`00ooooooooooooooooool00?ooooooo`00oooooooo003o00;o
oooo00?o003oooooooooool01Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`08ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00oooool01Ol00?oooooo
oooooooooooo003o00;ooooo00Co003ooooooooooooooooo0_l00?l4ooooo`03o`00oooooooooooo
00;o003o0_ooool00ol00?ooooooooooo`06ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2oooo
o`;o003o0oooool01?l00?ooooooooooooooool2o`00o`?ooooo00Go003oooooooooooooooooo`00
o`08ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool04_ooool2o`00o`;ooooo0_l0
0?l3ooooo`05o`00ooooooooooooooooool00?l02oooool2o`00o`?ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`09ooooo`04o`00ooooooooooooooooo`;o003o0oooool00ol00?oo
ooooooooo`02o`00o`?ooooo0_l00?l2ooooo`04o`00ooooooooooooooooo`;o003o0_ooool01ol0
0?oooooooooooooooooo003oooooool00?l00_ooool2o`00o`Cooooo00Go003oooooool00?oooooo
o`00o`07ooooo`08o`00ooooooooooooo`00oooooooo003oooooool00?l3ooooo`03o`00oooooooo
003o00;ooooo00?o003oooooooooool01oooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo
oooo00Gooooo00?o0000ooooooooool00Oooool0017ooooo0_l00009ooooo`05o`00oooooooo003o
ooooool00?l00_ooool00ol00?ooooooooooo`03ooooo`05o`00ooooooooooooooooool00?l00_oo
ool2o`00o`;ooooo00Oo003oooooooooooooooooo`00oooooooo003o00?ooooo00?o003ooooooooo
ool00_l00?l2ooooo`;o003o1oooool2o`00o`;ooooo0_l00?l3ooooo`05o`00oooooooooooooooo
ool00?l00oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Gooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l02oooool2o`00o`?ooooo00Co
003ooooooooooooooooo0_l00?l3ooooo`03o`00oooooooooooo00;o003o1oooool2o`00o`;ooooo
0_l00?l2ooooo`;o003o0oooool2o`00o`?ooooo00Co003ooooooooooooo003o1Oooool00ol00?oo
ooooo`00o`04ooooo`;o003o0_ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00
o`0:ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l00_ooool01ol00?ooooooo`00
oooooooo003oooooool00?l01Oooool01?l00?ooooooooooool00?l6ooooo`;o00000oooool0017o
oooo00?o0000ooooooooool01_ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00;o
003o0_ooool01ol00?ooooooo`00oooooooo003oooooool00?l00oooool01?l00?ooooooooooool0
0?l3ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00_l00?l2ooooo`;o003o0_oo
ool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooooooo`;o003o0_ooool2o`00o`?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`05o`00oooooooooooo
ooooool00?l02?ooool00ol00?ooooooooooo`06ooooo`05o`00ooooooooooooooooool000003?oo
ool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`;o
oooo0_l00?l3ooooo`03o`00oooooooooooo00Gooooo0_l00?l2ooooo`03o`00oooooooooooo00;o
oooo0_l00?l3ooooo`03o`00oooooooooooo00Kooooo00Go003oooooooooooooooooo`00o`02oooo
o`05o`00ooooooooooooooooool00?l01Oooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o
003oooooooooool00oooool01Ol00?oooooooooooooooooo003o00Kooooo00Wo003oooooool00?oo
ooooo`00oooooooo003oooooool00?l03_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`06ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00_l00?l2oooo
o`05o`00ooooooooooooooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00;ooooo00Go
003oooooooooooooooooo`00o`05ooooo`03o`00oooooooooooo00;o003o0_ooool00ol00?oooooo
o`00o`03ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00o`?ooooo00Co003ooooooooooooo
oooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`;o003o0oooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003oooooooooool01_ooool0
1Ol00?oooooooooooooooooo003o00Sooooo00?o0000ooooooooool00_l00?l8ooooo`03o`00oooo
oooooooo00;o003o1oooool01?l00?ooooooooooooooool2o`00o`;ooooo0_l00?l3ooooo`03o`00
oooooooooooo00;ooooo00Co003ooooooooooooo003o0oooool2o`00o`?ooooo00Co003ooooooooo
oooooooo0_l00?l3ooooo`03o`00oooooooooooo00;o003o1?ooool01?l00?ooooooooooool00?l3
ooooo`03o`00oooooooooooo00?ooooo00Go003oooooool00?ooooooo`00o`02ooooo`;o003o0_oo
ool01ol00?oooooooooooooooooo003oooooool00?l02?ooool02Ol00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00o`0<ooooo`03o`000?oooooooooo007ooooo000:ooooo`;o00001Oooool0
0ol0003oooooooooo`06ooooo`05o`00ooooooooooooooooool00?l01Oooool02?l00?oooooooooo
ool00?ooooooo`00oooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`08o`00oooooooooooo
o`00oooooooo003oooooool00?l5ooooo`03o`00oooooooooooo00;o003o0_ooool00ol00?oooooo
o`00o`02ooooo`;o003o1_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooooooo00Kooooo0_l00?l2ooooo`;o003o
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool01_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo0_l00?l3ooooo`03o`00oooooooooooo00;o003o0oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooo
ooooooooooooo`;o003o0_ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooooooo`;o
003o0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo0_l00?l2ooooo`;o
003o0_ooool2o`00o`;ooooo00?o003oooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`02o`00o`;ooooo00_o003ooooo
ooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`06ooooo`0;o`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?l02?ooool00ol0003oooooooooo`01ooooo`002Ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Kooooo00Go003oooooool00?oo
ooooo`00o`04ooooo`03o`00oooooooooooo00?ooooo00Go003oooooool00?ooooooo`00o`02oooo
o`04o`00ooooooooooooooooo`;o003o1?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o
003oooooooooool01Oooool00ol00?ooooooo`00o`02ooooo`;o003o1_ooool00ol00?oooooooooo
o`02ooooo`04o`00ooooooooooooooooo`;o003o0oooool00ol00?ooooooooooo`02o`00o`Oooooo
0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`08ooooo`03
o`00oooooooooooo00Gooooo00Co003ooooooooooooooooo0_l00?l3ooooo`03o`00oooooooooooo
00;o003o0oooool00ol00?ooooooooooo`06ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Sooooo00Co003ooooooooooooooooo0_l00?l3ooooo`03o`00
oooooooooooo00;o003o1?ooool01?l00?ooooooooooool00?l3ooooo`;o003o0_ooool01ol00?oo
oooooooooooooooo003oooooool00?l00_ooool2o`00o`?ooooo00Co003ooooooooooooo003o2?oo
ool2o`00o`;ooooo00Go003oooooool00?ooooooo`00o`03ooooo`03o`00oooooooo003o00;ooooo
00?o003oooooooooool01Oooool01ol00?ooooooo`00oooooooo003oooooool00?l02?ooool00ol0
003oooooooooo`01ooooo`002Oooool01?l0003oooooooooool00004ooooo`_o000000Go003oo`00
0?l00?oo0000o`00o`02o`000003o`00ool0003o000000?o000000Wo003oo`000?l0003o0000o`00
ool0003o003oo`000?l00?l00_l00002o`00o`Co000000Go003oo`000?l00?oo0000o`00o`02o`00
00;o003o0_l00002o`00o`Ko000000?o003oo`000?l00?l00_l00002o`00o`?o000000Co003oo`00
0?l0003o003o1?l00002o`00o`?o000000?o003oo`000?l000000_l00?l3o`000003o`00ool0003o
000000Go000000?o003oo`000?l000001_l000001Ol00?oo0000o`000?l0003o003o00Co000000?o
003oo`000?l000002Ol00002o`00o`?o000000Co003oo`000?l0003o003o1?l000000ol00?oo0000
o`000005o`0000;o003o0ol000001Ol00?oo0000o`000?l0003o003o00Co000000?o003oo`000?l0
00000_l00?l7o`0000;o003o0_l00002o`00o`;o00000_l00?l3o`0000;o003o0ol000001?l00?oo
0000o`000?l00?l3o`0000;o003o0_l000000ol00?oo0000o`000002o`0000;o003o0_l00002o`00
o`;o000000Go003oo`000?l00?oo0000o`00o`05o`000008o`00ool0003o0000o`00ool0003o003o
o`000?l00?l3o`000003o`00ool0003o003o00;o00000_l00?l2o`000003o`00ool0003o003o00Go
000000?o003oo`000?l00?l02Ol00003ooooo`002Oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Kooooo00?o003oooooool00?l00oooool01Ol00?ooooooo`00oooooooo003o
00;ooooo00Oo003oooooool00?ooooooo`00oooooooo003o00?ooooo00Co003ooooooooooooo003o
0oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00o`Kooooo
00?o003oooooooooool00_ooool2o`00o`?ooooo00Co003ooooooooooooo003o1?ooool01?l00?oo
ooooooooooooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool01Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`08ooooo`05o`00ooooooooooooooooool00?l01oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo0_l00?l2ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l0
0?l2ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo0_l00?l2ooooo`;o003o1?ooool01Ol00?oo
ooooo`00oooooooo003o00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooo003o00Cooooo0_l00?l2ooooo`05o`00oooooooo003oooooool00?l03_ooool0
0ol0003oooooooooo`01ooooo`002Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00Kooooo00?o003oooooool00?l00oooool01Ol00?ooooooo`00oooooooo003o00;ooooo00Go
003oooooooooooooooooo`00o`05ooooo`03o`00oooooooooooo00;o003o0_ooool01ol00?oooooo
oooooooooooo003oooooool00?l00_ooool2o`00o`;ooooo0_l00?l2ooooo`03o`00oooooooo003o
00Kooooo0_l00?l2ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l3ooooo`03o`00oooo
oooooooo00;o003o1oooool01?l00?ooooooooooooooool2o`00o`?ooooo00Go003ooooooooooooo
ooooo`00o`08ooooo`05o`000?ooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00Cooooo00?o003oooooooooool01Oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l0
0?l3ooooo`03o`00oooooooooooo00Gooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00
ooooooooooooooooo`;o003o0oooool00ol00?ooooooooooo`02o`00o`Cooooo00Co003ooooooooo
oooo003o0oooool00ol00?ooooooooooo`02ooooo`06o`00ooooooooooooo`00oooooooo003o0_oo
ool2o`00o`;ooooo0_l00?l2ooooo`03o`00oooooooo003o00Kooooo0_l00?l2ooooo`07o`00oooo
oooo003oooooool00?ooooooo`00o`0<ooooo`03o`000?oooooooooo007ooooo0009ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool01_ooool01ol00?oooooooooooooooooo003o
ooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`07o`00ooooooooooooooooool00?oo
ooooo`00o`03ooooo`08o`00ooooooooooooo`00oooooooo003oooooool00?l5ooooo`03o`00oooo
oooooooo00;o003o0_ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`?ooooo
00?o003oooooooooool00_ooool01?l00?ooooooooooooooool2o`00o`;ooooo0_l00?l2ooooo`;o
003o1oooool00ol00?ooooooooooo`06ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o0oooool01Ol00?oooooooooooooooooo
003o00Sooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`05ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`03o`00oooooooo003o00?o
oooo00?o003oooooooooool00_l00?l2ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`02
ooooo`;o003o0_ooool02ol00?oooooooooooooooooo003oooooool00?ooooooo`00oooooooo003o
00?ooooo00?o003oooooooooool00_l00?l2ooooo`07o`00oooooooo003oooooool00?ooooooo`00
o`08ooooo`03o`000?oooooooooo007ooooo000:ooooo`;o00001Oooool00ol0003oooooooooo`06
ooooo`05o`00oooooooo003oooooool00?l01Oooool03?l00?ooooooooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00o`?ooooo00?o003oooooool00?l01?ooool01ol00?ooooooo`00
oooooooo003oooooool00?l02?ooool01ol00?ooooooo`00oooooooo003oooooool00?l01_ooool0
1?l00?ooooooooooooooool2o`00o`Cooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooo
oooooooo00Kooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo00?o003oooooooooool04_oo
ool2o`00o`?ooooo00?o003oooooooooool00_l00?l3ooooo`05o`00ooooooooooooooooool00?l0
2?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool01_ooool01Ol00?oo
oooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool2o`00o`;ooooo00Co003ooooooooooooooooo0_l00?l4ooooo`05o`00
ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;o
003o0_ooool2o`00o`;ooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003o
ooooooooool01Oooool01ol00?ooooooo`00oooooooo003oooooool00?l02?ooool00ol0003ooooo
ooooo`01ooooo`004Oooool2o`0000Wooooo00Oo003oooooool00?ooooooo`00oooooooo003o00Ko
oooo00go003oooooooooooooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o00Co
oooo00Oo003oooooool00?ooooooo`00oooooooo003o00[ooooo00Go003oooooool00?ooooooo`00
o`02ooooo`;o003o0oooool00ol00?ooooooooooo`02o`00o`;ooooo00?o003oooooool00?l00ooo
ool00ol00?ooooooooooo`02o`00o`;ooooo0_l00?l4ooooo`04o`00ooooooooooooo`00o`?ooooo
0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`_ooooo0_l00?l3ooooo`03
o`00oooooooooooo00;o003o0oooool00ol00?ooooooooooo`0:ooooo`05o`00oooooooooooooooo
ool00?l02?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0_oo
ool01Ol00?oooooooooooooooooo003o00Cooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`02o`00o`;ooooo00Oo003ooooooooooooo
ooooo`00oooooooo003o00;ooooo0_l00?l:ooooo`03o`00oooooooo003o00Oooooo0_l00003oooo
o`004Oooool00ol0003oooooooooo`08ooooo`0;o`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?l00_ooool02ol00?oooooooooooooooooo003oooooool00?ooooooo`00oooo
oooo003o00Cooooo00?o003oooooool00?l00oooool01Ol00?ooooooo`00oooooooo003o00;ooooo
0_l00?l6ooooo`03o`00oooooooooooo00;ooooo0_l00?l3ooooo`04o`00ooooooooooooo`00o`?o
oooo00?o003oooooooooool00_ooool2o`00o`;ooooo0_l00?l2ooooo`;o003o1oooool2o`00o`Oo
oooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0oooool00ol00?ooooooooooo`05oooo
o`;o003o0oooool00ol00?ooooooooooo`04ooooo`;o003o0oooool00ol00?ooooooooooo`0:oooo
o`05o`00ooooooooooooooooool00?l00oooool2o`00o`Oooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool2o`00o`;ooooo0_l00?l2ooooo`;o
003o0_ooool00ol00?ooooooo`00o`07ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol0
0?ooooooo`00o`02ooooo`;o003o0_ooool2o`00o`Kooooo00?o003oooooool00?l02?ooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`06ooooo`03o`00oooooooo003o00?o
oooo00Oo003oooooool00?ooooooo`00oooooooo003o00Cooooo00?o003oooooool00?l00oooool0
0ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00?ooooo00Go003oooooool00?ooooooo`00
o`02ooooo`;o003o0_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00;ooooo0_l0
0?l3ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02o`00o`?ooooo0_l00?l3ooooo`03o`00oooooooooooo00;o003o0oooool01Ol00?oooooo
oooooooooooo003o00?ooooo0_l00?l3ooooo`03o`00oooooooooooo00[ooooo00Go0000oooooooo
ooooooooo`00o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03_ooool01?l0
0?ooooooooooooooool2o`00o`?ooooo00?o003oooooooooool01Oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01_l0
0?ooooooooooool00?ooooooo`00o`;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00Oooooo0_l00?l2ooooo`;o003o0_ooool00ol00?ooooooo`00o`0<ooooo`03o`00
0?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Kooooo00Oo003ooooooooooooooooo
o`00oooooooo003o00?ooooo00?o003oooooool00?l01?ooool01ol00?oooooooooooooooooo003o
ooooool00?l00oooool02?l00?ooooooooooool00?ooooooo`00oooooooo003o1Oooool00ol00?oo
ooooooooo`02o`00o`;ooooo00?o003oooooool00?l00oooool01Ol00?ooooooo`00oooooooo003o
00;ooooo0_l00?l3ooooo`06o`00ooooooooooooo`00oooooooo003o0_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo0_l00?l3ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l7ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo00;o
oooo00?o0000ooooooooool00_l00?l7ooooo`03o`00oooooooooooo01;ooooo0_l00?l3ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o0oooool0
0ol00?ooooooooooo`05ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`?ooooo0_l0
0?l2ooooo`04o`00ooooooooooooooooo`;o003o1?ooool01Ol00?oooooooooooooooooo003o00;o
oooo0_l00?l2ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`08ooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooo003o00;ooooo00Oo003oooooool00?ooooooo`00oooo
oooo003o00Gooooo00So003ooooooooooooo003oooooool00?ooooooo`00o`cooooo00Oo003ooooo
ool00?ooooooo`00oooooooo003o00Kooooo00Co003ooooooooooooooooo0_l00?l4ooooo`03o`00
oooooooooooo00;o003o0_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo003o00;ooooo
0_l00?l2ooooo`;o003o0_ooool2o`00o`_ooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;o003o0oooool01Ol00?oooooooooooooooooo003o01Wo
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool01Oooool01?l00?ooooooooooooooool2o`00o`;ooooo00Co003ooooooooooooooooo0_l0
0?l3ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooooooool2o`00o`;ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`03o`00oooooooo003o
00[ooooo0_l00?l2ooooo`03o`00oooooooo003o00Sooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool02?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00Co
oooo00Oo003oooooooooooooooooo`00oooooooo003o00?ooooo00?o003oooooool00?l01?ooool0
1ol00?ooooooo`00oooooooo003oooooool00?l02_ooool02Ol00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00o`02ooooo`;o003o0_ooool2o`00o`;ooooo00?o003oooooool00?l00oooool0
0ol00?ooooooooooo`02o`00o`Sooooo00Co003ooooooooooooo003o0oooool2o`00o`;ooooo0_l0
0?l7ooooo`;o003o2oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o0_oo
ool2o`00oagooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o
003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l2ooooo`04o`00oooooooooooo
ooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o2?ooool0
0ol00?ooooooooooo`02o`00o`;ooooo00Oo003oooooooooooooooooo`00oooooooo003o00;ooooo
0_l00?l7ooooo`06o`00ooooooooooooo`00oooooooo003o2?ooool00ol0003oooooooooo`01oooo
o`004Oooool2o`0000Wooooo00Oo003oooooool00?ooooooo`00oooooooo003o00Kooooo00_o003o
ooooooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`03ooooo`04o`00oooooooooooo
o`00o`?ooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l01_ooool01ol00?oo
ooooo`00oooooooo003oooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooo
oooo003o00?ooooo00?o003oooooooooool00_l00?l2ooooo`;o003o1oooool00ol00?oooooooooo
o`05ooooo`;o003o0oooool01?l00?ooooooooooooooool2o`00o`;ooooo00?o003oooooooooool0
2oooool01?l00?ooooooooooool00?l3ooooo`;o003o8Oooool01Ol00?oooooooooooooooooo003o
00?ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooooooo0_l00?l2ooooo`;o003o
0_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Cooooo0_l00?l3ooooo`;o003o
0_ooool2o`00o`Kooooo00?o003oooooool00?l01oooool2o`0000?ooooo000Aooooo`03o`000?oo
oooooooo00Gooooo00Co003ooooooooooooo003o0oooool01ol00?ooooooo`00oooooooo003ooooo
ool00?l00_ooool2o`00o`;ooooo00Oo003oooooooooooooooooo`00oooooooo003o00?ooooo00?o
003oooooooooool01?ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`02oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooo`00o`02ooooo`;o003o0_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooool00?l00oooool00ol00?oooooooooo
o`02o`00o`;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`;o003o0ooo
ool01?l00?ooooooooooooooool2o`00o`;ooooo00?o003oooooooooool02oooool00ol0003ooooo
ooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool07oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`08ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_l0
0?l3ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`07ooooo`;o003o
0_ooool2o`00o`;ooooo0_l00?l=ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo00Gooooo00?o003oooooooooool01?ooool01ol00?ooooooo`00oooooooo003oooooool0
0?l00oooool00ol00?ooooooooooo`04ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`04
ooooo`03o`00oooooooooooo00?ooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00oooo
oooo003o00?ooooo00Go003oooooool00?ooooooo`00o`02ooooo`;o003o0oooool02?l00?oooooo
ooooool00?ooooooo`00oooooooo003o1Oooool00ol00?ooooooooooo`02o`00o`;ooooo00?o003o
ooooool00?l00oooool00ol00?ooooooooooo`02o`00o`Kooooo0_l00?l3ooooo`;o003o0_ooool0
0ol00?ooooooooooo`0;ooooo`05o`000?oooooo003oooooool00?l01oooool00ol00?oooooooooo
o`0Oooooo`04o`00ooooooooooooooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o0oooool01Ol00?oooooooooooooo
oooo003o00?ooooo0_l00?l8ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00o`gooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l00_ooool2o`00o`Cooooo00?o003o
ooooooooool00oooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo003o00Oooooo00Go003o
ooooool00?ooooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l01Oooool00ol00?oooooo
ooooo`02ooooo`;o003o1?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooo`00o`02ooooo`;o003o0_ooool2o`00o`?ooooo00Go003ooooooooo
ooooooooo`00o`07ooooo`03o`00oooooooooooo00_ooooo00Go003oooooool00?ooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l08Oooool01Ol00?oooooooooooooooooo003o00Sooooo
00Go003oooooooooooooooooo`00o`03ooooo`;o003o0_ooool2o`00o`?ooooo00?o003ooooooooo
ool00_ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool0
1?l00?ooooooooooooooool2o`00o`;ooooo0_l00?l7ooooo`;o003o0_ooool2o`00o`;ooooo00?o
003oooooool00?l02?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`05
ooooo`06o`00ooooooooooooo`00oooooooo003o0oooool00ol00?ooooooooooo`04ooooo`;o003o
0_ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooo003o00Cooooo00Oo003oooooool00?oo
ooooo`00oooooooo003o00Oooooo00So003ooooooooooooo003oooooool00?ooooooo`00o`Gooooo
00?o003oooooooooool00_ooool2o`00o`Cooooo00Go003oooooooooooooooooo`00o`02ooooo`;o
003o1_ooool00ol00?ooooooo`00o`02ooooo`04o`00ooooooooooooooooo`;o003o0_ooool2o`00
o`Oooooo00?o003oooooooooool03oooool01Ol00?ooooooo`00oooooooo003o00;ooooo0_l00?lY
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool2o`00o`?ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02o`00o`Oooooo00Co003ooooooooooooooooo0_l00?l2ooooo`04o`00oooooooooooooooo
o`;o003o0oooool00ol00?ooooooooooo`05ooooo`;o003o0_ooool00ol00?ooooooo`00o`08oooo
o`03o`000?oooooooooo007ooooo000Aooooo`;o00002Oooool2o`00o`;ooooo00?o003oooooool0
0?l01_ooool03Ol00?oooooooooooooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?l01?ooool2o`00o`;ooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l01_oo
ool01ol00?ooooooo`00oooooooo003oooooool00?l00oooool01?l00?ooooooooooool00?l3oooo
o`03o`00oooooooo003o00?ooooo00?o003oooooooooool00_l00?l2ooooo`;o003o1_ooool00ol0
0?ooooooooooo`06ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l@ooooo`03o`00oooooooo003o
00Cooooo0_l00?lYooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool2o`00o`;ooooo00?o003oooooooooool00_ooool01?l00?oooooo
ooooooooool2o`00o`;ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`;o003o0_ooool2o`00
o`Kooooo0_l00?l8ooooo`;o00000oooool0017ooooo00?o0000ooooooooool01Oooool01?l00?oo
ooooooooool00?l3ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`;o003o0_oo
ool01ol00?oooooooooooooooooo003oooooool00?l00oooool00ol00?ooooooooooo`04ooooo`0;
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l01?ooool01ol00?oooooo
oooooooooooo003oooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`07o`00oooooooo
ooooooooool00?ooooooo`00o`03ooooo`03o`00oooooooooooo00;o003o0_ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00Cooooo0_l00?l2ooooo`;o003o0oooool2o`00o`;ooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`04ooooo`;o003o0_ooool00ol00?oooooo
ooooo`0Yooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003o
ooooooooool00_l00?l3ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`07ooooo`;o003o0_ooool2o`00o`;ooooo00?o003oooooooooool03?ooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`05ooooo`04o`00ooooooooooooo`00o`?ooooo00Oo
003oooooool00?ooooooo`00oooooooo003o00?ooooo00?o003oooooooooool01?ooool01ol00?oo
ooooo`00oooooooo003oooooool00?l00oooool03_l00?ooooooooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003o0_ooool00ol00?ooooooooooo`03ooooo`07o`00oooo
oooo003oooooool00?ooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`02o`00o`;ooooo00?o003oooooool00?l00oooool00ol0
0?ooooooooooo`02o`00o`Kooooo0_l00?l3ooooo`;o003o0_ooool00ol00?ooooooooooo`0;oooo
o`05o`000?ooooooooooooooool00?l00_ooool01Ol00?oooooooooooooooooo003o02oooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?l3ooooo`04
o`00ooooooooooooooooo`;o003o0_ooool2o`00o`Oooooo00Co003ooooooooooooooooo0_l00?l2
ooooo`;o003o3Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`05oooo
o`05o`00ooooooooooooooooool00?l00_ooool01ol00?oooooooooooooooooo003oooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00;ooooo00Oo003oooooooooooooooooo`00oooooooo
003o00;ooooo0_l00?l6ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`05o`00
ooooooooooooooooool00?l01Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooool00?l00oooool00ol00?ooooooooooo`02ooooo`;o003o0_ooool01ol00?oo
ooooo`00oooooooo003oooooool00?l00_ooool2o`00o`Kooooo0_l00?l7ooooo`03o`00oooooooo
oooo00_ooooo00Go003oooooool00?ooooooo`00o`03ooooo`04o`00ooooooooooooo`00oboooooo
00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o0oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00oooo
ooooooooooooool00?l00oooool2o`00o`;ooooo0_l00?l7ooooo`;o003o0_ooool2o`00o`;ooooo
0_l00?l9ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Gooooo00?o
003oooooooooool00_l00?l6ooooo`03o`00oooooooo003o00;ooooo0_l00?l2ooooo`;o003o1?oo
ool00ol00?ooooooo`00o`04ooooo`;o003o0_ooool00ol00?ooooooo`00o`07ooooo`03o`00oooo
oooooooo00;o003o0_ooool00ol00?ooooooooooo`03ooooo`07o`00ooooooooooooooooool00?oo
ooooo`00o`04ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`08ooooo`0;o`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?l00_ooool2o`00o`Kooooo00?o003ooooo
ooooool04?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo0_l00?l2ooooo`03o`00oooooooo
oooo037ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00
ooooooooooooooooo`;o003o0_ooool2o`00o`?ooooo00?o003oooooooooool01Oooool2o`00o`;o
oooo0_l00?l9ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00002Oooool2o`00o`;ooooo
0_l00?l7ooooo`04o`00ooooooooooooooooo`;o003o0_ooool01Ol00?ooooooo`00oooooooo003o
00Cooooo0_l00?l2ooooo`05o`00oooooooo003oooooool00?l02?ooool2o`00o`;ooooo00Go003o
ooooool00?ooooooo`00o`03ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?oooooo
o`00o`03ooooo`05o`00oooooooo003oooooool00?l00_ooool2o`00o`Kooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`;o003o0_ooool01ol00?oooooooooooooooooo003oooooool00?l04?oo
ool01Ol00?ooooooo`00oooooooo003o00;ooooo0_l00?ljooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00o`?ooooo
00?o003oooooooooool02Oooool2o`00o`Sooooo0_l00003ooooo`004Oooool00ol0003ooooooooo
o`08ooooo`04o`00ooooooooooooooooo`;o003o0_ooool00ol00?ooooooo`00o`02ooooo`04o`00
ooooooooooooooooo`;o003o0_ooool00ol00?ooooooo`00o`03ooooo`04o`00ooooooooooooo`00
o`?ooooo0_l00?l2ooooo`05o`00oooooooo003oooooool00?l01Oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooo003o00?ooooo00?o003oooooool00?l01?ooool02ol00?oooooooooooooo
oooo003oooooool00?ooooooo`00oooooooo003o00;ooooo0_l00?l6ooooo`03o`00oooooooo003o
00Kooooo0_l00?l2ooooo`;o003o1?ooool01?l00?ooooooooooool00?l=ooooo`03o`00oooooooo
oooo00Cooooo0_l00?l2ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?l7ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_l00?l3ooooo`04o`00ooooooooooooooooo`;o
003o1_ooool2o`00o`Wooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
1Oooool01?l00?ooooooooooool00?l3ooooo`;o003o0_ooool00ol00?ooooooo`00o`03ooooo`04
o`00ooooooooooooo`00o`?ooooo00?o003oooooool00?l00oooool00ol00?ooooooooooo`04oooo
o`;o003o0_ooool01ol00?ooooooo`00oooooooo003oooooool00?l00_ooool00ol00?oooooooooo
o`03ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`03ooooo`03o`00oooooooo003o00Co
oooo00?o003oooooooooool00oooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003ooooo
ool00?l00oooool01Ol00?ooooooo`00oooooooo003o00;ooooo00Co003ooooooooooooooooo0_l0
0?l2ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool02oooool01Ol0003ooooooooo
oooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`10ooooo`05o`00oooooooooooooooo
ool00?l00oooool01?l00?ooooooooooooooool2o`00o`?ooooo00Go003oooooooooooooooooo`00
o`04ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooooooo0_l00?l2ooooo`;o003o
3Oooool00ol0003oooooooooo`01ooooo`002Oooool3o`0000Gooooo00?o0000ooooooooool01Ooo
ool01Ol00?oooooooooooooooooo003o00;ooooo00Oo003oooooooooooooooooo`00oooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`02ooooo`07o`00ooooooooooooooooool00?oooooo
o`00o`02ooooo`;o003o1_ooool01ol00?ooooooo`00oooooooo003oooooool00?l00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooool00?ooooooo`00o`03ooooo`03o`00oooo
oooo003o00;ooooo00?o003oooooool00?l00oooool01ol00?oooooooooooooooooo003oooooool0
0?l00_ooool02ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o00Kooooo
0_l00?l2ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool02oooool01Ol0003ooooo
o`00oooooooo003o00Kooooo00?o003oooooooooool0@_ooool01Ol00?oooooooooooooooooo003o
00?ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`;ooooo0_l00?l3
ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`;ooooo0_l00?l9ooooo`03o`000?oo
oooooooo007ooooo000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
1Ol00?oooooooooooooooooo003o00Kooooo00?o003oooooool00?l00_ooool2o`00o`;ooooo0_l0
0?l6ooooo`03o`00oooooooo003o00;ooooo0_l00?l2ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool00_l00?l2ooooo`03o`00oooooooooooo00?ooooo00Oo003ooooooooooooooooo
o`00oooooooo003o00Cooooo00Oo003oooooool00?ooooooo`00oooooooo003o00Sooooo00_o003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`02ooooo`;o003o1_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00_ooooo00Go003oooooool00?ooooooo`00o`03
ooooo`04o`00ooooooooooooo`00odSooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o2oooool2o`00o`;o
oooo0_l00?l9ooooo`03o`000?oooooooooo007ooooo000:ooooo`03o`000?oooooooooo00Cooooo
0ol00008ooooo`;o003o0oooool00ol00?ooooooooooo`05ooooo`04o`00ooooooooooooooooo`;o
003o0oooool01?l00?ooooooooooool00?l4ooooo`;o003o0_ooool2o`00o`_ooooo0_l00?l2oooo
o`;o003o0_ooool02ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o00;o
oooo00Wo003oooooooooooooooooo`00oooooooo003oooooool00?l02?ooool00ol00?ooooooo`00
o`03ooooo`03o`00oooooooo003o00;ooooo0_l00?l8ooooo`03o`00oooooooooooo00kooooo0_l0
0?l2ooooo`05o`00oooooooo003oooooool00?l0Boooool00ol00?ooooooooooo`06ooooo`05o`00
ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00o`?ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`02o`00o`Oooooo0ol00003ooooo`002_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Sooooo0_l00?l2ooooo`;o003o1oooool01?l00?oo
ooooooooooooool2o`00o`;ooooo0_l00?l4ooooo`04o`00ooooooooooooo`00o`?ooooo0_l00?l2
ooooo`05o`00oooooooo003oooooool00?l01Oooool00ol00?ooooooooooo`02o`00o`;ooooo00Oo
003oooooooooooooooooo`00oooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool02Ol0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00o`06ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooool00?l00_ooool2o`00o`Cooooo00?o003oooooool00?l03_ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooo003o04_ooooo00Go003oooooooooooooooooo`00o`08ooooo`03
o`00oooooooooooo00Gooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l01oooool2o`00
o`Wooooo00?o0000ooooooooool00Oooool000[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`;ooooo0_l00?l3oooo
o`;o003o0_ooool01?l00?ooooooooooooooool2o`00o`Cooooo00?o003oooooooooool01?ooool2
o`00o`;ooooo00Oo003oooooool00?ooooooo`00oooooooo003o00Oooooo00So003ooooooooooooo
003oooooool00?ooooooo`00o`?ooooo00?o003oooooool00?l01?ooool00ol00?ooooooo`00o`03
ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?ooooooo`00oooooooo003o00;ooooo0_l00?l2ooooo`05o`00oooooooo003o
ooooool00?l03_ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool0B_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`06ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`0<ooooo`03o`000?oooooooooo007ooooo0009ooooo`;o00001_ooool00ol0003ooooooooo
o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?l2ooooo`;o003o1?oo
ool01Ol00?oooooooooooooooooo003o00;ooooo00Co003ooooooooooooooooo0_l00?l4ooooo`03
o`00oooooooooooo00Cooooo0_l00?l2ooooo`03o`00oooooooo003o00;ooooo00Co003ooooooooo
oooooooo0_l00?l2ooooo`05o`00oooooooo003oooooool00?l00oooool00ol00?ooooooo`00o`02
ooooo`03o`00oooooooo003o00Gooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo
00Wo003oooooooooooooooooo`00oooooooo003oooooool00?l01_ooool2o`00o`;ooooo00Go003o
ooooool00?ooooooo`00o`0>ooooo`05o`000?l00?ooooooooooool00?l01_ooool00ol00?oooooo
ooooo`1?ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`06ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0<ooooo`03o`000?oooooooooo
007ooooo000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00Cooooo0_l00?l3ooooo`;o003o0oooool00ol00?oo
ooooooooo`04ooooo`;o003o0oooool2o`00o`Oooooo00Ko003ooooooooooooo003oooooool00?l2
ooooo`;o003o0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooool00?l01?ooool2o`00o`;ooooo00?o003oooooool00?l01oooool03?l00?ooooooooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00o`?ooooo00Go003oooooooooooooooooo`00
o`02ooooo`05o`00ooooooooooooooooool00?l03_ooool2o`00o`;ooooo00Go003ooooooooooooo
ooooo`00o`02ooooo`03o`00oooooooooooo04oooooo00Go003oooooooooooooooooo`00o`03oooo
o`04o`00ooooooooooooooooo`;o003o1oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l0
0?l9ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00001Oooool01?l00?oooooooooooooo
ool2o`00o`?ooooo00?o003oooooooooool01Oooool01?l00?ooooooooooooooool2o`00o`?ooooo
00Co003ooooooooooooo003o1?ooool2o`00o`;ooooo0_l00?l8ooooo`03o`00oooooooooooo00;o
003o0_ooool2o`00o`?ooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`04ooooo`09
o`00ooooooooooooooooool00?ooooooo`00oooooooo003o00Gooooo00Ko003ooooooooooooo003o
ooooool00?l3ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`06ooooo`03o`00oooooooo
oooo013ooooo0_l00?l2ooooo`05o`00oooooooo003oooooool00?l0F?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo0_l00?l3ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo
oooo0_l00?l8ooooo`;o00000oooool0017ooooo00?o0000ooooooooool02?ooool2o`00o`;ooooo
0_l00?l7ooooo`04o`00ooooooooooooooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l3ooooo`;o
003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool00_l00?l2ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`03ooooo`04o`00oooooooo
ooooo`00o`?ooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l01_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooo003o00;ooooo0_l00?l4ooooo`03o`00oooooooooooo
00kooooo0_l00?l4ooooo`03o`00oooooooo003o05cooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l01oooool2o`00o`Wooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool01?ooool01Ol00?oooooooooooooooooo003o00?ooooo0_l0
0?l2ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l3ooooo`03o`00
oooooooooooo00Gooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`Cooooo00Go003ooooooooooooo
ooooo`00o`02ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00_ooool02ol00?oooooooooooooooooo003oooooool00?ooooooo`00oooooooo
003o00Kooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`02ooooo`;o003o0_ooool0
1Ol00?ooooooo`00oooooooo003o00kooooo00?o003oooooooooool00oooool00ol00?ooooooo`00
o`02ooooo`03o`00oooooooooooo063ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?oo
ool00ol00?ooooooooooo`05ooooo`;o003o0_ooool2o`00o`?ooooo00?o003oooooooooool01Ooo
ool2o`00o`;ooooo0_l00?l4ooooo`05o`00ooooooooooooooooool00?l00_ooool2o`00o`;ooooo
0_l00?l3ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?l2ooooo`07o`00
ooooooooooooooooool00?ooooooo`00o`03ooooo`03o`00oooooooooooo00Cooooo00Oo003ooooo
ool00?ooooooo`00oooooooo003o00;ooooo00Wo003oooooooooooooooooo`00oooooooo003ooooo
ool00?l01Oooool00ol00?ooooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l03_ooool0
1ol0003o003ooooooooooooo003oooooool00?l01?ooool00ol00?ooooooooooo`1Pooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0<ooooo`03o`000?oooooooooo007o
oooo000Aooooo`03o`000?oooooooooo00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`04
o`00ooooooooooooooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`04o`00oooooooooooo
o`00o`?ooooo0_l00?l3ooooo`;o003o1_ooool2o`00o`;ooooo0_l00?l3ooooo`;o003o0_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01?ooool2
o`00o`Cooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`02ooooo`;o003o0_ooool0
1Ol00?ooooooo`00oooooooo003o00Gooooo00?o003oooooool00?l00_ooool01Ol00?oooooooooo
oooooooo003o00kooooo0_l00?l2ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`1Woooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`08ooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00Go003oooooooooooooooooo`00o`07
ooooo`;o003o0oooool01?l00?ooooooooooooooool2o`00o`?ooooo00Co003ooooooooooooo003o
1?ooool01?l00?ooooooooooooooool2o`00o`Oooooo00Co003ooooooooooooooooo0_l00?l2oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`04oooo
o`;o003o0_ooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00;o003o0_ooool02Ol0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00o`06ooooo`03o`00oooooooooooo013ooooo
00Wo003oooooooooooooooooo`00oooooooo003oooooool00?l0KOooool01Ol00?oooooooooooooo
oooo003o00[ooooo00?o0000ooooooooool00Oooool0017ooooo0_l00009ooooo`04o`00oooooooo
ooooooooo`;o003o1oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l2ooooo`03o`00
oooooooooooo00;ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`03o`00oooooooooooo00Ko
oooo0_l00?l2ooooo`;o003o0_ooool01?l00?ooooooooooooooool2o`00o`Cooooo00Co003ooooo
oooooooo003o0oooool2o`00o`;ooooo00Go003oooooool00?ooooooo`00o`05ooooo`03o`00oooo
oooooooo00;ooooo00Wo003oooooooooooooooooo`00oooooooo003oooooool00?l01_ooool00ol0
0?ooooooooooo`0>ooooo`09o`00ooooooooooooooooool00?ooooooo`00oooooooo003o077ooooo
00?o003oooooooooool01oooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo00Sooooo00Co
003ooooooooooooooooo0_l00?l2ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?o
oooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`;ooooo0_l00?l2oooo
o`03o`00oooooooooooo00?ooooo00Go003oooooooooooooooooo`00o`02ooooo`04o`00oooooooo
ooooooooo`;o003o1?ooool01Ol00?oooooooooooooooooo003o00;ooooo0_l00?l2ooooo`05o`00
oooooooo003oooooool00?l02?ooool00ol00?ooooooooooo`03ooooo`07o`00oooooooo003ooooo
ool00?ooooooo`00o`04ooooo`03o`00oooooooo003o00kooooo00?o003oooooooooool00oooool0
1Ol00?ooooooo`00oooooooo003o06oooooo00?o003oooooooooool02?ooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01?l00?ooooooooooooooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o
003o0_ooool2o`00o`Oooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02o`00o`;ooooo00Oo003oooooooooooooooooo`00oooooooo
003o00?ooooo00?o003oooooooooool01?ooool01ol00?ooooooo`00oooooooo003oooooool00?l0
0_ooool01?l00?ooooooooooooooool2o`00o`;ooooo00?o003oooooool00?l00oooool01Ol00?oo
ooooo`00oooooooo003o00;ooooo00?o003oooooool00?l03_ooool01ol0003ooooooooooooooooo
003oooooool00?l00oooool00ol00?ooooooooooo`1hooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooo
ooooooooooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooo
oooooooo0_l00?l3ooooo`03o`00oooooooooooo00Gooooo0_l00?l2ooooo`;o003o0oooool01Ol0
0?oooooooooooooooooo003o00?ooooo0_l00?l6ooooo`03o`00oooooooo003o00;ooooo0_l00?l3
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooool00?ooooooo`00o`02ooooo`;o003o0_oo
ool2o`00o`;ooooo00?o003oooooooooool00oooool01Ol00?ooooooo`00oooooooo003o00;ooooo
00?o003oooooool00?l03_ooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003ooooooooo
ool0N?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`05o`00
ooooooooooooooooool00?l01oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`07oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`08ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0_ooool00ol00?ooooooooooo`02ooooo`;o003o0_ooool2o`00o`Sooooo00?o003oooooooooool0
0_l00?l2ooooo`;o003o0_ooool01Ol00?ooooooo`00oooooooo003o00Gooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0<ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooo`00o`1jooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00002Oooool01Ol00?oo
oooooooooooooooo003o00Sooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`0<ooooo`04o`00ooooooooooooooooo`;o
003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`03o`00oooooooo003o00;ooooo00Co003ooooooooo
oooooooo0_l00?l2ooooo`;o003o1oooool2o`00o`?ooooo00So003ooooooooooooo003oooooool0
0?ooooooo`00o`Sooooo00?o003oooooooooool03_ooool02Ol0003ooooooooooooooooo003ooooo
ool00?ooooooo`00o`1kooooo`;o00000oooool0017ooooo00?o0000ooooooooool03?ooool00ol0
0?ooooooooooo`06ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o0_ooool00ol00?oooooo
ooooo`02ooooo`04o`00ooooooooooooooooo`;o003o0_ooool01?l00?ooooooooooooooool2o`00
o`Cooooo00?o003oooooooooool01?ooool2o`00o`;ooooo0_l00?l2ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool01_ooool01ol00?ooooooo`00oooooooo003oooooool00?l01?oo
ool00ol00?ooooooo`00o`0>ooooo`03o`000?oooooooooo00?ooooo00Go003oooooool00?oooooo
o`00o`1jooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00cooooo00Co
003ooooooooooooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooooooo0_l00?l2oooo
o`;o003o1oooool01?l00?ooooooooooooooool2o`00o`;ooooo00Co003ooooooooooooooooo0_l0
0?l4ooooo`04o`00ooooooooooooo`00o`?ooooo0_l00?l2ooooo`03o`00oooooooo003o00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`0;o`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?l00_ooool00ol00?ooooooo`00o`0>ooooo`03o`000?oooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`1hooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`03o`00oooooooooooo00Go
oooo0_l00?l2ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l2oooo
o`04o`00ooooooooooooooooo`;o003o0oooool2o`00o`Kooooo0_l00?l2ooooo`03o`00oooooooo
003o00;ooooo0_l00?l2ooooo`;o003o0_ooool00ol00?ooooooooooo`03ooooo`05o`00oooooooo
003oooooool00?l00_ooool2o`00o`oooooo00Go0000ooooooooooooooooo`00o`05ooooo`03o`00
oooooooooooo07Sooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool05Ooo
ool01Ol00?oooooooooooooooooo003o00Oooooo0_l00?l3ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool00_l00?l3ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o00;ooooo00?o003oooooooooool00_ooool2o`00o`;ooooo0_l00?l7oooo
o`04o`00ooooooooooooooooo`;o003o0_ooool2o`00o`;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooo003o00?ooooo00?o003oooooooooool03Oooool01Ol0003ooooooooo
oooooooo003o00?ooooo00?o003oooooool00?l0N_ooool00ol0003oooooooooo`01ooooo`004Ooo
ool2o`0001[ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`08ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o0_ooool00ol00?ooooooooooo`02oooo
o`04o`00ooooooooooooooooo`;o003o0_ooool00ol00?ooooooooooo`02ooooo`04o`00oooooooo
ooooooooo`;o003o0oooool00ol00?ooooooooooo`02o`00o`;ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0Aooooo`04o`000?ooooooooooooooo`;o003o0_ooool00ol00?oooooo
ooooo`1iooooo`;o00000oooool0017ooooo00?o0000ooooooooool07Oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l0
0?l3ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`;ooooo0_l00?l2ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool01Oooool02?l00?ooooooooooool00?ooooooo`00
oooooooo003o1?ooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00Co003o
oooooooooooo003oO?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0M
ooooo`05o`00ooooooooooooooooool00?l02?ooool01Ol00?oooooooooooooooooo003o00?ooooo
0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`;ooooo0_l00?l3ooooo`05
o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00o`;ooooo0_l00?l7
ooooo`03o`00oooooooooooo00;ooooo00[o003ooooooooooooo003oooooool00?ooooooo`00oooo
oooo003o0_ooool2o`00o`oooooo00?o0000ooooooooool00_ooool01_l00?ooooooooooool00?oo
ooooo`00og[ooooo00?o0000ooooooooool00Oooool000Sooooo1Ol00004ooooo`03o`000?oooooo
oooo027ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co
003ooooooooooooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`;o
oooo00Co003ooooooooooooooooo0_l00?l3ooooo`03o`00oooooooooooo00Gooooo0_l00?l2oooo
o`;o003o0oooool01?l00?ooooooooooooooool2o`00o`;ooooo00?o003oooooooooool00oooool0
1Ol00?ooooooo`00oooooooo003o00;ooooo0_l00?l?ooooo`04o`000?ooooooooooooooo`;o003o
1?ooool00ol00?ooooooooooo`1hooooo`03o`000?oooooooooo007ooooo0009ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool08Oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00Gooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`04ooooo`;o003o0oooool2o`00o`;ooooo0_l00?l2
ooooo`03o`00oooooooooooo00?ooooo00Go003oooooool00?ooooooo`00o`03ooooo`03o`00oooo
oooooooo00gooooo00Go0000ooooooooooooooooo`00o`03ooooo`;o003oNoooool00ol0003ooooo
ooooo`01ooooo`002_ooool00ol0003oooooooooo`04ooooo`?o00009_ooool01Ol00?oooooooooo
oooooooo003o00Oooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
ooooo`;o003o1oooool01?l00?ooooooooooooooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0_oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo017ooooo00Co0000oooooooooooooooo
0_l00?l2ooooo`03o`00oooooooooooo07Sooooo0ol00003ooooo`002oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02[ooooo00Go003oooooooooooooooooo`00o`08ooooo`05o`00
ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00o`?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`;o003o0_ooool2o`00o`;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00_ooool2o`00o`Oooooo00?o
003oooooooooool03_ooool01?l0003oooooooooooooool2o`00o`;ooooo00?o003oooooooooool0
N_ooool00ol0003oooooooooo`01ooooo`002?ooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool0;_ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o0oooool01Ol00?oooooooooooooo
oooo003o00?ooooo0_l00?l2ooooo`;o003o0_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooooooo00;ooooo0_l0
0?l?ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool00_l00?mkooooo`03o`000?oo
oooooooo007ooooo0008ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`0^ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0oooool00ol00?ooooooooooo`05oooo
o`;o003o0_ooool2o`00o`?ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`;o003o0oooool0
1_l00?ooooooooooool00?ooooooo`00o`;ooooo0_l00?l?ooooo`04o`000?ooooooooooooooo`;o
003o0oooool00ol00?ooooooooooo`1iooooo`03o`000?oooooooooo007ooooo0009ooooo`?o0000
1Oooool00ol0003oooooooooo`0booooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00Gooooo0_l00?l3ooooo`05o`00oooooooooooooooo
ool00?l01?ooool00ol00?ooooooooooo`02o`00o`?ooooo00Co003ooooooooooooooooo0_l00?l2
ooooo`03o`00oooooooooooo00;ooooo00Ko003ooooooooooooo003oooooool00?l2ooooo`;o003o
3oooool01Ol0003ooooooooooooooooo003o00Cooooo00?o003oooooooooool0NOooool00ol0003o
ooooooooo`01ooooo`004Oooool2o`0003Sooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l02?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo
0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool01?l0003ooooo
ooooooooool2o`00o`;ooooo0_l00?mjooooo`;o00000oooool0017ooooo00?o0000ooooooooool0
>oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?l3oooo
o`05o`00ooooooooooooooooool00?l00oooool2o`00o`Oooooo00Go003oooooooooooooooooo`00
o`03ooooo`;o003o0_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00kooooo00Co
0000oooooooooooooooo0_l00?l2ooooo`03o`00oooooooooooo07[ooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool0?oooool01Ol00?oooooooooooooooooo003o00Cooooo
00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o0_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00_l00?l2oooo
o`03o`00oooooooooooo00;ooooo0_l00?l?ooooo`03o`000?oooooooooo00;ooooo00?o003ooooo
ooooool00_l00?mkooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo03oo
oooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l0
0oooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0oooool2o`00o`oooooo00?o0000ooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o07_ooooo00?o0000ooooooooool00Oooool0017ooooo
00?o0000ooooooooool0@oooool01?l00?ooooooooooooooool2o`00o`?ooooo00?o003ooooooooo
ool01Oooool01?l00?ooooooooooooooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?l3ooooo`;o003o3oooool0
1Ol0003ooooooooooooooooo003o00Cooooo00?o003oooooooooool0NOooool00ol0003ooooooooo
o`01ooooo`004Oooool2o`0004Sooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00Sooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool01?l00?ooooooooooooooool2o`00o`Cooooo00?o003oooooooooool03Oooool01Ol0
003ooooooooooooooooo003o00?ooooo0_l00?mjooooo`;o00000oooool0017ooooo00?o0000oooo
ooooool0Aoooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oooooooooo
ooooool2o`00o`;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`05o`00
0?ooooooooooooooool00?l00oooool00ol00?ooooooooooo`1jooooo`03o`000?oooooooooo007o
oooo000Aooooo`03o`000?oooooooooo04cooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00;o003o0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00kooooo00Go0000oooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo07[ooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool0D?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool01_ooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l2ooooo`;o003o0ooo
ool00ol00?ooooooooooo`0>ooooo`05o`000?ooooooooooooooool00?l00oooool2o`00og_ooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0E?ooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_l00?l3ooooo`03o`00oooooooooooo00kooooo00Go0000oooooooo
ooooooooo`00o`04ooooo`03o`00oooooooooooo07Wooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool0F?ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o0oooool00ol0
0?ooooooooooo`0>ooooo`05o`000?ooooooooooooooool00?l00oooool2o`00og_ooooo00?o0000
ooooooooool00Oooool0017ooooo0_l0001Iooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oooooooooo
o`0Booooo`05o`000?ooooooooooooooool00?l00oooool00ol00?ooooooooooo`1iooooo`;o0000
0oooool0017ooooo00?o0000ooooooooool0GOooool01Ol00?oooooooooooooooooo003o00?ooooo
00Co003ooooooooooooooooo0_l00?l7ooooo`03o`00oooooooooooo00kooooo00Go0000oooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo07[ooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool0HOooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l2oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool03_ooool01Ol0003ooooooooooooooooo
003o00?ooooo00?o003oooooooooool0N_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`1Qooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oooooooooooooo
ool2o`00o`?ooooo00?o003oooooooooool03_ooool01Ol0003ooooooooooooooooo003o00?ooooo
00?o003oooooooooool0N_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`1Qooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00o`?o
oooo00?o003oooooooooool03_ooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo07[o
oooo00?o0000ooooooooool00Oooool0017ooooo0_l0001Vooooo`05o`00ooooooooooooooooool0
0?l01?ooool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o003ooooooooo
ool0NOooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo06Wooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool0
N_ooool00ol0003oooooooooo`01ooooo`002Oooool3o`0000Gooooo00?o0000ooooooooool0JOoo
ool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool03_ooool00ol0003ooooo
ooooo`05ooooo`03o`00oooooooooooo07[ooooo00?o0000ooooooooool00Oooool000Sooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo06gooooo0_l00?l3ooooo`03o`00
oooooooooooo00kooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`1jooooo`03o`00
0?oooooooooo007ooooo000<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0KOoo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00kooooo00?o0000ooooooooool01Ooo
ool00ol00?ooooooooooo`1jooooo`03o`000?oooooooooo007ooooo000:ooooo`;o00001Oooool3
o`0007;ooooo00?o003oooooooooool03_ooool00ol0003oooooooooo`05ooooo`03o`00oooooooo
oooo07Sooooo0ol00003ooooo`003?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
08?ooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`01ooooo`002?ooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo007ooooo0009ooooo`?o00001Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo007ooooo000Aoooooooo00003Ol00003ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-11.9139, -3.66181, \
0.0788464, 0.0386451}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Magnitude plot of DFT as a function of frequency", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fft\  = \ DFT[xd];\)\), "\n", 
    \(\(g3 = 
        DiscreteListPlot[\({#[\([1]\)], \ Abs[#[\([2]\)]]} &\)\  /@ \ fft, 
          Red, \ PlotRange \[Rule] All, \ Frame \[Rule] True, \ 
          Axes \[Rule] False];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0161421 0.0147151 0.0196201 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18523 -0.0125 -6 -9 ]
[.18523 -0.0125 6 0 ]
[.34665 -0.0125 -6 -9 ]
[.34665 -0.0125 6 0 ]
[.50807 -0.0125 -6 -9 ]
[.50807 -0.0125 6 0 ]
[.66949 -0.0125 -6 -9 ]
[.66949 -0.0125 6 0 ]
[.83091 -0.0125 -6 -9 ]
[.83091 -0.0125 6 0 ]
[.99233 -0.0125 -6 -9 ]
[.99233 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11282 -6 -4.5 ]
[-0.0125 .11282 0 4.5 ]
[-0.0125 .21092 -12 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18523 0 m
.18523 .00625 L
s
[(10)] .18523 -0.0125 0 1 Mshowa
.34665 0 m
.34665 .00625 L
s
[(20)] .34665 -0.0125 0 1 Mshowa
.50807 0 m
.50807 .00625 L
s
[(30)] .50807 -0.0125 0 1 Mshowa
.66949 0 m
.66949 .00625 L
s
[(40)] .66949 -0.0125 0 1 Mshowa
.83091 0 m
.83091 .00625 L
s
[(50)] .83091 -0.0125 0 1 Mshowa
.99233 0 m
.99233 .00625 L
s
[(60)] .99233 -0.0125 0 1 Mshowa
.125 Mabswid
.05609 0 m
.05609 .00375 L
s
.08838 0 m
.08838 .00375 L
s
.12066 0 m
.12066 .00375 L
s
.15295 0 m
.15295 .00375 L
s
.21751 0 m
.21751 .00375 L
s
.2498 0 m
.2498 .00375 L
s
.28208 0 m
.28208 .00375 L
s
.31437 0 m
.31437 .00375 L
s
.37893 0 m
.37893 .00375 L
s
.41122 0 m
.41122 .00375 L
s
.4435 0 m
.4435 .00375 L
s
.47579 0 m
.47579 .00375 L
s
.54036 0 m
.54036 .00375 L
s
.57264 0 m
.57264 .00375 L
s
.60492 0 m
.60492 .00375 L
s
.63721 0 m
.63721 .00375 L
s
.70178 0 m
.70178 .00375 L
s
.73406 0 m
.73406 .00375 L
s
.76634 0 m
.76634 .00375 L
s
.79863 0 m
.79863 .00375 L
s
.8632 0 m
.8632 .00375 L
s
.89548 0 m
.89548 .00375 L
s
.92776 0 m
.92776 .00375 L
s
.96005 0 m
.96005 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11282 m
.00625 .11282 L
s
[(5)] -0.0125 .11282 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(10)] -0.0125 .21092 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(15)] -0.0125 .30902 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(20)] -0.0125 .40712 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(25)] -0.0125 .50522 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(30)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .0932 m
.00375 .0932 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .17168 m
.00375 .17168 L
s
0 .1913 m
.00375 .1913 L
s
0 .23054 m
.00375 .23054 L
s
0 .25016 m
.00375 .25016 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .32864 m
.00375 .32864 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .4856 m
.00375 .4856 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .56408 m
.00375 .56408 L
s
0 .5837 m
.00375 .5837 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18523 .61178 m
.18523 .61803 L
s
.34665 .61178 m
.34665 .61803 L
s
.50807 .61178 m
.50807 .61803 L
s
.66949 .61178 m
.66949 .61803 L
s
.83091 .61178 m
.83091 .61803 L
s
.99233 .61178 m
.99233 .61803 L
s
.125 Mabswid
.05609 .61428 m
.05609 .61803 L
s
.08838 .61428 m
.08838 .61803 L
s
.12066 .61428 m
.12066 .61803 L
s
.15295 .61428 m
.15295 .61803 L
s
.21751 .61428 m
.21751 .61803 L
s
.2498 .61428 m
.2498 .61803 L
s
.28208 .61428 m
.28208 .61803 L
s
.31437 .61428 m
.31437 .61803 L
s
.37893 .61428 m
.37893 .61803 L
s
.41122 .61428 m
.41122 .61803 L
s
.4435 .61428 m
.4435 .61803 L
s
.47579 .61428 m
.47579 .61803 L
s
.54036 .61428 m
.54036 .61803 L
s
.57264 .61428 m
.57264 .61803 L
s
.60492 .61428 m
.60492 .61803 L
s
.63721 .61428 m
.63721 .61803 L
s
.70178 .61428 m
.70178 .61803 L
s
.73406 .61428 m
.73406 .61803 L
s
.76634 .61428 m
.76634 .61803 L
s
.79863 .61428 m
.79863 .61803 L
s
.8632 .61428 m
.8632 .61803 L
s
.89548 .61428 m
.89548 .61803 L
s
.92776 .61428 m
.92776 .61803 L
s
.96005 .61428 m
.96005 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11282 m
1 .11282 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .50522 m
1 .50522 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03434 m
1 .03434 L
s
.99625 .05396 m
1 .05396 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .0932 m
1 .0932 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .15206 m
1 .15206 L
s
.99625 .17168 m
1 .17168 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .23054 m
1 .23054 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .26978 m
1 .26978 L
s
.99625 .2894 m
1 .2894 L
s
.99625 .32864 m
1 .32864 L
s
.99625 .34826 m
1 .34826 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .44636 m
1 .44636 L
s
.99625 .46598 m
1 .46598 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .52484 m
1 .52484 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .56408 m
1 .56408 L
s
.99625 .5837 m
1 .5837 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .01472 L
s
.03995 .01472 m
.03995 .01472 L
s
.05609 .01472 m
.05609 .01472 L
s
.07224 .01472 m
.07224 .60332 L
s
.08838 .01472 m
.08838 .01472 L
s
.10452 .01472 m
.10452 .01472 L
s
.12066 .01472 m
.12066 .01472 L
s
.1368 .01472 m
.1368 .01472 L
s
.15295 .01472 m
.15295 .01472 L
s
.16909 .01472 m
.16909 .01472 L
s
.18523 .01472 m
.18523 .01472 L
s
.20137 .01472 m
.20137 .01472 L
s
.21751 .01472 m
.21751 .01472 L
s
.23366 .01472 m
.23366 .01472 L
s
.2498 .01472 m
.2498 .01472 L
s
.26594 .01472 m
.26594 .01472 L
s
.28208 .01472 m
.28208 .01472 L
s
.29822 .01472 m
.29822 .01472 L
s
.31437 .01472 m
.31437 .01472 L
s
.33051 .01472 m
.33051 .01472 L
s
.34665 .01472 m
.34665 .01472 L
s
.36279 .01472 m
.36279 .01472 L
s
.37893 .01472 m
.37893 .01472 L
s
.39508 .01472 m
.39508 .01472 L
s
.41122 .01472 m
.41122 .01472 L
s
.42736 .01472 m
.42736 .01472 L
s
.4435 .01472 m
.4435 .01472 L
s
.45964 .01472 m
.45964 .01472 L
s
.47579 .01472 m
.47579 .01472 L
s
.49193 .01472 m
.49193 .01472 L
s
.50807 .01472 m
.50807 .01472 L
s
.52421 .01472 m
.52421 .01472 L
s
.54036 .01472 m
.54036 .01472 L
s
.5565 .01472 m
.5565 .01472 L
s
.57264 .01472 m
.57264 .01472 L
s
.58878 .01472 m
.58878 .01472 L
s
.60492 .01472 m
.60492 .01472 L
s
.62107 .01472 m
.62107 .01472 L
s
.63721 .01472 m
.63721 .01472 L
s
.65335 .01472 m
.65335 .01472 L
s
.66949 .01472 m
.66949 .01472 L
s
.68563 .01472 m
.68563 .01472 L
s
.70178 .01472 m
.70178 .01472 L
s
.71792 .01472 m
.71792 .01472 L
s
.73406 .01472 m
.73406 .01472 L
s
.7502 .01472 m
.7502 .01472 L
s
.76634 .01472 m
.76634 .01472 L
s
.78249 .01472 m
.78249 .01472 L
s
.79863 .01472 m
.79863 .01472 L
s
.81477 .01472 m
.81477 .01472 L
s
.83091 .01472 m
.83091 .01472 L
s
.84705 .01472 m
.84705 .01472 L
s
.8632 .01472 m
.8632 .01472 L
s
.87934 .01472 m
.87934 .01472 L
s
.89548 .01472 m
.89548 .01472 L
s
.91162 .01472 m
.91162 .01472 L
s
.92776 .01472 m
.92776 .01472 L
s
.94391 .01472 m
.94391 .60332 L
s
.96005 .01472 m
.96005 .01472 L
s
.97619 .01472 m
.97619 .01472 L
s
.015 w
.02381 .01472 Mdot
.03995 .01472 Mdot
.05609 .01472 Mdot
.07224 .60332 Mdot
.08838 .01472 Mdot
.10452 .01472 Mdot
.12066 .01472 Mdot
.1368 .01472 Mdot
.15295 .01472 Mdot
.16909 .01472 Mdot
.18523 .01472 Mdot
.20137 .01472 Mdot
.21751 .01472 Mdot
.23366 .01472 Mdot
.2498 .01472 Mdot
.26594 .01472 Mdot
.28208 .01472 Mdot
.29822 .01472 Mdot
.31437 .01472 Mdot
.33051 .01472 Mdot
.34665 .01472 Mdot
.36279 .01472 Mdot
.37893 .01472 Mdot
.39508 .01472 Mdot
.41122 .01472 Mdot
.42736 .01472 Mdot
.4435 .01472 Mdot
.45964 .01472 Mdot
.47579 .01472 Mdot
.49193 .01472 Mdot
.50807 .01472 Mdot
.52421 .01472 Mdot
.54036 .01472 Mdot
.5565 .01472 Mdot
.57264 .01472 Mdot
.58878 .01472 Mdot
.60492 .01472 Mdot
.62107 .01472 Mdot
.63721 .01472 Mdot
.65335 .01472 Mdot
.66949 .01472 Mdot
.68563 .01472 Mdot
.70178 .01472 Mdot
.71792 .01472 Mdot
.73406 .01472 Mdot
.7502 .01472 Mdot
.76634 .01472 Mdot
.78249 .01472 Mdot
.79863 .01472 Mdot
.81477 .01472 Mdot
.83091 .01472 Mdot
.84705 .01472 Mdot
.8632 .01472 Mdot
.87934 .01472 Mdot
.89548 .01472 Mdot
.91162 .01472 Mdot
.92776 .01472 Mdot
.94391 .60332 Mdot
.96005 .01472 Mdot
.97619 .01472 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005Oooool2o`0002Gooooo0ol00004ooooo`;o00008Oooool5o`0000?ooooo0_l0000Roooo
o`?o00001?ooool2o`0002?ooooo0ol00003ooooo`;o00008_ooool3o`0000Cooooo0_l0000Qoooo
o`?o00001?ooool2o`0000Gooooo000Dooooo`04o`000?ooooooooooo`0002Gooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool0000Qooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00008?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00008oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool07_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00007oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool001Cooooo00Co0000oooooooo
oooo00009Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002;ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000Tooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool07_ooool5o`0000;ooooo00Co0000oooooooooooo00009?ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo01gooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000Cooooo000Dooooo`04o`000?ooooooooooo`0002Gooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool0000Sooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`0Pooooo`;o00000oooool01?l0003oooooooooool0000Poooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00009?ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo01gooooo1?l00003ooooo`04o`000?ooooooooooo`0000Co
oooo000Dooooo`04o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000Pooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
000Tooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool07oooool00ol0003ooooo
o`000003ooooo`04o`000?ooooooooooo`00023ooooo1?l00003ooooo`04o`000?ooooooooooo`00
01oooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`005?ooool01?l0
003oooooooooool0000Tooooo`;o00001?ooool01?l0003oooooooooool0000Pooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool0000Pooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool0000Rooooo`;o00000oooool01?l0003oooooooooool0
000Pooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00008?ooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`0000Cooooo000Eooooo`;o00009_ooool00ol0003ooooo
ooooo`03ooooo`;o00008_ooool3o`0000Cooooo0_l0000Rooooo`?o00001?ooool2o`0002Cooooo
00?o0000ooooooooool00_ooool2o`00027ooooo1Ol00003ooooo`;o00008_ooool2o`0000Cooooo
0_l00005ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
4?ooooooo`0000_o00001_ooool000Wooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooool000001_ooool000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooo000000Kooooo0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool00_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo0006ooooo`?oo`00
00Coooooool00?oo003oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo00001?oo
ooooo`00ool00?oo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool000;ooooo0ooo
00001Oooooooo`00ool00?oo003ooooo00?oo`0000Coooooool00?oo003oo`000_ooool3ool00005
oooooooo003oo`00ool00?ooool00ooo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03
ool00004oooooooo003oo`00ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`00
0_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo00001?ooooooo`00ool00?oo0002oooo
o`?oo`0000Goooooool00?oo003oo`00ooooo`03ool000;ooooo0ooo00001Oooooooo`00ool00?oo
003ooooo00?oo`0000Coooooool00?oo003oo`000_ooool3ool00005oooooooo003oo`00ool00?oo
ool00ooo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool00004oooooooo003oo`00
ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Coooooool00?oo003oo`00
0_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo0002ooooo`?oo`0000Goooooool00?oo
003oo`00ooooo`03ool00004oooooooo003oo`00ool000;ooooo0ooo0005ooooo`?oo`000_ooool3
ool000Cooooo00?o0000ooooooooool01?ooool000Sooooo00Co0000oooooooooooo00001?ooool3
o`0000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`000oooool00ooo003ooooooooo
o`03ool00004oooooooo003oo`00ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?o
o`0000Coooooool00?oo003oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo0002
ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool00004oooooooo003oo`00ool000;ooooo
0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`000_ooool3ool00005oooooooo003oo`00ool0
0?ooool00ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`0000Goooooool00?oo003oo`00oooo
o`03ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Coooooool00?oo003o
o`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo0002ooooo`?oo`0000Goooooool0
0?oo003oo`00ooooo`03ool00004oooooooo003oo`00ool000;ooooo0ooo00001Oooooooo`00ool0
0?oo003ooooo00?oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo00001?oooooo
o`00ool00?oo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool00004oooooooo003o
o`00ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`000_ooool3ool00005oooo
oooo003oo`00ool00?ooool00ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`000_ooool00ooo
003oooooooooo`03ool000;ooooo0ooo0003ooooo`;o00001_ooool000Sooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`02ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03
ool000?ooooo00?oo`00ooooooooool00ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`0000Go
ooooool00?oo003oo`00ooooo`03ool00004oooooooo003oo`00ool000;ooooo0ooo00001Ooooooo
o`00ool00?oo003ooooo00?oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo0000
1?ooooooo`00ool00?oo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool000;ooooo
0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Coooooool00?oo003oo`000_ooool3ool0
0005oooooooo003oo`00ool00?ooool00ooo0002ooooo`?oo`0000Goooooool00?oo003oo`00oooo
o`03ool00004oooooooo003oo`00ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?o
o`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo00001?ooooooo`00ool00?oo0002
ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool000;ooooo0ooo00001Oooooooo`00ool0
0?oo003ooooo00?oo`0000Coooooool00?oo003oo`000_ooool3ool00005oooooooo003oo`00ool0
0?ooool00ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`0000Goooooool00?oo003oo`00oooo
o`03ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Coooooool00?oo003o
o`000_ooool3ool000;ooooo00?oo`00ooooooooool00ooo0002ooooo`?oo`001?ooool00ol0003o
ooooooooo`04ooooo`002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo013o
oooo00?oo`00ooooooooool0i?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00Co
oooo0009ooooo`;o00001Oooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo0>Cooooo
00?oo`00ooooooooool03?ooool00ol0003oooooooooo`04ooooo`004?ooool00ol0003ooooooooo
o`0@ooooo`03ool00?oooooooooo0>Cooooo00?oo`00ooooooooool03?ooool00ol0003ooooooooo
o`04ooooo`004?ooool2o`00017ooooo00?oo`00ooooooooool0i?ooool00ooo003oooooooooo`0;
ooooo`;o00001_ooool0013ooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`3Toooo
o`03ool00?oooooooooo00cooooo00?o0000ooooooooool01?ooool0013ooooo00?o0000oooooooo
ool04?ooool00ooo003oooooooooo`3Tooooo`03ool00?oooooooooo00cooooo00?o0000oooooooo
ool01?ooool0013ooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`3Tooooo`03ool0
0?oooooooooo00cooooo00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool04?oo
ool00ooo003oooooooooo`3Tooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool01?oo
ool0013ooooo0_l0000Aooooo`03ool00?oooooooooo0>Cooooo00?oo`00ooooooooool02oooool2
o`0000Kooooo000@ooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0i?ooool00ooo
003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03o`000?oooooooooo013o
oooo00?oo`00ooooooooool0i?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00Co
oooo000@ooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0i?ooool00ooo003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03o`000?oooooooooo013ooooo00?o
o`00ooooooooool0i?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo000@
ooooo`;o00004Oooool00ooo003oooooooooo`3Tooooo`03ool00?oooooooooo00_ooooo0_l00006
ooooo`004?ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo0>Cooooo00?oo`00oooo
ooooool03?ooool00ol0003oooooooooo`04ooooo`004?ooool00ol0003oooooooooo`0@ooooo`03
ool00?oooooooooo0>Cooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`04ooooo`00
4?ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo0>Cooooo00?oo`00ooooooooool0
3?ooool00ol0003oooooooooo`04ooooo`004?ooool00ol0003oooooooooo`0@ooooo`03ool00?oo
oooooooo0>Cooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`04ooooo`004?ooool0
0ol0003oooooooooo`0@ooooo`03ool00?oooooooooo0>Cooooo00?oo`00ooooooooool03?ooool0
0ol0003oooooooooo`04ooooo`004?ooool2o`00017ooooo00?oo`00ooooooooool0i?ooool00ooo
003oooooooooo`0;ooooo`;o00001_ooool0013ooooo00?o0000ooooooooool04?ooool00ooo003o
ooooooooo`3Tooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool01?ooool000Sooooo
0ol00005ooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0i?ooool00ooo003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Cooooo0007ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo0>Cooooo00?oo`00ooooooooool0
3?ooool00ol0003oooooooooo`04ooooo`002oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo013ooooo00?oo`00ooooooooool0i?ooool00ooo003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Cooooo000;ooooo`03o`000?oooooooooo00;ooooo0ol0000@ooooo`03ool00?oooooo
oooo0>Cooooo00?oo`00ooooooooool02oooool2o`0000Kooooo0007ooooo`Co00001Oooool00ol0
003oooooooooo`0@ooooo`03ool00?oooooooooo0>Cooooo00?oo`00ooooooooool03?ooool00ol0
003oooooooooo`04ooooo`001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013o
oooo00?oo`00ooooooooool0i?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00Co
oooo0007ooooo`Go00001?ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo0>Cooooo
00?oo`00ooooooooool03?ooool00ol0003oooooooooo`04ooooo`004?ooool00ol0003ooooooooo
o`0@ooooo`03ool00?oooooooooo0>Cooooo00?oo`00ooooooooool03?ooool00ol0003ooooooooo
o`04ooooo`004?ooool2o`00017ooooo00?oo`00ooooooooool0i?ooool00ooo003oooooooooo`0;
ooooo`;o00001_ooool0013ooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`3Toooo
o`03ool00?oooooooooo00cooooo00?o0000ooooooooool01?ooool0013ooooo00?o0000oooooooo
ool04?ooool00ooo003oooooooooo`3Tooooo`03ool00?oooooooooo00cooooo00?o0000oooooooo
ool01?ooool0013ooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`3Tooooo`03ool0
0?oooooooooo00cooooo00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool04?oo
ool00ooo003oooooooooo`3Tooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool01?oo
ool0013ooooo0_l0000Aooooo`03ool00?oooooooooo0>Cooooo00?oo`00ooooooooool02oooool2
o`0000Kooooo000@ooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0i?ooool00ooo
003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03o`000?oooooooooo013o
oooo00?oo`00ooooooooool0i?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00Co
oooo000@ooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0i?ooool00ooo003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03o`000?oooooooooo013ooooo00?o
o`00ooooooooool0i?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo000@
ooooo`;o00004Oooool00ooo003oooooooooo`3Tooooo`03ool00?oooooooooo00_ooooo0_l00006
ooooo`004?ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo0>Cooooo00?oo`00oooo
ooooool03?ooool00ol0003oooooooooo`04ooooo`004?ooool00ol0003oooooooooo`0@ooooo`03
ool00?oooooooooo0>Cooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`04ooooo`00
4?ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo0>Cooooo00?oo`00ooooooooool0
3?ooool00ol0003oooooooooo`04ooooo`004?ooool00ol0003oooooooooo`0@ooooo`03ool00?oo
oooooooo0>Cooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`04ooooo`004?ooool0
0ol0003oooooooooo`0@ooooo`03ool00?oooooooooo0>Cooooo00?oo`00ooooooooool03?ooool0
0ol0003oooooooooo`04ooooo`004?ooool2o`00017ooooo00?oo`00ooooooooool0i?ooool00ooo
003oooooooooo`0;ooooo`;o00001_ooool0013ooooo00?o0000ooooooooool04?ooool00ooo003o
ooooooooo`3Tooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool01?ooool000;ooooo
0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo0>Cooooo
00?oo`00ooooooooool03?ooool00ol0003oooooooooo`04ooooo`000oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool04?ooool00ooo003ooooo
ooooo`3Tooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool01?ooool000?ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo013ooooo
00?oo`00ooooooooool0i?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo
0003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool3o`00013ooooo
00?oo`00ooooooooool0i?ooool00ooo003oooooooooo`0;ooooo`;o00001_ooool000?ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo013ooooo
00?oo`00ooooooooool0i?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo
0002ooooo`;o00001?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo013ooooo
00?oo`00ooooooooool0i?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo
0003ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo013ooooo00?o
o`00ooooooooool0i?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo000@
ooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0i?ooool00ooo003oooooooooo`0<
ooooo`03o`000?oooooooooo00Cooooo000@ooooo`;o00004Oooool00ooo003oooooooooo`3Toooo
o`03ool00?oooooooooo00_ooooo0_l00006ooooo`004?ooool00ol0003oooooooooo`0@ooooo`03
ool00?oooooooooo0>Cooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`04ooooo`00
4?ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo0>Cooooo00?oo`00ooooooooool0
3?ooool00ol0003oooooooooo`04ooooo`004?ooool00ol0003oooooooooo`0@ooooo`03ool00?oo
oooooooo0>Cooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`04ooooo`004?ooool0
0ol0003oooooooooo`0@ooooo`03ool00?oooooooooo0>Cooooo00?oo`00ooooooooool03?ooool0
0ol0003oooooooooo`04ooooo`004?ooool2o`00017ooooo00?oo`00ooooooooool0i?ooool00ooo
003oooooooooo`0;ooooo`;o00001_ooool0013ooooo00?o0000ooooooooool04?ooool00ooo003o
ooooooooo`3Tooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool01?ooool0013ooooo
00?o0000ooooooooool04?ooool00ooo003oooooooooo`3Tooooo`03ool00?oooooooooo00cooooo
00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool04?ooool00ooo003ooooooooo
o`3Tooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool01?ooool0013ooooo00?o0000
ooooooooool04?ooool00ooo003oooooooooo`3Tooooo`03ool00?oooooooooo00cooooo00?o0000
ooooooooool01?ooool0013ooooo0_l0000Aooooo`03ool00?oooooooooo0>Cooooo00?oo`00oooo
ooooool02oooool2o`0000Kooooo000@ooooo`03o`000?oooooooooo013ooooo00?oo`00oooooooo
ool0i?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03o`00
0?oooooooooo013ooooo00?oo`00ooooooooool0i?ooool00ooo003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Cooooo000@ooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0i?oo
ool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03o`000?oooooo
oooo013ooooo00?oo`00ooooooooool0i?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Cooooo000@ooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0i?ooool00ooo
003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo000@ooooo`;o00004Oooool00ooo003o
ooooooooo`3Tooooo`03ool00?oooooooooo00_ooooo0_l00006ooooo`004?ooool00ol0003ooooo
ooooo`0@ooooo`03ool00?oooooooooo0>Cooooo00?oo`00ooooooooool03?ooool00ol0003ooooo
ooooo`04ooooo`000_ooool3o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo013ooooo00?o
o`00ooooooooool0i?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo0003
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo013ooooo00?oo`00ooooooooool0i?ooool00ooo003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Cooooo0003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0@ooooo`03ool00?oooooooooo0>Cooooo00?oo`00ooooooooool03?ooool0
0ol0003oooooooooo`04ooooo`000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo0ol0000@ooooo`03ool00?oooooooooo0>Cooooo00?oo`00ooooooooool02oooool2o`00
00Kooooo0003ooooo`04o`000?ooooooooooooooo`Co00001Oooool00ol0003oooooooooo`0@oooo
o`03ool00?oooooooooo0>Cooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`04oooo
o`000_ooool2o`0000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@ooooo`03
ool00?oooooooooo0>Cooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`04ooooo`00
0oooool01?l0003oooooooooooooool5o`0000Cooooo00?o0000ooooooooool04?ooool00ooo003o
ooooooooo`3Tooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool01?ooool0013ooooo
00?o0000ooooooooool04?ooool00ooo003oooooooooo`3Tooooo`03ool00?oooooooooo00cooooo
00?o0000ooooooooool01?ooool0013ooooo0_l0000Aooooo`03ool00?oooooooooo0>Cooooo00?o
o`00ooooooooool02oooool2o`0000Kooooo000@ooooo`03o`000?oooooooooo013ooooo00?oo`00
ooooooooool0i?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo000@oooo
o`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0i?ooool00ooo003oooooooooo`0<oooo
o`03o`000?oooooooooo00Cooooo000@ooooo`03o`000?oooooooooo013ooooo00?oo`00oooooooo
ool0i?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03o`00
0?oooooooooo013ooooo00?oo`00ooooooooool0i?ooool00ooo003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Cooooo000@ooooo`;o00004Oooool00ooo003oooooooooo`3Tooooo`03ool00?oo
oooooooo00_ooooo0_l00006ooooo`004?ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooo
oooo0>Cooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`04ooooo`004?ooool00ol0
003oooooooooo`0@ooooo`03ool00?oooooooooo0>Cooooo00?oo`00ooooooooool03?ooool00ol0
003oooooooooo`04ooooo`004?ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo0>Co
oooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`04ooooo`004?ooool00ol0003ooooo
ooooo`0@ooooo`03ool00?oooooooooo0>Cooooo00?oo`00ooooooooool03?ooool00ol0003ooooo
ooooo`04ooooo`004?ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo0>Cooooo00?o
o`00ooooooooool03?ooool00ol0003oooooooooo`04ooooo`004?ooool2o`00017ooooo00?oo`00
ooooooooool0i?ooool00ooo003oooooooooo`0;ooooo`;o00001_ooool0013ooooo00?o0000oooo
ooooool04?ooool00ooo003oooooooooo`3Tooooo`03ool00?oooooooooo00cooooo00?o0000oooo
ooooool01?ooool0013ooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`3Tooooo`03
ool00?oooooooooo00cooooo00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool0
4?ooool00ooo003oooooooooo`3Tooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool0
1?ooool0013ooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`3Tooooo`03ool00?oo
oooooooo00cooooo00?o0000ooooooooool01?ooool0013ooooo0_l0000Aooooo`03ool00?oooooo
oooo0>Cooooo00?oo`00ooooooooool02oooool2o`0000Kooooo000@ooooo`03o`000?oooooooooo
013ooooo00?oo`00ooooooooool0i?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo
00Cooooo00000ooooooo0000o`000003o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo013o
oooo00?oo`00ooooooooool0i?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00Co
oooo0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`0@ooooo`03ool00?oooooooooo0>Cooooo00?oo`00ooooooooool03?ooool00ol0
003oooooooooo`04ooooo`000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`3Tooooo`03ool00?oooooooooo
00cooooo00?o0000ooooooooool01?ooool000Cooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo00;ooooo0ol0000@ooooo`03ool00?oooooooooo0>Cooooo00?oo`00oooo
ooooool02oooool2o`0000Kooooo00000ooooooo0000ooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo
0>Cooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`04ooooo`0000?oooooo`000?oo
ool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool04?ooool00ooo003oooooooooo`3Tooooo`03ool00?oooooooooo00cooooo00?o0000oooo
ooooool01?ooool000;ooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`0@ooooo`03
ool00?oooooooooo0>Cooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`04ooooo`00
4?ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo0>Cooooo00?oo`00ooooooooool0
3?ooool00ol0003oooooooooo`04ooooo`004?ooool2o`00017ooooo00?oo`00ooooooooool0i?oo
ool00ooo003oooooooooo`0;ooooo`;o00001_ooool0013ooooo00?o0000ooooooooool04?ooool0
0ooo003oooooooooo`3Tooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool01?ooool0
013ooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`3Tooooo`03ool00?oooooooooo
00cooooo00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool04?ooool00ooo003o
ooooooooo`3Tooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool01?ooool0013ooooo
00?o0000ooooooooool04?ooool00ooo003oooooooooo`3Tooooo`03ool00?oooooooooo00cooooo
00?o0000ooooooooool01?ooool0013ooooo0_l0000Aooooo`03ool00?oooooooooo0>Cooooo00?o
o`00ooooooooool02oooool2o`0000Kooooo000@ooooo`03o`000?oooooooooo013ooooo00?oo`00
ooooooooool0i?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo000@oooo
o`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0i?ooool00ooo003oooooooooo`0<oooo
o`03o`000?oooooooooo00Cooooo000@ooooo`03o`000?oooooooooo013ooooo00?oo`00oooooooo
ool0i?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03o`00
0?oooooooooo013ooooo00?oo`00ooooooooool0i?ooool00ooo003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Cooooo000@ooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0i?oo
ool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo000@ooooo`;o00004Oooool0
0ooo003oooooooooo`3Tooooo`03ool00?oooooooooo00_ooooo0_l00006ooooo`004?ooool00ol0
003oooooooooo`0@ooooo`03ool00?oooooooooo0>Cooooo00?oo`00ooooooooool03?ooool00ol0
003oooooooooo`04ooooo`004?ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo0>Co
oooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`04ooooo`004?ooool00ol0003ooooo
ooooo`0@ooooo`03ool00?oooooooooo0>Cooooo00?oo`00ooooooooool03?ooool00ol0003ooooo
ooooo`04ooooo`004?ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo0>Cooooo00?o
o`00ooooooooool03?ooool00ol0003oooooooooo`04ooooo`004?ooool2o`00017ooooo00?oo`00
ooooooooool0i?ooool00ooo003oooooooooo`0;ooooo`;o00001_ooool0013ooooo00?o0000oooo
ooooool04?ooool00ooo003oooooooooo`3Tooooo`03ool00?oooooooooo00cooooo00?o0000oooo
ooooool01?ooool00003ooooool0003o000000?o00000_ooool3o`0000Gooooo00?o0000oooooooo
ool04?ooool00ooo003oooooooooo`3Tooooo`03ool00?oooooooooo00cooooo00?o0000oooooooo
ool01?ooool000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`3Tooooo`03ool00?oooooooooo
00cooooo00?o0000ooooooooool01?ooool000?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0i?ooool00ooo003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo0004ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool3o`00013ooooo00?oo`00ooooooooool0i?ooool00ooo003ooooo
ooooo`0;ooooo`;o00001_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooool000000ol0
0005ooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0i?ooool00ooo003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
000000Sooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`3Tooooo`03ool00?oooooo
oooo00cooooo00?o0000ooooooooool01?ooool000;ooooo0ol00002ooooo`Go00001?ooool00ol0
003oooooooooo`0@ooooo`03ool00?oooooooooo0>Cooooo00?oo`00ooooooooool03?ooool00ol0
003oooooooooo`04ooooo`004?ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo0>Co
oooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`04ooooo`004?ooool2o`00017ooooo
00?oo`00ooooooooool0i?ooool00ooo003oooooooooo`0;ooooo`;o00001_ooool0013ooooo00?o
0000ooooooooool04?ooool00ooo003oooooooooo`3Tooooo`03ool00?oooooooooo00cooooo00?o
0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`3T
ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool01?ooool0013ooooo00?o0000oooo
ooooool04?ooool00ooo003oooooooooo`3Tooooo`03ool00?oooooooooo00cooooo00?o0000oooo
ooooool01?ooool0013ooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`3Tooooo`03
ool00?oooooooooo00cooooo00?o0000ooooooooool01?ooool0013ooooo0_l0000Aooooo`03ool0
0?oooooooooo0>Cooooo00?oo`00ooooooooool02oooool2o`0000Kooooo000@ooooo`03o`000?oo
oooooooo013ooooo00?oo`00ooooooooool0i?ooool00ooo003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Cooooo000@ooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0i?ooool0
0ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03o`000?oooooooooo
013ooooo00?oo`00ooooooooool0i?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo
00Cooooo000@ooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0i?ooool00ooo003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03o`000?oooooooooo013ooooo
00?oo`00ooooooooool0i?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo
000@ooooo`;o00004Oooool00ooo003oooooooooo`3Tooooo`03ool00?oooooooooo00_ooooo0_l0
0006ooooo`004?ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo0>Cooooo00?oo`00
ooooooooool03?ooool00ol0003oooooooooo`04ooooo`004?ooool00ol0003oooooooooo`0@oooo
o`03ool00?oooooooooo0>Cooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`04oooo
o`004?ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo0>Cooooo00?oo`00oooooooo
ool03?ooool00ol0003oooooooooo`04ooooo`004?ooool00ol0003oooooooooo`0@ooooo`03ool0
0?oooooooooo0>Cooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`04ooooo`004?oo
ool2o`00017ooooo00?oo`00ooooooooool0i?ooool00ooo003oooooooooo`0;ooooo`;o00001_oo
ool0013ooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`3Tooooo`03ool00?oooooo
oooo00cooooo00?o0000ooooooooool01?ooool000;ooooo0ol00004ooooo`;o00001Oooool00ol0
003oooooooooo`0@ooooo`03ool00?oooooooooo0>Cooooo00?oo`00ooooooooool03?ooool00ol0
003oooooooooo`04ooooo`0000?oooooo`000?ooool00_ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`3Toooo
o`03ool00?oooooooooo00cooooo00?o0000ooooooooool01?ooool000Gooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo0ooo003Toooo
o`?oo`003Oooool00ol0003oooooooooo`04ooooo`000oooool2o`0000?ooooo00Co0000oooooooo
oooo00001?ooool3o`0000oooooo0ooo003Tooooo`?oo`003?ooool2o`0000Kooooo0005ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?oooo
o`?oo`00i?ooool3ool000gooooo00?o0000ooooooooool01?ooool00003ooooool0003ooooo00;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooool000001_ooool000;ooooo0ol00004ooooo`;o00001Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooo000000Kooooo000@oooooooo00002ol00006ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.32154, -3.11567, \
0.233424, 0.192046}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Phase plot of DFT as a function of index k", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fft\  = \ DFT[xd];\)\), "\n", 
    \(\(g4 = 
        DiscreteListPlot[\({#[\([1]\)], \ 
                Arg[#[\([2]\)] + 0.0000001]} &\)\  /@ \ fft, Red, \ 
          PlotRange \[Rule] {\(-\[Pi]\), \ \[Pi]}, \ Frame \[Rule] True, \ 
          Axes \[Rule] False];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0161421 0.309017 0.0983632 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18523 -0.0125 -6 -9 ]
[.18523 -0.0125 6 0 ]
[.34665 -0.0125 -6 -9 ]
[.34665 -0.0125 6 0 ]
[.50807 -0.0125 -6 -9 ]
[.50807 -0.0125 6 0 ]
[.66949 -0.0125 -6 -9 ]
[.66949 -0.0125 6 0 ]
[.83091 -0.0125 -6 -9 ]
[.83091 -0.0125 6 0 ]
[.99233 -0.0125 -6 -9 ]
[.99233 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01393 -12 -4.5 ]
[-0.0125 .01393 0 4.5 ]
[-0.0125 .11229 -12 -4.5 ]
[-0.0125 .11229 0 4.5 ]
[-0.0125 .21065 -12 -4.5 ]
[-0.0125 .21065 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40738 -6 -4.5 ]
[-0.0125 .40738 0 4.5 ]
[-0.0125 .50574 -6 -4.5 ]
[-0.0125 .50574 0 4.5 ]
[-0.0125 .60411 -6 -4.5 ]
[-0.0125 .60411 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18523 0 m
.18523 .00625 L
s
[(10)] .18523 -0.0125 0 1 Mshowa
.34665 0 m
.34665 .00625 L
s
[(20)] .34665 -0.0125 0 1 Mshowa
.50807 0 m
.50807 .00625 L
s
[(30)] .50807 -0.0125 0 1 Mshowa
.66949 0 m
.66949 .00625 L
s
[(40)] .66949 -0.0125 0 1 Mshowa
.83091 0 m
.83091 .00625 L
s
[(50)] .83091 -0.0125 0 1 Mshowa
.99233 0 m
.99233 .00625 L
s
[(60)] .99233 -0.0125 0 1 Mshowa
.125 Mabswid
.05609 0 m
.05609 .00375 L
s
.08838 0 m
.08838 .00375 L
s
.12066 0 m
.12066 .00375 L
s
.15295 0 m
.15295 .00375 L
s
.21751 0 m
.21751 .00375 L
s
.2498 0 m
.2498 .00375 L
s
.28208 0 m
.28208 .00375 L
s
.31437 0 m
.31437 .00375 L
s
.37893 0 m
.37893 .00375 L
s
.41122 0 m
.41122 .00375 L
s
.4435 0 m
.4435 .00375 L
s
.47579 0 m
.47579 .00375 L
s
.54036 0 m
.54036 .00375 L
s
.57264 0 m
.57264 .00375 L
s
.60492 0 m
.60492 .00375 L
s
.63721 0 m
.63721 .00375 L
s
.70178 0 m
.70178 .00375 L
s
.73406 0 m
.73406 .00375 L
s
.76634 0 m
.76634 .00375 L
s
.79863 0 m
.79863 .00375 L
s
.8632 0 m
.8632 .00375 L
s
.89548 0 m
.89548 .00375 L
s
.92776 0 m
.92776 .00375 L
s
.96005 0 m
.96005 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01393 m
.00625 .01393 L
s
[(-3)] -0.0125 .01393 1 0 Mshowa
0 .11229 m
.00625 .11229 L
s
[(-2)] -0.0125 .11229 1 0 Mshowa
0 .21065 m
.00625 .21065 L
s
[(-1)] -0.0125 .21065 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .40738 m
.00625 .40738 L
s
[(1)] -0.0125 .40738 1 0 Mshowa
0 .50574 m
.00625 .50574 L
s
[(2)] -0.0125 .50574 1 0 Mshowa
0 .60411 m
.00625 .60411 L
s
[(3)] -0.0125 .60411 1 0 Mshowa
.125 Mabswid
0 .0336 m
.00375 .0336 L
s
0 .05327 m
.00375 .05327 L
s
0 .07295 m
.00375 .07295 L
s
0 .09262 m
.00375 .09262 L
s
0 .13196 m
.00375 .13196 L
s
0 .15164 m
.00375 .15164 L
s
0 .17131 m
.00375 .17131 L
s
0 .19098 m
.00375 .19098 L
s
0 .23033 m
.00375 .23033 L
s
0 .25 m
.00375 .25 L
s
0 .26967 m
.00375 .26967 L
s
0 .28934 m
.00375 .28934 L
s
0 .32869 m
.00375 .32869 L
s
0 .34836 m
.00375 .34836 L
s
0 .36803 m
.00375 .36803 L
s
0 .38771 m
.00375 .38771 L
s
0 .42705 m
.00375 .42705 L
s
0 .44673 m
.00375 .44673 L
s
0 .4664 m
.00375 .4664 L
s
0 .48607 m
.00375 .48607 L
s
0 .52542 m
.00375 .52542 L
s
0 .54509 m
.00375 .54509 L
s
0 .56476 m
.00375 .56476 L
s
0 .58443 m
.00375 .58443 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18523 .61178 m
.18523 .61803 L
s
.34665 .61178 m
.34665 .61803 L
s
.50807 .61178 m
.50807 .61803 L
s
.66949 .61178 m
.66949 .61803 L
s
.83091 .61178 m
.83091 .61803 L
s
.99233 .61178 m
.99233 .61803 L
s
.125 Mabswid
.05609 .61428 m
.05609 .61803 L
s
.08838 .61428 m
.08838 .61803 L
s
.12066 .61428 m
.12066 .61803 L
s
.15295 .61428 m
.15295 .61803 L
s
.21751 .61428 m
.21751 .61803 L
s
.2498 .61428 m
.2498 .61803 L
s
.28208 .61428 m
.28208 .61803 L
s
.31437 .61428 m
.31437 .61803 L
s
.37893 .61428 m
.37893 .61803 L
s
.41122 .61428 m
.41122 .61803 L
s
.4435 .61428 m
.4435 .61803 L
s
.47579 .61428 m
.47579 .61803 L
s
.54036 .61428 m
.54036 .61803 L
s
.57264 .61428 m
.57264 .61803 L
s
.60492 .61428 m
.60492 .61803 L
s
.63721 .61428 m
.63721 .61803 L
s
.70178 .61428 m
.70178 .61803 L
s
.73406 .61428 m
.73406 .61803 L
s
.76634 .61428 m
.76634 .61803 L
s
.79863 .61428 m
.79863 .61803 L
s
.8632 .61428 m
.8632 .61803 L
s
.89548 .61428 m
.89548 .61803 L
s
.92776 .61428 m
.92776 .61803 L
s
.96005 .61428 m
.96005 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01393 m
1 .01393 L
s
.99375 .11229 m
1 .11229 L
s
.99375 .21065 m
1 .21065 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .40738 m
1 .40738 L
s
.99375 .50574 m
1 .50574 L
s
.99375 .60411 m
1 .60411 L
s
.125 Mabswid
.99625 .0336 m
1 .0336 L
s
.99625 .05327 m
1 .05327 L
s
.99625 .07295 m
1 .07295 L
s
.99625 .09262 m
1 .09262 L
s
.99625 .13196 m
1 .13196 L
s
.99625 .15164 m
1 .15164 L
s
.99625 .17131 m
1 .17131 L
s
.99625 .19098 m
1 .19098 L
s
.99625 .23033 m
1 .23033 L
s
.99625 .25 m
1 .25 L
s
.99625 .26967 m
1 .26967 L
s
.99625 .28934 m
1 .28934 L
s
.99625 .32869 m
1 .32869 L
s
.99625 .34836 m
1 .34836 L
s
.99625 .36803 m
1 .36803 L
s
.99625 .38771 m
1 .38771 L
s
.99625 .42705 m
1 .42705 L
s
.99625 .44673 m
1 .44673 L
s
.99625 .4664 m
1 .4664 L
s
.99625 .48607 m
1 .48607 L
s
.99625 .52542 m
1 .52542 L
s
.99625 .54509 m
1 .54509 L
s
.99625 .56476 m
1 .56476 L
s
.99625 .58443 m
1 .58443 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .30902 m
.02381 .30902 L
s
.03995 .30902 m
.03995 .30902 L
s
.05609 .30902 m
.05609 .30902 L
s
.07224 .30902 m
.07224 .30902 L
s
.08838 .30902 m
.08838 .30902 L
s
.10452 .30902 m
.10452 .30902 L
s
.12066 .30902 m
.12066 .30902 L
s
.1368 .30902 m
.1368 .30902 L
s
.15295 .30902 m
.15295 .30902 L
s
.16909 .30902 m
.16909 .30902 L
s
.18523 .30902 m
.18523 .30902 L
s
.20137 .30902 m
.20137 .30902 L
s
.21751 .30902 m
.21751 .30902 L
s
.23366 .30902 m
.23366 .30902 L
s
.2498 .30902 m
.2498 .30902 L
s
.26594 .30902 m
.26594 .30902 L
s
.28208 .30902 m
.28208 .30902 L
s
.29822 .30902 m
.29822 .30902 L
s
.31437 .30902 m
.31437 .30902 L
s
.33051 .30902 m
.33051 .30902 L
s
.34665 .30902 m
.34665 .30902 L
s
.36279 .30902 m
.36279 .30902 L
s
.37893 .30902 m
.37893 .30902 L
s
.39508 .30902 m
.39508 .30902 L
s
.41122 .30902 m
.41122 .30902 L
s
.42736 .30902 m
.42736 .30902 L
s
.4435 .30902 m
.4435 .30902 L
s
.45964 .30902 m
.45964 .30902 L
s
.47579 .30902 m
.47579 .30902 L
s
.49193 .30902 m
.49193 .30902 L
s
.50807 .30902 m
.50807 .30902 L
s
.52421 .30902 m
.52421 .30902 L
s
.54036 .30902 m
.54036 .30902 L
s
.5565 .30902 m
.5565 .30902 L
s
.57264 .30902 m
.57264 .30902 L
s
.58878 .30902 m
.58878 .30902 L
s
.60492 .30902 m
.60492 .30902 L
s
.62107 .30902 m
.62107 .30902 L
s
.63721 .30902 m
.63721 .30902 L
s
.65335 .30902 m
.65335 .30902 L
s
.66949 .30902 m
.66949 .30902 L
s
.68563 .30902 m
.68563 .30902 L
s
.70178 .30902 m
.70178 .30902 L
s
.71792 .30902 m
.71792 .30902 L
s
.73406 .30902 m
.73406 .30902 L
s
.7502 .30902 m
.7502 .30902 L
s
.76634 .30902 m
.76634 .30902 L
s
.78249 .30902 m
.78249 .30902 L
s
.79863 .30902 m
.79863 .30902 L
s
.81477 .30902 m
.81477 .30902 L
s
.83091 .30902 m
.83091 .30902 L
s
.84705 .30902 m
.84705 .30902 L
s
.8632 .30902 m
.8632 .30902 L
s
.87934 .30902 m
.87934 .30902 L
s
.89548 .30902 m
.89548 .30902 L
s
.91162 .30902 m
.91162 .30902 L
s
.92776 .30902 m
.92776 .30902 L
s
.94391 .30902 m
.94391 .30902 L
s
.96005 .30902 m
.96005 .30902 L
s
.97619 .30902 m
.97619 .30902 L
s
.015 w
.02381 .30902 Mdot
.03995 .30902 Mdot
.05609 .30902 Mdot
.07224 .30902 Mdot
.08838 .30902 Mdot
.10452 .30902 Mdot
.12066 .30902 Mdot
.1368 .30902 Mdot
.15295 .30902 Mdot
.16909 .30902 Mdot
.18523 .30902 Mdot
.20137 .30902 Mdot
.21751 .30902 Mdot
.23366 .30902 Mdot
.2498 .30902 Mdot
.26594 .30902 Mdot
.28208 .30902 Mdot
.29822 .30902 Mdot
.31437 .30902 Mdot
.33051 .30902 Mdot
.34665 .30902 Mdot
.36279 .30902 Mdot
.37893 .30902 Mdot
.39508 .30902 Mdot
.41122 .30902 Mdot
.42736 .30902 Mdot
.4435 .30902 Mdot
.45964 .30902 Mdot
.47579 .30902 Mdot
.49193 .30902 Mdot
.50807 .30902 Mdot
.52421 .30902 Mdot
.54036 .30902 Mdot
.5565 .30902 Mdot
.57264 .30902 Mdot
.58878 .30902 Mdot
.60492 .30902 Mdot
.62107 .30902 Mdot
.63721 .30902 Mdot
.65335 .30902 Mdot
.66949 .30902 Mdot
.68563 .30902 Mdot
.70178 .30902 Mdot
.71792 .30902 Mdot
.73406 .30902 Mdot
.7502 .30902 Mdot
.76634 .30902 Mdot
.78249 .30902 Mdot
.79863 .30902 Mdot
.81477 .30902 Mdot
.83091 .30902 Mdot
.84705 .30902 Mdot
.8632 .30902 Mdot
.87934 .30902 Mdot
.89548 .30902 Mdot
.91162 .30902 Mdot
.92776 .30902 Mdot
.94391 .30902 Mdot
.96005 .30902 Mdot
.97619 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005Oooool2o`0002Gooooo0ol00004ooooo`;o00008Oooool5o`0000?ooooo0_l0000Roooo
o`?o00001?ooool2o`0002?ooooo0ol00003ooooo`;o00008Oooool3o`0000Cooooo0_l0000Roooo
o`?o00001?ooool2o`0000Gooooo000Dooooo`04o`000?ooooooooooo`0002Gooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool0000Qooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00008?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00008oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool07Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool001Cooooo00Co0000oooooooo
oooo00009Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002;ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000Tooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool07_ooool5o`0000;ooooo00Co0000oooooooooooo00008oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000Cooooo000Dooooo`04o`000?ooooooooooo`0002Gooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool0000Sooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`0Pooooo`;o00000oooool01?l0003oooooooooool0000Poooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00008oooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo01kooooo1?l00003ooooo`04o`000?ooooooooooo`0000Co
oooo000Dooooo`04o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000Pooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
000Tooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool07oooool00ol0003ooooo
o`000003ooooo`04o`000?ooooooooooo`0001oooooo1?l00003ooooo`04o`000?ooooooooooo`00
023ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`005?ooool01?l0
003oooooooooool0000Tooooo`;o00001?ooool01?l0003oooooooooool0000Pooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool0000Pooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool0000Rooooo`;o00000oooool01?l0003oooooooooool0
000Oooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00008Oooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`0000Cooooo000Eooooo`;o00009_ooool00ol0003ooooo
ooooo`03ooooo`;o00008_ooool3o`0000Cooooo0_l0000Rooooo`?o00001?ooool2o`0002Cooooo
00?o0000ooooooooool00_ooool2o`00023ooooo1Ol00003ooooo`;o00008oooool2o`0000Cooooo
0_l00005ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
4?ooooooo`0000_o00001_ooool000Sooooo0ol00005ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooool000001_ooool000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooool000001_ooool00003ooooool0003o000000?o00001Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04
ooooo`002Oooool2o`0000Gooooo0ol0003oooooo`Kooooo0_l00006ooooo`002oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`00
1oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0ooooool7ooooo`03
o`000?oooooooooo00Cooooo0008ooooo`?o00001Oooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00Cooooo000@ooooo`;o0000ooooool7ooooo`;o00001_ooool0013ooooo00?o0000oooo
ooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03o`000?oooooooooo0?oo
oooo1oooool00ol0003oooooooooo`04ooooo`004?ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00Cooooo000@ooooo`;o0000ooooool7ooooo`;o00001_ooool0013ooooo00?o0000oooo
ooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03o`000?oooooooooo0?oo
oooo1oooool00ol0003oooooooooo`04ooooo`004?ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00Cooooo000@ooooo`;o0000ooooool7ooooo`;o00001_ooool0013ooooo00?o0000oooo
ooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03o`000?oooooooooo0?oo
oooo1oooool00ol0003oooooooooo`04ooooo`004?ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00Cooooo000@ooooo`;o0000ooooool7ooooo`;o00001_ooool0013ooooo00?o0000oooo
ooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03o`000?oooooooooo0?oo
oooo1oooool00ol0003oooooooooo`04ooooo`001oooool5o`0000Cooooo00?o0000ooooooooool0
ooooool7ooooo`03o`000?oooooooooo00Cooooo0008ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo00000ooooooo0000o`00
0003o`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o
0000ooooooooool01?ooool000[ooooo00?o0000ooooooooool00oooool3o`000?oooooo1_ooool2
o`0000Kooooo0007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`3o
ooooo`Oooooo00?o0000ooooooooool01?ooool000Oooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`002?ooool3o`00
00Gooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03
o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`004?ooool2o`000?oooooo
1oooool2o`0000Kooooo000@ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooooooo
o`04ooooo`004?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool01?ooool0
013ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03
o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`004?ooool2o`000?oooooo
1oooool2o`0000Kooooo000@ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooooooo
o`04ooooo`004?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool01?ooool0
013ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03
o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`004?ooool2o`000?oooooo
1oooool2o`0000Kooooo000@ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooooooo
o`04ooooo`004?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool01?ooool0
013ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03
o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`004?ooool2o`000?oooooo
1oooool2o`0000Kooooo000@ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooooooo
o`04ooooo`004?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool01?ooool0
00Sooooo0ol00005ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04oooo
o`002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003o
ooooooooo`04ooooo`0000?oooooo`000?l000000ol00003ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo0009ooooo`03o`000?oo
oooooooo00Cooooo0ol0003oooooo`Kooooo0_l00006ooooo`002Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`002?ooool2o`00
00Kooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo0009ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Co
oooo000@ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`004?oo
ool2o`000?oooooo1oooool2o`0000Kooooo000@ooooo`03o`000?oooooooooo0?oooooo1oooool0
0ol0003oooooooooo`04ooooo`004?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000oooo
ooooool01?ooool0013ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Co
oooo000@ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`004?oo
ool2o`000?oooooo1oooool2o`0000Kooooo000@ooooo`03o`000?oooooooooo0?oooooo1oooool0
0ol0003oooooooooo`04ooooo`004?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000oooo
ooooool01?ooool0013ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Co
oooo000@ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`004?oo
ool2o`000?oooooo1oooool2o`0000Kooooo000@ooooo`03o`000?oooooooooo0?oooooo1oooool0
0ol0003oooooooooo`04ooooo`004?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000oooo
ooooool01?ooool0013ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Co
oooo000@ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`004?oo
ool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool01?ooool0013ooooo0_l0003o
ooooo`Oooooo0_l00006ooooo`004?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000oooo
ooooool01?ooool000Wooooo0_l00005ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003o
ooooooooo`04ooooo`002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo0?oo
oooo1oooool00ol0003oooooooooo`04ooooo`002?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00;ooooo0ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`0000Goooooool0
0?oo003oo`00ooooo`03ool00004oooooooo003oo`00ool000;ooooo0ooo00001Oooooooo`00ool0
0?oo003ooooo00?oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo00001?oooooo
o`00ool00?oo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool00004oooooooo003o
o`00ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`000_ooool3ool00005oooo
oooo003oo`00ool00?ooool00ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`0000Goooooool0
0?oo003oo`00ooooo`03ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Co
ooooool00?oo003oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo00001?oooooo
o`00ool00?oo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool000;ooooo0ooo0000
1Oooooooo`00ool00?oo003ooooo00?oo`0000Coooooool00?oo003oo`000_ooool3ool00005oooo
oooo003oo`00ool00?ooool00ooo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool0
0004oooooooo003oo`00ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`000_oo
ool3ool00005oooooooo003oo`00ool00?ooool00ooo00001?ooooooo`00ool00?oo0002ooooo`?o
o`0000Goooooool00?oo003oo`00ooooo`03ool00004oooooooo003oo`00ool000Gooooo00?o0000
ooooooooool01?ooool000Sooooo00Co0000oooooooooooo00001?ooool3o`0000;ooooo0ooo0000
1?ooooooo`00ool00?oo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool00004oooo
oooo003oo`00ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`000_ooool3ool0
0005oooooooo003oo`00ool00?ooool00ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`0000Go
ooooool00?oo003oo`00ooooo`03ool00004oooooooo003oo`00ool000;ooooo0ooo00001Ooooooo
o`00ool00?oo003ooooo00?oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo0000
1?ooooooo`00ool00?oo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool000;ooooo
0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Coooooool00?oo003oo`000_ooool3ool0
0005oooooooo003oo`00ool00?ooool00ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`0000Go
ooooool00?oo003oo`00ooooo`03ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?o
o`0000Coooooool00?oo003oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo0002
ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool00004oooooooo003oo`00ool000;ooooo
0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`000_ooool3ool00005oooooooo003oo`00ool0
0?ooool00ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`0000Goooooool00?oo003oo`00oooo
o`03ool00004oooooooo003oo`00ool000Cooooo0_l00006ooooo`002?ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo00;ooooo0ooo00001?ooooooo`00ool00?oo0002ooooo`?o
o`0000Goooooool00?oo003oo`00ooooo`03ool00004oooooooo003oo`00ool000;ooooo0ooo0000
1Oooooooo`00ool00?oo003ooooo00?oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool0
0ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool0
0004oooooooo003oo`00ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`000_oo
ool3ool00005oooooooo003oo`00ool00?ooool00ooo00001?ooooooo`00ool00?oo0002ooooo`?o
o`0000Goooooool00?oo003oo`00ooooo`03ool000;ooooo0ooo00001Oooooooo`00ool00?oo003o
oooo00?oo`0000Coooooool00?oo003oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool0
0ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool0
00;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Coooooool00?oo003oo`000_oo
ool3ool00005oooooooo003oo`00ool00?ooool00ooo0002ooooo`?oo`0000Goooooool00?oo003o
o`00ooooo`03ool00004oooooooo003oo`00ool000;ooooo0ooo00001Oooooooo`00ool00?oo003o
oooo00?oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo00001?ooooooo`00ool0
0?oo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool00004oooooooo003oo`00ool0
00Gooooo00?o0000ooooooooool01?ooool000Sooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool01?ooool000Wooooo0_l00005ooooo`03
o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`004?ooool00ol0003ooooo
ooooo`3oooooo`Oooooo00?o0000ooooooooool01?ooool0013ooooo0_l0003oooooo`Oooooo0_l0
0006ooooo`004?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool01?ooool0
013ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03
o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`004?ooool00ol0003ooooo
ooooo`3oooooo`Oooooo00?o0000ooooooooool01?ooool0013ooooo0_l0003oooooo`Oooooo0_l0
0006ooooo`004?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool01?ooool0
013ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03
o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`004?ooool00ol0003ooooo
ooooo`3oooooo`Oooooo00?o0000ooooooooool01?ooool0013ooooo0_l0003oooooo`Oooooo0_l0
0006ooooo`004?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool01?ooool0
013ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03
o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`004?ooool00ol0003ooooo
ooooo`3oooooo`Oooooo00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool0oooo
ool7ooooo`03o`000?oooooooooo00Cooooo000@ooooo`;o0000ooooool7ooooo`;o00001_ooool0
013ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo0008ooooo`?o
00001Oooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool01?ooool000Wooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool0
1?ooool000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o
0000ooooooooool01?ooool000Wooooo00?o0000ooooooooool01?ooool3o`000?oooooo1_ooool2
o`0000Kooooo0009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool7oooo
o`03o`000?oooooooooo00Cooooo0008ooooo`;o00001_ooool00ol0003oooooooooo`3oooooo`Oo
oooo00?o0000ooooooooool01?ooool000Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3oooooo`Oooooo00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool0oooo
ool7ooooo`03o`000?oooooooooo00Cooooo000@ooooo`;o0000ooooool7ooooo`;o00001_ooool0
013ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03
o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`004?ooool00ol0003ooooo
ooooo`3oooooo`Oooooo00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool0oooo
ool7ooooo`03o`000?oooooooooo00Cooooo000@ooooo`;o0000ooooool7ooooo`;o00001_ooool0
013ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03
o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`004?ooool00ol0003ooooo
ooooo`3oooooo`Oooooo00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool0oooo
ool7ooooo`03o`000?oooooooooo00Cooooo000@ooooo`;o0000ooooool7ooooo`;o00001_ooool0
013ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03
o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`004?ooool00ol0003ooooo
ooooo`3oooooo`Oooooo00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool0oooo
ool7ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03o`000?oooooooooo0?oooooo1oooool0
0ol0003oooooooooo`04ooooo`004?ooool2o`000?oooooo1oooool2o`0000Kooooo000@ooooo`03
o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`001oooool5o`0000Cooooo
00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo0008ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo
0009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00Cooooo000:ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooo`Kooooo0_l00006
ooooo`001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0ooooool7
ooooo`03o`000?oooooooooo00Cooooo0007ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool01?ooool000Sooooo0ol00005oooo
o`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`004?ooool00ol0003o
ooooooooo`3oooooo`Oooooo00?o0000ooooooooool01?ooool0013ooooo0_l0003oooooo`Oooooo
0_l00006ooooo`004?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool01?oo
ool0013ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo000@oooo
o`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`004?ooool00ol0003o
ooooooooo`3oooooo`Oooooo00?o0000ooooooooool01?ooool0013ooooo0_l0003oooooo`Oooooo
0_l00006ooooo`004?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool01?oo
ool0013ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo000@oooo
o`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`004?ooool00ol0003o
ooooooooo`3oooooo`Oooooo00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool0
ooooool7ooooo`03o`000?oooooooooo00Cooooo000@ooooo`;o0000ooooool7ooooo`;o00001_oo
ool0013ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo000@oooo
o`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`004?ooool00ol0003o
ooooooooo`3oooooo`Oooooo00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool0
ooooool7ooooo`03o`000?oooooooooo00Cooooo000@ooooo`;o0000ooooool7ooooo`;o00001_oo
ool0013ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo0008oooo
o`?o00001Oooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool01?ooool000Oo
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0
003oooooooooo`04ooooo`002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oo
oooo1oooool00ol0003oooooooooo`04ooooo`002Oooool2o`0000Gooooo0ol0003oooooo`Kooooo
0_l00006ooooo`002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo1ooo
ool00ol0003oooooooooo`04ooooo`001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0:?ooool00ol0003oooooo`000006ooooo`002?ooool3o`0000Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooo`000006ooooo`004?ooooooo`0000_o00001_ooool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.36541, -3.6139, 0.233724, \
0.0383558}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Rearrange and scale DFT result", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g5 = 
        DiscreteListPlot[FourierRearrange[Abs[Last\  /@ \ fft], fs], Red, 
          PlotRange \[Rule] All, ImageSize \[Rule] 504, \ 
          Frame \[Rule] True, \ Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g6\  = \ Show[g1, g5];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.0147151 0.0195446 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11244 -6 -4.5 ]
[-0.0125 .11244 0 4.5 ]
[-0.0125 .21016 -12 -4.5 ]
[-0.0125 .21016 0 4.5 ]
[-0.0125 .30788 -12 -4.5 ]
[-0.0125 .30788 0 4.5 ]
[-0.0125 .40561 -12 -4.5 ]
[-0.0125 .40561 0 4.5 ]
[-0.0125 .50333 -12 -4.5 ]
[-0.0125 .50333 0 4.5 ]
[-0.0125 .60105 -12 -4.5 ]
[-0.0125 .60105 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11244 m
.00625 .11244 L
s
[(5)] -0.0125 .11244 1 0 Mshowa
0 .21016 m
.00625 .21016 L
s
[(10)] -0.0125 .21016 1 0 Mshowa
0 .30788 m
.00625 .30788 L
s
[(15)] -0.0125 .30788 1 0 Mshowa
0 .40561 m
.00625 .40561 L
s
[(20)] -0.0125 .40561 1 0 Mshowa
0 .50333 m
.00625 .50333 L
s
[(25)] -0.0125 .50333 1 0 Mshowa
0 .60105 m
.00625 .60105 L
s
[(30)] -0.0125 .60105 1 0 Mshowa
.125 Mabswid
0 .03426 m
.00375 .03426 L
s
0 .0538 m
.00375 .0538 L
s
0 .07335 m
.00375 .07335 L
s
0 .09289 m
.00375 .09289 L
s
0 .13198 m
.00375 .13198 L
s
0 .15153 m
.00375 .15153 L
s
0 .17107 m
.00375 .17107 L
s
0 .19062 m
.00375 .19062 L
s
0 .22971 m
.00375 .22971 L
s
0 .24925 m
.00375 .24925 L
s
0 .2688 m
.00375 .2688 L
s
0 .28834 m
.00375 .28834 L
s
0 .32743 m
.00375 .32743 L
s
0 .34697 m
.00375 .34697 L
s
0 .36652 m
.00375 .36652 L
s
0 .38606 m
.00375 .38606 L
s
0 .42515 m
.00375 .42515 L
s
0 .4447 m
.00375 .4447 L
s
0 .46424 m
.00375 .46424 L
s
0 .48379 m
.00375 .48379 L
s
0 .52287 m
.00375 .52287 L
s
0 .54242 m
.00375 .54242 L
s
0 .56196 m
.00375 .56196 L
s
0 .58151 m
.00375 .58151 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11244 m
1 .11244 L
s
.99375 .21016 m
1 .21016 L
s
.99375 .30788 m
1 .30788 L
s
.99375 .40561 m
1 .40561 L
s
.99375 .50333 m
1 .50333 L
s
.99375 .60105 m
1 .60105 L
s
.125 Mabswid
.99625 .03426 m
1 .03426 L
s
.99625 .0538 m
1 .0538 L
s
.99625 .07335 m
1 .07335 L
s
.99625 .09289 m
1 .09289 L
s
.99625 .13198 m
1 .13198 L
s
.99625 .15153 m
1 .15153 L
s
.99625 .17107 m
1 .17107 L
s
.99625 .19062 m
1 .19062 L
s
.99625 .22971 m
1 .22971 L
s
.99625 .24925 m
1 .24925 L
s
.99625 .2688 m
1 .2688 L
s
.99625 .28834 m
1 .28834 L
s
.99625 .32743 m
1 .32743 L
s
.99625 .34697 m
1 .34697 L
s
.99625 .36652 m
1 .36652 L
s
.99625 .38606 m
1 .38606 L
s
.99625 .42515 m
1 .42515 L
s
.99625 .4447 m
1 .4447 L
s
.99625 .46424 m
1 .46424 L
s
.99625 .48379 m
1 .48379 L
s
.99625 .52287 m
1 .52287 L
s
.99625 .54242 m
1 .54242 L
s
.99625 .56196 m
1 .56196 L
s
.99625 .58151 m
1 .58151 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .01472 m
.02608 .0232 L
.02723 .02697 L
.02847 .03029 L
.02913 .03169 L
.02972 .03272 L
.03001 .03313 L
.03033 .0335 L
.03062 .03378 L
.03089 .03399 L
.03105 .03408 L
.03121 .03416 L
.03131 .03419 L
.0314 .03422 L
.03148 .03424 L
.03156 .03425 L
.03166 .03426 L
.03174 .03427 L
.03184 .03426 L
.03193 .03425 L
.03202 .03424 L
.0321 .03422 L
.03228 .03416 L
.03243 .03409 L
.03257 .03401 L
.0329 .03377 L
.03321 .03345 L
.03355 .03304 L
.03419 .03203 L
.03478 .03086 L
.03611 .02742 L
.03736 .02338 L
.03854 .01911 L
.03907 .01709 L
.03935 .01599 L
.03949 .01544 L
.03962 .01495 L
.03976 .01503 L
.03991 .01561 L
.04023 .01684 L
.04079 .01897 L
.04208 .02367 L
.04327 .0275 L
.04438 .03041 L
.04496 .03166 L
.04559 .03275 L
.04592 .03321 L
.04622 .03357 L
.04652 .03386 L
.04681 .03407 L
Mistroke
.04696 .03415 L
.04712 .03423 L
.04722 .03426 L
.0473 .03428 L
.04738 .0343 L
.04747 .03431 L
.04763 .03432 L
.04771 .03432 L
.0478 .03431 L
.04795 .03428 L
.0481 .03424 L
.04825 .03417 L
.04841 .03409 L
.0487 .03388 L
.04902 .03359 L
.04936 .03318 L
.04998 .03224 L
.05056 .03112 L
.05163 .02847 L
.0528 .02492 L
.05405 .02048 L
.05466 .01817 L
.05522 .01603 L
.05536 .01547 L
.05552 .01485 L
.05567 .01516 L
.05581 .01569 L
.05643 .01812 L
.05776 .02304 L
.05886 .02668 L
.06003 .02996 L
.0607 .03149 L
.06132 .03262 L
.06161 .03307 L
.06194 .0335 L
.06222 .0338 L
.06252 .03407 L
.06267 .03417 L
.06283 .03426 L
.06297 .03433 L
.06311 .03438 L
.06323 .03441 L
.06337 .03443 L
.06352 .03444 L
.06365 .03443 L
.06373 .03442 L
.06381 .0344 L
.06396 .03436 L
.06412 .03429 L
.0643 .0342 L
Mistroke
.06461 .03397 L
.0649 .03368 L
.06554 .03285 L
.06612 .03184 L
.06744 .02875 L
.06864 .02508 L
.06992 .02053 L
.07054 .01816 L
.07085 .01698 L
.07113 .01588 L
.07126 .01536 L
.07139 .01488 L
.07152 .01506 L
.07166 .01561 L
.07223 .01783 L
.07459 .02635 L
.07576 .02972 L
.07684 .03214 L
.07741 .03311 L
.07801 .03389 L
.07833 .03418 L
.07862 .03439 L
.07879 .03447 L
.07894 .03454 L
.07903 .03456 L
.07911 .03458 L
.07921 .0346 L
.07929 .03461 L
.07943 .03461 L
.07958 .03459 L
.07973 .03456 L
.07986 .03452 L
.07998 .03447 L
.08011 .0344 L
.08038 .03423 L
.08066 .03397 L
.08097 .03363 L
.08153 .03284 L
.08217 .03166 L
.08275 .03033 L
.08409 .02657 L
.08525 .0226 L
.08651 .01783 L
.08684 .01656 L
.08701 .01586 L
.08718 .0152 L
.08732 .01479 L
.08747 .01538 L
.08779 .01665 L
.08899 .0213 L
Mistroke
.09124 .02882 L
.09247 .03186 L
.09317 .03314 L
.0935 .03363 L
.09381 .03402 L
.0941 .03432 L
.09437 .03453 L
.09451 .03462 L
.09467 .03471 L
.09475 .03474 L
.09483 .03477 L
.09499 .03482 L
.09506 .03483 L
.09515 .03484 L
.0953 .03484 L
.09545 .03483 L
.09559 .0348 L
.09574 .03475 L
.0959 .03468 L
.09608 .03458 L
.09624 .03447 L
.09684 .03387 L
.09718 .03341 L
.0975 .0329 L
.09869 .03037 L
.09977 .02731 L
.10093 .02342 L
.10206 .01916 L
.10265 .01682 L
.10295 .01562 L
.10303 .0153 L
.10312 .01495 L
.10327 .01512 L
.10342 .01571 L
.10358 .01636 L
.10388 .01753 L
.10442 .01968 L
.10548 .02366 L
.10672 .02783 L
.10787 .03104 L
.10851 .03244 L
.10908 .03348 L
.10972 .03435 L
.11008 .0347 L
.11024 .03482 L
.11041 .03493 L
.11058 .03502 L
.11073 .03508 L
.11087 .03512 L
.11102 .03514 L
Mistroke
.11116 .03514 L
.11128 .03514 L
.11142 .03511 L
.11157 .03507 L
.11173 .035 L
.1119 .03491 L
.11222 .03468 L
.11252 .03438 L
.1128 .03404 L
.11388 .0322 L
.11442 .03096 L
.11502 .02938 L
.11626 .02549 L
.11756 .0207 L
.11809 .01858 L
.11866 .01627 L
.11883 .01558 L
.11892 .01525 L
.11899 .01493 L
.11914 .01508 L
.11929 .01572 L
.11988 .01808 L
.12229 .0271 L
.12347 .03062 L
.12455 .03309 L
.12511 .03405 L
.12564 .03475 L
.12593 .03504 L
.1262 .03525 L
.12634 .03533 L
.1265 .03541 L
.12658 .03544 L
.12666 .03546 L
.12681 .0355 L
.12697 .03551 L
.12712 .03551 L
.1272 .0355 L
.12728 .03549 L
.12736 .03547 L
.12745 .03544 L
.12761 .03537 L
.12777 .03529 L
.12811 .03503 L
.12839 .03475 L
.12869 .03438 L
.1293 .03341 L
.13053 .03068 L
.13165 .02735 L
.13295 .02268 L
.13359 .02019 L
Mistroke
.13416 .01785 L
.13444 .01672 L
.13458 .01612 L
.13473 .01549 L
.13487 .01493 L
.13501 .01511 L
.13515 .01566 L
.13527 .01618 L
.13645 .02101 L
.13774 .02588 L
.13895 .02985 L
.14013 .03287 L
.14079 .03416 L
.14111 .03466 L
.14141 .03505 L
.14168 .03535 L
.14192 .03557 L
.1422 .03576 L
.14234 .03584 L
.14249 .0359 L
.14263 .03593 L
.14278 .03596 L
.14292 .03596 L
.14304 .03595 L
.14319 .03593 L
.14328 .0359 L
.14335 .03587 L
.1435 .03581 L
.14365 .03573 L
.14395 .0355 L
.14424 .03521 L
.14479 .03449 L
.14537 .03346 L
.14601 .03204 L
.14822 .02517 L
.14944 .02038 L
.15004 .01789 L
.15031 .01678 L
.1506 .01556 L
.15067 .01523 L
.15076 .01487 L
.15091 .01519 L
.15099 .01557 L
.15108 .01592 L
.15123 .01659 L
.15192 .01949 L
.15313 .02433 L
.15429 .02853 L
.15553 .03219 L
.15659 .0345 L
Mistroke
.15688 .03499 L
.15719 .03544 L
.15749 .0358 L
.15776 .03606 L
.15806 .03628 L
.15823 .03637 L
.15839 .03643 L
.15853 .03647 L
.15867 .03649 L
.15882 .03649 L
.15897 .03648 L
.15913 .03644 L
.15922 .03641 L
.1593 .03638 L
.15961 .0362 L
.15978 .03607 L
.15996 .03589 L
.1603 .0355 L
.16091 .03457 L
.16156 .03325 L
.16273 .03014 L
.16388 .02623 L
.1651 .02144 L
.16614 .01702 L
.16642 .01578 L
.16658 .01509 L
.16673 .01498 L
.16686 .01557 L
.16701 .01621 L
.16728 .01737 L
.16961 .02691 L
.1708 .03096 L
.17144 .03276 L
.17212 .03438 L
.17277 .03559 L
.17336 .03639 L
.17364 .03668 L
.17379 .0368 L
.17395 .03691 L
.17411 .03699 L
.17424 .03705 L
.17438 .03709 L
.17452 .03712 L
.17466 .03712 L
.17475 .03712 L
.17482 .03711 L
.17498 .03708 L
.17507 .03705 L
.17515 .03701 L
.17529 .03694 L
Mistroke
.17545 .03684 L
.17573 .03661 L
.17607 .03625 L
.17642 .03576 L
.17705 .03463 L
.17818 .03184 L
.1794 .02787 L
.18055 .02343 L
.18161 .01888 L
.18217 .01639 L
.18233 .01566 L
.18248 .01498 L
.18262 .01506 L
.18276 .01573 L
.18403 .02134 L
.18524 .02638 L
.18657 .03115 L
.18717 .03295 L
.18781 .03461 L
.18837 .03578 L
.18897 .03677 L
.18933 .03721 L
.1895 .03738 L
.18965 .03751 L
.1898 .03762 L
.18997 .03772 L
.19006 .03776 L
.19014 .03779 L
.19022 .03781 L
.1903 .03784 L
.19045 .03786 L
.19058 .03786 L
.19066 .03785 L
.19074 .03784 L
.19089 .0378 L
.19105 .03774 L
.19119 .03766 L
.19151 .03742 L
.19181 .03713 L
.19207 .03679 L
.19268 .0358 L
.19324 .03461 L
.19377 .03325 L
.19626 .02441 L
.19741 .01933 L
.19775 .01781 L
.19806 .01636 L
.1982 .01572 L
.19834 .01505 L
.1985 .01512 L
Mistroke
.19865 .0158 L
.20086 .02576 L
.20201 .03022 L
.20323 .03414 L
.20382 .03566 L
.20439 .03683 L
.20489 .03765 L
.20518 .03801 L
.20544 .03828 L
.20572 .0385 L
.20587 .03858 L
.20603 .03865 L
.20616 .03869 L
.20629 .03871 L
.20643 .03872 L
.20658 .03871 L
.20666 .03869 L
.20674 .03867 L
.20682 .03864 L
.20691 .0386 L
.20706 .03852 L
.20723 .03841 L
.20754 .03812 L
.20783 .03778 L
.20846 .03676 L
.20905 .03551 L
.21036 .03171 L
.21156 .02719 L
.21285 .02157 L
.21347 .01864 L
.21378 .01717 L
.21406 .01582 L
.21419 .01517 L
.21431 .01485 L
.21444 .01548 L
.21459 .01617 L
.21515 .01891 L
.21752 .02948 L
.21869 .03367 L
.21977 .03668 L
.22034 .03789 L
.22094 .03885 L
.22126 .03921 L
.22155 .03946 L
.22172 .03957 L
.22188 .03964 L
.22196 .03967 L
.22205 .0397 L
.22214 .03972 L
.22223 .03972 L
Mistroke
.22237 .03972 L
.22252 .0397 L
.22266 .03966 L
.22279 .0396 L
.22291 .03954 L
.22304 .03945 L
.22331 .03922 L
.2236 .0389 L
.22391 .03846 L
.22446 .03744 L
.2251 .03594 L
.22569 .03425 L
.22702 .02946 L
.22827 .02399 L
.22889 .02107 L
.22945 .01829 L
.22972 .01693 L
.22997 .01565 L
.2301 .015 L
.23024 .01512 L
.23039 .01589 L
.23053 .01659 L
.2317 .02241 L
.23299 .02841 L
.23418 .0332 L
.2353 .03681 L
.23587 .03824 L
.23649 .03947 L
.23682 .03997 L
.23711 .04033 L
.23728 .0405 L
.23746 .04064 L
.23763 .04075 L
.23778 .04083 L
.23794 .04088 L
.23809 .0409 L
.23823 .0409 L
.23837 .04089 L
.23853 .04084 L
.23861 .04081 L
.2387 .04077 L
.239 .04056 L
.23915 .04041 L
.2393 .04026 L
.23963 .03982 L
.24023 .03876 L
.24077 .0375 L
.24135 .03586 L
.24387 .02576 L
.24501 .02012 L
Mistroke
.2456 .01701 L
.24574 .01625 L
.2459 .01543 L
.24599 .01496 L
.24607 .0149 L
.24622 .01574 L
.24737 .0218 L
.24843 .02708 L
.24955 .03215 L
.25074 .03662 L
.25137 .0385 L
.25205 .04016 L
.25235 .04074 L
.25267 .04127 L
.25298 .04167 L
.25325 .04195 L
.25341 .04207 L
.25356 .04216 L
.25372 .04223 L
.25381 .04226 L
.25389 .04228 L
.25402 .04229 L
.25417 .04229 L
.25433 .04225 L
.25448 .0422 L
.25456 .04216 L
.25465 .0421 L
.25481 .04199 L
.25512 .04168 L
.25548 .04121 L
.25581 .04065 L
.25637 .03944 L
.25698 .03776 L
.25823 .03331 L
.26057 .02207 L
.26125 .0184 L
.26158 .01655 L
.26174 .01564 L
.26189 .01482 L
.26203 .01542 L
.26216 .01617 L
.26246 .01784 L
.26309 .02133 L
.2653 .03261 L
.26656 .0377 L
.26718 .03971 L
.26774 .04122 L
.26833 .04248 L
.26861 .04293 L
.2689 .04332 L
Mistroke
.26904 .04348 L
.26921 .04363 L
.26935 .04374 L
.26949 .04382 L
.26957 .04386 L
.26965 .04389 L
.26974 .04391 L
.26983 .04393 L
.2699 .04394 L
.26999 .04394 L
.27014 .04391 L
.27022 .04389 L
.27031 .04386 L
.27047 .04378 L
.27064 .04366 L
.27082 .04349 L
.27116 .04309 L
.27147 .0426 L
.27205 .04141 L
.27268 .03972 L
.2739 .03532 L
.27523 .02913 L
.2765 .0222 L
.2771 .01871 L
.27737 .01716 L
.27752 .01627 L
.27766 .01544 L
.27779 .01481 L
.27794 .01569 L
.27824 .0175 L
.27888 .02127 L
.28003 .02784 L
.28135 .03458 L
.28256 .03968 L
.28315 .04165 L
.28379 .04342 L
.28444 .04474 L
.28479 .04526 L
.28495 .04544 L
.28513 .04561 L
.28528 .04572 L
.28542 .0458 L
.28558 .04586 L
.28566 .04589 L
.28574 .0459 L
.28587 .0459 L
.28602 .04588 L
.28617 .04583 L
.2863 .04577 L
.28645 .04567 L
Mistroke
.28659 .04555 L
.28691 .04519 L
.28722 .04472 L
.28755 .04408 L
.28819 .04253 L
.28878 .04068 L
.29011 .03521 L
.29136 .02871 L
.29254 .02175 L
.29306 .01846 L
.29335 .01664 L
.29349 .01574 L
.29362 .01493 L
.29376 .0154 L
.29391 .01636 L
.29423 .01839 L
.29478 .02193 L
.29607 .02979 L
.29727 .03627 L
.29837 .04126 L
.29895 .04342 L
.29958 .04534 L
.2999 .04616 L
.3002 .0468 L
.30051 .04733 L
.30079 .04772 L
.30096 .04791 L
.30111 .04804 L
.30128 .04815 L
.30137 .0482 L
.30145 .04823 L
.30161 .04827 L
.30176 .04828 L
.30191 .04825 L
.30199 .04823 L
.30208 .04819 L
.30224 .0481 L
.30239 .04798 L
.30271 .04762 L
.303 .04718 L
.30331 .0466 L
.30385 .04531 L
.30444 .04348 L
.30574 .03805 L
.30696 .03148 L
.30814 .02407 L
.30879 .01975 L
.30911 .01759 L
.30924 .01665 L
.30939 .01562 L
Mistroke
.30953 .01476 L
.30966 .01564 L
.30991 .01737 L
.31046 .02117 L
.31162 .02898 L
.31389 .0419 L
.31451 .04464 L
.31517 .0471 L
.3158 .04892 L
.31638 .05013 L
.31668 .05059 L
.31695 .0509 L
.31711 .05102 L
.31719 .05107 L
.31727 .05112 L
.31742 .05117 L
.31757 .05119 L
.3177 .05119 L
.31784 .05116 L
.31797 .0511 L
.31809 .05102 L
.31824 .05091 L
.31839 .05075 L
.31867 .05038 L
.31897 .04986 L
.3193 .04914 L
.31997 .04723 L
.32117 .04235 L
.32241 .03563 L
.32371 .02712 L
.32482 .01908 L
.32512 .0168 L
.3252 .0162 L
.32529 .01555 L
.32544 .01507 L
.3256 .01628 L
.32575 .01739 L
.32603 .01949 L
.32844 .03677 L
.32962 .0438 L
.3307 .04893 L
.33122 .0509 L
.33179 .05261 L
.33211 .05335 L
.3324 .05391 L
.33267 .05432 L
.33283 .0545 L
.33297 .05463 L
.33311 .05474 L
.33326 .05481 L
Mistroke
.33341 .05485 L
.3335 .05485 L
.33358 .05485 L
.33372 .05481 L
.33386 .05475 L
.33401 .05465 L
.33415 .05452 L
.33448 .0541 L
.33478 .05357 L
.33511 .05282 L
.33546 .05185 L
.3366 .04745 L
.33782 .04081 L
.34002 .02495 L
.34062 .02016 L
.34094 .01747 L
.3411 .01615 L
.34124 .01493 L
.34133 .01521 L
.34142 .01596 L
.34161 .01754 L
.34194 .0203 L
.34258 .02563 L
.34375 .03498 L
.345 .04395 L
.34624 .05121 L
.34683 .05395 L
.34737 .05603 L
.34791 .05766 L
.3482 .05832 L
.34851 .05887 L
.34863 .05905 L
.34877 .05922 L
.34889 .05934 L
.34902 .05944 L
.34916 .05952 L
.34931 .05956 L
.34945 .05956 L
.34958 .05954 L
.34974 .05947 L
.34981 .05942 L
.3499 .05935 L
.35019 .05901 L
.35036 .05876 L
.35053 .05844 L
.35085 .05771 L
.35148 .05578 L
.35205 .05345 L
.3532 .04722 L
.35429 .03964 L
Mistroke
.35545 .03016 L
.35609 .0245 L
.3564 .02164 L
.35669 .01898 L
.35696 .01643 L
.3571 .01513 L
.35725 .01572 L
.3574 .01715 L
.35756 .01868 L
.35785 .02145 L
.35891 .03129 L
.36014 .04206 L
.36148 .05215 L
.36209 .05601 L
.36274 .05949 L
.36335 .0621 L
.36391 .06392 L
.36418 .06461 L
.36433 .06491 L
.36449 .06519 L
.36464 .06541 L
.36477 .06558 L
.36491 .0657 L
.36504 .06579 L
.36519 .06585 L
.36535 .06586 L
.36548 .06584 L
.36563 .06576 L
.36578 .06564 L
.36595 .06545 L
.36611 .06522 L
.36626 .06496 L
.3668 .06363 L
.36711 .06262 L
.36739 .06153 L
.36847 .05602 L
.36963 .04784 L
.37072 .03838 L
.37193 .02636 L
.37225 .02301 L
.37259 .01936 L
.37275 .01757 L
.37291 .01587 L
.37305 .01509 L
.3732 .01675 L
.37436 .02944 L
.37564 .04276 L
.37679 .05361 L
.37787 .06218 L
.37901 .06908 L
Mistroke
.37961 .0717 L
.37995 .07282 L
.38026 .07363 L
.38042 .07396 L
.38059 .07424 L
.38074 .07445 L
.38089 .07459 L
.38097 .07466 L
.38105 .0747 L
.38114 .07473 L
.38124 .07474 L
.38139 .07471 L
.38148 .07467 L
.38156 .07461 L
.38164 .07455 L
.38173 .07446 L
.38188 .07426 L
.38216 .07374 L
.38249 .07288 L
.3828 .07186 L
.38336 .06944 L
.38396 .06605 L
.38506 .05795 L
.38624 .04659 L
.38754 .03178 L
.38815 .02425 L
.38848 .01999 L
.38865 .01788 L
.3888 .01592 L
.38894 .01536 L
.38909 .01734 L
.38941 .02151 L
.38996 .02879 L
.39251 .06006 L
.39365 .07144 L
.39428 .07666 L
.39487 .0808 L
.39543 .08388 L
.39572 .0852 L
.39603 .08635 L
.39629 .08711 L
.39643 .08744 L
.39658 .08773 L
.39671 .08795 L
.39684 .0881 L
.39696 .08821 L
.39708 .08827 L
.39723 .08829 L
.39731 .08827 L
.39739 .08824 L
Mistroke
.39753 .08813 L
.39768 .08795 L
.39782 .08774 L
.39794 .08749 L
.39823 .08675 L
.39854 .08569 L
.39882 .08448 L
.39946 .0809 L
.4 .07697 L
.40059 .07177 L
.40167 .06007 L
.4029 .04382 L
.40405 .0263 L
.40436 .02133 L
.40453 .01857 L
.40468 .01599 L
.40477 .0148 L
.40486 .01626 L
.40504 .01938 L
.40537 .02488 L
.40658 .04491 L
.40897 .0811 L
.40962 .08929 L
.41032 .09682 L
.41092 .10225 L
.41123 .10465 L
.41157 .10683 L
.41186 .10846 L
.41218 .10989 L
.41232 .11041 L
.41247 .11088 L
.41261 .11124 L
.41275 .11152 L
.41289 .11174 L
.41304 .1119 L
.41318 .11197 L
.41332 .11196 L
.41345 .11189 L
.41358 .11176 L
.41371 .11155 L
.41385 .11126 L
.41402 .11081 L
.41417 .11029 L
.41453 .10878 L
.41484 .10704 L
.41517 .10478 L
.4158 .0993 L
.41637 .09305 L
.4176 .07572 L
.4189 .05233 L
Mistroke
.42 .02906 L
.4203 .02228 L
.42047 .01849 L
.42063 .01487 L
.42077 .01796 L
.42093 .02167 L
.42121 .02823 L
.42343 .0809 L
.42469 .10883 L
.42587 .13163 L
.42702 .14928 L
.42767 .15675 L
.42826 .16182 L
.42858 .16382 L
.42888 .16518 L
.42905 .16573 L
.42921 .16609 L
.4293 .16623 L
.42939 .16633 L
.42948 .16638 L
.42956 .16639 L
.42971 .16629 L
.42985 .16609 L
.43 .16573 L
.43016 .1652 L
.43033 .16446 L
.43049 .16359 L
.4308 .16153 L
.43135 .15627 L
.43196 .14818 L
.4326 .13716 L
.43319 .12442 L
.43542 .05774 L
.43603 .03433 L
.43618 .02815 L
.43633 .02221 L
.43646 .01679 L
.4366 .01862 L
.43675 .02504 L
.43689 .03106 L
.4372 .04477 L
.43785 .07508 L
.44008 .1886 L
.44253 .3198 L
.44483 .43383 L
.44703 .52237 L
.44827 .55939 L
.4494 .58381 L
.44997 .59257 L
.45029 .59635 L
Mistroke
.45058 .59907 L
.45086 .60101 L
.45101 .60185 L
.45115 .60245 L
.45128 .60285 L
.45141 .60315 L
.45155 .6033 L
.45169 .6033 L
.45184 .60313 L
.45193 .60294 L
.45201 .60272 L
.45216 .60217 L
.45232 .60141 L
.45259 .59962 L
.45289 .59698 L
.45356 .58869 L
.45419 .57793 L
.45538 .55004 L
.45662 .51118 L
.45886 .42247 L
.46346 .20488 L
.46602 .09277 L
.46724 .04765 L
.46777 .02984 L
.46791 .02519 L
.46807 .02031 L
.46822 .01581 L
.46835 .01764 L
.46849 .02168 L
.46864 .02599 L
.46892 .03352 L
.46952 .0486 L
.47013 .06212 L
.47078 .07442 L
.4714 .0842 L
.47196 .09139 L
.47253 .09705 L
.47307 .10098 L
.47336 .10259 L
.47363 .10375 L
.47378 .10427 L
.47393 .10466 L
.47401 .10484 L
.4741 .10501 L
.47425 .10522 L
.4744 .10534 L
.47448 .10537 L
.47456 .10537 L
.47465 .10535 L
.47472 .1053 L
Mistroke
.47481 .10522 L
.4749 .10512 L
.47504 .10487 L
.47518 .10457 L
.47549 .10365 L
.47579 .10249 L
.47606 .10115 L
.47657 .09805 L
.47772 .08867 L
.48015 .06163 L
.48237 .03417 L
.48294 .02754 L
.48355 .02077 L
.48384 .01764 L
.48399 .01614 L
.48412 .01478 L
.48424 .01587 L
.48437 .01713 L
.48464 .01973 L
.48584 .02981 L
.48647 .03414 L
.48714 .03796 L
.48772 .04068 L
.48836 .04296 L
.48864 .04375 L
.48894 .04444 L
.48923 .04495 L
.48948 .04531 L
.48962 .04546 L
.48977 .04558 L
.48989 .04566 L
.49003 .04573 L
.49017 .04576 L
.49033 .04577 L
.49048 .04575 L
.49062 .0457 L
.49075 .04562 L
.49088 .04553 L
.49117 .04525 L
.49142 .04492 L
.49169 .0445 L
.49234 .04316 L
.49293 .0416 L
.49428 .0372 L
.49671 .02769 L
.49781 .02328 L
.49898 .01866 L
.49933 .01731 L
.49966 .01603 L
.4998 .01548 L
Mistroke
.49995 .01489 L
.50003 .01484 L
.50012 .01518 L
.50027 .01578 L
.50148 .02046 L
.50401 .03059 L
.50512 .03495 L
.50633 .03931 L
.5069 .04112 L
.50751 .04279 L
.50804 .04398 L
.50861 .04497 L
.50877 .04518 L
.50895 .04537 L
.50911 .04552 L
.50926 .04563 L
.5094 .0457 L
.50955 .04575 L
.50963 .04577 L
.50971 .04577 L
.50986 .04576 L
.51 .04572 L
.51015 .04564 L
.51027 .04555 L
.51041 .04543 L
.51072 .04504 L
.511 .04454 L
.51157 .04317 L
.51219 .04105 L
.51283 .03811 L
.51344 .03472 L
.51451 .02706 L
.51507 .02232 L
.51538 .01952 L
.51567 .01677 L
.51581 .01532 L
.51597 .01571 L
.51606 .01663 L
.51615 .01752 L
.51631 .01921 L
.5169 .02571 L
.51824 .04157 L
.52067 .07142 L
.52182 .08422 L
.52246 .09036 L
.52306 .09538 L
.52362 .09928 L
.52391 .10099 L
.52422 .10251 L
.52448 .10356 L
Mistroke
.52462 .10403 L
.52477 .10445 L
.52491 .10477 L
.52503 .105 L
.52516 .10518 L
.52527 .1053 L
.52541 .10537 L
.52556 .10536 L
.5257 .10527 L
.52583 .10512 L
.52597 .10488 L
.52613 .10452 L
.52629 .10404 L
.52644 .10349 L
.52675 .10203 L
.52704 .10032 L
.52768 .09513 L
.52823 .08913 L
.52882 .08095 L
.5299 .06156 L
.53104 .03458 L
.53136 .02604 L
.53153 .02114 L
.53161 .01866 L
.53169 .01634 L
.53184 .01765 L
.53192 .0201 L
.53201 .02274 L
.5323 .03198 L
.53484 .12817 L
.53986 .36387 L
.54238 .47439 L
.54349 .51509 L
.5447 .55211 L
.54527 .56631 L
.54587 .57912 L
.5464 .58809 L
.54697 .59554 L
.5473 .59878 L
.54745 .59993 L
.54761 .60101 L
.54775 .60178 L
.54791 .60244 L
.54799 .60273 L
.54807 .60294 L
.54822 .60322 L
.54836 .60332 L
.5485 .60326 L
.54865 .60304 L
.5488 .60261 L
Mistroke
.54895 .60201 L
.54909 .60129 L
.54936 .59952 L
.54965 .59695 L
.54992 .59395 L
.55054 .58501 L
.55114 .57352 L
.55178 .55825 L
.55401 .48394 L
.55657 .36639 L
.55899 .23832 L
.56119 .12256 L
.56244 .06152 L
.56274 .04778 L
.56305 .0337 L
.56332 .02202 L
.56347 .01555 L
.56361 .01981 L
.56476 .0641 L
.566 .10362 L
.56722 .13353 L
.56791 .14608 L
.56853 .15485 L
.56911 .16081 L
.56941 .16299 L
.56958 .16399 L
.56973 .16476 L
.56987 .16529 L
.57001 .16575 L
.57016 .16611 L
.57031 .16631 L
.57044 .16639 L
.57058 .16635 L
.57072 .16621 L
.57084 .16599 L
.571 .16558 L
.57117 .16499 L
.57146 .16357 L
.57178 .1615 L
.57213 .15863 L
.57276 .15197 L
.57335 .14415 L
.57581 .09816 L
.57805 .04586 L
.57863 .03198 L
.57895 .02445 L
.5791 .0208 L
.57925 .01748 L
.57937 .01481 L
.5795 .0178 L
Mistroke
.57977 .024 L
.58035 .03679 L
.58156 .06118 L
.58286 .08279 L
.5835 .09151 L
.58411 .09839 L
.5847 .10376 L
.58496 .1057 L
.58524 .10753 L
.58549 .10887 L
.58576 .11005 L
.58591 .11058 L
.58604 .11098 L
.58617 .11131 L
.58631 .11158 L
.58645 .11179 L
.58659 .11192 L
.58674 .11197 L
.58682 .11197 L
.5869 .11194 L
.58704 .11183 L
.58717 .11166 L
.58731 .11141 L
.58746 .11106 L
.58777 .11009 L
.58806 .10885 L
.58861 .10574 L
.5892 .1013 L
.58984 .09528 L
.59205 .06669 L
.59328 .04719 L
.59444 .02795 L
.59474 .02297 L
.59502 .01826 L
.59518 .01568 L
.59527 .01521 L
.59535 .01656 L
.59565 .02143 L
.59698 .042 L
.59825 .05918 L
.59945 .07223 L
.60053 .08085 L
.60114 .0843 L
.60143 .08556 L
.6017 .08653 L
.60184 .08696 L
.60199 .08735 L
.60212 .08763 L
.60227 .08788 L
.60242 .08808 L
Mistroke
.6025 .08816 L
.60258 .08822 L
.60272 .08828 L
.60287 .08828 L
.60301 .08823 L
.60315 .08812 L
.6033 .08793 L
.60344 .0877 L
.6037 .08714 L
.60397 .08636 L
.60429 .08516 L
.60464 .08355 L
.60527 .07985 L
.60646 .07045 L
.60881 .04454 L
.61006 .02853 L
.61042 .02382 L
.61076 .01934 L
.61091 .0174 L
.61106 .01534 L
.61115 .01528 L
.61124 .01635 L
.6114 .01842 L
.61266 .03424 L
.61385 .04759 L
.61495 .05798 L
.61557 .06289 L
.61615 .06675 L
.61677 .07006 L
.61733 .07233 L
.61764 .07326 L
.61793 .07393 L
.61809 .07421 L
.61824 .07442 L
.6184 .07459 L
.61849 .07465 L
.61858 .0747 L
.61872 .07474 L
.61887 .07473 L
.61899 .07468 L
.61913 .07458 L
.61928 .07442 L
.61944 .0742 L
.61973 .07365 L
.62002 .07291 L
.62029 .07204 L
.62081 .06997 L
.62198 .06323 L
.62322 .0535 L
.62545 .03143 L
Mistroke
.62604 .02507 L
.62659 .01899 L
.62674 .01736 L
.6269 .01563 L
.62698 .01473 L
.62707 .01569 L
.62723 .01743 L
.62782 .02369 L
.63003 .04502 L
.63124 .05419 L
.63236 .06045 L
.63294 .06281 L
.63328 .06387 L
.63358 .06464 L
.63391 .06525 L
.63408 .0655 L
.63417 .06559 L
.63425 .06567 L
.63441 .06578 L
.63455 .06584 L
.6347 .06586 L
.63479 .06585 L
.63487 .06583 L
.63502 .06575 L
.63511 .06569 L
.63518 .06562 L
.63547 .06525 L
.63564 .06498 L
.63581 .06462 L
.63613 .06383 L
.63675 .06173 L
.63732 .0592 L
.63841 .05294 L
.63955 .04456 L
.6407 .03485 L
.64133 .02912 L
.64192 .02355 L
.64248 .0183 L
.64263 .01686 L
.64271 .01607 L
.64279 .01534 L
.64293 .01539 L
.64308 .01682 L
.64414 .02654 L
.64532 .03664 L
.64657 .04577 L
.64764 .05197 L
.6482 .05453 L
.6488 .05674 L
.64914 .05768 L
Mistroke
.64944 .05839 L
.64974 .05891 L
.64988 .05911 L
.65005 .05929 L
.65019 .05942 L
.65033 .0595 L
.65048 .05955 L
.65063 .05956 L
.65076 .05954 L
.65089 .05949 L
.65103 .05941 L
.65117 .05928 L
.65134 .05908 L
.6515 .05886 L
.65186 .0582 L
.65217 .05744 L
.6525 .05647 L
.6537 .05152 L
.65485 .04495 L
.65607 .03634 L
.65723 .02726 L
.65773 .02308 L
.65829 .01842 L
.65844 .01717 L
.6586 .01583 L
.65875 .01486 L
.65889 .01602 L
.65952 .02127 L
.66086 .03175 L
.66212 .04039 L
.66329 .04689 L
.66386 .04942 L
.66439 .05138 L
.66469 .05229 L
.66501 .05311 L
.6653 .05373 L
.66558 .05418 L
.66573 .05439 L
.66588 .05455 L
.66604 .05468 L
.66612 .05474 L
.66621 .05479 L
.66629 .05482 L
.66637 .05484 L
.66653 .05485 L
.66661 .05484 L
.66669 .05482 L
.66678 .05479 L
.66688 .05474 L
.66702 .05464 L
Mistroke
.66718 .05449 L
.6675 .05407 L
.6678 .05355 L
.66807 .05294 L
.66868 .05121 L
.66934 .04875 L
.67054 .04291 L
.67278 .02833 L
.67392 .01986 L
.67424 .01749 L
.67441 .01619 L
.67449 .01555 L
.67457 .01495 L
.67472 .01562 L
.6748 .01623 L
.67489 .01687 L
.67518 .01904 L
.67772 .03638 L
.67896 .04297 L
.67961 .04574 L
.6803 .04809 L
.68091 .04962 L
.68125 .05026 L
.68142 .05051 L
.68157 .05071 L
.68171 .05086 L
.68187 .05099 L
.68201 .05109 L
.68213 .05115 L
.68227 .05118 L
.68243 .0512 L
.6825 .05119 L
.68259 .05117 L
.68274 .05111 L
.68289 .05102 L
.68303 .05091 L
.68334 .05057 L
.68362 .05013 L
.68389 .04961 L
.6845 .0481 L
.68516 .04594 L
.68648 .04007 L
.6877 .0332 L
.6888 .02621 L
.6894 .02214 L
.68997 .01821 L
.69029 .01598 L
.69038 .01537 L
.69048 .01472 L
.69056 .01526 L
Mistroke
.69064 .01587 L
.69126 .02008 L
.69246 .02795 L
.6936 .03462 L
.69479 .04047 L
.69542 .04296 L
.6961 .04517 L
.6964 .04596 L
.69673 .04668 L
.697 .04719 L
.69731 .04764 L
.69762 .04798 L
.69779 .04811 L
.69787 .04816 L
.69795 .0482 L
.6981 .04825 L
.69823 .04828 L
.69838 .04827 L
.69846 .04826 L
.69854 .04824 L
.69862 .0482 L
.69871 .04816 L
.69888 .04805 L
.69904 .04791 L
.69919 .04775 L
.69952 .04728 L
.69988 .04664 L
.70048 .0452 L
.70103 .04348 L
.70231 .03834 L
.70455 .02605 L
.70517 .02222 L
.70582 .01807 L
.70609 .01635 L
.70623 .01545 L
.70638 .01493 L
.70646 .01544 L
.70655 .01599 L
.7067 .01696 L
.707 .01885 L
.70833 .02693 L
.70956 .03363 L
.71073 .03885 L
.71134 .04109 L
.71199 .04301 L
.7123 .04378 L
.71265 .04449 L
.71297 .04502 L
.71326 .04539 L
.7134 .04554 L
Mistroke
.71356 .04567 L
.71364 .04573 L
.71372 .04578 L
.71388 .04585 L
.71403 .04589 L
.71416 .0459 L
.71431 .04589 L
.71446 .04585 L
.71459 .0458 L
.71473 .04571 L
.71488 .0456 L
.71502 .04547 L
.71554 .04478 L
.71583 .04425 L
.7161 .04368 L
.7167 .04212 L
.7179 .03789 L
.71901 .03287 L
.7203 .02599 L
.72093 .02236 L
.72151 .01894 L
.72178 .01736 L
.72192 .01652 L
.72207 .01562 L
.72221 .01476 L
.72235 .01545 L
.7226 .01697 L
.72377 .02375 L
.72507 .03062 L
.72626 .03597 L
.72738 .03991 L
.72795 .04142 L
.72858 .04268 L
.7289 .04317 L
.7292 .04352 L
.72937 .04366 L
.72955 .04379 L
.72963 .04383 L
.72972 .04387 L
.72987 .04392 L
.73002 .04394 L
.73017 .04393 L
.73032 .0439 L
.73045 .04385 L
.7306 .04377 L
.73076 .04366 L
.73109 .04334 L
.73139 .04293 L
.73172 .04238 L
.73233 .04107 L
Mistroke
.73345 .03766 L
.73476 .0323 L
.73598 .02635 L
.73707 .02047 L
.73735 .01887 L
.73767 .01712 L
.73781 .01631 L
.73796 .01546 L
.73811 .01478 L
.73824 .01552 L
.73891 .01925 L
.73952 .02258 L
.74073 .02869 L
.74186 .03368 L
.74305 .03787 L
.74367 .03955 L
.74401 .04028 L
.74436 .04094 L
.74469 .04144 L
.74498 .04179 L
.74512 .04193 L
.74528 .04206 L
.74543 .04215 L
.74556 .04222 L
.7457 .04226 L
.74584 .04229 L
.74599 .04229 L
.74615 .04227 L
.74629 .04223 L
.74643 .04216 L
.74657 .04208 L
.7467 .04199 L
.74701 .04169 L
.74734 .04125 L
.74795 .04016 L
.74859 .03862 L
.74927 .03658 L
.75049 .03199 L
.75163 .02682 L
.75285 .02064 L
.75344 .01751 L
.75373 .01596 L
.75386 .01528 L
.754 .0149 L
.75413 .01557 L
.75425 .0162 L
.75451 .01758 L
.75506 .02044 L
.75728 .03092 L
.75854 .03553 L
Mistroke
.75916 .03732 L
.75972 .03865 L
.76001 .03922 L
.76032 .03974 L
.76059 .04012 L
.76088 .04045 L
.76104 .04059 L
.7612 .0407 L
.76129 .04076 L
.76137 .0408 L
.76145 .04084 L
.76153 .04086 L
.76168 .0409 L
.76176 .0409 L
.76184 .04091 L
.76199 .04089 L
.76213 .04086 L
.76229 .0408 L
.76237 .04075 L
.76246 .0407 L
.76276 .04046 L
.76311 .04007 L
.76344 .03959 L
.76404 .03845 L
.76467 .03688 L
.7659 .03291 L
.76724 .02743 L
.76839 .022 L
.769 .01896 L
.76932 .01734 L
.7695 .01645 L
.76966 .01562 L
.76981 .01487 L
.76997 .01536 L
.77006 .01581 L
.77014 .01625 L
.7703 .01705 L
.77089 .01998 L
.77205 .02546 L
.77328 .03064 L
.77458 .03506 L
.77513 .03654 L
.77573 .03783 L
.77607 .03842 L
.77638 .03887 L
.7767 .03923 L
.77685 .03937 L
.77699 .03948 L
.77712 .03956 L
.77726 .03963 L
Mistroke
.77741 .03968 L
.77755 .03971 L
.77768 .03973 L
.77781 .03972 L
.77793 .0397 L
.77806 .03967 L
.77821 .0396 L
.77835 .03953 L
.77866 .03929 L
.77895 .03898 L
.77922 .03862 L
.77978 .03767 L
.78039 .03631 L
.78163 .03263 L
.78385 .02359 L
.78444 .02083 L
.78507 .01784 L
.78533 .01659 L
.78547 .0159 L
.7856 .01525 L
.78576 .01495 L
.78591 .01564 L
.78619 .017 L
.7887 .02827 L
.78988 .0325 L
.79052 .03441 L
.79112 .03591 L
.79168 .03702 L
.79218 .0378 L
.79247 .03814 L
.79275 .03839 L
.79289 .03849 L
.79303 .03858 L
.79311 .03861 L
.7932 .03865 L
.79335 .03869 L
.7935 .03872 L
.79363 .03872 L
.79378 .0387 L
.79387 .03868 L
.79394 .03866 L
.7941 .0386 L
.79426 .03851 L
.79456 .03827 L
.79485 .03798 L
.79514 .03759 L
.79568 .0367 L
.7963 .03537 L
.79688 .03384 L
.79819 .02949 L
Mistroke
.79945 .02444 L
.80064 .01912 L
.80116 .01673 L
.8013 .01603 L
.80144 .01538 L
.80157 .01479 L
.80171 .01527 L
.80231 .01808 L
.80287 .02063 L
.80523 .03014 L
.80588 .03223 L
.80657 .03414 L
.80722 .0356 L
.80782 .03664 L
.80812 .03704 L
.80843 .03738 L
.80875 .03763 L
.80893 .03773 L
.80901 .03777 L
.8091 .0378 L
.80925 .03784 L
.80941 .03786 L
.80955 .03786 L
.80968 .03784 L
.80984 .0378 L
.80999 .03774 L
.81016 .03765 L
.81031 .03754 L
.81059 .03729 L
.81088 .03696 L
.8114 .03619 L
.81197 .0351 L
.81259 .03361 L
.81493 .02569 L
.81624 .02017 L
.81688 .01734 L
.81715 .01609 L
.8173 .01544 L
.81745 .01475 L
.81761 .0154 L
.81776 .01606 L
.81805 .01734 L
.81868 .02013 L
.82001 .02566 L
.82118 .02989 L
.82182 .03187 L
.82243 .03349 L
.82303 .0348 L
.82334 .03538 L
.82368 .03591 L
Mistroke
.82396 .03628 L
.82427 .03661 L
.82455 .03684 L
.82468 .03693 L
.82481 .037 L
.82495 .03705 L
.82509 .0371 L
.82523 .03712 L
.82537 .03712 L
.8255 .03711 L
.82563 .03709 L
.82575 .03705 L
.82587 .037 L
.82601 .03693 L
.82617 .03683 L
.82647 .03657 L
.82676 .03626 L
.82702 .03591 L
.82763 .03489 L
.82828 .03347 L
.82948 .03009 L
.83171 .0217 L
.83226 .01939 L
.83285 .01684 L
.83301 .01613 L
.83318 .01537 L
.83333 .01473 L
.83341 .01507 L
.83349 .0154 L
.8341 .01804 L
.8354 .02346 L
.83663 .02804 L
.83781 .03169 L
.83844 .03325 L
.8391 .03458 L
.83965 .03544 L
.83997 .03582 L
.84026 .0361 L
.8404 .03621 L
.84053 .03629 L
.84065 .03636 L
.84078 .03641 L
.84092 .03646 L
.84105 .03648 L
.8412 .0365 L
.84134 .03649 L
.84148 .03647 L
.84162 .03643 L
.84177 .03637 L
.84193 .03629 L
Mistroke
.84225 .03605 L
.84255 .03576 L
.84312 .03499 L
.84366 .03402 L
.84487 .03111 L
.84617 .02691 L
.84741 .02223 L
.84856 .01745 L
.84885 .01625 L
.849 .01559 L
.84914 .01498 L
.8493 .01511 L
.84938 .01546 L
.84947 .01584 L
.84977 .0171 L
.8511 .02256 L
.85234 .02714 L
.85368 .03124 L
.85429 .03274 L
.85494 .03404 L
.8555 .03489 L
.85581 .03527 L
.85611 .03555 L
.85626 .03567 L
.85642 .03577 L
.85656 .03584 L
.85671 .0359 L
.85679 .03592 L
.85687 .03594 L
.85702 .03596 L
.8571 .03596 L
.85719 .03596 L
.85728 .03595 L
.85737 .03594 L
.85752 .03589 L
.85767 .03583 L
.8578 .03576 L
.85794 .03567 L
.85826 .03541 L
.85856 .03509 L
.85908 .03437 L
.85964 .03334 L
.8608 .03057 L
.8621 .02646 L
.86333 .02185 L
.86444 .01735 L
.86475 .01609 L
.86491 .0154 L
.86507 .01475 L
.86522 .0153 L
Mistroke
.86538 .01596 L
.86566 .0171 L
.86789 .02575 L
.86915 .02979 L
.86977 .03143 L
.87033 .03271 L
.87089 .03375 L
.87149 .03462 L
.87183 .03497 L
.87197 .0351 L
.87213 .03522 L
.87227 .03531 L
.87243 .03539 L
.87251 .03542 L
.87259 .03545 L
.87274 .03549 L
.87289 .03551 L
.87304 .03551 L
.87319 .0355 L
.87333 .03547 L
.87341 .03544 L
.87349 .03541 L
.87366 .03533 L
.87398 .03512 L
.87428 .03484 L
.87461 .03445 L
.87528 .03341 L
.87591 .03214 L
.8765 .03068 L
.87762 .02738 L
.87885 .02308 L
.87951 .02051 L
.88014 .018 L
.88044 .01681 L
.88075 .01555 L
.88083 .01523 L
.88091 .01488 L
.881 .01492 L
.88109 .01527 L
.8814 .01654 L
.88254 .02107 L
.88476 .02875 L
.88599 .03192 L
.88668 .03327 L
.88701 .03379 L
.88733 .03421 L
.88762 .03453 L
.88789 .03476 L
.88818 .03496 L
.88835 .03504 L
Mistroke
.8885 .03509 L
.88865 .03513 L
.88874 .03514 L
.88881 .03514 L
.88896 .03514 L
.8891 .03512 L
.88918 .0351 L
.88926 .03508 L
.88941 .03502 L
.88958 .03494 L
.88975 .03483 L
.89006 .03458 L
.89038 .03423 L
.89098 .03338 L
.89157 .0323 L
.8921 .03109 L
.89463 .02328 L
.89571 .01917 L
.89628 .01691 L
.89643 .01632 L
.89659 .01567 L
.89674 .01507 L
.89688 .01491 L
.89695 .01523 L
.89704 .01557 L
.89719 .01619 L
.89754 .01758 L
.89816 .01998 L
.89936 .02444 L
.9006 .02843 L
.90175 .03142 L
.90234 .03261 L
.90296 .03361 L
.90332 .03405 L
.90366 .03438 L
.90396 .0346 L
.90413 .0347 L
.90429 .03477 L
.90445 .03481 L
.90452 .03483 L
.90461 .03484 L
.90476 .03484 L
.9049 .03483 L
.90499 .03482 L
.90507 .0348 L
.90522 .03475 L
.90539 .03468 L
.90557 .03458 L
.90587 .03434 L
.90619 .03402 L
Mistroke
.90677 .03325 L
.90732 .03228 L
.90784 .03119 L
.90901 .02808 L
.91124 .0204 L
.91186 .01804 L
.91219 .01672 L
.91236 .01607 L
.91251 .01547 L
.91265 .0149 L
.9128 .01513 L
.91296 .01573 L
.91312 .0164 L
.91368 .01859 L
.9161 .02717 L
.91742 .03075 L
.91806 .0321 L
.91865 .03312 L
.91925 .03388 L
.91957 .03418 L
.91973 .0343 L
.9199 .03441 L
.92007 .03449 L
.92023 .03455 L
.92038 .03459 L
.92053 .03461 L
.92067 .03461 L
.9208 .0346 L
.92094 .03457 L
.9211 .03452 L
.92125 .03446 L
.92139 .03438 L
.9217 .03416 L
.92198 .0339 L
.92227 .03356 L
.92278 .03283 L
.92333 .03181 L
.92456 .02888 L
.92567 .02548 L
.92698 .02086 L
.92762 .01844 L
.92789 .01737 L
.92819 .0162 L
.92834 .01564 L
.92849 .01504 L
.92862 .0149 L
.92876 .01546 L
.9293 .01756 L
.93048 .02202 L
.93179 .02647 L
Mistroke
.93298 .02985 L
.93356 .0312 L
.93419 .03241 L
.93478 .03331 L
.93533 .03392 L
.93563 .03415 L
.93577 .03423 L
.93591 .03431 L
.93599 .03434 L
.93608 .03437 L
.93622 .03441 L
.93631 .03442 L
.9364 .03443 L
.93648 .03444 L
.93656 .03444 L
.93664 .03443 L
.93672 .03442 L
.93688 .03438 L
.93696 .03435 L
.93704 .03432 L
.93722 .03423 L
.93753 .03403 L
.93786 .03373 L
.93849 .03292 L
.93908 .03192 L
.94041 .02882 L
.94283 .02088 L
.94345 .01857 L
.94377 .01733 L
.94411 .01601 L
.94425 .01545 L
.94441 .01485 L
.9445 .01492 L
.94458 .01524 L
.94474 .01585 L
.94531 .01808 L
.94756 .02606 L
.94868 .0293 L
.94986 .03195 L
.95048 .03297 L
.95081 .03339 L
.95117 .03377 L
.95149 .03402 L
.95163 .03411 L
.95179 .03419 L
.95193 .03425 L
.95207 .03429 L
.95222 .03431 L
.95237 .03432 L
.95252 .03432 L
Mistroke
.9526 .0343 L
.95268 .03429 L
.95277 .03426 L
.95284 .03424 L
.95301 .03417 L
.95316 .03409 L
.95332 .03398 L
.95361 .03374 L
.95395 .03338 L
.9543 .03291 L
.95495 .03183 L
.9561 .02922 L
.95738 .02547 L
.95851 .02155 L
.95971 .01706 L
.96001 .0159 L
.96018 .01525 L
.96034 .01479 L
.96043 .01513 L
.96052 .01551 L
.96069 .01616 L
.96102 .01743 L
.96222 .02193 L
.96346 .02611 L
.96462 .02943 L
.96583 .03206 L
.96647 .03306 L
.96683 .03349 L
.96715 .03381 L
.96731 .03393 L
.96746 .03403 L
.96759 .0341 L
.96773 .03416 L
.96788 .03421 L
.96802 .03425 L
.96818 .03426 L
.96826 .03427 L
.96834 .03426 L
.96849 .03425 L
.96862 .03421 L
.96874 .03417 L
.96888 .03412 L
.96917 .03394 L
.96945 .03372 L
.97002 .03308 L
.97066 .03209 L
.97195 .02927 L
.97399 .02296 L
.97619 .01472 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.03968 .01472 m
.03968 .01472 L
s
.05556 .01472 m
.05556 .01472 L
s
.07143 .01472 m
.07143 .01472 L
s
.0873 .01472 m
.0873 .01472 L
s
.10317 .01472 m
.10317 .01472 L
s
.11905 .01472 m
.11905 .01472 L
s
.13492 .01472 m
.13492 .01472 L
s
.15079 .01472 m
.15079 .01472 L
s
.16667 .01472 m
.16667 .01472 L
s
.18254 .01472 m
.18254 .01472 L
s
.19841 .01472 m
.19841 .01472 L
s
.21429 .01472 m
.21429 .01472 L
s
.23016 .01472 m
.23016 .01472 L
s
.24603 .01472 m
.24603 .01472 L
s
.2619 .01472 m
.2619 .01472 L
s
.27778 .01472 m
.27778 .01472 L
s
.29365 .01472 m
.29365 .01472 L
s
.30952 .01472 m
.30952 .01472 L
s
.3254 .01472 m
.3254 .01472 L
s
.34127 .01472 m
.34127 .01472 L
s
.35714 .01472 m
.35714 .01472 L
s
.37302 .01472 m
.37302 .01472 L
s
.38889 .01472 m
.38889 .01472 L
s
.40476 .01472 m
.40476 .01472 L
s
.42063 .01472 m
.42063 .01472 L
s
.43651 .01472 m
.43651 .01472 L
s
.45238 .01472 m
.45238 .60105 L
s
.46825 .01472 m
.46825 .01472 L
s
.48413 .01472 m
.48413 .01472 L
s
.5 .01472 m
.5 .01472 L
s
.51587 .01472 m
.51587 .01472 L
s
.53175 .01472 m
.53175 .01472 L
s
.54762 .01472 m
.54762 .60105 L
s
.56349 .01472 m
.56349 .01472 L
s
.57937 .01472 m
.57937 .01472 L
s
.59524 .01472 m
.59524 .01472 L
s
.61111 .01472 m
.61111 .01472 L
s
.62698 .01472 m
.62698 .01472 L
s
.64286 .01472 m
.64286 .01472 L
s
.65873 .01472 m
.65873 .01472 L
s
.6746 .01472 m
.6746 .01472 L
s
.69048 .01472 m
.69048 .01472 L
s
.70635 .01472 m
.70635 .01472 L
s
.72222 .01472 m
.72222 .01472 L
s
.7381 .01472 m
.7381 .01472 L
s
.75397 .01472 m
.75397 .01472 L
s
.76984 .01472 m
.76984 .01472 L
s
.78571 .01472 m
.78571 .01472 L
s
.80159 .01472 m
.80159 .01472 L
s
.81746 .01472 m
.81746 .01472 L
s
.83333 .01472 m
.83333 .01472 L
s
.84921 .01472 m
.84921 .01472 L
s
.86508 .01472 m
.86508 .01472 L
s
.88095 .01472 m
.88095 .01472 L
s
.89683 .01472 m
.89683 .01472 L
s
.9127 .01472 m
.9127 .01472 L
s
.92857 .01472 m
.92857 .01472 L
s
.94444 .01472 m
.94444 .01472 L
s
.96032 .01472 m
.96032 .01472 L
s
.97619 .01472 m
.97619 .01472 L
s
.015 w
.03968 .01472 Mdot
.05556 .01472 Mdot
.07143 .01472 Mdot
.0873 .01472 Mdot
.10317 .01472 Mdot
.11905 .01472 Mdot
.13492 .01472 Mdot
.15079 .01472 Mdot
.16667 .01472 Mdot
.18254 .01472 Mdot
.19841 .01472 Mdot
.21429 .01472 Mdot
.23016 .01472 Mdot
.24603 .01472 Mdot
.2619 .01472 Mdot
.27778 .01472 Mdot
.29365 .01472 Mdot
.30952 .01472 Mdot
.3254 .01472 Mdot
.34127 .01472 Mdot
.35714 .01472 Mdot
.37302 .01472 Mdot
.38889 .01472 Mdot
.40476 .01472 Mdot
.42063 .01472 Mdot
.43651 .01472 Mdot
.45238 .60105 Mdot
.46825 .01472 Mdot
.48413 .01472 Mdot
.5 .01472 Mdot
.51587 .01472 Mdot
.53175 .01472 Mdot
.54762 .60105 Mdot
.56349 .01472 Mdot
.57937 .01472 Mdot
.59524 .01472 Mdot
.61111 .01472 Mdot
.62698 .01472 Mdot
.64286 .01472 Mdot
.65873 .01472 Mdot
.6746 .01472 Mdot
.69048 .01472 Mdot
.70635 .01472 Mdot
.72222 .01472 Mdot
.7381 .01472 Mdot
.75397 .01472 Mdot
.76984 .01472 Mdot
.78571 .01472 Mdot
.80159 .01472 Mdot
.81746 .01472 Mdot
.83333 .01472 Mdot
.84921 .01472 Mdot
.86508 .01472 Mdot
.88095 .01472 Mdot
.89683 .01472 Mdot
.9127 .01472 Mdot
.92857 .01472 Mdot
.94444 .01472 Mdot
.96032 .01472 Mdot
.97619 .01472 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005_ooool3o`0000Cooooo0_l0000iooooo`?o0000>oooool2o`0003cooooo0ol0000ioooo
o`?o00001?ooool2o`0000Oooooo000Gooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000=oooool01Ol0003ooooooooooooooooo000003Wooooo00Co0000oooooooooooo0000>_oo
ool01Ol0003ooooooooooooooooo000003Wooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00006ooooo`003oooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000aooooo`Go00001Oooool00ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`00
03kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Kooooo000Gooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000>oooool0
0ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`0003kooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo000Gooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000=oooool4o`0003[ooooo00Co0000oooooooooooo
0000>_ooool4o`0003[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006oooo
o`005_ooool2o`0000Cooooo00Co0000oooooooooooo0000=oooool00ol0003oooooooooo`0koooo
o`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool0>_ooool2o`0000Cooooo00Co0000
oooooooooooo00001_ooool001Oooooo00?o0000ooooooooool00oooool2o`0003Sooooo1Ol0000j
ooooo`;o0000>oooool5o`0003Wooooo00?o0000ooooooooool00oooool2o`0000Oooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Aoooooooo00003Ol00003
ooooo`002_ooool2o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`01oooo
o`002Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo007ooooo0009ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01oooool3ool00005oooooooo003oo`00
ool00?ooool00ooo00001Oooooooo`00ool00?oo003ooooo00?oo`000_ooool3ool00005oooooooo
003oo`00ool00?ooool00ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`0000Goooooool00?oo
003oo`00ooooo`03ool00004oooooooo003oo`00ool000;ooooo0ooo00001Oooooooo`00ool00?oo
003ooooo00?oo`0000Goooooool00?oo003oo`00ooooo`03ool000;ooooo0ooo00001Oooooooo`00
ool00?oo003ooooo00?oo`0000Coooooool00?oo003oo`000_ooool3ool00005oooooooo003oo`00
ool00?ooool00ooo00001?ooooooo`00ool00?oo0006ooooo`?oo`0000Goooooool00?oo003oo`00
ooooo`03ool00004oooooooo003oo`00ool000;ooooo0ooo0005ooooo`?oo`0000Coooooool00?oo
003oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo00001Oooooooo`00ool00?oo
003ooooo00?oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo00001?ooooooo`00
ool00?oo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool00005oooooooo003oo`00
ool00?ooool00ooo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool00004oooooooo
003oo`00ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Coooooool00?oo
003oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo0005ooooo`03o`000?oooooo
oooo007ooooo0009ooooo`04o`000?ooooooooooo`0000Cooooo0ol00004ooooo`03o`00oooooooo
oooo00?oo`0000Goooooool00?oo003oo`00ooooo`03ool00005oooooooo003oo`00ool00?ooool0
0ooo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool00004oooooooo003oo`00ool0
00;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Coooooool00?oo003oo`000_oo
ool3ool00005oooooooo003oo`00ool00?ooool00ooo00001Oooooooo`00ool00?oo003ooooo00?o
o`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo00001?ooooooo`00ool00?oo0002
ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool00004oooooooo003oo`00ool000?ooooo
00?oo`00ooooooooool00ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Coooooool00?oo
003oo`000_ooool3ool000;ooooo00?oo`00ooooooooool00ooo00001?ooooooo`00ool00?oo0002
ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool00005oooooooo003oo`00ool00?ooool0
0ooo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool00004oooooooo003oo`00ool0
00;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Goooooool00?oo003oo`00oooo
o`03ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Coooooool00?oo003o
o`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo00001?ooooooo`00ool00?oo0002
ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool000?ooooo0ol00003ooooo`002Oooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool00ooo
00001Oooooooo`00ool00?oo003ooooo00?oo`0000Goooooool00?oo003oo`00ooooo`03ool000;o
oooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Coooooool00?oo003oo`000_ooool3
ool00005oooooooo003oo`00ool00?ooool00ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`00
00Goooooool00?oo003oo`00ooooo`03ool00005oooooooo003oo`00ool00?ooool00ooo0002oooo
o`?oo`0000Goooooool00?oo003oo`00ooooo`03ool00004oooooooo003oo`00ool000;ooooo0ooo
00001Oooooooo`00ool00?oo003ooooo00?oo`0000Coooooool00?oo003oo`000oooool00ooo003o
ooooooooo`03ool00005oooooooo003oo`00ool00?ooool00ooo00001?ooooooo`00ool00?oo0002
ooooo`?oo`000_ooool00ooo003oooooooooo`03ool00004oooooooo003oo`00ool000;ooooo0ooo
00001Oooooooo`00ool00?oo003ooooo00?oo`0000Goooooool00?oo003oo`00ooooo`03ool000;o
oooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Coooooool00?oo003oo`000_ooool3
ool00005oooooooo003oo`00ool00?ooool00ooo00001Oooooooo`00ool00?oo003ooooo00?oo`00
0_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo00001?ooooooo`00ool00?oo0002oooo
o`?oo`0000Goooooool00?oo003oo`00ooooo`03ool00004oooooooo003oo`00ool000;ooooo0ooo
00001Oooooooo`00ool00?oo003ooooo00?oo`001Oooool00ol0003oooooooooo`01ooooo`002Ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool0
0_ooool2o`00o`?ooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooo003o00;ooooo
00Co003ooooooooooooooooo0_l00?l2ooooo`04o`00ooooooooooooooooo`;o003o1oooool2o`00
o`;ooooo0_l00?l7ooooo`04o`00ooooooooooooooooo`;o003o0_ooool01?l00?oooooooooooooo
ool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`07ooooo`;o003o0oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00oooooooooooo
oooooooo00000oooool01?l00?ooooooooooooooool2o`00o`;ooooo0_l00?l3ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ooo003oooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l3ooooo`05o`00oooooooooooo
ooooool00?l00oooool01?l00?ooooooooooooooool2o`00o`?ooooo00?o003oooooooooool00_l0
0?l3ooooo`04o`00ooooooooooooooooo`;o003o0oooool00ol00?ooooooooooo`02o`00o`;ooooo
0_l00?l3ooooo`04o`00ooooooooooooooooo`;o003o0oooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`;o003o1oooool0
0ol00?ooooooooooo`04ooooo`03o`000?oooooooooo007ooooo000:ooooo`;o00001Oooool00ol0
003oooooooooo`09ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`05ooooo`04o`00oooo
ooooooooo`00o`Gooooo00?o003oooooool00?l01Oooool2o`00o`04ooooool00?ooooooo`00o`Ko
oooo00Co003ooooooooooooooooo0_l00?l6ooooo`03o`00oooooooo003o00;ooooo0_l00?l3oooo
o`03o`00oooooooooooo00;o003o0_ooool2o`00o`?ooooo00?o003oooooooooool01Oooool2o`00
o`;ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`?ooooo00Go003o
ooooooooooooooooool00007ooooo`;o003o0_ooool2o`00o`;ooooo00?o003oooooooooool00_oo
ool01Ol00?ooooooooooooooooooo`0000?ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool0
0?l00oooool01?l00?ooooooooooooooool2o`00o`;ooooo00Go003oooooooooooooooooo`00o`04
ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o0oooool2o`00o`;ooooo0_l0
0?l3ooooo`;o003o0_ooool01?l00?ooooooooooooooool2o`00o`;ooooo0_l00?l2ooooo`03o`00
oooooooooooo00;ooooo0_l00?l2ooooo`03o`00oooooooooooo00?ooooo00Co003oooooool00?oo
003o0oooool2o`00o`;ooooo0_l00?l2ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`03
ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool01Oooool2o`00o`;ooooo00Co003ooooooooooooooooo0ol00?l2ooooo`;o003o0_ooool0
0ol00?ooooooo`00o`03ooooo`03o`00oooooooo003o00Cooooo00oo003oooooooooooooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l01Oooool02?l00?oooooooooo
ool00?ooooooo`00oooooooo003o0oooool00ol00?ooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;o003o0oooool0
1?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00oooooooooooooooooooo00000oooool01?l00?ooooooooooooooool2o`00
o`;ooooo00Co003oo`000?oooooooooo0_l00?l3ooooo`05o`00oooooooooooooooooooo00000ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?oooooo
ooooool00?l3ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooooooo`02o`00
o`;ooooo00?o003oooooooooool00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003o
oooooooooooo003o0oooool00ol00?ooooooooooo`03ooooo`07o`00oooooooo003oooooool00?oo
ooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00Oo003oooooooooooooooooo`00oooo
oooo003o00Kooooo00Oo003oooooool00?ooooooo`00oooooooo003o00?ooooo00Co003oooooool0
0?oo003o2?ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000Kooooo0_l00?l3ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?l3ooooo`05o`00oooooooooooooooo
ool00?l00oooool01?l00?ooooooooooooooool2o`00o`;ooooo00?o003oooooooooool00_ooool2
o`00o`03ooooool00?oo003o00;ooooo0_l00?l3ooooo`?o003o00Coooooo`00oooooooo003o1ooo
ool00ol00?ooooooo`00o`02ooooo`;o003o0_ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00;o003o0oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooool00003ooooo`03o`00oooooooooooo00Cooooo00Go003oooooool0003o
003oooooo`02o`00o`?ooooo00Go003oooooooooooooooooool00003ooooo`;o003o0oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00?o003oooooooooool01?ooool2o`00o`;ooooo00Oo003o
ooooool00?ooooooo`00oooooooo003o00;ooooo0_l00?l2ooooo`;o003o3?ooool01?l00?oooooo
o`00ooooool2o`00o`06ooooool00?ooooooo`00oooooooo003o0oooool01?l00?ooooooo`00ool0
0?l4ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00o`Sooooo00Co003ooooooooooooo003o
2?ooool2o`00o`;ooooo0_l00?l6ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0;?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l3ooooo`04o`00ooooooooooooo`00o`?o
oooo00Co003oooooool00?oooooo0ol00?l4ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ool00?l00oooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
ooooooooo`0000?ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`000?l00?oooooo00;o
003o0oooool01Ol00?ooooooooooooooooooo`0000Cooooo00?o003oooooooooool00_l00?l3oooo
o`05o`00ooooooooooooooooool00?l00oooool2o`00o`;ooooo0_l00?l4ooooo`03o`00oooooooo
003o00Cooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00_ooool2o`00o`;ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`;o003o
0_ooool01?l00?ooooooooooooooool2o`00obWooooo00?o0000ooooooooool00Oooool0017ooooo
00?o0000ooooooooool0@Oooool2o`00o`;ooooo0_l00?l3ooooo`03o`00oooooooooooo00Cooooo
00Oo003oooooool00?ooooooo`00oooooooo003o00Cooooo0_l00?l2ooooo`;o003o0_ooool2o`00
o`?ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool01Ooo003ooooooooooooo
oooo003o00?ooooo1?l00?l01_oooooo0000o`00ool00?ooooooo`00o`?ooooo00Go003ooooooooo
ooooooooool00004ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`02
ooooo`;o003o0_ooool2o`00o`Cooooo00Oo003oooooooooooooooooo`00oooooooo003o00?ooooo
00?o003oooooooooool01?ooool2o`00o`;ooooo0_l00?l3ooooo`;o003o@_ooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`16ooooo`03o`00oooooooooooo00;o003o0_oo
ool2o`00o`;ooooo00Go003oooooool00?ooooooo`00o`06ooooo`;o003o0_ooool2o`00o`;ooooo
00?o003oooooool00?l00_ooool2o`00o`;ooooo0_l00?l3ooooo`05o`00oooooooooooooooooooo
00001oooool00ol00?ooooooo`00o`02ooooo`03o`000?oooooo003o00Gooooo00Go003ooooooooo
ooooooooool00003ooooo`;o003o0oooool00ol00?ooooooooooo`02o`00o`?ooooo0_l00?l2oooo
o`;o003o0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooool00?l01?ooool2
o`00o`;ooooo0_l00?l3ooooo`03o`00oooooooooooo04Gooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool0C_ooool01?l00?ooooooooooool00?l4ooooo`;o003o0_ooool0
3Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l00_ooool2
o`00o`;ooooo00Go003oooooooooooooooooo`00o`04ooooo`05ool00?ooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go003ooooooooooooo
ooooool00003ooooo`04o`00ooooooooooooooooo`;o003o0oooool00ol00?ooooooooooo`02oooo
o`04o`00ooooooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`06ooooo`;o003o0_oo
ool2o`00odoooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001Gooooo`;o003o0_ooool2
o`00o`;ooooo00?o003oooooool00?l03?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Co
o`00oooooooooooooooo0_l00?l7ooooo`03o`000?oooooooooo00;ooooo00Co003ooooooooooooo
003o0oooool01Ooo003ooooooooooooooooo003o00?ooooo00?o003oooooooooool00oooool01Ol0
0?oooooooooooooooooo003o00Gooooo00Ko003ooooooooooooo003oooooool00?l2ooooo`05o`00
ooooooooooooooooool00?l0Doooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo05[ooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`08ooooo`;o003o0_ooool2o`00o`?ooooo
00Coo`00oooooooooooooooo0_l00?l7ooooo`03o`000?oooooooooo00;ooooo00Co003ooooooooo
oooo003o0oooool01?oo003oooooooooooooool2o`00o`;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00_ooool2o`00o`;ooooo0_l00?mLooooo`03o`00
0?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo05kooooo0ol00?l02_oooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?l2ooooo`;o003o0oooool01Ol00?oooooooooooooo
ooooo`0000?ooooo0_l00?l00ooooooo003oooooo`04ooooo`03o`000?oooooooooo00;ooooo00Co
003ooooooooooooo003o0oooool00ooo003oooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00_ooool01Ol00?oooooooooooooooooo003o00;ooooo0_l00?l2ooooo`03o`00oooooooooooo
05oooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0G_ooool2o`00o`;o
oooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l00_ooool2o`00o`?ooooo00Go
003oooooooooooooooooool00004ooooo`03o`00oooooooo003o00Gooooo00?o0000ooooooooool0
1Oooool01Ol00?ooooooooooooooooooo`0000?ooooo0_l00?l3ooooo`0<o`00ooooooooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003o0_ooool2o`00of3ooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool0H_ooool02Ol00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00o`02ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ooo003ooooooooo
oooooooo003o00;ooooo00?o003oooooooooool00oooool00ol0003oooooooooo`04ooooo`;o003o
0oooool01Ooo003ooooooooooooooooo003o00?ooooo0_l00?l4ooooo`03o`00oooooooo003o00;o
oooo0_l00?mTooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000Hoooool2o`00o`Cooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`04ool00?ooooooooooooooo`;o
003o1oooool00ol0003oooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00_ooool01Ooo
003ooooooooooooooooo003o00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo06;ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1]oooo
o`;o003o0_ooool2o`00o`?ooooo00Coo`00oooooooooooooooo0_l00?l7ooooo`03o`000?oooooo
oooo00;ooooo00Go003oooooool00?ooooooo`00o`02ooooo`04ool00?ooooooooooooooo`;o003o
0_ooool02Ol00?oooooooooooooooooo003oooooool00?ooooooo`00o`1Xooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo06Oooooo0_l00?l01?oooooo003oooooooooool2
o`00o`;ooooo0_l00?l3ooooo`04ool00?ooooooooooooooo`;o003o00?oooooo`00ooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`00oooooooo003o00Cooooo00?oo`00ooooooooool00_oo
ool02?l00?ooooooooooool00?ooooooo`00oooooooo003o0oooool00ol00?ooooooooooo`1Voooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06Oooooo0_l00?l01_oooooo
003oooooool00?ooooooo`00o`?ooooo00Go003oooooooooooooooooool00004ooooo`03o`00oooo
oooo003o00Gooooo00?o0000ooooooooool00_ooool00ol00?ooooooo`00o`04ooooo`03ool00?oo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`02ooooo`03o`00oooo
oooooooo06Oooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Ioooool2
o`00o`06ooooool00?ooooooo`00oooooooo003o0_ooool2o`00o`?ooooo00Goo`00oooooooooooo
ooooo`00o`02ooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol00?oo
ooooo`00o`02ooooo`04ool00?ooooooooooooooo`;o003o0_ooool01Ol00?ooooooo`00oooooooo
003o00;ooooo00?o003oooooooooool0Ioooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`1Zooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool01Ooo
003ooooooooooooooooo003o00;ooooo00?o003oooooooooool00oooool00ol0003oooooooooo`03
ooooo`04o`00ooooooooooooo`00o`;ooooo00Goo`00ooooooooooooooooo`00o`03ooooo`03o`00
oooooooo003o06kooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001_ooooo`03o`00oooo
oooooooo00;o003o0oooool01?oo003oooooooooooooool2o`00o`Oooooo00?o0000ooooooooool0
0oooool01?l00?ooooooooooool00?l2ooooo`04ool00?ooooooooooooooo`;o003o0_ooool01?l0
0?ooooooooooool00?m/ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0Joooool2o`00
o`04ooooool00?ooooooooooo`;o003o0oooool01Ooo003oooooooooool00?oooooo00;o003o1_oo
ool00ol0003oooooooooo`03ooooo`;o003o1?ooool00ooo003oooooooooo`02ooooo`05o`00oooo
ooooooooo`00ooooool00_l00?m]ooooo`03o`000?oooooooooo007ooooo0009ooooo`?o00001Ooo
ool00ol0003oooooooooo`1[ooooo`;o003o00?oooooo`00ooooool00_ooool01Ol00?oooooooooo
ooooooooo`0000Cooooo0_l00?l6ooooo`03o`000?oooooooooo00?ooooo0_l00?l4ooooo`03ool0
0?oooooooooo00;ooooo00?o003oooooooooool00_ooool2o`00ofgooooo00?o0000ooooooooool0
0Oooool000Sooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo06_ooooo
0_l00?l00ooooooo003oooooo`02ooooo`05o`00oooooooooooooooooooo00001Oooool00ol00?oo
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0_l00?l01Ooooooo003oooooooooooooo`00
00?ooooo0_l00?l4ooooo`;o003oKOooool00ol0003oooooooooo`01ooooo`003?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06_ooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`02ooooo`04ool00?ooooooooooo`00o`Wooooo00?o0000ooooooooool01_ooool01?l0
0?oooooooooooooo0003ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`1^ooooo`03o`00
0?oooooooooo007ooooo000<ooooo`03o`000?oooooooooo00;ooooo0ol0001aooooo`03o`00oooo
oooooooo00;ooooo00Coo`00oooooooooooo003o2Oooool00ol0003oooooooooo`06ooooo`04o`00
ooooooooooooool000?ooooo00Go003oooooooooooooooooo`00o`1^ooooo`?o00000oooool000So
oooo1?l00005ooooo`03o`000?oooooooooo06oooooo00Co003oooooool00?oo003o0oooool01?oo
003oooooooooool00?l9ooooo`03o`000?oooooooooo00Kooooo00Co003oooooooooooooo`000ooo
ool2o`00o`03ooooool00?oooooo073ooooo00?o0000ooooooooool00Oooool000Sooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`04o`00ooooooooooooo`00o`?ooooo00?o
o`00ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo00;ooooo00?o
003oooooooooool0LOooool00ol0003oooooooooo`01ooooo`002?ooool5o`0000Cooooo00?o0000
ooooooooool0Koooool01?l00?ooooooooooool00?l3ooooo`03ool00?oooooooooo00[ooooo00?o
0000ooooooooool01_ooool01?l00?oooooooooooooo0003ooooo`;o003oLoooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`1aooooo`03o`00oooooooooooo00;ooooo00Co
o`00oooooooooooo003o2Oooool00ol0003oooooooooo`06ooooo`04o`00ooooooooooooool000?o
oooo00Co003ooooooooooooo003oLOooool00ol0003oooooooooo`01ooooo`004Oooool2o`0007;o
oooo00?o003oooooooooool00_ooool01?oo003oooooooooool00?l9ooooo`03o`000?oooooooooo
00Kooooo00Co003oooooooooooooo`000oooool01?l00?ooooooooooool00?m`ooooo`;o00000ooo
ool0017ooooo00?o0000ooooooooool0Koooool01?l00?ooooooo`00ool00?l3ooooo`04ool00?oo
ooooooooo`00o`Wooooo00?o0000ooooooooool01_ooool01?l00?oooooooooooooo0003ooooo`04
o`00oooooooo003oo`00og7ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0Koooool01?l00?ooooooo`00ool00?l3ooooo`04ool00?ooooooooooo`00o`Wooooo00?o0000
ooooooooool02Oooool00ooo003oooooooooo`03ooooo`;o003oLOooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`1_ooooo`04o`00ooooooooooooo`00o`?ooooo00?oo`00
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo00?ooooo00?o003o
ooooooooool0L?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1_oooo
o`Co003o0oooool01?oo003oooooooooool00?l9ooooo`03o`000?oooooooooo00Kooooo00Co003o
ooooooooooooo`000oooool01?l00?ooooooo`00ool00?maooooo`03o`000?oooooooooo007ooooo
000Aooooo`;o0000LOooool00ol00?ooooooooooo`03ooooo`04ool00?ooooooooooo`00o`Wooooo
00?o0000ooooooooool01_ooool01?l00?oooooooooooooo0003ooooo`04o`00ooooooooooooo`00
og3ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1_ooooo`;o003o00?oooooo`00oooo
ool00_ooool01?oo003oooooooooool00?l9ooooo`03o`000?oooooooooo00Kooooo00Co003ooooo
ooooooooo`000oooool01?l00?ooooooo`00ool00?maooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo06oooooo0_l00?l00ooooooo003oooooo`02ooooo`04ool00?oooooo
ooooo`00o`Wooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`03ooooo`;o003oLOoo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1_ooooo`04o`00oooooooo
ooooo`00o`?ooooo00?oo`00ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03ool00?oo
oooooooo00?ooooo00?o003oooooooooool0L?ooool00ol0003oooooooooo`01ooooo`004Oooool0
0ol0003oooooooooo`1`ooooo`03o`00oooooooo003o00?ooooo00?oo`00ooooooooool02_ooool0
0ol0003oooooooooo`06ooooo`04o`00ooooooooooooool000?ooooo00?o003oooooool00?l0L_oo
ool00ol0003oooooooooo`01ooooo`004Oooool2o`0007Oooooo00Coo`00oooooooooooo003o2Ooo
ool00ol0003oooooooooo`06ooooo`04o`00ooooooooooooool000?ooooo00?o003oooooooooool0
LOooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo07Kooooo00Coo`00oooooooooooo003o
2Oooool00ol0003oooooooooo`06ooooo`04o`00ooooooooooooool000?ooooo00?o003ooooooooo
ool0L_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1cooooo`04o`00
ooooooooooooool000;ooooo00?o003oooooooooool01oooool00ol0003oooooooooo`06ooooo`04
o`00ooooooooooooool000?ooooo00?o003oooooooooool0L_ooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`1cooooo`04o`00ooooooooooooool000cooooo00?o0000oooo
ooooool02Oooool00ooo003oooooooooo`1fooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo07?ooooo00Co003oooooooooooooo`003?ooool00ol0003oooooooooo`06oooo
o`04o`00ooooooooooooool000?ooooo00?o003oooooooooool0L_ooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`1fooooo`04ool00?ooooooooooo`00o`Wooooo00?o0000
ooooooooool01_ooool01?l00?oooooooooooooo0003ooooo`03o`00oooooooooooo07;ooooo00?o
0000ooooooooool00Oooool0017ooooo0_l0001gooooo`04ool00?ooooooooooo`00o`Wooooo00?o
0000ooooooooool01_ooool01?l00?oooooooooooooo0003ooooo`03o`00oooooooooooo077ooooo
0_l00003ooooo`004Oooool00ol0003oooooooooo`1cooooo`04o`00ooooooooooooool000;ooooo
00?o003oooooooooool01oooool00ol0003oooooooooo`06ooooo`04o`00ooooooooooooool000?o
oooo00?o003oooooooooool0L_ooool00ol0003oooooooooo`01ooooo`000oooool3o`0000Cooooo
0_l00005ooooo`03o`000?oooooooooo07?ooooo00Co003oooooooooooooo`000_ooool00ol00?oo
ooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool0M_ooool00ol0003o
ooooooooo`01ooooo`001?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0Loooool01?l00?oooooooooooooo000<ooooo`03o`000?oooooooooo
00Wooooo00?oo`00ooooooooool0M_ooool00ol0003oooooooooo`01ooooo`001?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Loooool01?l0
0?oooooooooooooo0002ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool01_ooool0
1?l00?oooooooooooooo0002ooooo`03o`00oooooooooooo07?ooooo00?o0000ooooooooool00Ooo
ool000Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`?o0000M_oo
ool01?oo003oooooooooool00?l9ooooo`03o`000?oooooooooo00Kooooo00Co003ooooooooooooo
o`000_ooool00ol00?ooooooooooo`1aooooo`?o00000oooool000Cooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo07?ooooo00Co003ooooooooo
ooooo`000_ooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00Co003ooooo
ooooooooo`000_ooool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo007ooooo0003oooo
o`;o00001?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo07?ooooo00Co003o
ooooooooooooo`000_ooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o
o`00ooooooooool0M_ooool00ol0003oooooooooo`01ooooo`001?ooool00ol0003oooooooooo`03
ooooo`;o00001Oooool00ol0003oooooooooo`1cooooo`04o`00ooooooooooooool000cooooo00?o
0000ooooooooool02Oooool00ooo003oooooooooo`1fooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo07?ooooo00Co003oooooooooooooo`003?ooool00ol0003ooooooooo
o`06ooooo`04o`00ooooooooooooool000;ooooo00?o003oooooooooool0Loooool00ol0003ooooo
ooooo`01ooooo`004Oooool2o`0007Oooooo00Coo`00oooooooooooo003o2Oooool00ol0003ooooo
ooooo`06ooooo`04o`00ooooooooooooool000;ooooo00?o003oooooooooool0L_ooool2o`0000?o
oooo000Aooooo`03o`000?oooooooooo07Kooooo00Coo`00oooooooooooo003o2Oooool00ol0003o
ooooooooo`06ooooo`04o`00ooooooooooooool000;ooooo00?o003oooooooooool0Loooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1cooooo`04o`00ooooooooooooool0
00;ooooo00?o003oooooooooool01oooool00ol0003oooooooooo`06ooooo`04o`00oooooooooooo
ool000;ooooo00?o003oooooooooool0Loooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`1cooooo`04o`00ooooooooooooool000cooooo00?o0000ooooooooool02Oooool0
0ooo003oooooooooo`1fooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
07?ooooo00Co003oooooooooooooo`003?ooool00ol0003oooooooooo`07ooooo`03o`00oooooooo
o`0000;ooooo00?o003oooooooooool0Loooool00ol0003oooooooooo`01ooooo`004Oooool2o`00
07Oooooo00Coo`00oooooooooooo003o2Oooool00ol0003oooooooooo`07ooooo`03o`00oooooooo
o`0000;ooooo00?o003oooooooooool0L_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo
07Kooooo00Coo`00oooooooooooo003o2Oooool00ol0003oooooooooo`07ooooo`03o`00oooooooo
o`0000;ooooo00?o003oooooooooool0Loooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`1cooooo`04o`00ooooooooooooool000;ooooo00?o003oooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`00ooooooooo`0000;ooooo00?o003oooooooooool0Loooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1cooooo`04o`00oooooooooooo
ool000;ooooo00?o003oooooooooool01oooool00ol0003oooooooooo`09ooooo`03ool00?oooooo
oooo07Kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Loooool01?l0
0?oooooooooooooo000<ooooo`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool0M_ooool0
0ol0003oooooooooo`01ooooo`004Oooool2o`0007Cooooo00Ko003oooooooooooooo`00ooooool0
0?l:ooooo`03o`000?oooooooooo00Oooooo00?o003ooooooooo00000_ooool00ol00?oooooooooo
o`1booooo`;o00000oooool0017ooooo00?o0000ooooooooool0M_ooool00ooo003oooooo`00o`0:
ooooo`03o`000?oooooooooo00Oooooo00?o003ooooooooo00000_ooool00ol00?ooooooooooo`1c
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07?ooooo00Ko003ooooo
ooooooooo`00ooooool00?l:ooooo`03o`000?oooooooooo00Oooooo00?o003ooooooooo00000_oo
ool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo07?ooooo00Ko003oooooooooooooo`00ooooool00?l:ooooo`03o`000?oooooooooo00Wooooo
00?oo`00ooooooooool0M_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`1cooooo`04o`00ooooooooooooool000cooooo00?o0000ooooooooool02Oooool00ooo003ooooo
ooooo`1fooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07?ooooo00Co
003oooooooooooooo`003?ooool00ol0003oooooooooo`07ooooo`03o`00ooooooooo`0000;ooooo
00?o003oooooooooool0Loooool00ol0003oooooooooo`01ooooo`004Oooool2o`0007Oooooo00?o
o`00ooooool00?l02_ooool00ol0003oooooooooo`07ooooo`03o`00ooooooooo`0000;ooooo00?o
003oooooooooool0L_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo07Kooooo00?oo`00
ooooool00?l02_ooool00ol0003oooooooooo`07ooooo`03o`00ooooooooo`0000;ooooo00?o003o
ooooooooool0Loooool00ol0003oooooooooo`01ooooo`000oooool3o`0000?ooooo0ol00005oooo
o`03o`000?oooooooooo07?ooooo00Ko003oooooooooooooo`00ooooool00?l:ooooo`03o`000?oo
oooooooo00Oooooo00?o003ooooooooo00000_ooool00ol00?ooooooooooo`1cooooo`03o`000?oo
oooooooo007ooooo0004ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo07?ooooo00Co003oooooooooooooo`003?ooool00ol0003ooooo
ooooo`09ooooo`03ool00?oooooooooo07Kooooo00?o0000ooooooooool00Oooool000Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07?ooooo00Co
003oooooooooooooo`003?ooool00ol0003oooooooooo`07ooooo`03o`00ooooooooo`0000;ooooo
00?o003oooooooooool0Loooool00ol0003oooooooooo`01ooooo`001?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo0ol0001fooooo`03ool00?oooooo003o00[ooooo00?o
0000ooooooooool01oooool00ol00?ooooooool00002ooooo`03o`00oooooooooooo077ooooo0ol0
0003ooooo`001?ooool01?l0003oooooooooooooool4o`0000Gooooo00?o0000ooooooooool0M_oo
ool00ooo003oooooo`00o`0:ooooo`03o`000?oooooooooo00Oooooo00?o003ooooooooo00000_oo
ool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo007ooooo0003ooooo`;o00000oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo07?ooooo00Ko003oooooooooooooo`00oooo
ool00?l:ooooo`03o`000?oooooooooo00Oooooo00?o003ooooooooo00000_ooool00ol00?oooooo
ooooo`1cooooo`03o`000?oooooooooo007ooooo0004ooooo`04o`000?ooooooooooooooo`Go0000
1?ooool00ol0003oooooooooo`1cooooo`06o`00ooooooooooooool00?oooooo003o2_ooool00ol0
003oooooooooo`09ooooo`03ool00?oooooooooo07Kooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool0Loooool01?l00?oooooooooooooo000<ooooo`03o`000?oooooooooo
00Wooooo00?oo`00ooooooooool0M_ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0007Co
oooo00Ko003oooooooooooooo`00ooooool00?l:ooooo`03o`000?oooooooooo00Oooooo00?o003o
oooooooo00000_ooool00ol00?ooooooooooo`1booooo`;o00000oooool0017ooooo00?o0000oooo
ooooool0M_ooool00ooo003oooooo`00o`0:ooooo`03o`000?oooooooooo00Oooooo00?o003ooooo
oooo00000_ooool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo07?ooooo00Ko003oooooooooooooo`00ooooool00?l:ooooo`03o`000?oooooo
oooo00Oooooo00?o003ooooooooo00000_ooool00ol00?ooooooooooo`1cooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo07?ooooo00Ko003oooooooooooooo`00ooooool0
0?l:ooooo`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool0M_ooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`1cooooo`04o`00ooooooooooooool000cooooo00?o
0000ooooooooool02Oooool00ooo003oooooooooo`1fooooo`03o`000?oooooooooo007ooooo000A
ooooo`;o0000M?ooool01?l00?oooooooooooooo000<ooooo`03o`000?oooooooooo00Oooooo00?o
003ooooooooo00000_ooool00ol00?ooooooooooo`1booooo`;o00000oooool0017ooooo00?o0000
ooooooooool0M_ooool00ooo003oooooo`00o`0:ooooo`03o`000?oooooooooo00Oooooo00?o003o
oooooooo00000_ooool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo07Kooooo00?oo`00ooooool00?l02_ooool00ol0003oooooooooo`07oooo
o`03o`00ooooooooo`0000;ooooo00?o003oooooooooool0Loooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`1cooooo`06o`00ooooooooooooool00?oooooo003o2_ooool0
0ol0003oooooooooo`07ooooo`03o`00ooooooooo`0000;ooooo00?o003oooooooooool0Loooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1cooooo`04o`00oooooooooooo
ool000cooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`1fooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo07Cooooo00?o003ooooooooo00003?ooool00ol0
003oooooooooo`07ooooo`03o`00ooooooooo`0000;ooooo00?o003oooooooooool0Loooool00ol0
003oooooooooo`01ooooo`004Oooool2o`0007Oooooo00?oo`00ooooool00?l02_ooool00ol0003o
ooooooooo`07ooooo`03o`00ooooooooo`0000;ooooo00?o003oooooooooool0L_ooool2o`0000?o
oooo000Aooooo`03o`000?oooooooooo07Kooooo00?oo`00ooooool00?l02_ooool00ol0003ooooo
ooooo`07ooooo`03o`00ooooooooo`0000;ooooo00?o003oooooooooool0Loooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`1dooooo`05o`00ooooooooo`00ooooool00?l0
2_ooool00ol0003oooooooooo`07ooooo`03o`00ooooooooo`0000;ooooo00?o003oooooooooool0
Loooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1dooooo`05o`00oooo
ooooo`00ooooool00?l02_ooool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo07Kooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0M?ooool00ol00?ooooooool0
000<ooooo`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool0M_ooool00ol0003ooooooooo
o`01ooooo`004Oooool2o`0007Gooooo00Go003ooooooooo003oooooo`00o`0:ooooo`03o`000?oo
oooooooo00Oooooo00?o003ooooooooo00000_ooool00ol00?ooooooooooo`1booooo`;o00000ooo
ool0017ooooo00?o0000ooooooooool0M_ooool00ooo003oooooo`00o`0:ooooo`03o`000?oooooo
oooo00Oooooo00?o003ooooooooo00000_ooool00ol00?ooooooooooo`1cooooo`03o`000?oooooo
oooo007ooooo0002ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0M?ooool01Ol0
0?ooooooool00?oooooo003o00[ooooo00?o0000ooooooooool01oooool01Ol00?ooooooool00?oo
oooo003o07Kooooo00?o0000ooooooooool00Oooool000?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo07Cooooo00Go003ooooooooo003o
ooooo`00o`0:ooooo`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool0M_ooool00ol0003o
ooooooooo`01ooooo`001?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0M?ooool00ol00?ooooooool0000<ooooo`03o`000?oooooooooo00Wo
oooo00?oo`00ooooooooool0M_ooool00ol0003oooooooooo`01ooooo`001Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooooooool00_ooool3o`0007Cooooo00?o003ooooooooo
00003?ooool00ol0003oooooooooo`07ooooo`05o`00ooooooooo`00ooooool00?l0M?ooool3o`00
00?ooooo0002ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo07Kooooo00?oo`00ooooool00?l02_ooool00ol0003oooooooooo`07
ooooo`05o`00ooooooooo`00ooooool00?l0M_ooool00ol0003oooooooooo`01ooooo`000_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`1fooooo`03ool00?oooooo003o00[ooooo00?o0000ooooooooool02?ooool01?l00?ooo`00
ooooool00?mfooooo`03o`000?oooooooooo007ooooo0003ooooo`?o00001?ooool2o`0000Gooooo
00?o0000ooooooooool0M?ooool01Ol00?ooooooool00?oooooo003o00[ooooo00?o0000oooooooo
ool02?ooool01?l00?ooo`00ooooool00?mfooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo07Cooooo00?o003ooooooooo00003?ooool00ol0003oooooooooo`09ooooo`03
ool00?oooooooooo07Kooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001eooooo`03o`00
ooooooooo`0000cooooo00?o0000ooooooooool02?ooool01?l00?ooo`00ooooool00?meooooo`;o
00000oooool0017ooooo00?o0000ooooooooool0M_ooool00ooo003oooooo`00o`0:ooooo`03o`00
0?oooooooooo00Sooooo00Co003oool00?oooooo003oM_ooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`1fooooo`03ool00?oooooo003o00[ooooo00?o0000ooooooooool0
2?ooool01?l00?ooo`00ooooool00?mfooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo07Cooooo00Go003ooooooooo003oooooo`00o`0:ooooo`03o`000?oooooooooo00So
oooo00Co003oool00?oooooo003oM_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`1dooooo`05o`00ooooooooo`00ooooool00?l02_ooool00ol0003oooooooooo`09oooo
o`03ool00?oooooooooo07Kooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001eooooo`03
o`00ooooooooo`0000cooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`1eooooo`;o
00000oooool0017ooooo00?o0000ooooooooool0M?ooool01?l00?ooooooool00?l00?l;ooooo`03
o`000?oooooooooo00Sooooo00Co003oool00?oooooo003oM_ooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`1fooooo`03ool00?l00?oooooo00[ooooo00?o0000oooooooo
ool02?ooool01?l00?ooo`00ooooool00?mfooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo07Cooooo00Co003ooooooooo003o003o2oooool00ol0003oooooooooo`08oooo
o`04o`00oooo003oooooo`00ogKooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool0M?ooool01?l00?ooooooool00?l00?l;ooooo`03o`000?oooooooooo00Wooooo00?oo`00
ooooooooool0M_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1doooo
o`03o`00ooooooooo`0000cooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`1foooo
o`03o`000?oooooooooo007ooooo000Aooooo`;o0000MOooool00ol00?ooooooool0000<ooooo`03
o`000?oooooooooo00Sooooo00Co003oool00?oooooo003oMOooool2o`0000?ooooo000Aooooo`03
o`000?oooooooooo07Kooooo00?oo`00o`00ooooool02_ooool00ol0003oooooooooo`08ooooo`04
o`00oooo003oooooo`00ogKooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0M?ooool01?l00?ooooooool00?l00?l;ooooo`03o`000?oooooooooo00Sooooo00Co003oool0
0?oooooo003oM_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1doooo
o`04o`00ooooooooo`00o`00o`_ooooo00?o0000ooooooooool02?ooool01?l00?ooo`00ooooool0
0?mfooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07Cooooo00?o003o
oooooooo00003?ooool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo07Kooooo00?o0000
ooooooooool00Oooool0017ooooo0_l0001eooooo`03o`00ooooooooo`0000cooooo00?o0000oooo
ooooool02?ooool01?l00?ooo`00ooooool00?meooooo`;o00000oooool0017ooooo00?o0000oooo
ooooool0M_ooool00ooo003o003oooooo`0:ooooo`03o`000?oooooooooo00Sooooo00Co003oool0
0?oooooo003oM_ooool00ol0003oooooooooo`01ooooo`000_ooool5o`0000;ooooo0ol00005oooo
o`03o`000?oooooooooo07Kooooo00?oo`00o`00ooooool02_ooool00ol0003oooooooooo`08oooo
o`04o`00oooo003oooooo`00ogKooooo00?o0000ooooooooool00Oooool000?ooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0M?oo
ool01?l00?ooooooool00?l00?l;ooooo`03o`000?oooooooooo00Sooooo00Co003oool00?oooooo
003oM_ooool00ol0003oooooooooo`01ooooo`001?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0M?ooool01?l00?ooooooool00?l00?l;ooooo`03
o`000?oooooooooo00Wooooo00?oo`00ooooooooool0M_ooool00ol0003oooooooooo`01ooooo`00
1Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0ol0001dooooo`03o`00
ooooooooo`0000cooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`1dooooo`?o0000
0oooool000;ooooo00Ko0000ooooooooooooooooo`000?ooool4o`0000Gooooo00?o0000oooooooo
ool0M_ooool00ooo003o003oooooo`0:ooooo`03o`000?oooooooooo00Sooooo00Co003oool00?oo
oooo003oM_ooool00ol0003oooooooooo`01ooooo`000_ooool01ol0003ooooooooooooooooo0000
ooooool000002?ooool00ol0003oooooooooo`1fooooo`03ool00?l00?oooooo00[ooooo00?o0000
ooooooooool02?ooool01?l00?ooo`00ooooool00?mfooooo`03o`000?oooooooooo007ooooo0003
ooooo`?o00000_ooool5o`0000Cooooo00?o0000ooooooooool0M?ooool01?l00?ooooooool00?l0
0?l;ooooo`03o`000?oooooooooo00Sooooo00Co003oool00?oooooo003oM_ooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`1dooooo`04o`00ooooooooo`00o`00o`_ooooo
00?o0000ooooooooool02Oooool00ooo003oooooooooo`1fooooo`03o`000?oooooooooo007ooooo
000Aooooo`;o0000MOooool00ol00?ooooooool0000<ooooo`03o`000?oooooooooo00Wooooo00?o
o`00ooooooooool0MOooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo07Cooooo00?o003o
oooooooo00003?ooool00ol0003oooooooooo`08ooooo`04o`00oooo003oooooo`00ogKooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0M_ooool00ooo003o003oooooo`0:
ooooo`03o`000?oooooooooo00Sooooo00Co003oool00?oooooo003oM_ooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`1eooooo`03o`00oooo003o003o00_ooooo00?o0000
ooooooooool02?ooool01?l00?ooo`00ooooool00?mfooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo07Gooooo00?o003oool00?l00?l02oooool00ol0003oooooooooo`08
ooooo`04o`00oooo003oooooo`00ogKooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001f
ooooo`03o`00oooo003ooooo00_ooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`1e
ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0MOooool00ol00?ooo`00ooooo`0;oooo
o`03o`000?oooooooooo00Sooooo00?o003oool00?l00?l0Moooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`1fooooo`03ool00?l00?oooooo00[ooooo00?o0000oooooooo
ool02?ooool00ol00?ooo`00o`00o`1gooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo07Kooooo00?oo`00o`00ooooool02_ooool00ol0003oooooooooo`09ooooo`03ool0
0?l00?oooooo07Kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0MOoo
ool00ol00?ooo`00o`00o`0;ooooo`03o`000?oooooooooo00Wooooo00?oo`00o`00ooooool0M_oo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1eooooo`03o`00oooo003o
003o00_ooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`1fooooo`03o`000?oooooo
oooo007ooooo000Aooooo`;o0000M_ooool00ol00?ooo`00ooooo`0;ooooo`03o`000?oooooooooo
00Wooooo00?oo`00o`00ooooool0MOooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo07Ko
oooo00?oo`00ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03ool00?l00?oooooo07Ko
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0M_ooool00ooo003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?oo`00o`00ooooool0M_ooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`1eooooo`03o`00oooo003ooooo00_ooooo00?o
0000ooooooooool02Oooool00ooo003o003oooooo`1fooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo07Gooooo00?o003oool00?ooool02oooool00ol0003oooooooooo`09
ooooo`03ool00?oooooooooo07Kooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001foooo
o`03o`00oooo003ooooo00_ooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`1eoooo
o`;o00000oooool0017ooooo00?o0000ooooooooool0MOooool00ol00?ooo`00ooooo`0;ooooo`03
o`000?oooooooooo00Wooooo00?oo`00o`00ooooool0M_ooool00ol0003oooooooooo`01ooooo`00
0oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo07Kooooo00?oo`00ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03ool00?l00?oooooo07Kooooo00?o0000ooooooooool0
0Oooool000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0MOooool00ol00?ooo`00ooooo`0;ooooo`03o`000?oooooooooo00Wo
oooo00?oo`00o`00ooooool0M_ooool00ol0003oooooooooo`01ooooo`001_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0M?ooool3ool000co
oooo00?o0000ooooooooool02?ooool3ool007Oooooo00?o0000ooooooooool00Oooool000Cooooo
0_l00003ooooo`04o`000?ooooooooooo`0000Cooooo0ol0001dooooo`?oo`003?ooool00ol0003o
ooooooooo`08ooooo`?oo`00MOooool3o`0000?ooooo0006ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1dooooo`?oo`003?ooool00ol0003o
ooooooooo`08ooooo`?oo`00Moooool00ol0003oooooooooo`01ooooo`000_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`23oooo
o`03o`000?oooooooooo08;ooooo00?o0000ooooooooool00Oooool000?ooooo0ol00004ooooo`;o
00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo007ooooo000Aoooooooo0000
3Ol00003ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-11.9139, -3.12156, \
0.0788464, 0.192104}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g7 = 
        DiscreteListPlot[
          FourierRearrange[Arg[\(\((Last[#] +  .0000001)\) &\)\  /@ \ fft], 
            fs], Red, PlotRange \[Rule] All, ImageSize \[Rule] 504, \ 
          Frame \[Rule] True, \ Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g8 = \ Show[g2, g7];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.309471 0.0971556 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .018 -12 -4.5 ]
[-0.0125 .018 0 4.5 ]
[-0.0125 .11516 -12 -4.5 ]
[-0.0125 .11516 0 4.5 ]
[-0.0125 .21232 -12 -4.5 ]
[-0.0125 .21232 0 4.5 ]
[-0.0125 .30947 -6 -4.5 ]
[-0.0125 .30947 0 4.5 ]
[-0.0125 .40663 -6 -4.5 ]
[-0.0125 .40663 0 4.5 ]
[-0.0125 .50378 -6 -4.5 ]
[-0.0125 .50378 0 4.5 ]
[-0.0125 .60094 -6 -4.5 ]
[-0.0125 .60094 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .018 m
.00625 .018 L
s
[(-3)] -0.0125 .018 1 0 Mshowa
0 .11516 m
.00625 .11516 L
s
[(-2)] -0.0125 .11516 1 0 Mshowa
0 .21232 m
.00625 .21232 L
s
[(-1)] -0.0125 .21232 1 0 Mshowa
0 .30947 m
.00625 .30947 L
s
[(0)] -0.0125 .30947 1 0 Mshowa
0 .40663 m
.00625 .40663 L
s
[(1)] -0.0125 .40663 1 0 Mshowa
0 .50378 m
.00625 .50378 L
s
[(2)] -0.0125 .50378 1 0 Mshowa
0 .60094 m
.00625 .60094 L
s
[(3)] -0.0125 .60094 1 0 Mshowa
.125 Mabswid
0 .03744 m
.00375 .03744 L
s
0 .05687 m
.00375 .05687 L
s
0 .0763 m
.00375 .0763 L
s
0 .09573 m
.00375 .09573 L
s
0 .13459 m
.00375 .13459 L
s
0 .15402 m
.00375 .15402 L
s
0 .17345 m
.00375 .17345 L
s
0 .19288 m
.00375 .19288 L
s
0 .23175 m
.00375 .23175 L
s
0 .25118 m
.00375 .25118 L
s
0 .27061 m
.00375 .27061 L
s
0 .29004 m
.00375 .29004 L
s
0 .3289 m
.00375 .3289 L
s
0 .34833 m
.00375 .34833 L
s
0 .36776 m
.00375 .36776 L
s
0 .3872 m
.00375 .3872 L
s
0 .42606 m
.00375 .42606 L
s
0 .44549 m
.00375 .44549 L
s
0 .46492 m
.00375 .46492 L
s
0 .48435 m
.00375 .48435 L
s
0 .52321 m
.00375 .52321 L
s
0 .54264 m
.00375 .54264 L
s
0 .56208 m
.00375 .56208 L
s
0 .58151 m
.00375 .58151 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .018 m
1 .018 L
s
.99375 .11516 m
1 .11516 L
s
.99375 .21232 m
1 .21232 L
s
.99375 .30947 m
1 .30947 L
s
.99375 .40663 m
1 .40663 L
s
.99375 .50378 m
1 .50378 L
s
.99375 .60094 m
1 .60094 L
s
.125 Mabswid
.99625 .03744 m
1 .03744 L
s
.99625 .05687 m
1 .05687 L
s
.99625 .0763 m
1 .0763 L
s
.99625 .09573 m
1 .09573 L
s
.99625 .13459 m
1 .13459 L
s
.99625 .15402 m
1 .15402 L
s
.99625 .17345 m
1 .17345 L
s
.99625 .19288 m
1 .19288 L
s
.99625 .23175 m
1 .23175 L
s
.99625 .25118 m
1 .25118 L
s
.99625 .27061 m
1 .27061 L
s
.99625 .29004 m
1 .29004 L
s
.99625 .3289 m
1 .3289 L
s
.99625 .34833 m
1 .34833 L
s
.99625 .36776 m
1 .36776 L
s
.99625 .3872 m
1 .3872 L
s
.99625 .42606 m
1 .42606 L
s
.99625 .44549 m
1 .44549 L
s
.99625 .46492 m
1 .46492 L
s
.99625 .48435 m
1 .48435 L
s
.99625 .52321 m
1 .52321 L
s
.99625 .54264 m
1 .54264 L
s
.99625 .56208 m
1 .56208 L
s
.99625 .58151 m
1 .58151 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30947 m
1 .30947 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .46208 m
.02847 .37402 L
.03355 .27797 L
.03602 .23127 L
.03723 .20849 L
.03832 .18777 L
.03887 .17744 L
.03916 .17199 L
.03932 .16901 L
.03946 .16622 L
.03959 .16379 L
.03973 .46641 L
.03988 .46351 L
.04002 .46086 L
.04054 .45108 L
.04291 .40624 L
.0477 .31573 L
.05231 .22867 L
.05353 .20558 L
.05468 .18383 L
.05499 .17797 L
.05532 .17178 L
.0554 .17022 L
.05549 .16855 L
.05559 .47193 L
.05568 .47022 L
.05601 .46398 L
.05721 .44124 L
.0622 .34696 L
.06469 .29979 L
.067 .25614 L
.06925 .21377 L
.07038 .19238 L
.07069 .18652 L
.07102 .1802 L
.07118 .1773 L
.07126 .17571 L
.07134 .17424 L
.07148 .47685 L
.07163 .47399 L
.07634 .38499 L
.08134 .2904 L
.08385 .24298 L
.08495 .22216 L
.08553 .21112 L
.08616 .19926 L
.08647 .19337 L
.08677 .18777 L
.08704 .18274 L
.08719 .1799 L
Mistroke
.08733 .48248 L
.08747 .47979 L
.0876 .47725 L
.08785 .47251 L
.08842 .4619 L
.0908 .41681 L
.09546 .32881 L
.09782 .28417 L
.10041 .23523 L
.1016 .21271 L
.10226 .20032 L
.10258 .19422 L
.10288 .18859 L
.10302 .18586 L
.10316 .1833 L
.1033 .48585 L
.10345 .48291 L
.10408 .47105 L
.10518 .45033 L
.10985 .36203 L
.11222 .31715 L
.11482 .26813 L
.11602 .24545 L
.1173 .22126 L
.11792 .2095 L
.11851 .19842 L
.11876 .19358 L
.1189 .19094 L
.11903 .18847 L
.11917 .49102 L
.11933 .48808 L
.1196 .48292 L
.12429 .39431 L
.12927 .30011 L
.13177 .25299 L
.13286 .23226 L
.13345 .22124 L
.13408 .20936 L
.13437 .20382 L
.13453 .2008 L
.13468 .19798 L
.13481 .19558 L
.13494 .49822 L
.13509 .49537 L
.13523 .49277 L
.13632 .47227 L
.1387 .42729 L
.14351 .33623 L
.14815 .24863 L
.14939 .22526 L
Mistroke
.14999 .21383 L
.15025 .20884 L
.15054 .20338 L
.1507 .20046 L
.15084 .50297 L
.15098 .50037 L
.15112 .49761 L
.15175 .48579 L
.15308 .46066 L
.1581 .36584 L
.16062 .31824 L
.16293 .27447 L
.16519 .23171 L
.16574 .22132 L
.16605 .2156 L
.16633 .21018 L
.1665 .20712 L
.16659 .20539 L
.16667 .50901 L
.16682 .50619 L
.16698 .50319 L
.16758 .49179 L
.17214 .4057 L
.17699 .31402 L
.17922 .27188 L
.18048 .24801 L
.1811 .23637 L
.18166 .2258 L
.18195 .22035 L
.1821 .21747 L
.18226 .21443 L
.1824 .21177 L
.18256 .51407 L
.1827 .51141 L
.18283 .50892 L
.18408 .48532 L
.18662 .43722 L
.19131 .34869 L
.19369 .30365 L
.19495 .27987 L
.19629 .25457 L
.19696 .24184 L
.19759 .22987 L
.19787 .22464 L
.19816 .21912 L
.19832 .21623 L
.1984 .2146 L
.19848 .5183 L
.19863 .51561 L
.19878 .51274 L
Mistroke
.20108 .46913 L
.20608 .37471 L
.20858 .32741 L
.2109 .28373 L
.21314 .24126 L
.21369 .23094 L
.21399 .22524 L
.21414 .22244 L
.21428 .21983 L
.21436 .52358 L
.21444 .52201 L
.21461 .51869 L
.21492 .51286 L
.21553 .50144 L
.22054 .40671 L
.22537 .31543 L
.22759 .27357 L
.22884 .2498 L
.22946 .23819 L
.22975 .23269 L
.23002 .2276 L
.23016 .22499 L
.2303 .52744 L
.23045 .52465 L
.23061 .52158 L
.23118 .51091 L
.23242 .48741 L
.23496 .43942 L
.23981 .34783 L
.24204 .30575 L
.2433 .2819 L
.24447 .2597 L
.24507 .24835 L
.24564 .23764 L
.24579 .23476 L
.24588 .23318 L
.24596 .23171 L
.24604 .53534 L
.24613 .53359 L
.2463 .53051 L
.24689 .51928 L
.24943 .47121 L
.25412 .38277 L
.2565 .33779 L
.25909 .28875 L
.2603 .26599 L
.26096 .25351 L
.26128 .24739 L
.26158 .24176 L
.26173 .23899 L
Mistroke
.26186 .23641 L
.262 .53895 L
.26216 .53599 L
.26279 .52412 L
.26389 .50341 L
.26858 .41466 L
.27098 .36946 L
.27358 .32034 L
.27479 .29743 L
.27608 .27311 L
.2766 .26312 L
.27717 .25236 L
.27733 .24935 L
.2775 .24619 L
.27764 .24349 L
.2778 .54577 L
.27795 .54299 L
.2781 .54003 L
.27839 .53469 L
.2834 .44006 L
.28822 .34888 L
.29043 .30709 L
.29169 .28335 L
.29231 .27175 L
.29287 .26117 L
.29315 .25579 L
.2933 .25296 L
.29346 .24994 L
.2936 .24731 L
.29375 .54964 L
.29389 .547 L
.29402 .54452 L
.29527 .52104 L
.29781 .47309 L
.30247 .38506 L
.30483 .34039 L
.30608 .31674 L
.30742 .29146 L
.30809 .27889 L
.30872 .26702 L
.30899 .26184 L
.30928 .25636 L
.30943 .25349 L
.30952 .25186 L
.3096 .55556 L
.30974 .55289 L
.30989 .55001 L
.3122 .50654 L
.31717 .41263 L
.31965 .36572 L
Mistroke
.32196 .32218 L
.32311 .3005 L
.32419 .28007 L
.32479 .26876 L
.32495 .26566 L
.32513 .26239 L
.32527 .2596 L
.32536 .25801 L
.32544 .56175 L
.32558 .55899 L
.32572 .55637 L
.32598 .55145 L
.32657 .54041 L
.33119 .45312 L
.33611 .36025 L
.33855 .31412 L
.33975 .29154 L
.34027 .28165 L
.34055 .27642 L
.34085 .27083 L
.34099 .26802 L
.34114 .26536 L
.34126 .26298 L
.3414 .56561 L
.34153 .56316 L
.34167 .56056 L
.34191 .5559 L
.34304 .53469 L
.3454 .4901 L
.34997 .40384 L
.35251 .35585 L
.35484 .31201 L
.35599 .29031 L
.3563 .28437 L
.35664 .27804 L
.3568 .27497 L
.35695 .27207 L
.35709 .26948 L
.35724 .57189 L
.35738 .5692 L
.35751 .56669 L
.35782 .56098 L
.35843 .54947 L
.35952 .52886 L
.36422 .44019 L
.36661 .39502 L
.36921 .34596 L
.37043 .32306 L
.37172 .29877 L
.37224 .28878 L
Mistroke
.37254 .28327 L
.37281 .27804 L
.37297 .27509 L
.37306 .57865 L
.37314 .5771 L
.37344 .57146 L
.37403 .56041 L
.37874 .47147 L
.38375 .37698 L
.38627 .32958 L
.38737 .30879 L
.38796 .29777 L
.38828 .2917 L
.38858 .28595 L
.38873 .28328 L
.38888 .28044 L
.38895 .58418 L
.38904 .58255 L
.38919 .57967 L
.38975 .56917 L
.39084 .54861 L
.39323 .50362 L
.39808 .41234 L
.4003 .37041 L
.40156 .34665 L
.40274 .32453 L
.40391 .30255 L
.40424 .29623 L
.40441 .29312 L
.40456 .29025 L
.4047 .28765 L
.40484 .59011 L
.40499 .58734 L
.40515 .58429 L
.4077 .53641 L
.41256 .44493 L
.41724 .35693 L
.41846 .334 L
.4191 .32188 L
.41979 .30898 L
.42013 .30259 L
.4203 .29946 L
.42045 .29658 L
.42059 .29396 L
.42074 .59641 L
.42089 .59363 L
.42105 .59058 L
.42221 .56867 L
.42709 .47706 L
.43179 .38897 L
Mistroke
.43302 .36594 L
.43435 .34091 L
.43496 .32945 L
.43561 .31728 L
.43617 .3069 L
.43632 .30405 L
.4364 .30256 L
.43648 .30099 L
.43664 .60332 L
.43678 .60067 L
.44138 .51462 L
.44627 .4232 L
.45099 .3354 L
.45599 .24239 L
.46082 .15317 L
.46546 .06783 L
.4667 .04514 L
.46731 .03407 L
.46786 .02398 L
.46801 .02137 L
.46816 .01853 L
.46831 .32106 L
.46845 .31858 L
.46907 .30719 L
.4704 .28307 L
.47513 .19806 L
.47755 .15528 L
.48015 .10979 L
.48138 .08869 L
.48268 .06671 L
.48321 .05774 L
.48378 .04821 L
.48395 .04541 L
.48404 .04404 L
.48411 .04277 L
.48426 .34563 L
.48441 .34307 L
.485 .3335 L
.48974 .26019 L
.4943 .20211 L
.49664 .17994 L
.49795 .17004 L
.49916 .16204 L
.49947 .16015 L
.49975 .15839 L
.49991 .15741 L
.5 .15687 L
.50008 .46159 L
.50023 .46069 L
.50038 .45975 L
Mistroke
.50171 .45124 L
.50413 .4323 L
.5065 .40789 L
.50871 .38026 L
.51096 .34856 L
.5134 .31114 L
.51405 .30088 L
.51473 .28983 L
.51532 .2803 L
.51548 .27767 L
.51565 .27483 L
.51573 .27352 L
.51582 .27214 L
.51596 .57489 L
.51612 .57237 L
.51626 .57008 L
.51657 .56492 L
.51712 .55557 L
.51839 .53411 L
.52321 .45029 L
.52785 .36746 L
.53025 .32412 L
.53083 .31354 L
.53115 .3077 L
.53146 .30216 L
.53163 .29903 L
.53173 .29726 L
.53182 .60085 L
.53197 .59795 L
.53214 .59487 L
.53279 .58315 L
.53781 .49109 L
.54264 .40176 L
.5473 .31541 L
.55225 .22326 L
.55702 .13428 L
.55942 .08942 L
.5616 .04854 L
.56218 .03767 L
.56281 .02587 L
.5631 .02046 L
.56326 .01749 L
.56341 .01472 L
.56354 .31758 L
.56367 .31504 L
.56396 .30963 L
.56648 .26235 L
.57145 .1692 L
.57393 .12266 L
.57624 .07939 L
Mistroke
.57738 .05787 L
.57846 .03757 L
.57875 .03211 L
.57906 .02634 L
.57922 .02332 L
.57931 .02161 L
.5794 .32523 L
.57955 .32241 L
.57971 .3194 L
.58084 .29816 L
.58582 .20446 L
.58831 .15758 L
.59062 .11415 L
.59286 .07203 L
.59399 .05074 L
.5943 .04491 L
.59464 .03862 L
.59479 .03573 L
.59495 .03268 L
.59509 .03008 L
.59524 .33245 L
.5954 .32947 L
.59555 .32671 L
.59588 .32048 L
.59648 .30917 L
.5976 .28799 L
.60013 .24043 L
.60488 .151 L
.60726 .10608 L
.60944 .06499 L
.61002 .05417 L
.61032 .04845 L
.61064 .04236 L
.6108 .03935 L
.61095 .03651 L
.61109 .03396 L
.61123 .33643 L
.61137 .33381 L
.61152 .33104 L
.61178 .32608 L
.6143 .27861 L
.61888 .19224 L
.62143 .14413 L
.62376 .10028 L
.62492 .0785 L
.62552 .06701 L
.62617 .05481 L
.62644 .04969 L
.62674 .04417 L
.62682 .04263 L
Mistroke
.6269 .04101 L
.62706 .34334 L
.6272 .34063 L
.62736 .33766 L
.62845 .31697 L
.63335 .22466 L
.63806 .13579 L
.63929 .11247 L
.64063 .08719 L
.64125 .07559 L
.6419 .06332 L
.64245 .05284 L
.64261 .04997 L
.64269 .04839 L
.64277 .04689 L
.64292 .3492 L
.64307 .34655 L
.64768 .25947 L
.65259 .1668 L
.65486 .1239 L
.65732 .07757 L
.65797 .06518 L
.65833 .05841 L
.65851 .05511 L
.65867 .0521 L
.65881 .35456 L
.65895 .35194 L
.65926 .34617 L
.65991 .33393 L
.66234 .28798 L
.66697 .20055 L
.66931 .1563 L
.6719 .10754 L
.67308 .08527 L
.67373 .07299 L
.67405 .06693 L
.6742 .06398 L
.67435 .06131 L
.67449 .05861 L
.67462 .3613 L
.67477 .35861 L
.67492 .35571 L
.67554 .3439 L
.67664 .32319 L
.68158 .22986 L
.68405 .18338 L
.68634 .13996 L
.68855 .09825 L
.68919 .08624 L
.68979 .07486 L
Mistroke
.69005 .06991 L
.6902 .06719 L
.69033 .06464 L
.69048 .36712 L
.69056 .36566 L
.69064 .36409 L
.69092 .35874 L
.69588 .26508 L
.70066 .17486 L
.70306 .12941 L
.70411 .10959 L
.70525 .08809 L
.70556 .08229 L
.70588 .07615 L
.70616 .0709 L
.70632 .06792 L
.70647 .37035 L
.70662 .36755 L
.70676 .36489 L
.70702 .3599 L
.70762 .34867 L
.71014 .30095 L
.71475 .21387 L
.71733 .16524 L
.71966 .12119 L
.72083 .0991 L
.72144 .08748 L
.72178 .08114 L
.72194 .07804 L
.72209 .07522 L
.72223 .37778 L
.72237 .37526 L
.72266 .3697 L
.72329 .35791 L
.72438 .33718 L
.72901 .24978 L
.73135 .20555 L
.73393 .15678 L
.73511 .13453 L
.73638 .11057 L
.73696 .09955 L
.73728 .09354 L
.73757 .08795 L
.73783 .08316 L
.73797 .08048 L
.7381 .38327 L
.73824 .3806 L
.73839 .37771 L
.73867 .37245 L
.74361 .27914 L
Mistroke
.74837 .18928 L
.75076 .1441 L
.7518 .12436 L
.75294 .10286 L
.75324 .09714 L
.75357 .09104 L
.7537 .08854 L
.75384 .08584 L
.754 .3881 L
.75415 .38531 L
.75529 .36371 L
.75781 .31608 L
.76277 .22245 L
.76524 .17576 L
.76754 .13227 L
.76868 .11072 L
.76924 .10014 L
.76949 .09548 L
.76962 .09302 L
.76976 .09036 L
.76991 .39276 L
.77005 .39012 L
.77035 .38433 L
.771 .37211 L
.77213 .35076 L
.7771 .25681 L
.77958 .20988 L
.78189 .16631 L
.78412 .12418 L
.78476 .11205 L
.78508 .1061 L
.78537 .10062 L
.7855 .09804 L
.78563 .09563 L
.78576 .39834 L
.78591 .39558 L
.7865 .38449 L
.79119 .29581 L
.79618 .20154 L
.79867 .15437 L
.79977 .13362 L
.80036 .1226 L
.80098 .11072 L
.80128 .10517 L
.80144 .10214 L
.80159 .09933 L
.80171 .40214 L
.80185 .39956 L
.80214 .3941 L
.80323 .37359 L
Mistroke
.80561 .32859 L
.81061 .234 L
.81312 .18659 L
.81422 .16577 L
.81543 .14287 L
.816 .13226 L
.8166 .12087 L
.81689 .11535 L
.81717 .11011 L
.81729 .10783 L
.81742 .10541 L
.81756 .40797 L
.81769 .40551 L
.82007 .36042 L
.8251 .26552 L
.82762 .21786 L
.82993 .17408 L
.83111 .15192 L
.8322 .13126 L
.83275 .12085 L
.83291 .11785 L
.83306 .11502 L
.83319 .11247 L
.83334 .41493 L
.83349 .4121 L
.83366 .40897 L
.83399 .40265 L
.83459 .39131 L
.83945 .29955 L
.84412 .21125 L
.84649 .16637 L
.84775 .14266 L
.84844 .12963 L
.84877 .12324 L
.84892 .12043 L
.849 .11895 L
.84909 .11735 L
.84924 .41961 L
.84939 .41684 L
.84971 .41077 L
.85039 .398 L
.85157 .37569 L
.85387 .33214 L
.85886 .23793 L
.86135 .19081 L
.86245 .17008 L
.86366 .14718 L
.86421 .13668 L
.86451 .13117 L
.86466 .12816 L
Mistroke
.86481 .12536 L
.86494 .12289 L
.86508 .42548 L
.86524 .42255 L
.86538 .41989 L
.8659 .41009 L
.86828 .3651 L
.8731 .27404 L
.87773 .18642 L
.87897 .16305 L
.88013 .14117 L
.88042 .13553 L
.88071 .13017 L
.88086 .12722 L
.88095 .12555 L
.88103 .42922 L
.88118 .42648 L
.88133 .42357 L
.88266 .39845 L
.88768 .30361 L
.8902 .25601 L
.89252 .21223 L
.89478 .16947 L
.89592 .14793 L
.89623 .14203 L
.8964 .13879 L
.89656 .13571 L
.89672 .13285 L
.8968 .13124 L
.89688 .43497 L
.89702 .43233 L
.89717 .42953 L
.90172 .34343 L
.90657 .25174 L
.9088 .20959 L
.91007 .18571 L
.91124 .1635 L
.91184 .15213 L
.91214 .14654 L
.91241 .14139 L
.91257 .13851 L
.91264 .13705 L
.91273 .44068 L
.91281 .43907 L
.9129 .43735 L
.91307 .43424 L
.91366 .42301 L
.91621 .3749 L
.92119 .28076 L
.92368 .23369 L
Mistroke
.92599 .19008 L
.92714 .1683 L
.9277 .15762 L
.92822 .14782 L
.92837 .14496 L
.92851 .14229 L
.92866 .44473 L
.92874 .44326 L
.92882 .44169 L
.92947 .42943 L
.9306 .40807 L
.9356 .31362 L
.9381 .26631 L
.94041 .22262 L
.94266 .18014 L
.9438 .1587 L
.94411 .15283 L
.94428 .14959 L
.94436 .14799 L
.94444 .14651 L
.94459 .44888 L
.94467 .44737 L
.94476 .44576 L
.94504 .44031 L
.95006 .34554 L
.95489 .25423 L
.95711 .21236 L
.95836 .18858 L
.95898 .17697 L
.95954 .16638 L
.95982 .16099 L
.95997 .15814 L
.96013 .15512 L
.96027 .15249 L
.96043 .45481 L
.96057 .45216 L
.9607 .44968 L
.96194 .42617 L
.96448 .37816 L
.96915 .28999 L
.97411 .19624 L
.97619 .15686 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.03968 .30947 m
.03968 .30947 L
s
.05556 .30947 m
.05556 .30947 L
s
.07143 .30947 m
.07143 .30947 L
s
.0873 .30947 m
.0873 .30947 L
s
.10317 .30947 m
.10317 .30947 L
s
.11905 .30947 m
.11905 .30947 L
s
.13492 .30947 m
.13492 .30947 L
s
.15079 .30947 m
.15079 .30947 L
s
.16667 .30947 m
.16667 .30947 L
s
.18254 .30947 m
.18254 .30947 L
s
.19841 .30947 m
.19841 .30947 L
s
.21429 .30947 m
.21429 .30947 L
s
.23016 .30947 m
.23016 .30947 L
s
.24603 .30947 m
.24603 .30947 L
s
.2619 .30947 m
.2619 .30947 L
s
.27778 .30947 m
.27778 .30947 L
s
.29365 .30947 m
.29365 .30947 L
s
.30952 .30947 m
.30952 .30947 L
s
.3254 .30947 m
.3254 .30947 L
s
.34127 .30947 m
.34127 .30947 L
s
.35714 .30947 m
.35714 .30947 L
s
.37302 .30947 m
.37302 .30947 L
s
.38889 .30947 m
.38889 .30947 L
s
.40476 .30947 m
.40476 .30947 L
s
.42063 .30947 m
.42063 .30947 L
s
.43651 .30947 m
.43651 .30947 L
s
.45238 .30947 m
.45238 .30947 L
s
.46825 .30947 m
.46825 .30947 L
s
.48413 .30947 m
.48413 .30947 L
s
.5 .30947 m
.5 .30947 L
s
.51587 .30947 m
.51587 .30947 L
s
.53175 .30947 m
.53175 .30947 L
s
.54762 .30947 m
.54762 .30947 L
s
.56349 .30947 m
.56349 .30947 L
s
.57937 .30947 m
.57937 .30947 L
s
.59524 .30947 m
.59524 .30947 L
s
.61111 .30947 m
.61111 .30947 L
s
.62698 .30947 m
.62698 .30947 L
s
.64286 .30947 m
.64286 .30947 L
s
.65873 .30947 m
.65873 .30947 L
s
.6746 .30947 m
.6746 .30947 L
s
.69048 .30947 m
.69048 .30947 L
s
.70635 .30947 m
.70635 .30947 L
s
.72222 .30947 m
.72222 .30947 L
s
.7381 .30947 m
.7381 .30947 L
s
.75397 .30947 m
.75397 .30947 L
s
.76984 .30947 m
.76984 .30947 L
s
.78571 .30947 m
.78571 .30947 L
s
.80159 .30947 m
.80159 .30947 L
s
.81746 .30947 m
.81746 .30947 L
s
.83333 .30947 m
.83333 .30947 L
s
.84921 .30947 m
.84921 .30947 L
s
.86508 .30947 m
.86508 .30947 L
s
.88095 .30947 m
.88095 .30947 L
s
.89683 .30947 m
.89683 .30947 L
s
.9127 .30947 m
.9127 .30947 L
s
.92857 .30947 m
.92857 .30947 L
s
.94444 .30947 m
.94444 .30947 L
s
.96032 .30947 m
.96032 .30947 L
s
.97619 .30947 m
.97619 .30947 L
s
.015 w
.03968 .30947 Mdot
.05556 .30947 Mdot
.07143 .30947 Mdot
.0873 .30947 Mdot
.10317 .30947 Mdot
.11905 .30947 Mdot
.13492 .30947 Mdot
.15079 .30947 Mdot
.16667 .30947 Mdot
.18254 .30947 Mdot
.19841 .30947 Mdot
.21429 .30947 Mdot
.23016 .30947 Mdot
.24603 .30947 Mdot
.2619 .30947 Mdot
.27778 .30947 Mdot
.29365 .30947 Mdot
.30952 .30947 Mdot
.3254 .30947 Mdot
.34127 .30947 Mdot
.35714 .30947 Mdot
.37302 .30947 Mdot
.38889 .30947 Mdot
.40476 .30947 Mdot
.42063 .30947 Mdot
.43651 .30947 Mdot
.45238 .30947 Mdot
.46825 .30947 Mdot
.48413 .30947 Mdot
.5 .30947 Mdot
.51587 .30947 Mdot
.53175 .30947 Mdot
.54762 .30947 Mdot
.56349 .30947 Mdot
.57937 .30947 Mdot
.59524 .30947 Mdot
.61111 .30947 Mdot
.62698 .30947 Mdot
.64286 .30947 Mdot
.65873 .30947 Mdot
.6746 .30947 Mdot
.69048 .30947 Mdot
.70635 .30947 Mdot
.72222 .30947 Mdot
.7381 .30947 Mdot
.75397 .30947 Mdot
.76984 .30947 Mdot
.78571 .30947 Mdot
.80159 .30947 Mdot
.81746 .30947 Mdot
.83333 .30947 Mdot
.84921 .30947 Mdot
.86508 .30947 Mdot
.88095 .30947 Mdot
.89683 .30947 Mdot
.9127 .30947 Mdot
.92857 .30947 Mdot
.94444 .30947 Mdot
.96032 .30947 Mdot
.97619 .30947 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005_ooool3o`0000Cooooo0_l0000iooooo`?o0000>oooool2o`0003cooooo0ol0000ioooo
o`?o00001?ooool2o`0000Oooooo000Gooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000=oooool01Ol0003ooooooooooooooooo000003Wooooo00Co0000oooooooooooo0000>_oo
ool01Ol0003ooooooooooooooooo000003Wooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00006ooooo`003oooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000aooooo`Go00001Oooool00ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`00
03kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Kooooo000Gooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000>oooool0
0ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`0003kooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo000Gooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000=oooool4o`0003[ooooo00Co0000oooooooooooo
0000>_ooool4o`0003[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006oooo
o`005_ooool2o`0000Cooooo00Co0000oooooooooooo0000=oooool00ol0003oooooooooo`0koooo
o`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool0>_ooool2o`0000Cooooo00Co0000
oooooooooooo00001_ooool001Oooooo00?o0000ooooooooool00oooool2o`0003Sooooo1Ol0000j
ooooo`;o0000>oooool5o`0003Wooooo00?o0000ooooooooool00oooool2o`0000Oooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Aoooooooo00003Ol00003
ooooo`004Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo007ooooo0009ooooo`?o
00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool0?Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`01ooooo`002?ooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo007o
oooo0002ooooo`Go00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08?ooooo
00?o0000ooooooooool03Oooool00ol00?ooooooooooo`1booooo`03o`000?oooooooooo007ooooo
000:ooooo`;o00001Oooool3o`0007[ooooo00?o003oooooooooool01_ooool00ol0003ooooooooo
o`0=ooooo`03o`00oooooooooooo073ooooo0ol00003ooooo`003?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo07[ooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`0=
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0KOooool00ol0003oooooooooo`01
ooooo`002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0N_ooool0
0ol00?ooooooooooo`06ooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`1]ooooo`03o`000?oooooooooo007ooooo0009ooooo`?o00001Oooool00ol0
003oooooooooo`1jooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0Joooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`1jooooo`03o`00oooooooooooo00Kooooo00?o0000oooo
ooooool03Oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`1Uooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000Noooool00ol0
0?ooooooooooo`06ooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0I?ooool2o`0000?ooooo000Aoooo
o`03o`000?oooooooooo07[ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`000?oooooo
oooo00gooooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l0
Ioooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1jooooo`05o`00oooo
ooooooooooooool00?l01?ooool00ol0003oooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo06Gooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool0N_ooool01Ol00?oooooooooooooooooo003o00Co
oooo00?o0000ooooooooool03Oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0G?ooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1jooooo`03o`00oooooooooooo
00Kooooo00?o0000ooooooooool03Oooool01?l00?ooooooooooooooool2o`00o`?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`1Jooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000N_ooool2o`00o`?ooooo00?o
003oooooooooool00_ooool00ol0003oooooooooo`0=ooooo`05o`00ooooooooooooooooool00?l0
1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?l3oooo
o`03o`00oooooooooooo05Oooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1iooooo`;o
003o0oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00gooooo00Co003ooooooooo
oooooooo0_l00?l2ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo05Cooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0N_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o
0000ooooooooool04_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00Kooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0D_ooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1jooooo`05o`00oooooooooooooooo
ool00?l01?ooool00ol0003oooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo00Co003ooooo
oooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`1;ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07Wooooo00?o
003oooooooooool01oooool00ol0003oooooooooo`0=ooooo`04o`00ooooooooooooooooo`;o003o
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo04_ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001jooooo`;o003o0oooool00ol0
0?ooooooooooo`02ooooo`03o`000?oooooooooo00gooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00o`?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`18ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0NOooool2o`00o`?o
oooo00?o003oooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00;o
oooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool2
o`00o`?ooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`15ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo07[ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`000?oooooooooo00cooooo
00?o003oooooooooool00_ooool2o`00o`;ooooo00Co003ooooooooooooooooo0_l00?l8ooooo`03
o`00oooooooooooo00;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o04Gooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool0N_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o0000
ooooooooool03Oooool01?l00?ooooooooooooooool2o`00o`;ooooo00Go003ooooooooooooooooo
o`00o`08ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooo
oooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0o
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07Wooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00cooooo0_l00?l4oooo
o`03o`00oooooooooooo00;o003o0_ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo
0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
03gooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001jooooo`03o`00oooooooooooo00Oo
oooo00?o0000ooooooooool03?ooool2o`00o`Sooooo00?o003oooooooooool00_l00?l3ooooo`04
o`00ooooooooooooooooo`;o003o0_ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l01?ooool00ol00?ooooooooooo`02o`00o`?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0=Oooool2o`0000?ooooo000A
ooooo`03o`000?oooooooooo07Wooooo0_l00?l3ooooo`03o`00oooooooooooo00;ooooo00?o0000
ooooooooool03?ooool2o`00o`?ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00oooo
ooooooooooooool00?l00oooool2o`00o`;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`05ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`03o`00oooooooooooo03Kooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool0NOooool2o`00o`?ooooo00?o003oooooooooool00_ooool00ol0003o
ooooooooo`0<ooooo`03o`00oooooooooooo00;ooooo0_l00?l2ooooo`;o003o0oooool01Ol00?oo
oooooooooooooooo003o00Cooooo00?o003oooooooooool00_l00?l3ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0=?ooool00ol0003ooooo
ooooo`01ooooo`002?ooool5o`0000Cooooo00?o0000ooooooooool0N_ooool00ol00?oooooooooo
o`02o`00o`Cooooo00?o0000ooooooooool03Oooool01_l00?ooooooooooool00?ooooooo`00o`;o
oooo00Go003oooooooooooooooooo`00o`09ooooo`05o`00ooooooooooooooooool00?l00_ooool0
0ol00?ooooooooooo`02ooooo`04o`00ooooooooooooooooo`;o003o0_ooool2o`00o`?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo02kooooo00?o0000ooooooooool00Oooool000Wooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1iooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol0003oooooooooo`0=ooooo`06o`00ooooooooooooo`00
oooooooo003o0_ooool2o`00o`;ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_l00?l3ooooo`04o`00ooooooooooooooooo`;o003o
0_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0^oooo
o`03o`000?oooooooooo007ooooo0002ooooo`Go00000oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo07Wooooo00?o003oooooooooool01oooool00ol0003oooooooooo`0<ooooo`;o
003o1?ooool01Ol00?oooooooooooooooooo003o00;ooooo0_l00?l2ooooo`;o003o0oooool01?l0
0?ooooooooooooooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooooooooooooooo
o`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0:_ooool0
0ol0003oooooooooo`01ooooo`002oooool00ol0003oooooooooo`03ooooo`?o0000NOooool2o`00
o`;ooooo00?o003oooooooooool00oooool00ol0003oooooooooo`0<ooooo`;o003o0_ooool00ol0
0?ooooooooooo`03ooooo`05o`00ooooooooooooooooool00?l00_ooool2o`00o`?ooooo0_l00?l2
ooooo`04o`00ooooooooooooooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool2o`00o`?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo02?ooooo0ol00003ooooo`002?ooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool0NOooool2o`00o`;ooooo0_l00?l4ooooo`03o`000?oooooooooo00co
oooo00Oo003oooooooooooooooooo`00oooooooo003o00;ooooo0_l00?l3ooooo`03o`00oooooooo
oooo00;o003o1?ooool00ol00?ooooooooooo`02o`00o`;ooooo0_l00?l7ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_l00?l3ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01oooool2o`00obOooooo
00?o0000ooooooooool00Oooool000Sooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo07[ooooo00?o003oooooooooool00_l00?l4ooooo`03o`000?oooooooooo013ooooo
00?o003oooooool00?l00_ooool01?l00?ooooooooooooooool2o`00o`Sooooo00?o003ooooooooo
ool00_l00?l2ooooo`04o`00ooooooooooooooooo`;o003o0oooool01?l00?ooooooooooooooool2
o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
1?ooool01Ol00?oooooooooooooooooo003o00Sooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo01gooooo00?o0000ooooooooool00Oooool000Wooooo0ol00005ooooo`03
o`000?oooooooooo07[ooooo00?o003oooooooooool00_l00?l4ooooo`03o`000?oooooooooo00go
oooo00So003ooooooooooooo003oooooool00?ooooooo`00o`Cooooo00?o003oooooooooool00_oo
ool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00o`?ooooo
0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l02?ooool01Ol00?oooooooooooooooooo003o01oooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0N?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooo
oooo00cooooo0_l00?l4ooooo`05o`00ooooooooooooooooool00?l00_ooool2o`00o`;ooooo0_l0
0?l2ooooo`03o`00oooooooooooo00;ooooo0_l00?l3ooooo`03o`00oooooooooooo00;o003o1?oo
ool01?l00?ooooooooooool00?l3ooooo`;o003o0_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_l00?l3ooooo`05o`00ooooooooooooooooool0
0?l00oooool2o`00o`Oooooo00Go003oooooooooooooooooo`00o`0Kooooo`03o`000?oooooooooo
007ooooo000Aooooo`;o0000NOooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00?o
oooo00?o0000ooooooooool03?ooool2o`00o`Sooooo00?o003oooooooooool00_l00?l2ooooo`;o
003o0_ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_l00?l4ooooo`03o`00oooooooooooo00;o003o0_ooool01?l00?ooooooooooooooool2o`00
o`?ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`03o`00oooooooooooo00Gooooo00Co003o
oooooooooooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`0Hooooo`;o00000oooool0017ooooo00?o0000ooooooooool0N?ooool00ol00?ooooooo`00
o`02ooooo`;o003o1?ooool00ol0003oooooooooo`0<ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00;o003o0_ooool00ol00?oooooo
o`00o`02ooooo`04o`00ooooooooooooooooo`;o003o1_ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooo
oooooooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l05oooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1jooooo`03o`00oooooooooooo00;o003o
1?ooool00ol0003oooooooooo`0<ooooo`09o`00ooooooooooooooooool00?ooooooo`00oooooooo
003o00Cooooo0_l00?l8ooooo`03o`00oooooooooooo00;o003o0_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool2o`00o`?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00Gooooo0_l00?l2ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o
00?ooooo0_l00?l3ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool0N_ooool00ol00?ooooooooooo`02o`00o`Cooooo00?o0000oooooooo
ool03Oooool02?l00?ooooooooooool00?ooooooo`00oooooooo003o1?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool2o`00o`;ooooo
00?o003oooooool00?l00_ooool2o`00o`?ooooo00?o003oooooooooool00_l00?l3ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_l00?l3ooooo`05o`00ooooooooooooooooool0
0?l01oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0oooool00ol0
0?ooooooooooo`0@ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07So
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00co
oooo0_l00?l4ooooo`05o`00oooooooo003oooooool00?l00_ooool01?l00?ooooooooooooooool2
o`00o`;ooooo00?o003oooooooooool00oooool01Ol00?oooooooooooooooooo003o00;ooooo0_l0
0?l2ooooo`03o`00oooooooo003o00;ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02o`00o`;ooooo
0_l00?l3ooooo`05o`00ooooooooooooooooool00?l02?ooool01Ol00?oooooooooooooooooo003o
00?ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l03_ooool00ol0003oooooooooo`01
ooooo`004Oooool2o`0007Wooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0<oooo
o`;o003o2?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo0_l00?l2ooooo`05o`00oooooooo
003oooooool00?l01Oooool00ol00?ooooooooooo`02o`00o`Cooooo00?o003oooooooooool00_l0
0?l2ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooooooool2o`00o`?o
oooo00?o003oooooooooool01Oooool01?l00?ooooooooooooooool2o`00o`Oooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Wooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1hooooo`03o`00oooo
oooo003o00;ooooo0_l00?l4ooooo`03o`000?oooooooooo00_ooooo00?o003oooooool00?l00_oo
ool01ol00?oooooooooooooooooo003oooooool00?l00oooool00ol00?ooooooooooo`02o`00o`;o
oooo00Go003oooooool00?ooooooo`00o`04ooooo`;o003o1_ooool00ol00?ooooooo`00o`03oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool2o`00o`?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o0_ooool2o`00o`?o
oooo00Go003oooooooooooooooooo`00o`08ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`08ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
07Sooooo00?o003oooooool00?l00_ooool2o`00o`?ooooo0_l00?l=ooooo`03o`00oooooooooooo
00;ooooo00Oo003oooooool00?ooooooo`00oooooooo003o00?ooooo00?o003oooooooooool01_oo
ool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00;o003o0oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o1oooool2o`00o`;ooooo0_l00?l3oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Kooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`1_ooooo`05o`00oooo
oooo003oooooool00?l00oooool2o`00o`oooooo00So003ooooooooooooo003oooooool00?oooooo
o`00o`?ooooo00?o003oooooooooool02?ooool01Ol00?oooooooooooooooooo003o00;ooooo00Co
003ooooooooooooooooo0_l00?l2ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`03oooo
o`03o`00oooooooooooo00;o003o0oooool01?l00?ooooooooooooooool2o`00o`;ooooo00Co003o
oooooooooooooooo0_l00?l3ooooo`03o`00oooooooooooo00Gooooo0_l00?l2ooooo`;o003o0ooo
ool01?l00?ooooooooooooooool2o`00o`;ooooo00?o003oooooooooool01_ooool01Ol00?oooooo
oooooooooooo003o00Kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
2?ooool01Ol00?oooooooooooooooooo003o06_ooooo00?o003oooooooooool00oooool01?l00?oo
ooooooooooooool2o`00o`oooooo00co003ooooooooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?l4ooooo`;o003o0_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00;o003o0_ooool2o`00o`;ooooo00Go003oooooool00?ooooooo`00o`04ooooo`;o003o0_ooool0
1?l00?ooooooooooooooool2o`00o`Cooooo00?o003oooooooooool00_l00?l2ooooo`;o003o0ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooooooo
0_l00?l2ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool01?ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000Wooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool01oooool00ol00?oo
0000ooooo`0<ooooo`03o`00oooooooo003o00Cooooo00Wo003oooooooooooooooooo`00oooooooo
003oooooool00?l00_ooool2o`00o`;ooooo00Oo003oooooooooooooooooo`00oooooooo003o00?o
oooo00?o003oooooooooool00_l00?l4ooooo`03o`00oooooooo003o00Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo0_l00?l3ooooo`03o`00oooooooooooo
00Cooooo0_l00?l3ooooo`;o003o1_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_l00?l3ooooo`03o`00oooooooooooo00_ooooo0_l00003oooo
o`004Oooool00ol0003oooooooooo`08ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`1Uooooo`05o`00oooooooo003oooooool00?l01_ooool00ol0003oooooooooo`0;
ooooo`05o`00oooooooo003oooooool00?l01_ooool02Ol00?oooooooooooooooooo003oooooool0
0?ooooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l00oooool00ol00?ooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooo
oooooooo00;ooooo00Co003ooooooooooooo003o1?ooool2o`00o`?ooooo00?o003oooooooooool0
1?ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00So
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Sooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool02?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Pooooo`07o`00oooooooo003o
ooooool00?ooooooo`00o`04ooooo`03o`00oooooooooooo00_ooooo00Go003ooooooooooooooooo
o`00o`02ooooo`05o`00oooooooo003oooooool00?l00oooool01Ol00?ooooooo`00oooooooo003o
00Cooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l01_ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00;o003o0oooool00ol00?ooooooooooo`02o`00o`;ooooo
00?o003oooooooooool00_ooool01?l00?ooooooooooooooool2o`00o`Oooooo0_l00?l2ooooo`;o
003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`06ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo00Sooooo00Go003oooooooooooooooooo`00
o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`1Nooooo`05o`00
oooooooo003oooooool00?l00oooool2o`00oa7ooooo00Ko003ooooooooooooo003oooooool00?l3
ooooo`03o`00oooooooo003o00Sooooo00Oo003oooooool00?ooooooo`00oooooooo003o00Cooooo
0_l00?l2ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`03ooooo`03o`00oooooooooooo
00;o003o0oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooooooo`;o003o2?oo
ool00ol00?ooooooooooo`02o`00o`;ooooo0_l00?l3ooooo`04o`00ooooooooooooooooo`;o003o
0_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`04ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Sooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo05[ooooo00Go003oooooool00?ooooooo`00o`03
ooooo`;o003o3oooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo003o00?ooooo00Oo003o
ooooooooooooooooo`00oooooooo003o00;ooooo00?o003oooooooooool00oooool01Ol00?oooooo
o`00oooooooo003o00;ooooo0_l00?l2ooooo`05o`00oooooooo003oooooool00?l01Oooool00ol0
0?ooooooooooo`02o`00o`;ooooo0_l00?l4ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00
o`;ooooo0_l00?l7ooooo`;o003o0_ooool2o`00o`?ooooo00Co003ooooooooooooooooo0_l00?l2
ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00Kooooo
00?o0000ooooooooool00Oooool0017ooooo0_l00009ooooo`05o`00ooooooooooooooooool00?l0
0oooool01?l00?ooooooooooooooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`1Joooo
o`03o`00oooooooooooo00Kooooo00?o003oooooool00?l03Oooool00ol00?ooooooo`00o`04oooo
o`0=o`00ooooooooooooooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`02oooo
o`07o`00ooooooooooooooooool00?ooooooo`00o`03ooooo`05o`00oooooooo003oooooool00?l0
1?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooo003o00;ooooo00Co003ooooooooooooo
oooo0_l00?l4ooooo`03o`00oooooooooooo00;o003o0_ooool01?l00?ooooooooooooooool2o`00
o`?ooooo0_l00?l6ooooo`04o`00ooooooooooooooooo`;o003o0oooool2o`00o`;ooooo0_l00?l2
ooooo`;o003o1oooool00ol00?ooooooooooo`03ooooo`;o00000oooool0017ooooo00?o0000oooo
ooooool02?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`1Dooooo`05o`00
oooooooo003oooooool00?l01_ooool00ol0003oooooooooo`0;ooooo`03o`00oooooooo003o00So
oooo00_o003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00
oooooooo003o00Gooooo00Go003oooooool00?ooooooo`00o`04ooooo`07o`00oooooooo003ooooo
ool00?ooooooo`00o`04ooooo`;o003o0_ooool01ol00?oooooooooooooooooo003oooooool00?l0
0oooool00ol00?ooooooooooo`04ooooo`;o003o0oooool2o`00o`;ooooo0_l00?l2ooooo`;o003o
0_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00o`?ooooo
00?o003oooooooooool02?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`08ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool0C_ooool02?l00?ooooooooooool00?ooooooo`00oooooooo003o1?ooool00ol00?oooooo
ooooo`0;ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooo`00o`03ooooo`07
o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00?ooooo00?o003o
ooooool00?l01_ooool00ol00?ooooooooooo`03ooooo`05o`00oooooooo003oooooool00?l00ooo
ool00ol00?ooooooooooo`02o`00o`;ooooo00Oo003oooooooooooooooooo`00oooooooo003o00;o
oooo0_l00?l3ooooo`06o`00ooooooooooooo`00oooooooo003o0_ooool2o`00o`?ooooo00?o003o
ooooooooool00_l00?l3ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?l3
ooooo`05o`00ooooooooooooooooool00?l01_ooool00ol0003oooooooooo`01ooooo`002Oooool3
o`0000Gooooo00?o0000ooooooooool01oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`1Aooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?oo
ooooo`00o`0=ooooo`05o`00ooooooooooooooooool00?l00_ooool2o`00o`Cooooo00?o003ooooo
ool00?l02?ooool01ol00?ooooooo`00oooooooo003oooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`03ooooo`03o`00oooooooooooo00;o
003o0oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00;ooooo0_l00?l6oooo
o`03o`00oooooooo003o00;ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l2oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?l3ooooo`03o`00oooooooooooo
00Cooooo00?o0000ooooooooool00Oooool000[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`08ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`1?ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?oo
ooooo`00o`0?ooooo`03o`00oooooooo003o00;ooooo0_l00?l4ooooo`03o`00oooooooooooo00Go
oooo00Co003ooooooooooooo003o0oooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooo003o
00;ooooo00Oo003oooooool00?ooooooo`00oooooooo003o00?ooooo00?o003oooooooooool00_l0
0?l3ooooo`03o`00oooooooooooo00;ooooo00Go003oooooool00?ooooooo`00o`02ooooo`;o003o
0_ooool2o`00o`Oooooo0_l00?l2ooooo`;o003o0oooool01_l00?ooooooooooool00?ooooooo`00
o`;ooooo00?o003oooooooooool01Oooool2o`00o`?ooooo00?o003oooooooooool01?ooool00ol0
003oooooooooo`01ooooo`000_ooool5o`0000?ooooo00?o0000ooooooooool01?ooool3o`0000So
oooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o0oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00
ooooooooooooooooool00?l0B?ooool00ol00?ooooooooooo`04ooooo`06o`00ooooooooooooo`00
oooooooo003o3Oooool00ol00?ooooooo`00o`04ooooo`;o003o0_ooool00ol00?ooooooo`00o`03
ooooo`05o`00oooooooo003oooooool00?l01_ooool02Ol00?oooooooooooooooooo003oooooool0
0?ooooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l00oooool01Ol00?ooooooo`00oooo
oooo003o00Cooooo0_l00?l4ooooo`05o`00oooooooo003oooooool00?l00_ooool2o`00o`;ooooo
0_l00?l2ooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooooooooooo0_l00?l2ooooo`03
o`00oooooooo003o00;ooooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`?o00000oooool000[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`07ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooo
oooooooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`12ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00000=ooooo`03o`00
oooooooo003o00Sooooo00_o003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
o`02ooooo`03o`00oooooooo003o00Gooooo00Go003oooooool00?ooooooo`00o`04ooooo`07o`00
oooooooo003oooooool00?ooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Oo003ooooo
ooooooooooooo`00oooooooo003o00?ooooo00?o003oooooooooool01?ooool2o`00o`;ooooo00?o
003oooooool00?l01_ooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooooooool0
0_l00?l2ooooo`;o003o0_ooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo007ooooo
000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool01?l00?oooooooooo
ooooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0oooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0mooooo`08o`00oooooooo
ooooo`00oooooooo003oooooool00?l4ooooo`03o`000?oooooooooo00_ooooo00Go003oooooool0
0?ooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00Oo003oooooool00?ooooooo`00
oooooooo003o00;ooooo00?o003oooooool00?l00oooool00ol00?ooooooo`00o`05ooooo`04o`00
ooooooooooooo`00o`?ooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l3oooo
o`03o`00oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`02ooooo`;o003o0_ooool0
1ol00?ooooooo`00oooooooo003oooooool00?l00oooool01?l00?ooooooooooool00?l9ooooo`03
o`00oooooooooooo00;o003o0_ooool2o`00o`[ooooo00?o0000ooooooooool00Oooool000Wooooo
0_l00006ooooo`03o`000?oooooooooo00Oooooo00Go003oooooooooooooooooo`00o`04ooooo`04
o`00ooooooooooooooooo`;o003o0_ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`;o003o0oooool00ol00?ooooooooooo`09ooooo`;o003o?oooool02?l00?ooooooooooool0
0?ooooooo`00oooooooo003o0_ooool00ol00?ooooooo`00o`0=ooooo`05o`00oooooooooooooooo
ool00?l00_ooool2o`00o`;ooooo00Go003oooooooooooooooooo`00o`08ooooo`;o003o0_ooool0
0ol00?ooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01_ooool01Ol00?ooooooo`00
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`02ooooo`05o`00oooooooooooooooo
ool00?l01?ooool2o`00o`Kooooo00Oo003oooooool00?ooooooo`00oooooooo003o00?ooooo00?o
003oooooooooool00_l00?l2ooooo`03o`00oooooooooooo00?ooooo00Go003ooooooooooooooooo
o`00o`02ooooo`;o003o0oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo007ooooo
000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool01?l00?oooooooooo
ool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?l3ooooo`05o`00
ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02o`00o`?ooooo00?o003ooooooooo
ool01Oooool2o`00o`?ooooo00?o003oooooooooool0??ooool01Ol00?ooooooo`00oooooooo003o
00;ooooo00?o003oooooool00?l03oooool00ol00?ooooooo`00o`02ooooo`;o003o0oooool00ol0
0?ooooooooooo`09ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`03ooooo`05o`00oooo
oooo003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo003o00?ooooo00Go003oooooool0
0?ooooooo`00o`03ooooo`08o`00ooooooooooooo`00oooooooo003oooooool00?l4ooooo`;o003o
0_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo003o00;ooooo0_l00?l3ooooo`06o`00
ooooooooooooo`00oooooooo003o0_ooool00ol00?ooooooooooo`05ooooo`;o003o0oooool00ol0
0?ooooooooooo`04ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00So
oooo00?o003oooooooooool00_l00?l3ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0>Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooo`00o`02ooooo`;o003o0_ooool2o`00o`Cooooo00Go003oooooool00?oooooo
o`00o`06ooooo`0;o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l00_oo
ool00ol00?ooooooo`00o`03ooooo`05o`00oooooooo003oooooool00?l00oooool00ol00?oooooo
o`00o`04ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00;ooooo0_l00?l;
ooooo`03o`00oooooooooooo00;ooooo00Ko003ooooooooooooo003oooooool00?l2ooooo`;o003o
0_ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Oooooo00?o0000oooooooo
ool00Oooool0017ooooo0_l00008ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?o
oooo0_l00?l2ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`04ooooo`05o`00ooooooooooooooooool00?l0=oooool00ol00?ooooooooooo`06ooooo`04o`00
ooooooooooooo`0000cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooooooool2
o`00o`;ooooo00Oo003oooooool00?ooooooo`00oooooooo003o00?ooooo00?o003oooooooooool0
1?ooool01Ol00?ooooooo`00oooooooo003o00Cooooo0_l00?l4ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00?ooooo00?o003ooooo
ooooool01?ooool2o`00o`;ooooo00?o003oooooool00?l01_ooool01Ol00?oooooooooooooooooo
003o00Gooooo00Go003oooooool00?ooooooo`00o`02ooooo`;o003o3Oooool2o`0000?ooooo000A
ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03
ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0<Ooo
ool00ol00?ooooooooooo`02o`00o`Oooooo00?o0000ooooooooool02_ooool01_l00?oooooooooo
ool00?ooooooo`00o`Kooooo00_o003oooooooooooooooooo`00oooooooo003oooooool00?oooooo
o`00o`02ooooo`;o003o1?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Oo003oooooooooooooooooo`00oooooooo003o00Gooooo00?o003oooooool00?l01?ooool00ol0
0?ooooooo`00o`03ooooo`03o`00oooooooooooo00Cooooo0_l00?l2ooooo`07o`00oooooooo003o
ooooool00?ooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`Oooooo00?o003oooooool00?l0
0_ooool2o`00o`;ooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`07ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?oooooo
ooooooooool2o`00o`;ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooooooooooo
ooooo`;o003o0_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool2o`00o`;ooooo0_l00?l7ooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool00_l0
0?l2ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;o003o0_ooool02Ol00?oooooooooooooooooo003oooooool0
0?ooooooo`00o`04ooooo`;o003o0_ooool01Ol00?ooooooo`00oooooooo003o00Gooooo00?o003o
ooooooooool01?ooool01Ol00?ooooooo`00oooooooo003o00?ooooo00Go003oooooool00?oooooo
o`00o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooo`00o`06ooooo`07
o`00oooooooo003oooooool00?ooooooo`00o`03ooooo`03o`00oooooooooooo00;o003o0_ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00o`;ooooo00?o003o
ooooooooool01Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`07oooo
o`;o003o0_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00;o003o0_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?l3oooo
o`03o`00oooooooooooo00Gooooo0_l00?l2ooooo`;o003o1oooool01Ol00?oooooooooooooooooo
003o03;ooooo0_l00?l2ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool03_ooool0
1?l00?ooooooooooooooool2o`00o`?ooooo00Co003ooooooooooooo003o2?ooool2o`00o`;ooooo
0_l00?l4ooooo`05o`00oooooooo003oooooool00?l00oooool01?l00?ooooooooooool00?l3oooo
o`05o`00oooooooo003oooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`07o`00oooo
ooooooooooooool00?ooooooo`00o`08ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooo
oooo003o00?ooooo00Ko003ooooooooooooo003oooooool00?l7ooooo`03o`00oooooooooooo00;o
003o0_ooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo00Sooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooooooo00?ooooo
00Go003oooooooooooooooooo`00o`02ooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;o003o0oooool01Ol00?oooooooooooooooooo003o00Oooooo0_l00?l3oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo02oooooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0=ooooo`;o003o0oooool2
o`00o`?ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooo003o00Kooooo0_l0
0?l2ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`;o003o1_ooool02Ol00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00o`04ooooo`0=o`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00o`06ooooo`07o`00oooooooo003oooooool00?oo
ooooo`00o`03ooooo`08o`00ooooooooooooo`00oooooooo003oooooool00?l3ooooo`03o`00oooo
oooooooo00?ooooo00Co003ooooooooooooo003o1oooool00ol0003oooooooooo`01ooooo`004Ooo
ool2o`0000Sooooo0_l00?l3ooooo`03o`00oooooooooooo00;o003o0oooool2o`00o`;ooooo0_l0
0?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`0Vooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooooooo003o3?oo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooooooo`;o003o0_ooool2o`00o`;o
oooo00?o003oooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`05o`00oooooooo003o
ooooool00?l01?ooool2o`00o`Cooooo00Go003oooooool00?ooooooo`00o`03ooooo`03o`00oooo
oooo003o00Cooooo00Oo003oooooool00?ooooooo`00oooooooo003o00?ooooo00?o003oooooool0
0?l00_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00;ooooo0_l00?l4ooooo`09
o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00Kooooo00?o003oooooooooool01?oo
ool2o`0000?ooooo000Aooooo`03o`000?oooooooooo00Oooooo0_l00?l3ooooo`03o`00oooooooo
oooo00;o003o0oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_l0
0?l3ooooo`04o`00ooooooooooooooooo`;o003o0_ooool2o`00o`?ooooo00Co003ooooooooooooo
oooo0_l00?l7ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2
o`00o`?ooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`02o`00o`Oooooo00?o0000
ooooooooool02_ooool01?l00?ooooooooooool00?l8ooooo`;o003o0_ooool2o`00o`;ooooo00?o
003oooooool00?l00_ooool2o`00o`Kooooo00Go003oooooooooooooooooo`00o`04ooooo`;o003o
0_ooool00ol00?ooooooo`00o`03ooooo`05o`00oooooooo003oooooool00?l00oooool01?l00?oo
ooooooooool00?l3ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l00_ooool02ol0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003ooooooooo
ool00oooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooo
oooooooo00Wooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01oooool0
1?l00?ooooooooooooooool2o`00o`?ooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooooooool2o`00o`?ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0oooool00ol00?ooooooooooo`05
ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool08?ooool00ol00?ooooooooooo`02o`00o`;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0:ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?oo
ooooooooool00?l3ooooo`;o003o0_ooool00ol00?ooooooo`00o`02ooooo`;o003o0_ooool2o`00
o`;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`;o003o0_ooool02ol0
0?oooooooooooooooooo003oooooool00?ooooooo`00oooooooo003o00Cooooo00Oo003oooooool0
0?ooooooo`00oooooooo003o00?ooooo00[o003ooooooooooooo003oooooool00?ooooooo`00oooo
oooo003o0oooool00ol00?ooooooooooo`02o`00o`;ooooo00_o003oooooooooooooooooo`00oooo
oooo003oooooool00?ooooooo`00o`02ooooo`;o003o0_ooool00ol00?ooooooooooo`05ooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Oooooo0_l00?l2ooooo`03o`00
oooooooooooo00;ooooo00Ko003ooooooooooooo003oooooool00?l2ooooo`;o003o0_ooool01?l0
0?ooooooooooooooool2o`00o`Cooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooo
oooo00Kooooo0_l00?l2ooooo`;o003o1oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo02?ooooo0_l00?l2ooooo`03o`00
oooooooo003o00;ooooo00?o003oooooooooool02_ooool01Ol00?oooooooooooooooooo003o00?o
oooo0_l00?l3ooooo`04o`00ooooooooooooo`00o`Sooooo0_l00?l2ooooo`;o003o0oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00_ooool02Ol00?oooooooooooooo
oooo003oooooool00?ooooooo`00o`03ooooo`03o`00oooooooo003o00Cooooo00Oo003ooooooooo
ooooooooo`00oooooooo003o00Kooooo00oo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`07ooooo`03o`00oooo
oooooooo00;o003o0_ooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooo
oooo00?ooooo00Go003oooooooooooooooooo`00o`02ooooo`;o003o0_ooool2o`00o`Cooooo00?o
003oooooooooool00_l00?l2ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool00_l0
0?l2ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l3ooooo`05o`00
ooooooooooooooooool00?l00oooool2o`00ob3ooooo0_l00?l2ooooo`03o`00oooooooo003o00;o
oooo00?o003oooooooooool03Oooool2o`00o`?ooooo0_l00?l3ooooo`03o`00oooooooooooo00Go
oooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0oooool01_l00?ooooooooooool00?oo
ooooo`00o`;ooooo0_l00?l2ooooo`09o`00ooooooooooooooooool00?ooooooo`00oooooooo003o
00?ooooo00?o003oooooooooool00_ooool2o`00o`;ooooo00Wo003oooooool00?ooooooo`00oooo
oooo003oooooool00?l01_ooool01ol00?ooooooo`00oooooooo003oooooool00?l00oooool02?l0
0?ooooooooooool00?ooooooo`00oooooooo003o2?ooool2o`00o`;ooooo00?o003oooooooooool0
1Oooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000Wooooo00?o003oooooooooool00_l0
0?l2ooooo`;o003o0_ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00;o003o0_oo
ool00ol00?ooooooooooo`02ooooo`;o003o0oooool00ol00?ooooooooooo`02o`00o`;ooooo0_l0
0?l7ooooo`04o`00ooooooooooooooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool06oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo003o00;ooooo00?o003ooooo
ooooool02_ooool01?l00?ooooooooooool00?l4ooooo`;o003o0_ooool2o`00o`?ooooo00?o003o
ooooooooool00_l00?l7ooooo`04o`00ooooooooooooooooo`;o003o0_ooool00ol00?ooooooo`00
o`02ooooo`;o003o0oooool01_l00?ooooooooooool00?ooooooo`00o`?ooooo00?o003oooooool0
0?l01?ooool2o`00o`;ooooo00_o003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00o`08ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`02ooooo`09o`00oooooooo003o
ooooool00?ooooooo`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1_ooool2o`0000?o
oooo000Aooooo`03o`000?oooooooooo00Kooooo00?o003oooooool00?l00oooool00ol00?oooooo
ooooo`02o`00o`;ooooo00?o003oooooooooool00_ooool2o`00o`?ooooo00Co003ooooooooooooo
003o1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00o`?o
oooo0_l00?l6ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l0
0?l3ooooo`03o`00oooooooooooo01;ooooo00Co003ooooooooooooooooo0_l00?l7ooooo`05o`00
0?ooooooooooooooool00?l02?ooool01?l00?ooooooooooool00?l8ooooo`;o003o0_ooool2o`00
o`;ooooo0_l00?l3ooooo`;o003o1_ooool2o`00o`;ooooo00?o003oooooooooool00_ooool2o`00
o`;ooooo0_l00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool0
0?l3ooooo`03o`00oooooooooooo00?ooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00
oooooooooooo00?ooooo00Go003oooooooooooooooooo`00o`06ooooo`0;o`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?l03?ooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00;ooooo0_l00?l2ooooo`;o003o0_oo
ool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooooooo`;o003o0oooool01_l00?oooooo
ooooool00?ooooooo`00o`;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02o`00
o`?ooooo0_l00?l3ooooo`03o`00oooooooooooo00;o003o0oooool01Ol00?oooooooooooooooooo
003o00?ooooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`;o003o0oooool00ol00?ooooooooooo`0Booooo`04o`00ooooooooooooooooo`;o003o
0_ooool00ol00?ooooooooooo`02ooooo`05o`000?ooooooooooooooool00?l02?ooool00ol00?oo
ooooooooo`02o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0_ooool2o`00
o`?ooooo0_l00?l3ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o0ooo
ool2o`00o`?ooooo00Ko003ooooooooooooo003oooooool00?l3ooooo`04o`00ooooooooooooo`00
o`?ooooo00_o003oooooooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`02ooooo`05
o`00oooooooo003oooooool00?l00oooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00_o003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03
o`00oooooooooooo00Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
1_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00[o003ooooooooooooo
003oooooool00?ooooooo`00oooooooo003o0_ooool00ol00?ooooooooooo`02ooooo`06o`00oooo
ooooooooo`00oooooooo003o0_ooool00ol00?ooooooooooo`0:ooooo`;o003o0_ooool2o`00o`Ko
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
003o0oooool00ol00?ooooooooooo`05ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o
013ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`;o003o0oooool01Ol00?oooooooooooooo
oooo003o00Sooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`06ooooo`;o003o0_ooool2o`00o`?ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`04ooooo`;o003o0_ooool2o`00o`;ooooo00Oo003ooooooooo
ooooooooo`00oooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`05
ooooo`08o`00ooooooooooooo`00oooooooo003oooooool00?l3ooooo`07o`00oooooooo003ooooo
ool00?ooooooo`00o`06ooooo`09o`00ooooooooooooooooool00?ooooooo`00oooooooo003o00;o
oooo00?o003oooooooooool01Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`08ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00oooool01Ol00?oooooo
oooooooooooo003o00;ooooo00Co003ooooooooooooooooo0_l00?l4ooooo`03o`00oooooooooooo
00;o003o0_ooool00ol00?ooooooooooo`06ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2oooo
o`;o003o0oooool01?l00?ooooooooooooooool2o`00o`?ooooo00Go003oooooooooooooooooo`00
o`08ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool04_ooool2o`00o`;ooooo0_l0
0?l3ooooo`05o`00ooooooooooooooooool00?l02oooool2o`00o`?ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`09ooooo`04o`00ooooooooooooooooo`;o003o0oooool00ol00?oo
ooooooooo`02o`00o`?ooooo0_l00?l2ooooo`04o`00ooooooooooooooooo`;o003o0_ooool01ol0
0?oooooooooooooooooo003oooooool00?l00_ooool2o`00o`Cooooo00Go003oooooool00?oooooo
o`00o`07ooooo`08o`00ooooooooooooo`00oooooooo003oooooool00?l3ooooo`03o`00oooooooo
003o00;ooooo00?o003oooooooooool01oooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo
oooo00Gooooo00?o0000ooooooooool00Oooool0017ooooo0_l00009ooooo`05o`00oooooooo003o
ooooool00?l00_ooool00ol00?ooooooooooo`03ooooo`05o`00ooooooooooooooooool00?l00_oo
ool2o`00o`;ooooo00Oo003oooooooooooooooooo`00oooooooo003o00?ooooo00?o003ooooooooo
ool00_l00?l2ooooo`;o003o1oooool2o`00o`;ooooo0_l00?l3ooooo`05o`00oooooooooooooooo
ool00?l00oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Gooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l02oooool2o`00o`?ooooo00Co
003ooooooooooooooooo0_l00?l3ooooo`03o`00oooooooooooo00;o003o1oooool2o`00o`;ooooo
0_l00?l2ooooo`;o003o0oooool2o`00o`?ooooo00Co003ooooooooooooo003o1Oooool00ol00?oo
ooooo`00o`04ooooo`;o003o0_ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00
o`0:ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l00_ooool01ol00?ooooooo`00
oooooooo003oooooool00?l01Oooool01?l00?ooooooooooool00?l6ooooo`;o00000oooool0017o
oooo00?o0000ooooooooool01_ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00;o
003o0_ooool01ol00?ooooooo`00oooooooo003oooooool00?l00oooool01?l00?ooooooooooool0
0?l3ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00_l00?l2ooooo`;o003o0_oo
ool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooooooo`;o003o0_ooool2o`00o`?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`05o`00oooooooooooo
ooooool00?l02?ooool00ol00?ooooooooooo`06ooooo`05o`00ooooooooooooooooool000003?oo
ool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`;o
oooo0_l00?l3ooooo`03o`00oooooooooooo00Gooooo0_l00?l2ooooo`03o`00oooooooooooo00;o
oooo0_l00?l3ooooo`03o`00oooooooooooo00Kooooo00Go003oooooooooooooooooo`00o`02oooo
o`05o`00ooooooooooooooooool00?l01Oooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o
003oooooooooool00oooool01Ol00?oooooooooooooooooo003o00Kooooo00Wo003oooooool00?oo
ooooo`00oooooooo003oooooool00?l03_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`06ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00_l00?l2oooo
o`05o`00ooooooooooooooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00;ooooo00Go
003oooooooooooooooooo`00o`05ooooo`03o`00oooooooooooo00;o003o0_ooool00ol00?oooooo
o`00o`03ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00o`?ooooo00Co003ooooooooooooo
oooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`;o003o0oooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003oooooooooool01_ooool0
1Ol00?oooooooooooooooooo003o00Sooooo00?o0000ooooooooool00_l00?l8ooooo`03o`00oooo
oooooooo00;o003o1oooool01?l00?ooooooooooooooool2o`00o`;ooooo0_l00?l3ooooo`03o`00
oooooooooooo00;ooooo00Co003ooooooooooooo003o0oooool2o`00o`?ooooo00Co003ooooooooo
oooooooo0_l00?l3ooooo`03o`00oooooooooooo00;o003o1?ooool01?l00?ooooooooooool00?l3
ooooo`03o`00oooooooooooo00?ooooo00Go003oooooool00?ooooooo`00o`02ooooo`;o003o0_oo
ool01ol00?oooooooooooooooooo003oooooool00?l02?ooool02Ol00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00o`0<ooooo`03o`000?oooooooooo007ooooo000:ooooo`;o00001Oooool0
0ol0003oooooooooo`06ooooo`05o`00ooooooooooooooooool00?l01Oooool02?l00?oooooooooo
ool00?ooooooo`00oooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`08o`00oooooooooooo
o`00oooooooo003oooooool00?l5ooooo`03o`00oooooooooooo00;o003o0_ooool00ol00?oooooo
o`00o`02ooooo`;o003o1_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooooooo00Kooooo0_l00?l2ooooo`;o003o
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool01_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo0_l00?l3ooooo`03o`00oooooooooooo00;o003o0oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooo
ooooooooooooo`;o003o0_ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooooooo`;o
003o0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo0_l00?l2ooooo`;o
003o0_ooool2o`00o`;ooooo00?o003oooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`02o`00o`;ooooo00_o003ooooo
ooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`06ooooo`0;o`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?l02?ooool00ol0003oooooooooo`01ooooo`002Ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Kooooo00Go003oooooool00?oo
ooooo`00o`04ooooo`03o`00oooooooooooo00?ooooo00Go003oooooool00?ooooooo`00o`02oooo
o`04o`00ooooooooooooooooo`;o003o1?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o
003oooooooooool01Oooool00ol00?ooooooo`00o`02ooooo`;o003o1_ooool00ol00?oooooooooo
o`02ooooo`04o`00ooooooooooooooooo`;o003o0oooool00ol00?ooooooooooo`02o`00o`Oooooo
0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`08ooooo`03
o`00oooooooooooo00Gooooo00Co003ooooooooooooooooo0_l00?l3ooooo`03o`00oooooooooooo
00;o003o0oooool00ol00?ooooooooooo`06ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Sooooo00Co003ooooooooooooooooo0_l00?l3ooooo`03o`00
oooooooooooo00;o003o1?ooool01?l00?ooooooooooool00?l3ooooo`;o003o0_ooool01ol00?oo
oooooooooooooooo003oooooool00?l00_ooool2o`00o`?ooooo00Co003ooooooooooooo003o2?oo
ool2o`00o`;ooooo00Go003oooooool00?ooooooo`00o`03ooooo`03o`00oooooooo003o00;ooooo
00?o003oooooooooool01Oooool01ol00?ooooooo`00oooooooo003oooooool00?l02?ooool00ol0
003oooooooooo`01ooooo`002Oooool01?l0003oooooooooool00004ooooo`[o00000ooo00001Ol0
0?ooo`00ool00?oo003o000000?oo`0000Go0000ool00?oo003oo`00o`000003ool00003o`000?l0
0?ooo`0000;oo`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00ool000;o
00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003oo`000_l00003
ool00005o`000?oo003oo`00ool00?l000000ooo00001Ol0003oo`00ool00?oo003o000000?oo`00
0_l00003ool00005o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?oo0002o`00
00?oo`0000Go0000ool00?oo003oo`00o`000003ool00005o`000?oo003oo`00ool00?l000000ooo
0002o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00ool000;o
00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003oo`000_l00003
ool00005o`000?oo003oo`00ool00?l000000ooo00001Ol0003oo`00ool00?oo003o000000?oo`00
00?o003oo`000?oo00000_oo00001Ol0003oo`00ool00?oo003o000000?oo`0000Ko003oool00?oo
003oo`00o`00ool00003ool00005o`000?oo003oo`00ool00?l000000ooo00001Ol0003oo`00ool0
0?oo003o003o00?oo`0000?o003oo`000?oo00000_oo00001Ol00?ooo`00ool00?oo003o000000?o
o`0000Ko003oool00?oo003oo`00o`000?l00?l3ool00005o`000?oo003oo`00ool00?l00?l00ooo
00001_l00?ooo`00ool00?oo003o0000o`00o`?oo`0000Go0000ool00?oo003oo`00o`00o`03ool0
00Ko00000oooool000Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`06oooo
o`05o`00oooo003oo`00ool00?ooool00ooo00001Ol00?ooo`00ool00?oo003ooooo00?oo`0000Co
ooooool00?oo003oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo00001?oooooo
o`00ool00?oo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool00004oooooooo003o
o`00ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Goooooool00?oo003o
o`00ooooo`03ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Coooooool0
0?oo003oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo00001Oooooooo`00ool0
0?oo003ooooo00?oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo00001?oooooo
o`00ool00?oo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool00004oooooooo003o
o`00ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Goooooool00?oo003o
o`00ooooo`03ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Koooooool0
0?oo003oo`00o`00ooooool3ool00005oooooooo003oo`00ool00?ooool00ooo00001Oooooooo`00
ool00?oo003o003o00?oo`0000?o003ooooooooo00000_oo00001Ol00?ooo`00ool00?oo003o003o
00?oo`0000Koooooool00?oo003oo`00o`00ooooool3ool00005o`00oooo003oo`00ool00?ooool0
0ooo00001_l00?ooo`00ool00?oo003oooooo`00o`?oo`0000Goooooool00?oo003oo`00ooooo`03
ool000Gooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`06ooooo`05o`00oooo003oo`00ool00?ooool00ooo00001Ol00?ooo`00ool0
0?oo003ooooo00?oo`0000Coooooool00?oo003oo`000_ooool3ool00005oooooooo003oo`00ool0
0?ooool00ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`0000Goooooool00?oo003oo`00oooo
o`03ool00004oooooooo003oo`00ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?o
o`0000Goooooool00?oo003oo`00ooooo`03ool000;ooooo0ooo00001Oooooooo`00ool00?oo003o
oooo00?oo`0000Coooooool00?oo003oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool0
0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`000_ooool3ool00005oooooooo003oo`00ool0
0?ooool00ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`0000Goooooool00?oo003oo`00oooo
o`03ool00004oooooooo003oo`00ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?o
o`0000Goooooool00?oo003oo`00ooooo`03ool000;ooooo0ooo00001Oooooooo`00ool00?oo003o
oooo00?oo`0000Koooooool00?oo003oo`00o`00ooooool3ool00005oooooooo003oo`00ool00?oo
ool00ooo00001Ol00?ooo`00ool00?oo003ooooo00?oo`000_ooool3ool00005oooooooo003oo`00
ool00?l00?l00ooo00001_l00?ooo`00ool00?oo003o003oooooo`?oo`0000Go003oool00?oo003o
o`00ooooo`03ool00006o`00oooo003oo`00ool00?oooooo003o0ooo00001Ol00?ooo`00ool00?oo
003ooooo00?oo`001Oooool00ol0003oooooooooo`01ooooo`002Oooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo00Kooooo00Oo003oooooooooooooooooo`00oooooooo003o00?o
oooo00Co003ooooooooooooo003o0oooool01ol00?oooooooooooooooooo003oooooool00?l00ooo
ool02?l00?ooooooooooool00?ooooooo`00oooooooo003o1Oooool00ol00?ooooooooooo`02o`00
o`;ooooo00?o003oooooool00?l00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooo
oooo00;ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`Oooooo00?o
003oooooooooool01_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02o`00o`?ooooo00Go003oooooooooooooooooo`00o`08ooooo`05
o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00o`?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Ooo
ool2o`00o`;ooooo0_l00?l2ooooo`;o003o0_ooool00ol00?ooooooo`00o`03ooooo`03o`00oooo
oooooooo00;o003o0_ooool01ol00?oooooooooooooooooo003oooooool00?l00_ooool2o`00o`;o
oooo00_o003oooooooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`03ooooo`03o`00
oooooooooooo00;o003o0_ooool01ol00?ooooooo`00oooooooo003oooooool00?l02?ooool00ol0
003oooooooooo`01ooooo`002_ooool2o`0000Gooooo00?o0000ooooooooool01_ooool01Ol00?oo
ooooo`00oooooooo003o00Gooooo00co003ooooooooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?l3ooooo`03o`00oooooooo003o00Cooooo00Oo003oooooool00?ooooooo`00oooo
oooo003o00Sooooo00Oo003oooooool00?ooooooo`00oooooooo003o00Kooooo00Co003ooooooooo
oooooooo0_l00?l4ooooo`03o`00oooooooooooo00;o003o0_ooool00ol00?ooooooooooo`06oooo
o`;o003o0_ooool2o`00o`;ooooo0_l00?l3ooooo`03o`00oooooooooooo01;ooooo0_l00?l3oooo
o`03o`00oooooooooooo00;o003o0oooool01Ol00?oooooooooooooooooo003o00Sooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Kooooo00Go003ooooooooooooooooo
o`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo0_l00?l2ooooo`04o`00ooooooooooooooooo`;o003o1?ooool01Ol00?oooooooooooooo
oooo003o00;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`02o`00o`;ooooo0_l0
0?l2ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00Go
oooo00Oo003oooooool00?ooooooo`00oooooooo003o00Sooooo00?o0000ooooooooool00Oooool0
017ooooo0_l00009ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`06ooooo`0=o`00oooo
ooooooooooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`04ooooo`07o`00oooo
oooo003oooooool00?ooooooo`00o`0:ooooo`05o`00oooooooo003oooooool00?l00_ooool2o`00
o`?ooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooo003o00?ooooo00?o003ooooo
ooooool00_l00?l2ooooo`;o003o1?ooool01?l00?ooooooooooool00?l3ooooo`;o003o0oooool0
1Ol00?oooooooooooooooooo003o00?ooooo0_l00?l;ooooo`;o003o0oooool00ol00?oooooooooo
o`02o`00o`?ooooo00?o003oooooooooool02_ooool01Ol00?oooooooooooooooooo003o00Sooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`;ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool00_l00?l2ooooo`07o`00ooooooooooooooooool00?oooooo
o`00o`02ooooo`;o003o2_ooool00ol00?ooooooo`00o`07ooooo`;o00000oooool0017ooooo00?o
0000ooooooooool02?ooool02ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003o00;ooooo00_o003oooooooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`04oooo
o`03o`00oooooooo003o00?ooooo00Go003oooooool00?ooooooo`00o`02ooooo`;o003o1_ooool0
0ol00?ooooooooooo`02ooooo`;o003o0oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooo
oooooooo00;ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`Oooooo0_l00?l7ooooo`05o`00oooo
ooooooooooooool00?l00oooool2o`00o`?ooooo00?o003oooooooooool01Oooool2o`00o`?ooooo
00?o003oooooooooool01?ooool2o`00o`?ooooo00?o003oooooooooool02_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo0_l00?l7ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`04o`00ooooooooooooo`00o`Cooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo00?o
003oooooool00?l01oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooool00?l0
0_ooool2o`00o`;ooooo0_l00?l6ooooo`03o`00oooooooo003o00Sooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool01_ooool00ol00?ooooooo`00o`03ooooo`07o`00oooo
oooo003oooooool00?ooooooo`00o`04ooooo`03o`00oooooooo003o00?ooooo00?o003oooooool0
0?l01?ooool00ol00?ooooooooooo`03ooooo`05o`00oooooooo003oooooool00?l00_ooool2o`00
o`;ooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`02ooooo`;o003o0oooool01?l0
0?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?l3
ooooo`;o003o0oooool00ol00?ooooooooooo`02o`00o`?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`;o003o0oooool00ol00?ooooooooooo`0:ooooo`05o`000?ooooooooooooooool00?l0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00kooooo00Co003ooooooooooooo
oooo0_l00?l3ooooo`03o`00oooooooooooo00Gooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Ko003ooooooooooooo
003oooooool00?l2ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`07
ooooo`;o003o0_ooool2o`00o`;ooooo00?o003oooooool00?l03?ooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`06ooooo`07o`00ooooooooooooooooool00?ooooooo`00
o`03ooooo`03o`00oooooooo003o00Cooooo00Oo003oooooooooooooooooo`00oooooooo003o00?o
oooo00So003ooooooooooooo003oooooool00?ooooooo`00o`Gooooo00?o003oooooooooool00_l0
0?l2ooooo`03o`00oooooooo003o00?ooooo00Go003oooooool00?ooooooo`00o`02ooooo`;o003o
0oooool01_l00?ooooooooooool00?ooooooo`00o`;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`;o003o0oooool2o`00o`;ooooo0_l00?l2ooooo`;o003o1oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`02ooooo`03o`000?oo
oooooooo00;o003o1oooool00ol00?ooooooooooo`0Booooo`;o003o0oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02o`00o`?ooooo00?o003ooooooooo
ool01Oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l3ooooo`;o003o0_ooool01?l0
0?ooooooooooooooool2o`00o`Cooooo00Go003oooooooooooooooooo`00o`02ooooo`;o003o0_oo
ool01ol00?ooooooo`00oooooooo003oooooool00?l02?ooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0oooool00ol00?ooooooo`00o`02ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`05oooo
o`08o`00ooooooooooooo`00oooooooo003oooooool00?l<ooooo`07o`00oooooooo003oooooool0
0?ooooooo`00o`06ooooo`04o`00ooooooooooooooooo`;o003o1?ooool00ol00?ooooooooooo`02
o`00o`;ooooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`02ooooo`;o003o0_ooool2
o`00o`;ooooo0_l00?l;ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02o`00o`?ooooo00Go003oooooooooooooooooo`00o`0Iooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo
00Co003ooooooooooooooooo0_l00?l2ooooo`04o`00ooooooooooooooooo`;o003o0oooool00ol0
0?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooooooo0_l0
0?l2ooooo`04o`00ooooooooooooooooo`;o003o0_ooool00ol00?ooooooo`00o`0:ooooo`;o003o
0_ooool00ol00?ooooooo`00o`08ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo00Sooooo00?o003oooooool00?l00oooool00ol00?ooooooooooo`04ooooo`07o`00oooo
ooooooooooooool00?ooooooo`00o`03ooooo`03o`00oooooooo003o00Cooooo00Oo003oooooool0
0?ooooooo`00oooooooo003o00[ooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool0
0?l00_ooool2o`00o`;ooooo0_l00?l2ooooo`03o`00oooooooo003o00?ooooo00?o003ooooooooo
ool00_l00?l8ooooo`04o`00ooooooooooooo`00o`?ooooo0_l00?l2ooooo`;o003o1oooool2o`00
o`_ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02o`00o`;ooooo0_l00?lMoooo
o`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00o`?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`;o003o0_ooool01?l00?ooooooooooooooool2o`00o`?o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02o`00o`Sooooo00?o003ooooooooo
ool00_l00?l2ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`02ooooo`;o003o1oooool0
1_l00?ooooooooooool00?ooooooo`00o`Sooooo00?o0000ooooooooool00Oooool0017ooooo0_l0
0009ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`06ooooo`0;o`00oooooooooooooooo
ool00?ooooooo`00oooooooo003oooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`09
o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00Kooooo00Oo003oooooool00?oooooo
o`00oooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooo`00o`03oooo
o`03o`00oooooooooooo00;o003o0_ooool2o`00o`Oooooo00?o003oooooooooool01Oooool2o`00
o`?ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`03o`00oooooooooooo00_ooooo00Co003o
oooooooooooo003o0oooool2o`00ob7ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01?l00?oo
ooooooooool00?l4ooooo`04o`00ooooooooooooooooo`;o003o0_ooool2o`00o`;ooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`04ooooo`;o003o0oooool2o`00o`;ooooo0_l00?l6
ooooo`03o`00oooooooo003o00Oooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`05oooo
o`04o`00ooooooooooooo`00o`?ooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo
0_l00?l2ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`03ooooo`03o`00oooooooooooo
00Cooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooool00?l00_ooool2o`00o`;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooo003o00?ooooo00?o003oooooooooool00_l00?l2oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool2o`00o`?ooooo00Co003ooooo
oooooooooooo0_l00?l2ooooo`03o`00oooooooooooo00_ooooo00?o0000ooooooooool01?ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01oooooo00Go003oooooooooooooooooo`00
o`04ooooo`05o`00ooooooooooooooooool00?l02?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;o003o0oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01oooool2o`00o`;ooooo0_l00?l2
ooooo`;o003o3Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`05oooo
o`03o`00oooooooooooo00Cooooo00Oo003oooooool00?ooooooo`00oooooooo003o00?ooooo00?o
003oooooooooool01?ooool01ol00?oooooooooooooooooo003oooooool00?l01?ooool00ol00?oo
ooooooooo`03ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`03oooo
o`05o`00oooooooo003oooooool00?l00_ooool2o`00o`?ooooo00So003ooooooooooooo003ooooo
ool00?ooooooo`00o`Gooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooo003o00?o
oooo00?o003oooooooooool00_l00?l6ooooo`;o003o0oooool2o`00o`;ooooo00?o003ooooooooo
ool02oooool01Ol0003oooooo`00oooooooo003o00Oooooo00?o003oooooooooool07oooool01?l0
0?ooooooooooooooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooo
ooooooooooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02o`00o`?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`;o003o2?ooool00ol00?ooooooooooo`02o`00o`;ooooo0_l00?l=ooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooo003o00;ooooo0_l00?l4ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooool00?l00_ooool00ol00?ooooooo`00o`07ooooo`05o`00oooooooo003ooooo
ool00?l00_ooool01Ol00?ooooooo`00oooooooo003o00Gooooo00?o003oooooooooool00_ooool2
o`00o`Cooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooool00?l00_ooool2o`00o`;ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l0
1oooool00ol00?ooooooooooo`0;ooooo`05o`00oooooooo003oooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o027ooooo00Go003oooooooooooooooooo`00o`08ooooo`05o`00oooooooo
ooooooooool00?l00oooool2o`00o`;ooooo0_l00?l3ooooo`03o`00oooooooooooo00;ooooo00Co
003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooo
oooooooo0_l00?l2ooooo`;o003o1oooool2o`00o`;ooooo0_l00?l2ooooo`03o`00oooooooo003o
00Sooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01Oooool01_l00?oo
ooooooooool00?ooooooo`00o`?ooooo00?o003oooooooooool01?ooool2o`00o`;ooooo00?o003o
ooooool00?l00oooool00ol00?ooooooo`00o`04ooooo`07o`00oooooooo003oooooool00?oooooo
o`00o`07ooooo`08o`00ooooooooooooo`00oooooooo003oooooool00?l5ooooo`03o`00oooooooo
oooo00;ooooo0_l00?l4ooooo`05o`00ooooooooooooooooool00?l00_ooool2o`00o`Kooooo00?o
003oooooool00?l00_ooool01?l00?ooooooooooooooool2o`00o`;ooooo0_l00?l7ooooo`03o`00
oooooooooooo00oooooo00Go003oooooool00?ooooooo`00o`02ooooo`;o003o:Oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo0_l00?l3ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?l7
ooooo`04o`00ooooooooooooooooo`;o003o0_ooool01?l00?ooooooooooooooool2o`00o`?ooooo
00?o003oooooooooool01Oooool2o`00o`;ooooo00?o003oooooool00?l02?ooool00ol0003ooooo
ooooo`01ooooo`004Oooool2o`0000Wooooo0_l00?l2ooooo`03o`00oooooooo003o00Kooooo00go
003oooooooooooooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o00Cooooo0_l0
0?l2ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00Kooooo00Oo003ooooo
ool00?ooooooo`00oooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool00ol00?oooooo
o`00o`03ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00o`Kooooo00?o003oooooooooool0
1_ooool2o`00o`;ooooo0_l00?l3ooooo`;o003o4?ooool00ol00?ooooooo`00o`04ooooo`;o003o
:Oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooooooo0_l0
0?l2ooooo`04o`00ooooooooooooooooo`;o003o0oooool2o`00o`;ooooo0_l00?l6ooooo`;o003o
2?ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo00Gooooo00Co003ooooooooooooo003o
0oooool01ol00?ooooooo`00oooooooo003oooooool00?l00_ooool2o`00o`;ooooo00Oo003ooooo
ooooooooooooo`00oooooooo003o00?ooooo00?o003oooooooooool01?ooool02ol00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003o00Cooooo00Oo003oooooooooooooooooo`00
oooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool01ol00?oooooooooooooooooo003o
ooooool00?l00oooool00ol00?ooooooooooo`02o`00o`;ooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`04ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l2ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool01?ooool2o`00o`;ooooo00?o003oooooooooool0:Oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;o
003o0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01oooool2o`00
o`;ooooo0_l00?l2ooooo`03o`00oooooooooooo00cooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool01Oooool01?l00?ooooooooooool00?l3ooooo`07o`00oooooooo003o
ooooool00?ooooooo`00o`03ooooo`03o`00oooooooooooo00Cooooo00Oo003oooooool00?oooooo
o`00oooooooo003o00?ooooo00ko003ooooooooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00o`;ooooo00?o003oooooooooool00oooool01ol00?ooooooo`00oooooooo
003oooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooo003o00?ooooo00?o003oooooooooool0
0_l00?l6ooooo`;o003o0oooool2o`00o`;ooooo00?o003oooooooooool02oooool01Ol0003ooooo
oooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`0_ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o0oooool01?l00?oooooooooo
ooooool2o`00o`;ooooo0_l00?l7ooooo`04o`00ooooooooooooooooo`;o003o0_ooool2o`00o`go
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01Oooool01Ol00?oooooo
oooooooooooo003o00;ooooo00Oo003oooooooooooooooooo`00oooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`02ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`02ooooo`;o
003o1_ooool01ol00?ooooooo`00oooooooo003oooooool00?l00_ooool01Ol00?oooooooooooooo
oooo003o00Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooo003o00?ooooo00?o003oooooooooool00_ooool2o`00o`;ooooo00Oo003oooooool00?oooooo
o`00oooooooo003o00;ooooo0_l00?l6ooooo`;o003o1oooool00ol00?ooooooooooo`0;ooooo`05
o`00oooooooo003oooooool00?l00oooool01?l00?ooooooooooool00?l_ooooo`05o`00oooooooo
ooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00o`?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o0oooool01Ol00?oooooooooooooooooo
003o00?ooooo0_l00?l2ooooo`;o003o1oooool2o`00o`;ooooo0_l00?l2ooooo`;o003o2Oooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo
00;o003o1_ooool00ol00?ooooooo`00o`02ooooo`;o003o0_ooool2o`00o`Cooooo00?o003ooooo
ool00?l01?ooool2o`00o`;ooooo00?o003oooooool00?l01oooool00ol00?ooooooooooo`02o`00
o`;ooooo00?o003oooooooooool00oooool01ol00?oooooooooooooooooo003oooooool00?l01?oo
ool01ol00?ooooooo`00oooooooo003oooooool00?l02?ooool02ol00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003o00;ooooo0_l00?l6ooooo`03o`00oooooooooooo013ooooo
00Go003oooooool00?ooooooo`00o`02ooooo`;o003o0_ooool00ol00?ooooooooooo`0aooooo`05
o`00ooooooooooooooooool00?l00oooool2o`00o`?ooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oooooooooooooo
ool2o`00o`;ooooo0_l00?l3ooooo`03o`00oooooooooooo00Gooooo0_l00?l2ooooo`;o003o2Ooo
ool00ol0003oooooooooo`01ooooo`004Oooool2o`0000Wooooo0_l00?l2ooooo`;o003o1oooool0
1?l00?ooooooooooooooool2o`00o`;ooooo00Go003oooooool00?ooooooo`00o`04ooooo`;o003o
0_ooool01Ol00?ooooooo`00oooooooo003o00Sooooo0_l00?l2ooooo`05o`00oooooooo003ooooo
ool00?l00oooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003oooooool00?l00oooool0
1Ol00?ooooooo`00oooooooo003o00;ooooo0_l00?l6ooooo`05o`00ooooooooooooooooool00?l0
1?ooool2o`00o`;ooooo00Oo003oooooooooooooooooo`00oooooooo003o013ooooo00Go003ooooo
ool00?ooooooo`00o`02ooooo`;o003o>_ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`03o`00oooooooo
oooo00Wooooo0_l00?l8ooooo`;o00000oooool0017ooooo00?o0000ooooooooool02?ooool01?l0
0?ooooooooooooooool2o`00o`;ooooo00?o003oooooool00?l00_ooool01?l00?oooooooooooooo
ool2o`00o`;ooooo00?o003oooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`;o003o
0_ooool01Ol00?ooooooo`00oooooooo003o00Gooooo00?o003oooooooooool00_ooool00ol00?oo
ooooo`00o`03ooooo`03o`00oooooooo003o00Cooooo00_o003oooooooooooooooooo`00oooooooo
003oooooool00?ooooooo`00o`02ooooo`;o003o1_ooool00ol00?ooooooo`00o`06ooooo`;o003o
0_ooool2o`00o`Cooooo00Co003ooooooooooooo003o3Oooool00ol00?ooooooooooo`04ooooo`;o
003o0_ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o1oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;o003o0oooool01?l00?ooooooooooooooool2o`00o`Kooooo0_l0
0?l9ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Gooooo00Co003o
oooooooooooo003o0oooool2o`00o`;ooooo00?o003oooooool00?l00oooool01?l00?oooooooooo
ool00?l3ooooo`03o`00oooooooo003o00?ooooo00?o003oooooooooool01?ooool2o`00o`;ooooo
00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool00oooool01ol0
0?ooooooo`00oooooooo003oooooool00?l00oooool00ol00?ooooooo`00o`04ooooo`03o`00oooo
oooooooo00?ooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00?ooooo
00Go003oooooool00?ooooooo`00o`02ooooo`04o`00ooooooooooooooooo`;o003o0_ooool00ol0
0?ooooooo`00o`02ooooo`03o`00oooooooooooo00_ooooo00Go0000ooooooooooooooooo`00o`02
ooooo`05o`00ooooooooooooooooool00?l0@?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol0
0?ooooooooooo`05ooooo`04o`00ooooooooooooooooo`;o003o0_ooool2o`00o`gooooo00?o0000
ooooooooool00Oooool000Wooooo0ol00005ooooo`03o`000?oooooooooo00Gooooo00Go003ooooo
ooooooooooooo`00o`02ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00_ooool01ol00?oooooooooooooooooo003oooooool00?l00_ooool2
o`00o`Kooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00oooooooo003oooooool00?l00oooool00ol00?ooooooo`00o`02oooo
o`03o`00oooooooo003o00?ooooo00Oo003oooooooooooooooooo`00oooooooo003o00;ooooo00_o
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`06ooooo`;o003o0_ooool0
0ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00_ooooo00Go0000ooooool00?ooooooo`00
o`06ooooo`03o`00oooooooooooo04;ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o
0oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l2ooooo`;o003o0oooool01Ol00?oo
oooooooooooooooo003o00?ooooo0_l00?l2ooooo`;o003o2Oooool00ol0003oooooooooo`01oooo
o`002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00Go003ooooooooo
ooooooooo`00o`06ooooo`03o`00oooooooo003o00;ooooo0_l00?l2ooooo`;o003o1_ooool00ol0
0?ooooooo`00o`02ooooo`;o003o0_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00;o003o0_ooool00ol00?ooooooooooo`03ooooo`07o`00ooooooooooooooooool00?ooooooo`00
o`04ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`08ooooo`0;o`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?l00_ooool2o`00o`Kooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0;ooooo`05o`00oooooooo003oooooool00?l00oooool01?l00?oo
ooooooooool00?m8ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`_ooooo0_l00?l2ooooo`;o003o2Ooo
ool00ol0003oooooooooo`01ooooo`002_ooool00ol0003oooooooooo`04ooooo`?o00002?ooool2
o`00o`?ooooo00?o003oooooooooool01Oooool01?l00?ooooooooooooooool2o`00o`?ooooo00Co
003ooooooooooooo003o1?ooool2o`00o`;ooooo0_l00?l;ooooo`;o003o0_ooool2o`00o`;ooooo
00_o003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`02ooooo`09o`00oooo
ooooooooooooool00?ooooooo`00oooooooo003o00Sooooo00?o003oooooool00?l00oooool00ol0
0?ooooooo`00o`02ooooo`;o003o2?ooool00ol00?ooooooooooo`0>ooooo`;o003o0_ooool01Ol0
0?ooooooo`00oooooooo003o04_ooooo00?o003oooooooooool01_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool00_l00?l7ooooo`?o00000oooool000[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`08ooooo`;o003o0_ooool2o`00o`Oooooo00Co003ooooooooooooooooo
0_l00?l2ooooo`;o003o1?ooool01?l00?ooooooooooool00?l3ooooo`;o003o0_ooool01Ol00?oo
ooooo`00oooooooo003o00Gooooo00?o003oooooooooool00_l00?l2ooooo`07o`00oooooooooooo
ooooool00?ooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00Wo003oooooool00?oo
ooooo`00oooooooo003oooooool00?l01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
003o00;ooooo0_l00?l4ooooo`03o`00oooooooo003o00kooooo00?o003oooooooooool00oooool0
0ol00?ooooooo`00o`1;ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol00?oooooooooo
o`05ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00Oooooo0_l00?l9ooooo`03o`00
0?oooooooooo007ooooo000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l2ooooo`;o003o0oooool2o`00o`;ooooo
00Co003ooooooooooooooooo0_l00?l4ooooo`03o`00oooooooooooo00Cooooo0_l00?l2ooooo`07
o`00oooooooo003oooooool00?ooooooo`00o`07ooooo`08o`00ooooooooooooo`00oooooooo003o
ooooool00?l3ooooo`03o`00oooooooo003o00Cooooo00?o003oooooool00?l00oooool01ol00?oo
ooooo`00oooooooo003oooooool00?l00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooool00?ooooooo`00o`02ooooo`;o003o0_ooool01Ol00?ooooooo`00oooooooo003o00ko
oooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo04[o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool01_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool03?ooool0
0ol0003oooooooooo`01ooooo`002Oooool2o`0000Kooooo00?o0000ooooooooool01?ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00o`Cooooo00Go003ooooo
ooooooooooooo`00o`02ooooo`04o`00ooooooooooooooooo`;o003o1?ooool00ol00?oooooooooo
o`04ooooo`;o003o0_ooool00ol00?ooooooo`00o`02ooooo`04o`00ooooooooooooooooo`;o003o
0_ooool01Ol00?ooooooo`00oooooooo003o00?ooooo00?o003oooooool00?l00_ooool00ol00?oo
ooooo`00o`05ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`09o`00oooooooo
ooooooooool00?ooooooo`00oooooooo003o00Kooooo0_l00?l2ooooo`05o`00oooooooo003ooooo
ool00?l03_ooool01Ol0003o003ooooooooooooo003o00Kooooo00?o003oooooooooool0Coooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool01_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool03?ooool00ol0003oooooooooo`01ooooo`002_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`04ooooo`;o003o0oooool2o`00o`?ooooo00?o003oooooooooool01?oo
ool2o`00o`?ooooo0_l00?l7ooooo`06o`00ooooooooooooo`00oooooooo003o0_ooool2o`00o`;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Co
oooo0_l00?l2ooooo`03o`00oooooooo003o00Oooooo00co003ooooooooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?l3ooooo`05o`00ooooooooooooooooool00?l00_ooool01Ol0
0?oooooooooooooooooo003o00kooooo0_l00?l2ooooo`05o`00ooooooooooooooooool00?l00_oo
ool00ol00?ooooooooooo`1?ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oooooo
ooooooooool2o`00o`Oooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o2Oooool00ol0
003oooooooooo`01ooooo`004Oooool2o`0000Gooooo00Co003ooooooooooooooooo0_l00?l3oooo
o`03o`00oooooooooooo00Gooooo00Co003ooooooooooooooooo0_l00?l3ooooo`04o`00oooooooo
ooooo`00o`Cooooo0_l00?l2ooooo`;o003o2?ooool00ol00?ooooooooooo`02o`00o`;ooooo0_l0
0?l3ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01?ooool02Ol00?oooooooooo
oooooooo003oooooool00?ooooooo`00o`05ooooo`06o`00ooooooooooooo`00oooooooo003o0ooo
ool01ol00?ooooooo`00oooooooo003oooooool00?l01_ooool00ol00?ooooooooooo`0@ooooo`;o
003o0_ooool01Ol00?ooooooo`00oooooooo003o05Sooooo00Go003oooooooooooooooooo`00o`03
ooooo`;o003o0oooool00ol00?ooooooooooo`05ooooo`04o`00ooooooooooooooooo`;o003o2?oo
ool2o`0000?ooooo000Aooooo`03o`000?oooooooooo00Sooooo0_l00?l2ooooo`;o003o1oooool0
1?l00?ooooooooooooooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0oooool2o`00o`;ooooo0_l0
0?l2ooooo`;o003o0_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;o003o0_oo
ool01ol00?oooooooooooooooooo003oooooool00?l00oooool01?l00?ooooooooooool00?l3oooo
o`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00Kooooo00?o003oooooooooool0
1Oooool00ol00?ooooooo`00o`02ooooo`;o003o1?ooool00ol00?ooooooooooo`0>ooooo`;o003o
1?ooool00ol00?ooooooo`00o`1Looooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o00Oooooo0_l00?l9ooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0_ooool2o`00
o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0oooool00ol00?ooooooooooo`05
ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l4ooooo`05o`00ooooooooooooooooool00?l00_oo
ool01ol00?oooooooooooooooooo003oooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00;ooooo00_o003oooooooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`06ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooool00?l00_ooool2o`00o`;ooooo00Go003oooooool0
0?ooooooo`00o`0>ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l00_ooool00ol0
0?ooooooooooo`1Pooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0<
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o003ooooo
ooooool01Oooool2o`00o`;ooooo0_l00?l3ooooo`03o`00oooooooooooo00Gooooo0_l00?l2oooo
o`;o003o1?ooool01Ol00?oooooooooooooooooo003o00;ooooo0_l00?l2ooooo`;o003o0oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o0_ooool01ol00?oooooooooooooo
oooo003oooooool00?l00oooool00ol00?ooooooooooo`04ooooo`07o`00oooooooo003oooooool0
0?ooooooo`00o`02ooooo`09o`00ooooooooooooooooool00?ooooooo`00oooooooo003o00Gooooo
00?o003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo003o00kooooo00Oo0000o`00oooo
ooooooooo`00oooooooo003o00Cooooo00?o003oooooooooool0H?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool03?ooool00ol0003oooooooooo`01ooooo`004Oooool0
0ol0003oooooooooo`04ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oooooooooo
ooooool2o`00o`?ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l3ooooo`;o
003o0oooool2o`00o`Kooooo0_l00?l2ooooo`;o003o0oooool2o`00o`;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Cooooo0_l00?l4ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooool00?l00_ooool2o`00o`;ooooo00Go003oooooool0
0?ooooooo`00o`05ooooo`03o`00oooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`0>
ooooo`;o003o0_ooool01ol00?oooooooooooooooooo003oooooool00?l0Ioooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`04ooooo`05o`00ooooooooooooooooool00?l01oooool2o`00o`?o
oooo00Co003ooooooooooooooooo0_l00?l3ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooooooo0_l00?l7ooooo`04o`00ooooooooooooooooo`;o003o0_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01?ooool2o`00o`;ooooo
00?o003oooooool00?l01oooool00ol00?ooooooooooo`02o`00o`;ooooo00Wo003oooooool00?oo
ooooo`00oooooooo003oooooool00?l01_ooool00ol00?ooooooooooo`0@ooooo`09o`00oooooooo
ooooooooool00?ooooooo`00oooooooo003o06gooooo00Go003oooooooooooooooooo`00o`0:oooo
o`03o`000?oooooooooo007ooooo000Aooooo`;o00002Oooool01?l00?ooooooooooooooool2o`00
o`Oooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0_ooool00ol00?ooooooooooo`02
ooooo`04o`00ooooooooooooooooo`;o003o0_ooool00ol00?ooooooooooo`06ooooo`;o003o0_oo
ool2o`00o`;ooooo00Co003ooooooooooooooooo0_l00?l4ooooo`04o`00ooooooooooooo`00o`?o
oooo0_l00?l2ooooo`05o`00oooooooo003oooooool00?l01Oooool00ol00?ooooooooooo`02oooo
o`09o`00ooooooooooooooooool00?ooooooo`00oooooooo003o00Kooooo00?o003oooooooooool0
3_ooool02Ol00?oooooooooooooooooo003oooooool00?ooooooo`00o`1aooooo`03o`00oooooooo
oooo00Oooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`08ooooo`04o`00oooooooooooo
ooooo`;o003o0_ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l2ooooo`;o003o0_ooool00ol00?oooooo
ooooo`03ooooo`05o`00ooooooooooooooooool00?l00_ooool01?l00?ooooooooooooooool2o`00
o`Cooooo00Go003oooooooooooooooooo`00o`02ooooo`;o003o0_ooool01Ol00?ooooooo`00oooo
oooo003o00Sooooo00?o003oooooooooool00oooool01ol00?ooooooo`00oooooooo003oooooool0
0?l01?ooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooooooo00?ooooo00Go003oooooool0
0?ooooooo`00o`1_ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooo
oooooooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`;ooooo0_l0
0?l7ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l3ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_l00?l2ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`03ooooo`03
o`00oooooooooooo00Cooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00Co003o
oooooooooooooooo0_l00?l2ooooo`03o`00oooooooo003o00?ooooo00Go003oooooool00?oooooo
o`00o`02ooooo`03o`00oooooooo003o00kooooo00Oo0000ooooooooooooooooo`00oooooooo003o
00?ooooo00?o003oooooooooool0N?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`04ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2
o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o
0oooool00ol00?ooooooooooo`05ooooo`;o003o0_ooool2o`00o`?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`;o003o1_ooool00ol00?ooooooo`00o`02ooooo`;o003o0oooool00ol00?oo
ooooooooo`02ooooo`05o`00oooooooo003oooooool00?l00_ooool2o`00o`;ooooo0_l00?l2oooo
o`03o`00oooooooooooo00?ooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo
003o00kooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooooooo07Sooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool01Ol00?oooooooooooooo
oooo003o00Oooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l02?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003o
ooooooooool00_ooool2o`00o`;ooooo0_l00?l8ooooo`03o`00oooooooooooo00;o003o0_ooool2
o`00o`;ooooo00Go003oooooool00?ooooooo`00o`05ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool03?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooool00?l0
N_ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000Wooooo00Go003ooooooooooooooooo
o`00o`08ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4oooo
o`05o`00ooooooooooooooooool00?l03?ooool01?l00?ooooooooooooooool2o`00o`;ooooo0_l0
0?l2ooooo`;o003o0_ooool00ol00?ooooooo`00o`02ooooo`04o`00ooooooooooooooooo`;o003o
0_ooool2o`00o`Oooooo0_l00?l3ooooo`08o`00ooooooooooooo`00oooooooo003oooooool00?l8
ooooo`03o`00oooooooooooo00kooooo00Wo0000ooooooooooooooooo`00oooooooo003oooooool0
0?l0Noooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo00cooooo00?o003oooooooooool0
1_ooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l3ooooo`05o`00oooooooooooooooo
ool00?l00oooool01?l00?ooooooooooooooool2o`00o`;ooooo00?o003oooooooooool00_ooool0
1?l00?ooooooooooooooool2o`00o`;ooooo00Co003ooooooooooooooooo0_l00?l4ooooo`03o`00
oooooooooooo00Cooooo0_l00?l2ooooo`;o003o0_ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00Kooooo00Oo003oooooool00?ooooooo`00oooooooo003o00Cooooo00?o003ooooo
ool00?l03_ooool00ol0003oooooooooo`03ooooo`05o`00oooooooo003oooooool00?l0N_ooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0<ooooo`04o`00oooooooooooo
ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`05ooooo`04o`00ooooooooooooooooo`;o003o0_ooool2o`00o`Oooooo
00Co003ooooooooooooooooo0_l00?l2ooooo`04o`00ooooooooooooooooo`;o003o1?ooool01?l0
0?ooooooooooool00?l3ooooo`;o003o0_ooool00ol00?ooooooo`00o`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool02ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003o00;ooooo00?o003oooooool00?l03_ooool00ol0003oooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool0N?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`04o`00ooooooooooooooooo`;o003o0oooool00ol00?ooooooooooo`05ooooo`;o003o0_oo
ool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0_ooool01?l00?oooooo
ooooooooool2o`00o`?ooooo0_l00?l6ooooo`;o003o0_ooool00ol00?ooooooo`00o`02ooooo`;o
003o0_ooool2o`00o`;ooooo00?o003oooooooooool00oooool01Ol00?ooooooo`00oooooooo003o
00;ooooo0_l00?l?ooooo`05o`000?ooooooooooooooool00?l01Oooool00ol00?ooooooooooo`1h
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01Gooooo00Go003ooooo
ooooooooooooo`00o`07ooooo`;o003o0oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00;o003o0oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooooooo
o`00o`02ooooo`03o`00oooooooooooo00;ooooo0_l00?l2ooooo`;o003o1oooool01?l00?oooooo
ooooooooool2o`00o`;ooooo0_l00?l2ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooo`00o`03ooooo`03o`00oooooooooooo00gooooo00Go0000ooooooooooooooooo`00o`03
ooooo`03o`00oooooooo003o07[ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0000Joooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l02?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02o`00o`;ooooo00?o003oooooooooool00_ooool01?l00?oooooo
ooooooooool2o`00o`;ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooooooool2o`00
o`?ooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool04Oooool01?l0003oooooooooooooool2o`00o`;ooooo00?o003oooooooooool0NOooool2
o`0000?ooooo000Aooooo`03o`000?oooooooooo01gooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo
00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o0oooool01Ol0
0?oooooooooooooooooo003o00?ooooo0_l00?l2ooooo`;o003o0_ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00Gooooo00So003ooooooooooooo003oooooool00?ooooooo`00o`Co
oooo00?o003oooooooooool03_ooool00ol0003oooooooooo`02ooooo`04o`00ooooooooooooo`00
ogcooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool07Oooool01Ol00?oo
oooooooooooooooo003o00Sooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0oooool0
1Ol00?oooooooooooooooooo003o00?ooooo0_l00?l2ooooo`;o003o0oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`;o003o1oooool00ol00?oo
ooooooooo`02ooooo`0:o`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`;ooooo
0_l00?l?ooooo`03o`000?oooooooooo00;ooooo00Ko003ooooooooooooo003oooooool00?mjoooo
o`03o`000?oooooooooo007ooooo0008ooooo`Go00001?ooool00ol0003oooooooooo`0Qooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooooooooooo
ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l2ooooo`04o`00oooo
ooooooooooooo`;o003o0oooool00ol00?ooooooooooo`05ooooo`;o003o0_ooool2o`00o`?ooooo
00Co003ooooooooooooooooo0_l00?l2ooooo`03o`00oooooooooooo00?ooooo00Go003oooooool0
0?ooooooo`00o`02ooooo`;o003o3oooool01?l0003oooooooooooooool2o`00o`Cooooo00?o003o
ooooooooool0N?ooool00ol0003oooooooooo`01ooooo`002Oooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo027ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`05
ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool01?ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o0_ooool00ol00?oo
ooooooooo`03ooooo`05o`00oooooooo003oooooool00?l00oooool00ol00?ooooooooooo`0=oooo
o`05o`000?ooooooooooooooool00?l00oooool2o`00og_ooooo00?o0000ooooooooool00Oooool0
00[ooooo00?o0000ooooooooool01?ooool3o`0002Kooooo00Go003oooooooooooooooooo`00o`07
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooooooool2o`00o`Oo
oooo00Co003ooooooooooooooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`0Aooooo`04o`000?ooooooooooooooo`;o003o0_ooool0
0ol00?ooooooooooo`1hooooo`?o00000oooool000_ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Zooooo`05o`00ooooooooooooooooool00?l02?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool0
0?l00oooool2o`00o`;ooooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00;ooooo0_l00?l7ooooo`03o`00oooooooooooo
00kooooo00Co0000oooooooooooooooo0_l00?l2ooooo`03o`00oooooooooooo07[ooooo00?o0000
ooooooooool00Oooool000Sooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo02kooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0
0oooool01?l00?ooooooooooooooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`;o003o0_ooool2o`00o`;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;o003o0_ooool00ol00?ooooooooooo`02ooooo`;o003o3oooool00ol0
003oooooooooo`02ooooo`03o`00oooooooooooo00;o003oNoooool00ol0003oooooooooo`01oooo
o`002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0;_ooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool2o`00o`?ooooo00?o003oooooooooool01Oooool2o`00o`;ooooo
0_l00?l3ooooo`04o`00ooooooooooooooooo`;o003o0_ooool2o`00o`?ooooo00Ko003ooooooooo
oooo003oooooool00?l2ooooo`;o003o3oooool01?l0003oooooooooooooool2o`00o`?ooooo00?o
003oooooooooool0NOooool00ol0003oooooooooo`01ooooo`002Oooool3o`0000Gooooo00?o0000
ooooooooool0<_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`05ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00Cooooo
00?o003oooooooooool00_l00?l3ooooo`04o`00ooooooooooooooooo`;o003o0_ooool00ol00?oo
ooooooooo`02ooooo`06o`00ooooooooooooo`00oooooooo003o0_ooool2o`00o`oooooo00Go0000
ooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo07Wooooo00?o0000ooooooooool00Ooo
ool0017ooooo0_l0000hooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00So
oooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o0_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00Co0000oooooooooooooooo0_l0
0?l2ooooo`;o003oN_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo03_ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o0oooool01Ol00?oooooo
oooooooooooo003o00?ooooo0_l00?l7ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00
o`;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0>ooooo`04o`000?oooooooooo
ooooo`;o003o0_ooool00ol00?ooooooooooo`1jooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo03oooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00o`;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00;o003o0_ooool00ol00?oooooo
ooooo`02ooooo`;o003o3oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00;o003o
Noooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0oooooo`05o`00oooo
ooooooooooooool00?l00oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`04
o`00ooooooooooooooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l2
ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l?ooooo`03o`000?oooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`1kooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo04?ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`03o`00oooooooooooo00Gooooo00Co
003ooooooooooooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;o003o0oooool2o`00o`oooooo00Go0000oooooooo
ooooooooo`00o`04ooooo`03o`00oooooooooooo07Wooooo00?o0000ooooooooool00Oooool0017o
oooo0_l00018ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`08oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co
003ooooooooooooooooo0_l00?l4ooooo`03o`00oooooooooooo00gooooo00Go0000oooooooooooo
ooooo`00o`03ooooo`;o003oN_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo04Oooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?l2
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool01Ol0003ooooooooooooo
oooo003o00?ooooo00?o003oooooooooool0N_ooool00ol0003oooooooooo`01ooooo`004Oooool0
0ol0003oooooooooo`1<ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`02o`00o`;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0>ooooo`05o`000?ooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`1jooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo053ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Ko
oooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0_ooool2o`00o`?ooooo00?o003ooooo
ooooool03_ooool01Ol0003ooooooooooooooooo003o00?ooooo0_l00?mkooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo05Cooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;o003o0oooool00ol00?ooooooooooo`0>ooooo`05o`000?ooooooooooooooool00?l0
1?ooool00ol00?ooooooooooo`1iooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo05Sooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02o`00o`?ooooo00?o003oooooooooool0
3_ooool01Ol0003ooooooooooooooooo003o00?ooooo0_l00?mkooooo`03o`000?oooooooooo007o
oooo000Aooooo`;o0000FOooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool04_ooool01Ol0
003ooooooooooooooooo003o00?ooooo00?o003oooooooooool0NOooool2o`0000?ooooo000Aoooo
o`03o`000?oooooooooo05gooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooooooo
ooooooooo`;o003o1oooool00ol00?ooooooooooo`0>ooooo`05o`000?ooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`1jooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo067ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00kooooo00Go0000ooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo07[ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
HOooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?l3oooo
o`03o`00oooooooooooo00kooooo00Go0000ooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo07[ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0HOooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`03o`00oooo
oooooooo00kooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`1jooooo`03o`000?oo
oooooooo007ooooo000Aooooo`;o0000I_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o
003oooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo07Wooooo0_l0
0003ooooo`004Oooool00ol0003oooooooooo`1Yooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo07[ooooo00?o0000
ooooooooool00Oooool000Wooooo0ol00005ooooo`03o`000?oooooooooo06Wooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`03o`00oooooooooooo00kooooo00?o0000ooooooooool01Oooool0
0ol00?ooooooooooo`1jooooo`03o`000?oooooooooo007ooooo0008ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`1]ooooo`;o003o0oooool00ol00?ooooooooooo`0>
ooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool0N_ooool00ol0003oooooooooo`01
ooooo`003?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06gooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo00?o003ooooo
ooooool0N_ooool00ol0003oooooooooo`01ooooo`002_ooool2o`0000Gooooo0ol0001booooo`03
o`00oooooooooooo00kooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`1hooooo`?o
00000oooool000cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`23ooooo`03o`00
0?oooooooooo08;ooooo00?o0000ooooooooool00Oooool000Sooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0P_ooool00ol0003ooooo
ooooo`01ooooo`002Oooool3o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`01ooooo`004Oooooooo`0000go00000oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-11.9139, -3.66181, \
0.0788464, 0.0386451}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Show all", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{{g3, g4}, {g6, g8}}], \ 
        ImageSize \[Rule] 504];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 504 311.489 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.0147151 0.0195446 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11244 -6 -4.5 ]
[-0.0125 .11244 0 4.5 ]
[-0.0125 .21016 -12 -4.5 ]
[-0.0125 .21016 0 4.5 ]
[-0.0125 .30788 -12 -4.5 ]
[-0.0125 .30788 0 4.5 ]
[-0.0125 .40561 -12 -4.5 ]
[-0.0125 .40561 0 4.5 ]
[-0.0125 .50333 -12 -4.5 ]
[-0.0125 .50333 0 4.5 ]
[-0.0125 .60105 -12 -4.5 ]
[-0.0125 .60105 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11244 m
.00625 .11244 L
s
[(5)] -0.0125 .11244 1 0 Mshowa
0 .21016 m
.00625 .21016 L
s
[(10)] -0.0125 .21016 1 0 Mshowa
0 .30788 m
.00625 .30788 L
s
[(15)] -0.0125 .30788 1 0 Mshowa
0 .40561 m
.00625 .40561 L
s
[(20)] -0.0125 .40561 1 0 Mshowa
0 .50333 m
.00625 .50333 L
s
[(25)] -0.0125 .50333 1 0 Mshowa
0 .60105 m
.00625 .60105 L
s
[(30)] -0.0125 .60105 1 0 Mshowa
.125 Mabswid
0 .03426 m
.00375 .03426 L
s
0 .0538 m
.00375 .0538 L
s
0 .07335 m
.00375 .07335 L
s
0 .09289 m
.00375 .09289 L
s
0 .13198 m
.00375 .13198 L
s
0 .15153 m
.00375 .15153 L
s
0 .17107 m
.00375 .17107 L
s
0 .19062 m
.00375 .19062 L
s
0 .22971 m
.00375 .22971 L
s
0 .24925 m
.00375 .24925 L
s
0 .2688 m
.00375 .2688 L
s
0 .28834 m
.00375 .28834 L
s
0 .32743 m
.00375 .32743 L
s
0 .34697 m
.00375 .34697 L
s
0 .36652 m
.00375 .36652 L
s
0 .38606 m
.00375 .38606 L
s
0 .42515 m
.00375 .42515 L
s
0 .4447 m
.00375 .4447 L
s
0 .46424 m
.00375 .46424 L
s
0 .48379 m
.00375 .48379 L
s
0 .52287 m
.00375 .52287 L
s
0 .54242 m
.00375 .54242 L
s
0 .56196 m
.00375 .56196 L
s
0 .58151 m
.00375 .58151 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11244 m
1 .11244 L
s
.99375 .21016 m
1 .21016 L
s
.99375 .30788 m
1 .30788 L
s
.99375 .40561 m
1 .40561 L
s
.99375 .50333 m
1 .50333 L
s
.99375 .60105 m
1 .60105 L
s
.125 Mabswid
.99625 .03426 m
1 .03426 L
s
.99625 .0538 m
1 .0538 L
s
.99625 .07335 m
1 .07335 L
s
.99625 .09289 m
1 .09289 L
s
.99625 .13198 m
1 .13198 L
s
.99625 .15153 m
1 .15153 L
s
.99625 .17107 m
1 .17107 L
s
.99625 .19062 m
1 .19062 L
s
.99625 .22971 m
1 .22971 L
s
.99625 .24925 m
1 .24925 L
s
.99625 .2688 m
1 .2688 L
s
.99625 .28834 m
1 .28834 L
s
.99625 .32743 m
1 .32743 L
s
.99625 .34697 m
1 .34697 L
s
.99625 .36652 m
1 .36652 L
s
.99625 .38606 m
1 .38606 L
s
.99625 .42515 m
1 .42515 L
s
.99625 .4447 m
1 .4447 L
s
.99625 .46424 m
1 .46424 L
s
.99625 .48379 m
1 .48379 L
s
.99625 .52287 m
1 .52287 L
s
.99625 .54242 m
1 .54242 L
s
.99625 .56196 m
1 .56196 L
s
.99625 .58151 m
1 .58151 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .01472 m
.02608 .0232 L
.02723 .02697 L
.02847 .03029 L
.02913 .03169 L
.02972 .03272 L
.03001 .03313 L
.03033 .0335 L
.03062 .03378 L
.03089 .03399 L
.03105 .03408 L
.03121 .03416 L
.03131 .03419 L
.0314 .03422 L
.03148 .03424 L
.03156 .03425 L
.03166 .03426 L
.03174 .03427 L
.03184 .03426 L
.03193 .03425 L
.03202 .03424 L
.0321 .03422 L
.03228 .03416 L
.03243 .03409 L
.03257 .03401 L
.0329 .03377 L
.03321 .03345 L
.03355 .03304 L
.03419 .03203 L
.03478 .03086 L
.03611 .02742 L
.03736 .02338 L
.03854 .01911 L
.03907 .01709 L
.03935 .01599 L
.03949 .01544 L
.03962 .01495 L
.03976 .01503 L
.03991 .01561 L
.04023 .01684 L
.04079 .01897 L
.04208 .02367 L
.04327 .0275 L
.04438 .03041 L
.04496 .03166 L
.04559 .03275 L
.04592 .03321 L
.04622 .03357 L
.04652 .03386 L
.04681 .03407 L
Mistroke
.04696 .03415 L
.04712 .03423 L
.04722 .03426 L
.0473 .03428 L
.04738 .0343 L
.04747 .03431 L
.04763 .03432 L
.04771 .03432 L
.0478 .03431 L
.04795 .03428 L
.0481 .03424 L
.04825 .03417 L
.04841 .03409 L
.0487 .03388 L
.04902 .03359 L
.04936 .03318 L
.04998 .03224 L
.05056 .03112 L
.05163 .02847 L
.0528 .02492 L
.05405 .02048 L
.05466 .01817 L
.05522 .01603 L
.05536 .01547 L
.05552 .01485 L
.05567 .01516 L
.05581 .01569 L
.05643 .01812 L
.05776 .02304 L
.05886 .02668 L
.06003 .02996 L
.0607 .03149 L
.06132 .03262 L
.06161 .03307 L
.06194 .0335 L
.06222 .0338 L
.06252 .03407 L
.06267 .03417 L
.06283 .03426 L
.06297 .03433 L
.06311 .03438 L
.06323 .03441 L
.06337 .03443 L
.06352 .03444 L
.06365 .03443 L
.06373 .03442 L
.06381 .0344 L
.06396 .03436 L
.06412 .03429 L
.0643 .0342 L
Mistroke
.06461 .03397 L
.0649 .03368 L
.06554 .03285 L
.06612 .03184 L
.06744 .02875 L
.06864 .02508 L
.06992 .02053 L
.07054 .01816 L
.07085 .01698 L
.07113 .01588 L
.07126 .01536 L
.07139 .01488 L
.07152 .01506 L
.07166 .01561 L
.07223 .01783 L
.07459 .02635 L
.07576 .02972 L
.07684 .03214 L
.07741 .03311 L
.07801 .03389 L
.07833 .03418 L
.07862 .03439 L
.07879 .03447 L
.07894 .03454 L
.07903 .03456 L
.07911 .03458 L
.07921 .0346 L
.07929 .03461 L
.07943 .03461 L
.07958 .03459 L
.07973 .03456 L
.07986 .03452 L
.07998 .03447 L
.08011 .0344 L
.08038 .03423 L
.08066 .03397 L
.08097 .03363 L
.08153 .03284 L
.08217 .03166 L
.08275 .03033 L
.08409 .02657 L
.08525 .0226 L
.08651 .01783 L
.08684 .01656 L
.08701 .01586 L
.08718 .0152 L
.08732 .01479 L
.08747 .01538 L
.08779 .01665 L
.08899 .0213 L
Mistroke
.09124 .02882 L
.09247 .03186 L
.09317 .03314 L
.0935 .03363 L
.09381 .03402 L
.0941 .03432 L
.09437 .03453 L
.09451 .03462 L
.09467 .03471 L
.09475 .03474 L
.09483 .03477 L
.09499 .03482 L
.09506 .03483 L
.09515 .03484 L
.0953 .03484 L
.09545 .03483 L
.09559 .0348 L
.09574 .03475 L
.0959 .03468 L
.09608 .03458 L
.09624 .03447 L
.09684 .03387 L
.09718 .03341 L
.0975 .0329 L
.09869 .03037 L
.09977 .02731 L
.10093 .02342 L
.10206 .01916 L
.10265 .01682 L
.10295 .01562 L
.10303 .0153 L
.10312 .01495 L
.10327 .01512 L
.10342 .01571 L
.10358 .01636 L
.10388 .01753 L
.10442 .01968 L
.10548 .02366 L
.10672 .02783 L
.10787 .03104 L
.10851 .03244 L
.10908 .03348 L
.10972 .03435 L
.11008 .0347 L
.11024 .03482 L
.11041 .03493 L
.11058 .03502 L
.11073 .03508 L
.11087 .03512 L
.11102 .03514 L
Mistroke
.11116 .03514 L
.11128 .03514 L
.11142 .03511 L
.11157 .03507 L
.11173 .035 L
.1119 .03491 L
.11222 .03468 L
.11252 .03438 L
.1128 .03404 L
.11388 .0322 L
.11442 .03096 L
.11502 .02938 L
.11626 .02549 L
.11756 .0207 L
.11809 .01858 L
.11866 .01627 L
.11883 .01558 L
.11892 .01525 L
.11899 .01493 L
.11914 .01508 L
.11929 .01572 L
.11988 .01808 L
.12229 .0271 L
.12347 .03062 L
.12455 .03309 L
.12511 .03405 L
.12564 .03475 L
.12593 .03504 L
.1262 .03525 L
.12634 .03533 L
.1265 .03541 L
.12658 .03544 L
.12666 .03546 L
.12681 .0355 L
.12697 .03551 L
.12712 .03551 L
.1272 .0355 L
.12728 .03549 L
.12736 .03547 L
.12745 .03544 L
.12761 .03537 L
.12777 .03529 L
.12811 .03503 L
.12839 .03475 L
.12869 .03438 L
.1293 .03341 L
.13053 .03068 L
.13165 .02735 L
.13295 .02268 L
.13359 .02019 L
Mistroke
.13416 .01785 L
.13444 .01672 L
.13458 .01612 L
.13473 .01549 L
.13487 .01493 L
.13501 .01511 L
.13515 .01566 L
.13527 .01618 L
.13645 .02101 L
.13774 .02588 L
.13895 .02985 L
.14013 .03287 L
.14079 .03416 L
.14111 .03466 L
.14141 .03505 L
.14168 .03535 L
.14192 .03557 L
.1422 .03576 L
.14234 .03584 L
.14249 .0359 L
.14263 .03593 L
.14278 .03596 L
.14292 .03596 L
.14304 .03595 L
.14319 .03593 L
.14328 .0359 L
.14335 .03587 L
.1435 .03581 L
.14365 .03573 L
.14395 .0355 L
.14424 .03521 L
.14479 .03449 L
.14537 .03346 L
.14601 .03204 L
.14822 .02517 L
.14944 .02038 L
.15004 .01789 L
.15031 .01678 L
.1506 .01556 L
.15067 .01523 L
.15076 .01487 L
.15091 .01519 L
.15099 .01557 L
.15108 .01592 L
.15123 .01659 L
.15192 .01949 L
.15313 .02433 L
.15429 .02853 L
.15553 .03219 L
.15659 .0345 L
Mistroke
.15688 .03499 L
.15719 .03544 L
.15749 .0358 L
.15776 .03606 L
.15806 .03628 L
.15823 .03637 L
.15839 .03643 L
.15853 .03647 L
.15867 .03649 L
.15882 .03649 L
.15897 .03648 L
.15913 .03644 L
.15922 .03641 L
.1593 .03638 L
.15961 .0362 L
.15978 .03607 L
.15996 .03589 L
.1603 .0355 L
.16091 .03457 L
.16156 .03325 L
.16273 .03014 L
.16388 .02623 L
.1651 .02144 L
.16614 .01702 L
.16642 .01578 L
.16658 .01509 L
.16673 .01498 L
.16686 .01557 L
.16701 .01621 L
.16728 .01737 L
.16961 .02691 L
.1708 .03096 L
.17144 .03276 L
.17212 .03438 L
.17277 .03559 L
.17336 .03639 L
.17364 .03668 L
.17379 .0368 L
.17395 .03691 L
.17411 .03699 L
.17424 .03705 L
.17438 .03709 L
.17452 .03712 L
.17466 .03712 L
.17475 .03712 L
.17482 .03711 L
.17498 .03708 L
.17507 .03705 L
.17515 .03701 L
.17529 .03694 L
Mistroke
.17545 .03684 L
.17573 .03661 L
.17607 .03625 L
.17642 .03576 L
.17705 .03463 L
.17818 .03184 L
.1794 .02787 L
.18055 .02343 L
.18161 .01888 L
.18217 .01639 L
.18233 .01566 L
.18248 .01498 L
.18262 .01506 L
.18276 .01573 L
.18403 .02134 L
.18524 .02638 L
.18657 .03115 L
.18717 .03295 L
.18781 .03461 L
.18837 .03578 L
.18897 .03677 L
.18933 .03721 L
.1895 .03738 L
.18965 .03751 L
.1898 .03762 L
.18997 .03772 L
.19006 .03776 L
.19014 .03779 L
.19022 .03781 L
.1903 .03784 L
.19045 .03786 L
.19058 .03786 L
.19066 .03785 L
.19074 .03784 L
.19089 .0378 L
.19105 .03774 L
.19119 .03766 L
.19151 .03742 L
.19181 .03713 L
.19207 .03679 L
.19268 .0358 L
.19324 .03461 L
.19377 .03325 L
.19626 .02441 L
.19741 .01933 L
.19775 .01781 L
.19806 .01636 L
.1982 .01572 L
.19834 .01505 L
.1985 .01512 L
Mistroke
.19865 .0158 L
.20086 .02576 L
.20201 .03022 L
.20323 .03414 L
.20382 .03566 L
.20439 .03683 L
.20489 .03765 L
.20518 .03801 L
.20544 .03828 L
.20572 .0385 L
.20587 .03858 L
.20603 .03865 L
.20616 .03869 L
.20629 .03871 L
.20643 .03872 L
.20658 .03871 L
.20666 .03869 L
.20674 .03867 L
.20682 .03864 L
.20691 .0386 L
.20706 .03852 L
.20723 .03841 L
.20754 .03812 L
.20783 .03778 L
.20846 .03676 L
.20905 .03551 L
.21036 .03171 L
.21156 .02719 L
.21285 .02157 L
.21347 .01864 L
.21378 .01717 L
.21406 .01582 L
.21419 .01517 L
.21431 .01485 L
.21444 .01548 L
.21459 .01617 L
.21515 .01891 L
.21752 .02948 L
.21869 .03367 L
.21977 .03668 L
.22034 .03789 L
.22094 .03885 L
.22126 .03921 L
.22155 .03946 L
.22172 .03957 L
.22188 .03964 L
.22196 .03967 L
.22205 .0397 L
.22214 .03972 L
.22223 .03972 L
Mistroke
.22237 .03972 L
.22252 .0397 L
.22266 .03966 L
.22279 .0396 L
.22291 .03954 L
.22304 .03945 L
.22331 .03922 L
.2236 .0389 L
.22391 .03846 L
.22446 .03744 L
.2251 .03594 L
.22569 .03425 L
.22702 .02946 L
.22827 .02399 L
.22889 .02107 L
.22945 .01829 L
.22972 .01693 L
.22997 .01565 L
.2301 .015 L
.23024 .01512 L
.23039 .01589 L
.23053 .01659 L
.2317 .02241 L
.23299 .02841 L
.23418 .0332 L
.2353 .03681 L
.23587 .03824 L
.23649 .03947 L
.23682 .03997 L
.23711 .04033 L
.23728 .0405 L
.23746 .04064 L
.23763 .04075 L
.23778 .04083 L
.23794 .04088 L
.23809 .0409 L
.23823 .0409 L
.23837 .04089 L
.23853 .04084 L
.23861 .04081 L
.2387 .04077 L
.239 .04056 L
.23915 .04041 L
.2393 .04026 L
.23963 .03982 L
.24023 .03876 L
.24077 .0375 L
.24135 .03586 L
.24387 .02576 L
.24501 .02012 L
Mistroke
.2456 .01701 L
.24574 .01625 L
.2459 .01543 L
.24599 .01496 L
.24607 .0149 L
.24622 .01574 L
.24737 .0218 L
.24843 .02708 L
.24955 .03215 L
.25074 .03662 L
.25137 .0385 L
.25205 .04016 L
.25235 .04074 L
.25267 .04127 L
.25298 .04167 L
.25325 .04195 L
.25341 .04207 L
.25356 .04216 L
.25372 .04223 L
.25381 .04226 L
.25389 .04228 L
.25402 .04229 L
.25417 .04229 L
.25433 .04225 L
.25448 .0422 L
.25456 .04216 L
.25465 .0421 L
.25481 .04199 L
.25512 .04168 L
.25548 .04121 L
.25581 .04065 L
.25637 .03944 L
.25698 .03776 L
.25823 .03331 L
.26057 .02207 L
.26125 .0184 L
.26158 .01655 L
.26174 .01564 L
.26189 .01482 L
.26203 .01542 L
.26216 .01617 L
.26246 .01784 L
.26309 .02133 L
.2653 .03261 L
.26656 .0377 L
.26718 .03971 L
.26774 .04122 L
.26833 .04248 L
.26861 .04293 L
.2689 .04332 L
Mistroke
.26904 .04348 L
.26921 .04363 L
.26935 .04374 L
.26949 .04382 L
.26957 .04386 L
.26965 .04389 L
.26974 .04391 L
.26983 .04393 L
.2699 .04394 L
.26999 .04394 L
.27014 .04391 L
.27022 .04389 L
.27031 .04386 L
.27047 .04378 L
.27064 .04366 L
.27082 .04349 L
.27116 .04309 L
.27147 .0426 L
.27205 .04141 L
.27268 .03972 L
.2739 .03532 L
.27523 .02913 L
.2765 .0222 L
.2771 .01871 L
.27737 .01716 L
.27752 .01627 L
.27766 .01544 L
.27779 .01481 L
.27794 .01569 L
.27824 .0175 L
.27888 .02127 L
.28003 .02784 L
.28135 .03458 L
.28256 .03968 L
.28315 .04165 L
.28379 .04342 L
.28444 .04474 L
.28479 .04526 L
.28495 .04544 L
.28513 .04561 L
.28528 .04572 L
.28542 .0458 L
.28558 .04586 L
.28566 .04589 L
.28574 .0459 L
.28587 .0459 L
.28602 .04588 L
.28617 .04583 L
.2863 .04577 L
.28645 .04567 L
Mistroke
.28659 .04555 L
.28691 .04519 L
.28722 .04472 L
.28755 .04408 L
.28819 .04253 L
.28878 .04068 L
.29011 .03521 L
.29136 .02871 L
.29254 .02175 L
.29306 .01846 L
.29335 .01664 L
.29349 .01574 L
.29362 .01493 L
.29376 .0154 L
.29391 .01636 L
.29423 .01839 L
.29478 .02193 L
.29607 .02979 L
.29727 .03627 L
.29837 .04126 L
.29895 .04342 L
.29958 .04534 L
.2999 .04616 L
.3002 .0468 L
.30051 .04733 L
.30079 .04772 L
.30096 .04791 L
.30111 .04804 L
.30128 .04815 L
.30137 .0482 L
.30145 .04823 L
.30161 .04827 L
.30176 .04828 L
.30191 .04825 L
.30199 .04823 L
.30208 .04819 L
.30224 .0481 L
.30239 .04798 L
.30271 .04762 L
.303 .04718 L
.30331 .0466 L
.30385 .04531 L
.30444 .04348 L
.30574 .03805 L
.30696 .03148 L
.30814 .02407 L
.30879 .01975 L
.30911 .01759 L
.30924 .01665 L
.30939 .01562 L
Mistroke
.30953 .01476 L
.30966 .01564 L
.30991 .01737 L
.31046 .02117 L
.31162 .02898 L
.31389 .0419 L
.31451 .04464 L
.31517 .0471 L
.3158 .04892 L
.31638 .05013 L
.31668 .05059 L
.31695 .0509 L
.31711 .05102 L
.31719 .05107 L
.31727 .05112 L
.31742 .05117 L
.31757 .05119 L
.3177 .05119 L
.31784 .05116 L
.31797 .0511 L
.31809 .05102 L
.31824 .05091 L
.31839 .05075 L
.31867 .05038 L
.31897 .04986 L
.3193 .04914 L
.31997 .04723 L
.32117 .04235 L
.32241 .03563 L
.32371 .02712 L
.32482 .01908 L
.32512 .0168 L
.3252 .0162 L
.32529 .01555 L
.32544 .01507 L
.3256 .01628 L
.32575 .01739 L
.32603 .01949 L
.32844 .03677 L
.32962 .0438 L
.3307 .04893 L
.33122 .0509 L
.33179 .05261 L
.33211 .05335 L
.3324 .05391 L
.33267 .05432 L
.33283 .0545 L
.33297 .05463 L
.33311 .05474 L
.33326 .05481 L
Mistroke
.33341 .05485 L
.3335 .05485 L
.33358 .05485 L
.33372 .05481 L
.33386 .05475 L
.33401 .05465 L
.33415 .05452 L
.33448 .0541 L
.33478 .05357 L
.33511 .05282 L
.33546 .05185 L
.3366 .04745 L
.33782 .04081 L
.34002 .02495 L
.34062 .02016 L
.34094 .01747 L
.3411 .01615 L
.34124 .01493 L
.34133 .01521 L
.34142 .01596 L
.34161 .01754 L
.34194 .0203 L
.34258 .02563 L
.34375 .03498 L
.345 .04395 L
.34624 .05121 L
.34683 .05395 L
.34737 .05603 L
.34791 .05766 L
.3482 .05832 L
.34851 .05887 L
.34863 .05905 L
.34877 .05922 L
.34889 .05934 L
.34902 .05944 L
.34916 .05952 L
.34931 .05956 L
.34945 .05956 L
.34958 .05954 L
.34974 .05947 L
.34981 .05942 L
.3499 .05935 L
.35019 .05901 L
.35036 .05876 L
.35053 .05844 L
.35085 .05771 L
.35148 .05578 L
.35205 .05345 L
.3532 .04722 L
.35429 .03964 L
Mistroke
.35545 .03016 L
.35609 .0245 L
.3564 .02164 L
.35669 .01898 L
.35696 .01643 L
.3571 .01513 L
.35725 .01572 L
.3574 .01715 L
.35756 .01868 L
.35785 .02145 L
.35891 .03129 L
.36014 .04206 L
.36148 .05215 L
.36209 .05601 L
.36274 .05949 L
.36335 .0621 L
.36391 .06392 L
.36418 .06461 L
.36433 .06491 L
.36449 .06519 L
.36464 .06541 L
.36477 .06558 L
.36491 .0657 L
.36504 .06579 L
.36519 .06585 L
.36535 .06586 L
.36548 .06584 L
.36563 .06576 L
.36578 .06564 L
.36595 .06545 L
.36611 .06522 L
.36626 .06496 L
.3668 .06363 L
.36711 .06262 L
.36739 .06153 L
.36847 .05602 L
.36963 .04784 L
.37072 .03838 L
.37193 .02636 L
.37225 .02301 L
.37259 .01936 L
.37275 .01757 L
.37291 .01587 L
.37305 .01509 L
.3732 .01675 L
.37436 .02944 L
.37564 .04276 L
.37679 .05361 L
.37787 .06218 L
.37901 .06908 L
Mistroke
.37961 .0717 L
.37995 .07282 L
.38026 .07363 L
.38042 .07396 L
.38059 .07424 L
.38074 .07445 L
.38089 .07459 L
.38097 .07466 L
.38105 .0747 L
.38114 .07473 L
.38124 .07474 L
.38139 .07471 L
.38148 .07467 L
.38156 .07461 L
.38164 .07455 L
.38173 .07446 L
.38188 .07426 L
.38216 .07374 L
.38249 .07288 L
.3828 .07186 L
.38336 .06944 L
.38396 .06605 L
.38506 .05795 L
.38624 .04659 L
.38754 .03178 L
.38815 .02425 L
.38848 .01999 L
.38865 .01788 L
.3888 .01592 L
.38894 .01536 L
.38909 .01734 L
.38941 .02151 L
.38996 .02879 L
.39251 .06006 L
.39365 .07144 L
.39428 .07666 L
.39487 .0808 L
.39543 .08388 L
.39572 .0852 L
.39603 .08635 L
.39629 .08711 L
.39643 .08744 L
.39658 .08773 L
.39671 .08795 L
.39684 .0881 L
.39696 .08821 L
.39708 .08827 L
.39723 .08829 L
.39731 .08827 L
.39739 .08824 L
Mistroke
.39753 .08813 L
.39768 .08795 L
.39782 .08774 L
.39794 .08749 L
.39823 .08675 L
.39854 .08569 L
.39882 .08448 L
.39946 .0809 L
.4 .07697 L
.40059 .07177 L
.40167 .06007 L
.4029 .04382 L
.40405 .0263 L
.40436 .02133 L
.40453 .01857 L
.40468 .01599 L
.40477 .0148 L
.40486 .01626 L
.40504 .01938 L
.40537 .02488 L
.40658 .04491 L
.40897 .0811 L
.40962 .08929 L
.41032 .09682 L
.41092 .10225 L
.41123 .10465 L
.41157 .10683 L
.41186 .10846 L
.41218 .10989 L
.41232 .11041 L
.41247 .11088 L
.41261 .11124 L
.41275 .11152 L
.41289 .11174 L
.41304 .1119 L
.41318 .11197 L
.41332 .11196 L
.41345 .11189 L
.41358 .11176 L
.41371 .11155 L
.41385 .11126 L
.41402 .11081 L
.41417 .11029 L
.41453 .10878 L
.41484 .10704 L
.41517 .10478 L
.4158 .0993 L
.41637 .09305 L
.4176 .07572 L
.4189 .05233 L
Mistroke
.42 .02906 L
.4203 .02228 L
.42047 .01849 L
.42063 .01487 L
.42077 .01796 L
.42093 .02167 L
.42121 .02823 L
.42343 .0809 L
.42469 .10883 L
.42587 .13163 L
.42702 .14928 L
.42767 .15675 L
.42826 .16182 L
.42858 .16382 L
.42888 .16518 L
.42905 .16573 L
.42921 .16609 L
.4293 .16623 L
.42939 .16633 L
.42948 .16638 L
.42956 .16639 L
.42971 .16629 L
.42985 .16609 L
.43 .16573 L
.43016 .1652 L
.43033 .16446 L
.43049 .16359 L
.4308 .16153 L
.43135 .15627 L
.43196 .14818 L
.4326 .13716 L
.43319 .12442 L
.43542 .05774 L
.43603 .03433 L
.43618 .02815 L
.43633 .02221 L
.43646 .01679 L
.4366 .01862 L
.43675 .02504 L
.43689 .03106 L
.4372 .04477 L
.43785 .07508 L
.44008 .1886 L
.44253 .3198 L
.44483 .43383 L
.44703 .52237 L
.44827 .55939 L
.4494 .58381 L
.44997 .59257 L
.45029 .59635 L
Mistroke
.45058 .59907 L
.45086 .60101 L
.45101 .60185 L
.45115 .60245 L
.45128 .60285 L
.45141 .60315 L
.45155 .6033 L
.45169 .6033 L
.45184 .60313 L
.45193 .60294 L
.45201 .60272 L
.45216 .60217 L
.45232 .60141 L
.45259 .59962 L
.45289 .59698 L
.45356 .58869 L
.45419 .57793 L
.45538 .55004 L
.45662 .51118 L
.45886 .42247 L
.46346 .20488 L
.46602 .09277 L
.46724 .04765 L
.46777 .02984 L
.46791 .02519 L
.46807 .02031 L
.46822 .01581 L
.46835 .01764 L
.46849 .02168 L
.46864 .02599 L
.46892 .03352 L
.46952 .0486 L
.47013 .06212 L
.47078 .07442 L
.4714 .0842 L
.47196 .09139 L
.47253 .09705 L
.47307 .10098 L
.47336 .10259 L
.47363 .10375 L
.47378 .10427 L
.47393 .10466 L
.47401 .10484 L
.4741 .10501 L
.47425 .10522 L
.4744 .10534 L
.47448 .10537 L
.47456 .10537 L
.47465 .10535 L
.47472 .1053 L
Mistroke
.47481 .10522 L
.4749 .10512 L
.47504 .10487 L
.47518 .10457 L
.47549 .10365 L
.47579 .10249 L
.47606 .10115 L
.47657 .09805 L
.47772 .08867 L
.48015 .06163 L
.48237 .03417 L
.48294 .02754 L
.48355 .02077 L
.48384 .01764 L
.48399 .01614 L
.48412 .01478 L
.48424 .01587 L
.48437 .01713 L
.48464 .01973 L
.48584 .02981 L
.48647 .03414 L
.48714 .03796 L
.48772 .04068 L
.48836 .04296 L
.48864 .04375 L
.48894 .04444 L
.48923 .04495 L
.48948 .04531 L
.48962 .04546 L
.48977 .04558 L
.48989 .04566 L
.49003 .04573 L
.49017 .04576 L
.49033 .04577 L
.49048 .04575 L
.49062 .0457 L
.49075 .04562 L
.49088 .04553 L
.49117 .04525 L
.49142 .04492 L
.49169 .0445 L
.49234 .04316 L
.49293 .0416 L
.49428 .0372 L
.49671 .02769 L
.49781 .02328 L
.49898 .01866 L
.49933 .01731 L
.49966 .01603 L
.4998 .01548 L
Mistroke
.49995 .01489 L
.50003 .01484 L
.50012 .01518 L
.50027 .01578 L
.50148 .02046 L
.50401 .03059 L
.50512 .03495 L
.50633 .03931 L
.5069 .04112 L
.50751 .04279 L
.50804 .04398 L
.50861 .04497 L
.50877 .04518 L
.50895 .04537 L
.50911 .04552 L
.50926 .04563 L
.5094 .0457 L
.50955 .04575 L
.50963 .04577 L
.50971 .04577 L
.50986 .04576 L
.51 .04572 L
.51015 .04564 L
.51027 .04555 L
.51041 .04543 L
.51072 .04504 L
.511 .04454 L
.51157 .04317 L
.51219 .04105 L
.51283 .03811 L
.51344 .03472 L
.51451 .02706 L
.51507 .02232 L
.51538 .01952 L
.51567 .01677 L
.51581 .01532 L
.51597 .01571 L
.51606 .01663 L
.51615 .01752 L
.51631 .01921 L
.5169 .02571 L
.51824 .04157 L
.52067 .07142 L
.52182 .08422 L
.52246 .09036 L
.52306 .09538 L
.52362 .09928 L
.52391 .10099 L
.52422 .10251 L
.52448 .10356 L
Mistroke
.52462 .10403 L
.52477 .10445 L
.52491 .10477 L
.52503 .105 L
.52516 .10518 L
.52527 .1053 L
.52541 .10537 L
.52556 .10536 L
.5257 .10527 L
.52583 .10512 L
.52597 .10488 L
.52613 .10452 L
.52629 .10404 L
.52644 .10349 L
.52675 .10203 L
.52704 .10032 L
.52768 .09513 L
.52823 .08913 L
.52882 .08095 L
.5299 .06156 L
.53104 .03458 L
.53136 .02604 L
.53153 .02114 L
.53161 .01866 L
.53169 .01634 L
.53184 .01765 L
.53192 .0201 L
.53201 .02274 L
.5323 .03198 L
.53484 .12817 L
.53986 .36387 L
.54238 .47439 L
.54349 .51509 L
.5447 .55211 L
.54527 .56631 L
.54587 .57912 L
.5464 .58809 L
.54697 .59554 L
.5473 .59878 L
.54745 .59993 L
.54761 .60101 L
.54775 .60178 L
.54791 .60244 L
.54799 .60273 L
.54807 .60294 L
.54822 .60322 L
.54836 .60332 L
.5485 .60326 L
.54865 .60304 L
.5488 .60261 L
Mistroke
.54895 .60201 L
.54909 .60129 L
.54936 .59952 L
.54965 .59695 L
.54992 .59395 L
.55054 .58501 L
.55114 .57352 L
.55178 .55825 L
.55401 .48394 L
.55657 .36639 L
.55899 .23832 L
.56119 .12256 L
.56244 .06152 L
.56274 .04778 L
.56305 .0337 L
.56332 .02202 L
.56347 .01555 L
.56361 .01981 L
.56476 .0641 L
.566 .10362 L
.56722 .13353 L
.56791 .14608 L
.56853 .15485 L
.56911 .16081 L
.56941 .16299 L
.56958 .16399 L
.56973 .16476 L
.56987 .16529 L
.57001 .16575 L
.57016 .16611 L
.57031 .16631 L
.57044 .16639 L
.57058 .16635 L
.57072 .16621 L
.57084 .16599 L
.571 .16558 L
.57117 .16499 L
.57146 .16357 L
.57178 .1615 L
.57213 .15863 L
.57276 .15197 L
.57335 .14415 L
.57581 .09816 L
.57805 .04586 L
.57863 .03198 L
.57895 .02445 L
.5791 .0208 L
.57925 .01748 L
.57937 .01481 L
.5795 .0178 L
Mistroke
.57977 .024 L
.58035 .03679 L
.58156 .06118 L
.58286 .08279 L
.5835 .09151 L
.58411 .09839 L
.5847 .10376 L
.58496 .1057 L
.58524 .10753 L
.58549 .10887 L
.58576 .11005 L
.58591 .11058 L
.58604 .11098 L
.58617 .11131 L
.58631 .11158 L
.58645 .11179 L
.58659 .11192 L
.58674 .11197 L
.58682 .11197 L
.5869 .11194 L
.58704 .11183 L
.58717 .11166 L
.58731 .11141 L
.58746 .11106 L
.58777 .11009 L
.58806 .10885 L
.58861 .10574 L
.5892 .1013 L
.58984 .09528 L
.59205 .06669 L
.59328 .04719 L
.59444 .02795 L
.59474 .02297 L
.59502 .01826 L
.59518 .01568 L
.59527 .01521 L
.59535 .01656 L
.59565 .02143 L
.59698 .042 L
.59825 .05918 L
.59945 .07223 L
.60053 .08085 L
.60114 .0843 L
.60143 .08556 L
.6017 .08653 L
.60184 .08696 L
.60199 .08735 L
.60212 .08763 L
.60227 .08788 L
.60242 .08808 L
Mistroke
.6025 .08816 L
.60258 .08822 L
.60272 .08828 L
.60287 .08828 L
.60301 .08823 L
.60315 .08812 L
.6033 .08793 L
.60344 .0877 L
.6037 .08714 L
.60397 .08636 L
.60429 .08516 L
.60464 .08355 L
.60527 .07985 L
.60646 .07045 L
.60881 .04454 L
.61006 .02853 L
.61042 .02382 L
.61076 .01934 L
.61091 .0174 L
.61106 .01534 L
.61115 .01528 L
.61124 .01635 L
.6114 .01842 L
.61266 .03424 L
.61385 .04759 L
.61495 .05798 L
.61557 .06289 L
.61615 .06675 L
.61677 .07006 L
.61733 .07233 L
.61764 .07326 L
.61793 .07393 L
.61809 .07421 L
.61824 .07442 L
.6184 .07459 L
.61849 .07465 L
.61858 .0747 L
.61872 .07474 L
.61887 .07473 L
.61899 .07468 L
.61913 .07458 L
.61928 .07442 L
.61944 .0742 L
.61973 .07365 L
.62002 .07291 L
.62029 .07204 L
.62081 .06997 L
.62198 .06323 L
.62322 .0535 L
.62545 .03143 L
Mistroke
.62604 .02507 L
.62659 .01899 L
.62674 .01736 L
.6269 .01563 L
.62698 .01473 L
.62707 .01569 L
.62723 .01743 L
.62782 .02369 L
.63003 .04502 L
.63124 .05419 L
.63236 .06045 L
.63294 .06281 L
.63328 .06387 L
.63358 .06464 L
.63391 .06525 L
.63408 .0655 L
.63417 .06559 L
.63425 .06567 L
.63441 .06578 L
.63455 .06584 L
.6347 .06586 L
.63479 .06585 L
.63487 .06583 L
.63502 .06575 L
.63511 .06569 L
.63518 .06562 L
.63547 .06525 L
.63564 .06498 L
.63581 .06462 L
.63613 .06383 L
.63675 .06173 L
.63732 .0592 L
.63841 .05294 L
.63955 .04456 L
.6407 .03485 L
.64133 .02912 L
.64192 .02355 L
.64248 .0183 L
.64263 .01686 L
.64271 .01607 L
.64279 .01534 L
.64293 .01539 L
.64308 .01682 L
.64414 .02654 L
.64532 .03664 L
.64657 .04577 L
.64764 .05197 L
.6482 .05453 L
.6488 .05674 L
.64914 .05768 L
Mistroke
.64944 .05839 L
.64974 .05891 L
.64988 .05911 L
.65005 .05929 L
.65019 .05942 L
.65033 .0595 L
.65048 .05955 L
.65063 .05956 L
.65076 .05954 L
.65089 .05949 L
.65103 .05941 L
.65117 .05928 L
.65134 .05908 L
.6515 .05886 L
.65186 .0582 L
.65217 .05744 L
.6525 .05647 L
.6537 .05152 L
.65485 .04495 L
.65607 .03634 L
.65723 .02726 L
.65773 .02308 L
.65829 .01842 L
.65844 .01717 L
.6586 .01583 L
.65875 .01486 L
.65889 .01602 L
.65952 .02127 L
.66086 .03175 L
.66212 .04039 L
.66329 .04689 L
.66386 .04942 L
.66439 .05138 L
.66469 .05229 L
.66501 .05311 L
.6653 .05373 L
.66558 .05418 L
.66573 .05439 L
.66588 .05455 L
.66604 .05468 L
.66612 .05474 L
.66621 .05479 L
.66629 .05482 L
.66637 .05484 L
.66653 .05485 L
.66661 .05484 L
.66669 .05482 L
.66678 .05479 L
.66688 .05474 L
.66702 .05464 L
Mistroke
.66718 .05449 L
.6675 .05407 L
.6678 .05355 L
.66807 .05294 L
.66868 .05121 L
.66934 .04875 L
.67054 .04291 L
.67278 .02833 L
.67392 .01986 L
.67424 .01749 L
.67441 .01619 L
.67449 .01555 L
.67457 .01495 L
.67472 .01562 L
.6748 .01623 L
.67489 .01687 L
.67518 .01904 L
.67772 .03638 L
.67896 .04297 L
.67961 .04574 L
.6803 .04809 L
.68091 .04962 L
.68125 .05026 L
.68142 .05051 L
.68157 .05071 L
.68171 .05086 L
.68187 .05099 L
.68201 .05109 L
.68213 .05115 L
.68227 .05118 L
.68243 .0512 L
.6825 .05119 L
.68259 .05117 L
.68274 .05111 L
.68289 .05102 L
.68303 .05091 L
.68334 .05057 L
.68362 .05013 L
.68389 .04961 L
.6845 .0481 L
.68516 .04594 L
.68648 .04007 L
.6877 .0332 L
.6888 .02621 L
.6894 .02214 L
.68997 .01821 L
.69029 .01598 L
.69038 .01537 L
.69048 .01472 L
.69056 .01526 L
Mistroke
.69064 .01587 L
.69126 .02008 L
.69246 .02795 L
.6936 .03462 L
.69479 .04047 L
.69542 .04296 L
.6961 .04517 L
.6964 .04596 L
.69673 .04668 L
.697 .04719 L
.69731 .04764 L
.69762 .04798 L
.69779 .04811 L
.69787 .04816 L
.69795 .0482 L
.6981 .04825 L
.69823 .04828 L
.69838 .04827 L
.69846 .04826 L
.69854 .04824 L
.69862 .0482 L
.69871 .04816 L
.69888 .04805 L
.69904 .04791 L
.69919 .04775 L
.69952 .04728 L
.69988 .04664 L
.70048 .0452 L
.70103 .04348 L
.70231 .03834 L
.70455 .02605 L
.70517 .02222 L
.70582 .01807 L
.70609 .01635 L
.70623 .01545 L
.70638 .01493 L
.70646 .01544 L
.70655 .01599 L
.7067 .01696 L
.707 .01885 L
.70833 .02693 L
.70956 .03363 L
.71073 .03885 L
.71134 .04109 L
.71199 .04301 L
.7123 .04378 L
.71265 .04449 L
.71297 .04502 L
.71326 .04539 L
.7134 .04554 L
Mistroke
.71356 .04567 L
.71364 .04573 L
.71372 .04578 L
.71388 .04585 L
.71403 .04589 L
.71416 .0459 L
.71431 .04589 L
.71446 .04585 L
.71459 .0458 L
.71473 .04571 L
.71488 .0456 L
.71502 .04547 L
.71554 .04478 L
.71583 .04425 L
.7161 .04368 L
.7167 .04212 L
.7179 .03789 L
.71901 .03287 L
.7203 .02599 L
.72093 .02236 L
.72151 .01894 L
.72178 .01736 L
.72192 .01652 L
.72207 .01562 L
.72221 .01476 L
.72235 .01545 L
.7226 .01697 L
.72377 .02375 L
.72507 .03062 L
.72626 .03597 L
.72738 .03991 L
.72795 .04142 L
.72858 .04268 L
.7289 .04317 L
.7292 .04352 L
.72937 .04366 L
.72955 .04379 L
.72963 .04383 L
.72972 .04387 L
.72987 .04392 L
.73002 .04394 L
.73017 .04393 L
.73032 .0439 L
.73045 .04385 L
.7306 .04377 L
.73076 .04366 L
.73109 .04334 L
.73139 .04293 L
.73172 .04238 L
.73233 .04107 L
Mistroke
.73345 .03766 L
.73476 .0323 L
.73598 .02635 L
.73707 .02047 L
.73735 .01887 L
.73767 .01712 L
.73781 .01631 L
.73796 .01546 L
.73811 .01478 L
.73824 .01552 L
.73891 .01925 L
.73952 .02258 L
.74073 .02869 L
.74186 .03368 L
.74305 .03787 L
.74367 .03955 L
.74401 .04028 L
.74436 .04094 L
.74469 .04144 L
.74498 .04179 L
.74512 .04193 L
.74528 .04206 L
.74543 .04215 L
.74556 .04222 L
.7457 .04226 L
.74584 .04229 L
.74599 .04229 L
.74615 .04227 L
.74629 .04223 L
.74643 .04216 L
.74657 .04208 L
.7467 .04199 L
.74701 .04169 L
.74734 .04125 L
.74795 .04016 L
.74859 .03862 L
.74927 .03658 L
.75049 .03199 L
.75163 .02682 L
.75285 .02064 L
.75344 .01751 L
.75373 .01596 L
.75386 .01528 L
.754 .0149 L
.75413 .01557 L
.75425 .0162 L
.75451 .01758 L
.75506 .02044 L
.75728 .03092 L
.75854 .03553 L
Mistroke
.75916 .03732 L
.75972 .03865 L
.76001 .03922 L
.76032 .03974 L
.76059 .04012 L
.76088 .04045 L
.76104 .04059 L
.7612 .0407 L
.76129 .04076 L
.76137 .0408 L
.76145 .04084 L
.76153 .04086 L
.76168 .0409 L
.76176 .0409 L
.76184 .04091 L
.76199 .04089 L
.76213 .04086 L
.76229 .0408 L
.76237 .04075 L
.76246 .0407 L
.76276 .04046 L
.76311 .04007 L
.76344 .03959 L
.76404 .03845 L
.76467 .03688 L
.7659 .03291 L
.76724 .02743 L
.76839 .022 L
.769 .01896 L
.76932 .01734 L
.7695 .01645 L
.76966 .01562 L
.76981 .01487 L
.76997 .01536 L
.77006 .01581 L
.77014 .01625 L
.7703 .01705 L
.77089 .01998 L
.77205 .02546 L
.77328 .03064 L
.77458 .03506 L
.77513 .03654 L
.77573 .03783 L
.77607 .03842 L
.77638 .03887 L
.7767 .03923 L
.77685 .03937 L
.77699 .03948 L
.77712 .03956 L
.77726 .03963 L
Mistroke
.77741 .03968 L
.77755 .03971 L
.77768 .03973 L
.77781 .03972 L
.77793 .0397 L
.77806 .03967 L
.77821 .0396 L
.77835 .03953 L
.77866 .03929 L
.77895 .03898 L
.77922 .03862 L
.77978 .03767 L
.78039 .03631 L
.78163 .03263 L
.78385 .02359 L
.78444 .02083 L
.78507 .01784 L
.78533 .01659 L
.78547 .0159 L
.7856 .01525 L
.78576 .01495 L
.78591 .01564 L
.78619 .017 L
.7887 .02827 L
.78988 .0325 L
.79052 .03441 L
.79112 .03591 L
.79168 .03702 L
.79218 .0378 L
.79247 .03814 L
.79275 .03839 L
.79289 .03849 L
.79303 .03858 L
.79311 .03861 L
.7932 .03865 L
.79335 .03869 L
.7935 .03872 L
.79363 .03872 L
.79378 .0387 L
.79387 .03868 L
.79394 .03866 L
.7941 .0386 L
.79426 .03851 L
.79456 .03827 L
.79485 .03798 L
.79514 .03759 L
.79568 .0367 L
.7963 .03537 L
.79688 .03384 L
.79819 .02949 L
Mistroke
.79945 .02444 L
.80064 .01912 L
.80116 .01673 L
.8013 .01603 L
.80144 .01538 L
.80157 .01479 L
.80171 .01527 L
.80231 .01808 L
.80287 .02063 L
.80523 .03014 L
.80588 .03223 L
.80657 .03414 L
.80722 .0356 L
.80782 .03664 L
.80812 .03704 L
.80843 .03738 L
.80875 .03763 L
.80893 .03773 L
.80901 .03777 L
.8091 .0378 L
.80925 .03784 L
.80941 .03786 L
.80955 .03786 L
.80968 .03784 L
.80984 .0378 L
.80999 .03774 L
.81016 .03765 L
.81031 .03754 L
.81059 .03729 L
.81088 .03696 L
.8114 .03619 L
.81197 .0351 L
.81259 .03361 L
.81493 .02569 L
.81624 .02017 L
.81688 .01734 L
.81715 .01609 L
.8173 .01544 L
.81745 .01475 L
.81761 .0154 L
.81776 .01606 L
.81805 .01734 L
.81868 .02013 L
.82001 .02566 L
.82118 .02989 L
.82182 .03187 L
.82243 .03349 L
.82303 .0348 L
.82334 .03538 L
.82368 .03591 L
Mistroke
.82396 .03628 L
.82427 .03661 L
.82455 .03684 L
.82468 .03693 L
.82481 .037 L
.82495 .03705 L
.82509 .0371 L
.82523 .03712 L
.82537 .03712 L
.8255 .03711 L
.82563 .03709 L
.82575 .03705 L
.82587 .037 L
.82601 .03693 L
.82617 .03683 L
.82647 .03657 L
.82676 .03626 L
.82702 .03591 L
.82763 .03489 L
.82828 .03347 L
.82948 .03009 L
.83171 .0217 L
.83226 .01939 L
.83285 .01684 L
.83301 .01613 L
.83318 .01537 L
.83333 .01473 L
.83341 .01507 L
.83349 .0154 L
.8341 .01804 L
.8354 .02346 L
.83663 .02804 L
.83781 .03169 L
.83844 .03325 L
.8391 .03458 L
.83965 .03544 L
.83997 .03582 L
.84026 .0361 L
.8404 .03621 L
.84053 .03629 L
.84065 .03636 L
.84078 .03641 L
.84092 .03646 L
.84105 .03648 L
.8412 .0365 L
.84134 .03649 L
.84148 .03647 L
.84162 .03643 L
.84177 .03637 L
.84193 .03629 L
Mistroke
.84225 .03605 L
.84255 .03576 L
.84312 .03499 L
.84366 .03402 L
.84487 .03111 L
.84617 .02691 L
.84741 .02223 L
.84856 .01745 L
.84885 .01625 L
.849 .01559 L
.84914 .01498 L
.8493 .01511 L
.84938 .01546 L
.84947 .01584 L
.84977 .0171 L
.8511 .02256 L
.85234 .02714 L
.85368 .03124 L
.85429 .03274 L
.85494 .03404 L
.8555 .03489 L
.85581 .03527 L
.85611 .03555 L
.85626 .03567 L
.85642 .03577 L
.85656 .03584 L
.85671 .0359 L
.85679 .03592 L
.85687 .03594 L
.85702 .03596 L
.8571 .03596 L
.85719 .03596 L
.85728 .03595 L
.85737 .03594 L
.85752 .03589 L
.85767 .03583 L
.8578 .03576 L
.85794 .03567 L
.85826 .03541 L
.85856 .03509 L
.85908 .03437 L
.85964 .03334 L
.8608 .03057 L
.8621 .02646 L
.86333 .02185 L
.86444 .01735 L
.86475 .01609 L
.86491 .0154 L
.86507 .01475 L
.86522 .0153 L
Mistroke
.86538 .01596 L
.86566 .0171 L
.86789 .02575 L
.86915 .02979 L
.86977 .03143 L
.87033 .03271 L
.87089 .03375 L
.87149 .03462 L
.87183 .03497 L
.87197 .0351 L
.87213 .03522 L
.87227 .03531 L
.87243 .03539 L
.87251 .03542 L
.87259 .03545 L
.87274 .03549 L
.87289 .03551 L
.87304 .03551 L
.87319 .0355 L
.87333 .03547 L
.87341 .03544 L
.87349 .03541 L
.87366 .03533 L
.87398 .03512 L
.87428 .03484 L
.87461 .03445 L
.87528 .03341 L
.87591 .03214 L
.8765 .03068 L
.87762 .02738 L
.87885 .02308 L
.87951 .02051 L
.88014 .018 L
.88044 .01681 L
.88075 .01555 L
.88083 .01523 L
.88091 .01488 L
.881 .01492 L
.88109 .01527 L
.8814 .01654 L
.88254 .02107 L
.88476 .02875 L
.88599 .03192 L
.88668 .03327 L
.88701 .03379 L
.88733 .03421 L
.88762 .03453 L
.88789 .03476 L
.88818 .03496 L
.88835 .03504 L
Mistroke
.8885 .03509 L
.88865 .03513 L
.88874 .03514 L
.88881 .03514 L
.88896 .03514 L
.8891 .03512 L
.88918 .0351 L
.88926 .03508 L
.88941 .03502 L
.88958 .03494 L
.88975 .03483 L
.89006 .03458 L
.89038 .03423 L
.89098 .03338 L
.89157 .0323 L
.8921 .03109 L
.89463 .02328 L
.89571 .01917 L
.89628 .01691 L
.89643 .01632 L
.89659 .01567 L
.89674 .01507 L
.89688 .01491 L
.89695 .01523 L
.89704 .01557 L
.89719 .01619 L
.89754 .01758 L
.89816 .01998 L
.89936 .02444 L
.9006 .02843 L
.90175 .03142 L
.90234 .03261 L
.90296 .03361 L
.90332 .03405 L
.90366 .03438 L
.90396 .0346 L
.90413 .0347 L
.90429 .03477 L
.90445 .03481 L
.90452 .03483 L
.90461 .03484 L
.90476 .03484 L
.9049 .03483 L
.90499 .03482 L
.90507 .0348 L
.90522 .03475 L
.90539 .03468 L
.90557 .03458 L
.90587 .03434 L
.90619 .03402 L
Mistroke
.90677 .03325 L
.90732 .03228 L
.90784 .03119 L
.90901 .02808 L
.91124 .0204 L
.91186 .01804 L
.91219 .01672 L
.91236 .01607 L
.91251 .01547 L
.91265 .0149 L
.9128 .01513 L
.91296 .01573 L
.91312 .0164 L
.91368 .01859 L
.9161 .02717 L
.91742 .03075 L
.91806 .0321 L
.91865 .03312 L
.91925 .03388 L
.91957 .03418 L
.91973 .0343 L
.9199 .03441 L
.92007 .03449 L
.92023 .03455 L
.92038 .03459 L
.92053 .03461 L
.92067 .03461 L
.9208 .0346 L
.92094 .03457 L
.9211 .03452 L
.92125 .03446 L
.92139 .03438 L
.9217 .03416 L
.92198 .0339 L
.92227 .03356 L
.92278 .03283 L
.92333 .03181 L
.92456 .02888 L
.92567 .02548 L
.92698 .02086 L
.92762 .01844 L
.92789 .01737 L
.92819 .0162 L
.92834 .01564 L
.92849 .01504 L
.92862 .0149 L
.92876 .01546 L
.9293 .01756 L
.93048 .02202 L
.93179 .02647 L
Mistroke
.93298 .02985 L
.93356 .0312 L
.93419 .03241 L
.93478 .03331 L
.93533 .03392 L
.93563 .03415 L
.93577 .03423 L
.93591 .03431 L
.93599 .03434 L
.93608 .03437 L
.93622 .03441 L
.93631 .03442 L
.9364 .03443 L
.93648 .03444 L
.93656 .03444 L
.93664 .03443 L
.93672 .03442 L
.93688 .03438 L
.93696 .03435 L
.93704 .03432 L
.93722 .03423 L
.93753 .03403 L
.93786 .03373 L
.93849 .03292 L
.93908 .03192 L
.94041 .02882 L
.94283 .02088 L
.94345 .01857 L
.94377 .01733 L
.94411 .01601 L
.94425 .01545 L
.94441 .01485 L
.9445 .01492 L
.94458 .01524 L
.94474 .01585 L
.94531 .01808 L
.94756 .02606 L
.94868 .0293 L
.94986 .03195 L
.95048 .03297 L
.95081 .03339 L
.95117 .03377 L
.95149 .03402 L
.95163 .03411 L
.95179 .03419 L
.95193 .03425 L
.95207 .03429 L
.95222 .03431 L
.95237 .03432 L
.95252 .03432 L
Mistroke
.9526 .0343 L
.95268 .03429 L
.95277 .03426 L
.95284 .03424 L
.95301 .03417 L
.95316 .03409 L
.95332 .03398 L
.95361 .03374 L
.95395 .03338 L
.9543 .03291 L
.95495 .03183 L
.9561 .02922 L
.95738 .02547 L
.95851 .02155 L
.95971 .01706 L
.96001 .0159 L
.96018 .01525 L
.96034 .01479 L
.96043 .01513 L
.96052 .01551 L
.96069 .01616 L
.96102 .01743 L
.96222 .02193 L
.96346 .02611 L
.96462 .02943 L
.96583 .03206 L
.96647 .03306 L
.96683 .03349 L
.96715 .03381 L
.96731 .03393 L
.96746 .03403 L
.96759 .0341 L
.96773 .03416 L
.96788 .03421 L
.96802 .03425 L
.96818 .03426 L
.96826 .03427 L
.96834 .03426 L
.96849 .03425 L
.96862 .03421 L
.96874 .03417 L
.96888 .03412 L
.96917 .03394 L
.96945 .03372 L
.97002 .03308 L
.97066 .03209 L
.97195 .02927 L
.97399 .02296 L
.97619 .01472 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.03968 .01472 m
.03968 .01472 L
s
.05556 .01472 m
.05556 .01472 L
s
.07143 .01472 m
.07143 .01472 L
s
.0873 .01472 m
.0873 .01472 L
s
.10317 .01472 m
.10317 .01472 L
s
.11905 .01472 m
.11905 .01472 L
s
.13492 .01472 m
.13492 .01472 L
s
.15079 .01472 m
.15079 .01472 L
s
.16667 .01472 m
.16667 .01472 L
s
.18254 .01472 m
.18254 .01472 L
s
.19841 .01472 m
.19841 .01472 L
s
.21429 .01472 m
.21429 .01472 L
s
.23016 .01472 m
.23016 .01472 L
s
.24603 .01472 m
.24603 .01472 L
s
.2619 .01472 m
.2619 .01472 L
s
.27778 .01472 m
.27778 .01472 L
s
.29365 .01472 m
.29365 .01472 L
s
.30952 .01472 m
.30952 .01472 L
s
.3254 .01472 m
.3254 .01472 L
s
.34127 .01472 m
.34127 .01472 L
s
.35714 .01472 m
.35714 .01472 L
s
.37302 .01472 m
.37302 .01472 L
s
.38889 .01472 m
.38889 .01472 L
s
.40476 .01472 m
.40476 .01472 L
s
.42063 .01472 m
.42063 .01472 L
s
.43651 .01472 m
.43651 .01472 L
s
.45238 .01472 m
.45238 .60105 L
s
.46825 .01472 m
.46825 .01472 L
s
.48413 .01472 m
.48413 .01472 L
s
.5 .01472 m
.5 .01472 L
s
.51587 .01472 m
.51587 .01472 L
s
.53175 .01472 m
.53175 .01472 L
s
.54762 .01472 m
.54762 .60105 L
s
.56349 .01472 m
.56349 .01472 L
s
.57937 .01472 m
.57937 .01472 L
s
.59524 .01472 m
.59524 .01472 L
s
.61111 .01472 m
.61111 .01472 L
s
.62698 .01472 m
.62698 .01472 L
s
.64286 .01472 m
.64286 .01472 L
s
.65873 .01472 m
.65873 .01472 L
s
.6746 .01472 m
.6746 .01472 L
s
.69048 .01472 m
.69048 .01472 L
s
.70635 .01472 m
.70635 .01472 L
s
.72222 .01472 m
.72222 .01472 L
s
.7381 .01472 m
.7381 .01472 L
s
.75397 .01472 m
.75397 .01472 L
s
.76984 .01472 m
.76984 .01472 L
s
.78571 .01472 m
.78571 .01472 L
s
.80159 .01472 m
.80159 .01472 L
s
.81746 .01472 m
.81746 .01472 L
s
.83333 .01472 m
.83333 .01472 L
s
.84921 .01472 m
.84921 .01472 L
s
.86508 .01472 m
.86508 .01472 L
s
.88095 .01472 m
.88095 .01472 L
s
.89683 .01472 m
.89683 .01472 L
s
.9127 .01472 m
.9127 .01472 L
s
.92857 .01472 m
.92857 .01472 L
s
.94444 .01472 m
.94444 .01472 L
s
.96032 .01472 m
.96032 .01472 L
s
.97619 .01472 m
.97619 .01472 L
s
.015 w
.03968 .01472 Mdot
.05556 .01472 Mdot
.07143 .01472 Mdot
.0873 .01472 Mdot
.10317 .01472 Mdot
.11905 .01472 Mdot
.13492 .01472 Mdot
.15079 .01472 Mdot
.16667 .01472 Mdot
.18254 .01472 Mdot
.19841 .01472 Mdot
.21429 .01472 Mdot
.23016 .01472 Mdot
.24603 .01472 Mdot
.2619 .01472 Mdot
.27778 .01472 Mdot
.29365 .01472 Mdot
.30952 .01472 Mdot
.3254 .01472 Mdot
.34127 .01472 Mdot
.35714 .01472 Mdot
.37302 .01472 Mdot
.38889 .01472 Mdot
.40476 .01472 Mdot
.42063 .01472 Mdot
.43651 .01472 Mdot
.45238 .60105 Mdot
.46825 .01472 Mdot
.48413 .01472 Mdot
.5 .01472 Mdot
.51587 .01472 Mdot
.53175 .01472 Mdot
.54762 .60105 Mdot
.56349 .01472 Mdot
.57937 .01472 Mdot
.59524 .01472 Mdot
.61111 .01472 Mdot
.62698 .01472 Mdot
.64286 .01472 Mdot
.65873 .01472 Mdot
.6746 .01472 Mdot
.69048 .01472 Mdot
.70635 .01472 Mdot
.72222 .01472 Mdot
.7381 .01472 Mdot
.75397 .01472 Mdot
.76984 .01472 Mdot
.78571 .01472 Mdot
.80159 .01472 Mdot
.81746 .01472 Mdot
.83333 .01472 Mdot
.84921 .01472 Mdot
.86508 .01472 Mdot
.88095 .01472 Mdot
.89683 .01472 Mdot
.9127 .01472 Mdot
.92857 .01472 Mdot
.94444 .01472 Mdot
.96032 .01472 Mdot
.97619 .01472 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.309471 0.0971556 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .018 -12 -4.5 ]
[-0.0125 .018 0 4.5 ]
[-0.0125 .11516 -12 -4.5 ]
[-0.0125 .11516 0 4.5 ]
[-0.0125 .21232 -12 -4.5 ]
[-0.0125 .21232 0 4.5 ]
[-0.0125 .30947 -6 -4.5 ]
[-0.0125 .30947 0 4.5 ]
[-0.0125 .40663 -6 -4.5 ]
[-0.0125 .40663 0 4.5 ]
[-0.0125 .50378 -6 -4.5 ]
[-0.0125 .50378 0 4.5 ]
[-0.0125 .60094 -6 -4.5 ]
[-0.0125 .60094 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .018 m
.00625 .018 L
s
[(-3)] -0.0125 .018 1 0 Mshowa
0 .11516 m
.00625 .11516 L
s
[(-2)] -0.0125 .11516 1 0 Mshowa
0 .21232 m
.00625 .21232 L
s
[(-1)] -0.0125 .21232 1 0 Mshowa
0 .30947 m
.00625 .30947 L
s
[(0)] -0.0125 .30947 1 0 Mshowa
0 .40663 m
.00625 .40663 L
s
[(1)] -0.0125 .40663 1 0 Mshowa
0 .50378 m
.00625 .50378 L
s
[(2)] -0.0125 .50378 1 0 Mshowa
0 .60094 m
.00625 .60094 L
s
[(3)] -0.0125 .60094 1 0 Mshowa
.125 Mabswid
0 .03744 m
.00375 .03744 L
s
0 .05687 m
.00375 .05687 L
s
0 .0763 m
.00375 .0763 L
s
0 .09573 m
.00375 .09573 L
s
0 .13459 m
.00375 .13459 L
s
0 .15402 m
.00375 .15402 L
s
0 .17345 m
.00375 .17345 L
s
0 .19288 m
.00375 .19288 L
s
0 .23175 m
.00375 .23175 L
s
0 .25118 m
.00375 .25118 L
s
0 .27061 m
.00375 .27061 L
s
0 .29004 m
.00375 .29004 L
s
0 .3289 m
.00375 .3289 L
s
0 .34833 m
.00375 .34833 L
s
0 .36776 m
.00375 .36776 L
s
0 .3872 m
.00375 .3872 L
s
0 .42606 m
.00375 .42606 L
s
0 .44549 m
.00375 .44549 L
s
0 .46492 m
.00375 .46492 L
s
0 .48435 m
.00375 .48435 L
s
0 .52321 m
.00375 .52321 L
s
0 .54264 m
.00375 .54264 L
s
0 .56208 m
.00375 .56208 L
s
0 .58151 m
.00375 .58151 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .018 m
1 .018 L
s
.99375 .11516 m
1 .11516 L
s
.99375 .21232 m
1 .21232 L
s
.99375 .30947 m
1 .30947 L
s
.99375 .40663 m
1 .40663 L
s
.99375 .50378 m
1 .50378 L
s
.99375 .60094 m
1 .60094 L
s
.125 Mabswid
.99625 .03744 m
1 .03744 L
s
.99625 .05687 m
1 .05687 L
s
.99625 .0763 m
1 .0763 L
s
.99625 .09573 m
1 .09573 L
s
.99625 .13459 m
1 .13459 L
s
.99625 .15402 m
1 .15402 L
s
.99625 .17345 m
1 .17345 L
s
.99625 .19288 m
1 .19288 L
s
.99625 .23175 m
1 .23175 L
s
.99625 .25118 m
1 .25118 L
s
.99625 .27061 m
1 .27061 L
s
.99625 .29004 m
1 .29004 L
s
.99625 .3289 m
1 .3289 L
s
.99625 .34833 m
1 .34833 L
s
.99625 .36776 m
1 .36776 L
s
.99625 .3872 m
1 .3872 L
s
.99625 .42606 m
1 .42606 L
s
.99625 .44549 m
1 .44549 L
s
.99625 .46492 m
1 .46492 L
s
.99625 .48435 m
1 .48435 L
s
.99625 .52321 m
1 .52321 L
s
.99625 .54264 m
1 .54264 L
s
.99625 .56208 m
1 .56208 L
s
.99625 .58151 m
1 .58151 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30947 m
1 .30947 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .46208 m
.02847 .37402 L
.03355 .27797 L
.03602 .23127 L
.03723 .20849 L
.03832 .18777 L
.03887 .17744 L
.03916 .17199 L
.03932 .16901 L
.03946 .16622 L
.03959 .16379 L
.03973 .46641 L
.03988 .46351 L
.04002 .46086 L
.04054 .45108 L
.04291 .40624 L
.0477 .31573 L
.05231 .22867 L
.05353 .20558 L
.05468 .18383 L
.05499 .17797 L
.05532 .17178 L
.0554 .17022 L
.05549 .16855 L
.05559 .47193 L
.05568 .47022 L
.05601 .46398 L
.05721 .44124 L
.0622 .34696 L
.06469 .29979 L
.067 .25614 L
.06925 .21377 L
.07038 .19238 L
.07069 .18652 L
.07102 .1802 L
.07118 .1773 L
.07126 .17571 L
.07134 .17424 L
.07148 .47685 L
.07163 .47399 L
.07634 .38499 L
.08134 .2904 L
.08385 .24298 L
.08495 .22216 L
.08553 .21112 L
.08616 .19926 L
.08647 .19337 L
.08677 .18777 L
.08704 .18274 L
.08719 .1799 L
Mistroke
.08733 .48248 L
.08747 .47979 L
.0876 .47725 L
.08785 .47251 L
.08842 .4619 L
.0908 .41681 L
.09546 .32881 L
.09782 .28417 L
.10041 .23523 L
.1016 .21271 L
.10226 .20032 L
.10258 .19422 L
.10288 .18859 L
.10302 .18586 L
.10316 .1833 L
.1033 .48585 L
.10345 .48291 L
.10408 .47105 L
.10518 .45033 L
.10985 .36203 L
.11222 .31715 L
.11482 .26813 L
.11602 .24545 L
.1173 .22126 L
.11792 .2095 L
.11851 .19842 L
.11876 .19358 L
.1189 .19094 L
.11903 .18847 L
.11917 .49102 L
.11933 .48808 L
.1196 .48292 L
.12429 .39431 L
.12927 .30011 L
.13177 .25299 L
.13286 .23226 L
.13345 .22124 L
.13408 .20936 L
.13437 .20382 L
.13453 .2008 L
.13468 .19798 L
.13481 .19558 L
.13494 .49822 L
.13509 .49537 L
.13523 .49277 L
.13632 .47227 L
.1387 .42729 L
.14351 .33623 L
.14815 .24863 L
.14939 .22526 L
Mistroke
.14999 .21383 L
.15025 .20884 L
.15054 .20338 L
.1507 .20046 L
.15084 .50297 L
.15098 .50037 L
.15112 .49761 L
.15175 .48579 L
.15308 .46066 L
.1581 .36584 L
.16062 .31824 L
.16293 .27447 L
.16519 .23171 L
.16574 .22132 L
.16605 .2156 L
.16633 .21018 L
.1665 .20712 L
.16659 .20539 L
.16667 .50901 L
.16682 .50619 L
.16698 .50319 L
.16758 .49179 L
.17214 .4057 L
.17699 .31402 L
.17922 .27188 L
.18048 .24801 L
.1811 .23637 L
.18166 .2258 L
.18195 .22035 L
.1821 .21747 L
.18226 .21443 L
.1824 .21177 L
.18256 .51407 L
.1827 .51141 L
.18283 .50892 L
.18408 .48532 L
.18662 .43722 L
.19131 .34869 L
.19369 .30365 L
.19495 .27987 L
.19629 .25457 L
.19696 .24184 L
.19759 .22987 L
.19787 .22464 L
.19816 .21912 L
.19832 .21623 L
.1984 .2146 L
.19848 .5183 L
.19863 .51561 L
.19878 .51274 L
Mistroke
.20108 .46913 L
.20608 .37471 L
.20858 .32741 L
.2109 .28373 L
.21314 .24126 L
.21369 .23094 L
.21399 .22524 L
.21414 .22244 L
.21428 .21983 L
.21436 .52358 L
.21444 .52201 L
.21461 .51869 L
.21492 .51286 L
.21553 .50144 L
.22054 .40671 L
.22537 .31543 L
.22759 .27357 L
.22884 .2498 L
.22946 .23819 L
.22975 .23269 L
.23002 .2276 L
.23016 .22499 L
.2303 .52744 L
.23045 .52465 L
.23061 .52158 L
.23118 .51091 L
.23242 .48741 L
.23496 .43942 L
.23981 .34783 L
.24204 .30575 L
.2433 .2819 L
.24447 .2597 L
.24507 .24835 L
.24564 .23764 L
.24579 .23476 L
.24588 .23318 L
.24596 .23171 L
.24604 .53534 L
.24613 .53359 L
.2463 .53051 L
.24689 .51928 L
.24943 .47121 L
.25412 .38277 L
.2565 .33779 L
.25909 .28875 L
.2603 .26599 L
.26096 .25351 L
.26128 .24739 L
.26158 .24176 L
.26173 .23899 L
Mistroke
.26186 .23641 L
.262 .53895 L
.26216 .53599 L
.26279 .52412 L
.26389 .50341 L
.26858 .41466 L
.27098 .36946 L
.27358 .32034 L
.27479 .29743 L
.27608 .27311 L
.2766 .26312 L
.27717 .25236 L
.27733 .24935 L
.2775 .24619 L
.27764 .24349 L
.2778 .54577 L
.27795 .54299 L
.2781 .54003 L
.27839 .53469 L
.2834 .44006 L
.28822 .34888 L
.29043 .30709 L
.29169 .28335 L
.29231 .27175 L
.29287 .26117 L
.29315 .25579 L
.2933 .25296 L
.29346 .24994 L
.2936 .24731 L
.29375 .54964 L
.29389 .547 L
.29402 .54452 L
.29527 .52104 L
.29781 .47309 L
.30247 .38506 L
.30483 .34039 L
.30608 .31674 L
.30742 .29146 L
.30809 .27889 L
.30872 .26702 L
.30899 .26184 L
.30928 .25636 L
.30943 .25349 L
.30952 .25186 L
.3096 .55556 L
.30974 .55289 L
.30989 .55001 L
.3122 .50654 L
.31717 .41263 L
.31965 .36572 L
Mistroke
.32196 .32218 L
.32311 .3005 L
.32419 .28007 L
.32479 .26876 L
.32495 .26566 L
.32513 .26239 L
.32527 .2596 L
.32536 .25801 L
.32544 .56175 L
.32558 .55899 L
.32572 .55637 L
.32598 .55145 L
.32657 .54041 L
.33119 .45312 L
.33611 .36025 L
.33855 .31412 L
.33975 .29154 L
.34027 .28165 L
.34055 .27642 L
.34085 .27083 L
.34099 .26802 L
.34114 .26536 L
.34126 .26298 L
.3414 .56561 L
.34153 .56316 L
.34167 .56056 L
.34191 .5559 L
.34304 .53469 L
.3454 .4901 L
.34997 .40384 L
.35251 .35585 L
.35484 .31201 L
.35599 .29031 L
.3563 .28437 L
.35664 .27804 L
.3568 .27497 L
.35695 .27207 L
.35709 .26948 L
.35724 .57189 L
.35738 .5692 L
.35751 .56669 L
.35782 .56098 L
.35843 .54947 L
.35952 .52886 L
.36422 .44019 L
.36661 .39502 L
.36921 .34596 L
.37043 .32306 L
.37172 .29877 L
.37224 .28878 L
Mistroke
.37254 .28327 L
.37281 .27804 L
.37297 .27509 L
.37306 .57865 L
.37314 .5771 L
.37344 .57146 L
.37403 .56041 L
.37874 .47147 L
.38375 .37698 L
.38627 .32958 L
.38737 .30879 L
.38796 .29777 L
.38828 .2917 L
.38858 .28595 L
.38873 .28328 L
.38888 .28044 L
.38895 .58418 L
.38904 .58255 L
.38919 .57967 L
.38975 .56917 L
.39084 .54861 L
.39323 .50362 L
.39808 .41234 L
.4003 .37041 L
.40156 .34665 L
.40274 .32453 L
.40391 .30255 L
.40424 .29623 L
.40441 .29312 L
.40456 .29025 L
.4047 .28765 L
.40484 .59011 L
.40499 .58734 L
.40515 .58429 L
.4077 .53641 L
.41256 .44493 L
.41724 .35693 L
.41846 .334 L
.4191 .32188 L
.41979 .30898 L
.42013 .30259 L
.4203 .29946 L
.42045 .29658 L
.42059 .29396 L
.42074 .59641 L
.42089 .59363 L
.42105 .59058 L
.42221 .56867 L
.42709 .47706 L
.43179 .38897 L
Mistroke
.43302 .36594 L
.43435 .34091 L
.43496 .32945 L
.43561 .31728 L
.43617 .3069 L
.43632 .30405 L
.4364 .30256 L
.43648 .30099 L
.43664 .60332 L
.43678 .60067 L
.44138 .51462 L
.44627 .4232 L
.45099 .3354 L
.45599 .24239 L
.46082 .15317 L
.46546 .06783 L
.4667 .04514 L
.46731 .03407 L
.46786 .02398 L
.46801 .02137 L
.46816 .01853 L
.46831 .32106 L
.46845 .31858 L
.46907 .30719 L
.4704 .28307 L
.47513 .19806 L
.47755 .15528 L
.48015 .10979 L
.48138 .08869 L
.48268 .06671 L
.48321 .05774 L
.48378 .04821 L
.48395 .04541 L
.48404 .04404 L
.48411 .04277 L
.48426 .34563 L
.48441 .34307 L
.485 .3335 L
.48974 .26019 L
.4943 .20211 L
.49664 .17994 L
.49795 .17004 L
.49916 .16204 L
.49947 .16015 L
.49975 .15839 L
.49991 .15741 L
.5 .15687 L
.50008 .46159 L
.50023 .46069 L
.50038 .45975 L
Mistroke
.50171 .45124 L
.50413 .4323 L
.5065 .40789 L
.50871 .38026 L
.51096 .34856 L
.5134 .31114 L
.51405 .30088 L
.51473 .28983 L
.51532 .2803 L
.51548 .27767 L
.51565 .27483 L
.51573 .27352 L
.51582 .27214 L
.51596 .57489 L
.51612 .57237 L
.51626 .57008 L
.51657 .56492 L
.51712 .55557 L
.51839 .53411 L
.52321 .45029 L
.52785 .36746 L
.53025 .32412 L
.53083 .31354 L
.53115 .3077 L
.53146 .30216 L
.53163 .29903 L
.53173 .29726 L
.53182 .60085 L
.53197 .59795 L
.53214 .59487 L
.53279 .58315 L
.53781 .49109 L
.54264 .40176 L
.5473 .31541 L
.55225 .22326 L
.55702 .13428 L
.55942 .08942 L
.5616 .04854 L
.56218 .03767 L
.56281 .02587 L
.5631 .02046 L
.56326 .01749 L
.56341 .01472 L
.56354 .31758 L
.56367 .31504 L
.56396 .30963 L
.56648 .26235 L
.57145 .1692 L
.57393 .12266 L
.57624 .07939 L
Mistroke
.57738 .05787 L
.57846 .03757 L
.57875 .03211 L
.57906 .02634 L
.57922 .02332 L
.57931 .02161 L
.5794 .32523 L
.57955 .32241 L
.57971 .3194 L
.58084 .29816 L
.58582 .20446 L
.58831 .15758 L
.59062 .11415 L
.59286 .07203 L
.59399 .05074 L
.5943 .04491 L
.59464 .03862 L
.59479 .03573 L
.59495 .03268 L
.59509 .03008 L
.59524 .33245 L
.5954 .32947 L
.59555 .32671 L
.59588 .32048 L
.59648 .30917 L
.5976 .28799 L
.60013 .24043 L
.60488 .151 L
.60726 .10608 L
.60944 .06499 L
.61002 .05417 L
.61032 .04845 L
.61064 .04236 L
.6108 .03935 L
.61095 .03651 L
.61109 .03396 L
.61123 .33643 L
.61137 .33381 L
.61152 .33104 L
.61178 .32608 L
.6143 .27861 L
.61888 .19224 L
.62143 .14413 L
.62376 .10028 L
.62492 .0785 L
.62552 .06701 L
.62617 .05481 L
.62644 .04969 L
.62674 .04417 L
.62682 .04263 L
Mistroke
.6269 .04101 L
.62706 .34334 L
.6272 .34063 L
.62736 .33766 L
.62845 .31697 L
.63335 .22466 L
.63806 .13579 L
.63929 .11247 L
.64063 .08719 L
.64125 .07559 L
.6419 .06332 L
.64245 .05284 L
.64261 .04997 L
.64269 .04839 L
.64277 .04689 L
.64292 .3492 L
.64307 .34655 L
.64768 .25947 L
.65259 .1668 L
.65486 .1239 L
.65732 .07757 L
.65797 .06518 L
.65833 .05841 L
.65851 .05511 L
.65867 .0521 L
.65881 .35456 L
.65895 .35194 L
.65926 .34617 L
.65991 .33393 L
.66234 .28798 L
.66697 .20055 L
.66931 .1563 L
.6719 .10754 L
.67308 .08527 L
.67373 .07299 L
.67405 .06693 L
.6742 .06398 L
.67435 .06131 L
.67449 .05861 L
.67462 .3613 L
.67477 .35861 L
.67492 .35571 L
.67554 .3439 L
.67664 .32319 L
.68158 .22986 L
.68405 .18338 L
.68634 .13996 L
.68855 .09825 L
.68919 .08624 L
.68979 .07486 L
Mistroke
.69005 .06991 L
.6902 .06719 L
.69033 .06464 L
.69048 .36712 L
.69056 .36566 L
.69064 .36409 L
.69092 .35874 L
.69588 .26508 L
.70066 .17486 L
.70306 .12941 L
.70411 .10959 L
.70525 .08809 L
.70556 .08229 L
.70588 .07615 L
.70616 .0709 L
.70632 .06792 L
.70647 .37035 L
.70662 .36755 L
.70676 .36489 L
.70702 .3599 L
.70762 .34867 L
.71014 .30095 L
.71475 .21387 L
.71733 .16524 L
.71966 .12119 L
.72083 .0991 L
.72144 .08748 L
.72178 .08114 L
.72194 .07804 L
.72209 .07522 L
.72223 .37778 L
.72237 .37526 L
.72266 .3697 L
.72329 .35791 L
.72438 .33718 L
.72901 .24978 L
.73135 .20555 L
.73393 .15678 L
.73511 .13453 L
.73638 .11057 L
.73696 .09955 L
.73728 .09354 L
.73757 .08795 L
.73783 .08316 L
.73797 .08048 L
.7381 .38327 L
.73824 .3806 L
.73839 .37771 L
.73867 .37245 L
.74361 .27914 L
Mistroke
.74837 .18928 L
.75076 .1441 L
.7518 .12436 L
.75294 .10286 L
.75324 .09714 L
.75357 .09104 L
.7537 .08854 L
.75384 .08584 L
.754 .3881 L
.75415 .38531 L
.75529 .36371 L
.75781 .31608 L
.76277 .22245 L
.76524 .17576 L
.76754 .13227 L
.76868 .11072 L
.76924 .10014 L
.76949 .09548 L
.76962 .09302 L
.76976 .09036 L
.76991 .39276 L
.77005 .39012 L
.77035 .38433 L
.771 .37211 L
.77213 .35076 L
.7771 .25681 L
.77958 .20988 L
.78189 .16631 L
.78412 .12418 L
.78476 .11205 L
.78508 .1061 L
.78537 .10062 L
.7855 .09804 L
.78563 .09563 L
.78576 .39834 L
.78591 .39558 L
.7865 .38449 L
.79119 .29581 L
.79618 .20154 L
.79867 .15437 L
.79977 .13362 L
.80036 .1226 L
.80098 .11072 L
.80128 .10517 L
.80144 .10214 L
.80159 .09933 L
.80171 .40214 L
.80185 .39956 L
.80214 .3941 L
.80323 .37359 L
Mistroke
.80561 .32859 L
.81061 .234 L
.81312 .18659 L
.81422 .16577 L
.81543 .14287 L
.816 .13226 L
.8166 .12087 L
.81689 .11535 L
.81717 .11011 L
.81729 .10783 L
.81742 .10541 L
.81756 .40797 L
.81769 .40551 L
.82007 .36042 L
.8251 .26552 L
.82762 .21786 L
.82993 .17408 L
.83111 .15192 L
.8322 .13126 L
.83275 .12085 L
.83291 .11785 L
.83306 .11502 L
.83319 .11247 L
.83334 .41493 L
.83349 .4121 L
.83366 .40897 L
.83399 .40265 L
.83459 .39131 L
.83945 .29955 L
.84412 .21125 L
.84649 .16637 L
.84775 .14266 L
.84844 .12963 L
.84877 .12324 L
.84892 .12043 L
.849 .11895 L
.84909 .11735 L
.84924 .41961 L
.84939 .41684 L
.84971 .41077 L
.85039 .398 L
.85157 .37569 L
.85387 .33214 L
.85886 .23793 L
.86135 .19081 L
.86245 .17008 L
.86366 .14718 L
.86421 .13668 L
.86451 .13117 L
.86466 .12816 L
Mistroke
.86481 .12536 L
.86494 .12289 L
.86508 .42548 L
.86524 .42255 L
.86538 .41989 L
.8659 .41009 L
.86828 .3651 L
.8731 .27404 L
.87773 .18642 L
.87897 .16305 L
.88013 .14117 L
.88042 .13553 L
.88071 .13017 L
.88086 .12722 L
.88095 .12555 L
.88103 .42922 L
.88118 .42648 L
.88133 .42357 L
.88266 .39845 L
.88768 .30361 L
.8902 .25601 L
.89252 .21223 L
.89478 .16947 L
.89592 .14793 L
.89623 .14203 L
.8964 .13879 L
.89656 .13571 L
.89672 .13285 L
.8968 .13124 L
.89688 .43497 L
.89702 .43233 L
.89717 .42953 L
.90172 .34343 L
.90657 .25174 L
.9088 .20959 L
.91007 .18571 L
.91124 .1635 L
.91184 .15213 L
.91214 .14654 L
.91241 .14139 L
.91257 .13851 L
.91264 .13705 L
.91273 .44068 L
.91281 .43907 L
.9129 .43735 L
.91307 .43424 L
.91366 .42301 L
.91621 .3749 L
.92119 .28076 L
.92368 .23369 L
Mistroke
.92599 .19008 L
.92714 .1683 L
.9277 .15762 L
.92822 .14782 L
.92837 .14496 L
.92851 .14229 L
.92866 .44473 L
.92874 .44326 L
.92882 .44169 L
.92947 .42943 L
.9306 .40807 L
.9356 .31362 L
.9381 .26631 L
.94041 .22262 L
.94266 .18014 L
.9438 .1587 L
.94411 .15283 L
.94428 .14959 L
.94436 .14799 L
.94444 .14651 L
.94459 .44888 L
.94467 .44737 L
.94476 .44576 L
.94504 .44031 L
.95006 .34554 L
.95489 .25423 L
.95711 .21236 L
.95836 .18858 L
.95898 .17697 L
.95954 .16638 L
.95982 .16099 L
.95997 .15814 L
.96013 .15512 L
.96027 .15249 L
.96043 .45481 L
.96057 .45216 L
.9607 .44968 L
.96194 .42617 L
.96448 .37816 L
.96915 .28999 L
.97411 .19624 L
.97619 .15686 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.03968 .30947 m
.03968 .30947 L
s
.05556 .30947 m
.05556 .30947 L
s
.07143 .30947 m
.07143 .30947 L
s
.0873 .30947 m
.0873 .30947 L
s
.10317 .30947 m
.10317 .30947 L
s
.11905 .30947 m
.11905 .30947 L
s
.13492 .30947 m
.13492 .30947 L
s
.15079 .30947 m
.15079 .30947 L
s
.16667 .30947 m
.16667 .30947 L
s
.18254 .30947 m
.18254 .30947 L
s
.19841 .30947 m
.19841 .30947 L
s
.21429 .30947 m
.21429 .30947 L
s
.23016 .30947 m
.23016 .30947 L
s
.24603 .30947 m
.24603 .30947 L
s
.2619 .30947 m
.2619 .30947 L
s
.27778 .30947 m
.27778 .30947 L
s
.29365 .30947 m
.29365 .30947 L
s
.30952 .30947 m
.30952 .30947 L
s
.3254 .30947 m
.3254 .30947 L
s
.34127 .30947 m
.34127 .30947 L
s
.35714 .30947 m
.35714 .30947 L
s
.37302 .30947 m
.37302 .30947 L
s
.38889 .30947 m
.38889 .30947 L
s
.40476 .30947 m
.40476 .30947 L
s
.42063 .30947 m
.42063 .30947 L
s
.43651 .30947 m
.43651 .30947 L
s
.45238 .30947 m
.45238 .30947 L
s
.46825 .30947 m
.46825 .30947 L
s
.48413 .30947 m
.48413 .30947 L
s
.5 .30947 m
.5 .30947 L
s
.51587 .30947 m
.51587 .30947 L
s
.53175 .30947 m
.53175 .30947 L
s
.54762 .30947 m
.54762 .30947 L
s
.56349 .30947 m
.56349 .30947 L
s
.57937 .30947 m
.57937 .30947 L
s
.59524 .30947 m
.59524 .30947 L
s
.61111 .30947 m
.61111 .30947 L
s
.62698 .30947 m
.62698 .30947 L
s
.64286 .30947 m
.64286 .30947 L
s
.65873 .30947 m
.65873 .30947 L
s
.6746 .30947 m
.6746 .30947 L
s
.69048 .30947 m
.69048 .30947 L
s
.70635 .30947 m
.70635 .30947 L
s
.72222 .30947 m
.72222 .30947 L
s
.7381 .30947 m
.7381 .30947 L
s
.75397 .30947 m
.75397 .30947 L
s
.76984 .30947 m
.76984 .30947 L
s
.78571 .30947 m
.78571 .30947 L
s
.80159 .30947 m
.80159 .30947 L
s
.81746 .30947 m
.81746 .30947 L
s
.83333 .30947 m
.83333 .30947 L
s
.84921 .30947 m
.84921 .30947 L
s
.86508 .30947 m
.86508 .30947 L
s
.88095 .30947 m
.88095 .30947 L
s
.89683 .30947 m
.89683 .30947 L
s
.9127 .30947 m
.9127 .30947 L
s
.92857 .30947 m
.92857 .30947 L
s
.94444 .30947 m
.94444 .30947 L
s
.96032 .30947 m
.96032 .30947 L
s
.97619 .30947 m
.97619 .30947 L
s
.015 w
.03968 .30947 Mdot
.05556 .30947 Mdot
.07143 .30947 Mdot
.0873 .30947 Mdot
.10317 .30947 Mdot
.11905 .30947 Mdot
.13492 .30947 Mdot
.15079 .30947 Mdot
.16667 .30947 Mdot
.18254 .30947 Mdot
.19841 .30947 Mdot
.21429 .30947 Mdot
.23016 .30947 Mdot
.24603 .30947 Mdot
.2619 .30947 Mdot
.27778 .30947 Mdot
.29365 .30947 Mdot
.30952 .30947 Mdot
.3254 .30947 Mdot
.34127 .30947 Mdot
.35714 .30947 Mdot
.37302 .30947 Mdot
.38889 .30947 Mdot
.40476 .30947 Mdot
.42063 .30947 Mdot
.43651 .30947 Mdot
.45238 .30947 Mdot
.46825 .30947 Mdot
.48413 .30947 Mdot
.5 .30947 Mdot
.51587 .30947 Mdot
.53175 .30947 Mdot
.54762 .30947 Mdot
.56349 .30947 Mdot
.57937 .30947 Mdot
.59524 .30947 Mdot
.61111 .30947 Mdot
.62698 .30947 Mdot
.64286 .30947 Mdot
.65873 .30947 Mdot
.6746 .30947 Mdot
.69048 .30947 Mdot
.70635 .30947 Mdot
.72222 .30947 Mdot
.7381 .30947 Mdot
.75397 .30947 Mdot
.76984 .30947 Mdot
.78571 .30947 Mdot
.80159 .30947 Mdot
.81746 .30947 Mdot
.83333 .30947 Mdot
.84921 .30947 Mdot
.86508 .30947 Mdot
.88095 .30947 Mdot
.89683 .30947 Mdot
.9127 .30947 Mdot
.92857 .30947 Mdot
.94444 .30947 Mdot
.96032 .30947 Mdot
.97619 .30947 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0161421 0.0147151 0.0196201 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18523 -0.0125 -6 -9 ]
[.18523 -0.0125 6 0 ]
[.34665 -0.0125 -6 -9 ]
[.34665 -0.0125 6 0 ]
[.50807 -0.0125 -6 -9 ]
[.50807 -0.0125 6 0 ]
[.66949 -0.0125 -6 -9 ]
[.66949 -0.0125 6 0 ]
[.83091 -0.0125 -6 -9 ]
[.83091 -0.0125 6 0 ]
[.99233 -0.0125 -6 -9 ]
[.99233 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11282 -6 -4.5 ]
[-0.0125 .11282 0 4.5 ]
[-0.0125 .21092 -12 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18523 0 m
.18523 .00625 L
s
[(10)] .18523 -0.0125 0 1 Mshowa
.34665 0 m
.34665 .00625 L
s
[(20)] .34665 -0.0125 0 1 Mshowa
.50807 0 m
.50807 .00625 L
s
[(30)] .50807 -0.0125 0 1 Mshowa
.66949 0 m
.66949 .00625 L
s
[(40)] .66949 -0.0125 0 1 Mshowa
.83091 0 m
.83091 .00625 L
s
[(50)] .83091 -0.0125 0 1 Mshowa
.99233 0 m
.99233 .00625 L
s
[(60)] .99233 -0.0125 0 1 Mshowa
.125 Mabswid
.05609 0 m
.05609 .00375 L
s
.08838 0 m
.08838 .00375 L
s
.12066 0 m
.12066 .00375 L
s
.15295 0 m
.15295 .00375 L
s
.21751 0 m
.21751 .00375 L
s
.2498 0 m
.2498 .00375 L
s
.28208 0 m
.28208 .00375 L
s
.31437 0 m
.31437 .00375 L
s
.37893 0 m
.37893 .00375 L
s
.41122 0 m
.41122 .00375 L
s
.4435 0 m
.4435 .00375 L
s
.47579 0 m
.47579 .00375 L
s
.54036 0 m
.54036 .00375 L
s
.57264 0 m
.57264 .00375 L
s
.60492 0 m
.60492 .00375 L
s
.63721 0 m
.63721 .00375 L
s
.70178 0 m
.70178 .00375 L
s
.73406 0 m
.73406 .00375 L
s
.76634 0 m
.76634 .00375 L
s
.79863 0 m
.79863 .00375 L
s
.8632 0 m
.8632 .00375 L
s
.89548 0 m
.89548 .00375 L
s
.92776 0 m
.92776 .00375 L
s
.96005 0 m
.96005 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11282 m
.00625 .11282 L
s
[(5)] -0.0125 .11282 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(10)] -0.0125 .21092 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(15)] -0.0125 .30902 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(20)] -0.0125 .40712 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(25)] -0.0125 .50522 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(30)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .0932 m
.00375 .0932 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .17168 m
.00375 .17168 L
s
0 .1913 m
.00375 .1913 L
s
0 .23054 m
.00375 .23054 L
s
0 .25016 m
.00375 .25016 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .32864 m
.00375 .32864 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .4856 m
.00375 .4856 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .56408 m
.00375 .56408 L
s
0 .5837 m
.00375 .5837 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18523 .61178 m
.18523 .61803 L
s
.34665 .61178 m
.34665 .61803 L
s
.50807 .61178 m
.50807 .61803 L
s
.66949 .61178 m
.66949 .61803 L
s
.83091 .61178 m
.83091 .61803 L
s
.99233 .61178 m
.99233 .61803 L
s
.125 Mabswid
.05609 .61428 m
.05609 .61803 L
s
.08838 .61428 m
.08838 .61803 L
s
.12066 .61428 m
.12066 .61803 L
s
.15295 .61428 m
.15295 .61803 L
s
.21751 .61428 m
.21751 .61803 L
s
.2498 .61428 m
.2498 .61803 L
s
.28208 .61428 m
.28208 .61803 L
s
.31437 .61428 m
.31437 .61803 L
s
.37893 .61428 m
.37893 .61803 L
s
.41122 .61428 m
.41122 .61803 L
s
.4435 .61428 m
.4435 .61803 L
s
.47579 .61428 m
.47579 .61803 L
s
.54036 .61428 m
.54036 .61803 L
s
.57264 .61428 m
.57264 .61803 L
s
.60492 .61428 m
.60492 .61803 L
s
.63721 .61428 m
.63721 .61803 L
s
.70178 .61428 m
.70178 .61803 L
s
.73406 .61428 m
.73406 .61803 L
s
.76634 .61428 m
.76634 .61803 L
s
.79863 .61428 m
.79863 .61803 L
s
.8632 .61428 m
.8632 .61803 L
s
.89548 .61428 m
.89548 .61803 L
s
.92776 .61428 m
.92776 .61803 L
s
.96005 .61428 m
.96005 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11282 m
1 .11282 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .50522 m
1 .50522 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03434 m
1 .03434 L
s
.99625 .05396 m
1 .05396 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .0932 m
1 .0932 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .15206 m
1 .15206 L
s
.99625 .17168 m
1 .17168 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .23054 m
1 .23054 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .26978 m
1 .26978 L
s
.99625 .2894 m
1 .2894 L
s
.99625 .32864 m
1 .32864 L
s
.99625 .34826 m
1 .34826 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .44636 m
1 .44636 L
s
.99625 .46598 m
1 .46598 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .52484 m
1 .52484 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .56408 m
1 .56408 L
s
.99625 .5837 m
1 .5837 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .01472 L
s
.03995 .01472 m
.03995 .01472 L
s
.05609 .01472 m
.05609 .01472 L
s
.07224 .01472 m
.07224 .60332 L
s
.08838 .01472 m
.08838 .01472 L
s
.10452 .01472 m
.10452 .01472 L
s
.12066 .01472 m
.12066 .01472 L
s
.1368 .01472 m
.1368 .01472 L
s
.15295 .01472 m
.15295 .01472 L
s
.16909 .01472 m
.16909 .01472 L
s
.18523 .01472 m
.18523 .01472 L
s
.20137 .01472 m
.20137 .01472 L
s
.21751 .01472 m
.21751 .01472 L
s
.23366 .01472 m
.23366 .01472 L
s
.2498 .01472 m
.2498 .01472 L
s
.26594 .01472 m
.26594 .01472 L
s
.28208 .01472 m
.28208 .01472 L
s
.29822 .01472 m
.29822 .01472 L
s
.31437 .01472 m
.31437 .01472 L
s
.33051 .01472 m
.33051 .01472 L
s
.34665 .01472 m
.34665 .01472 L
s
.36279 .01472 m
.36279 .01472 L
s
.37893 .01472 m
.37893 .01472 L
s
.39508 .01472 m
.39508 .01472 L
s
.41122 .01472 m
.41122 .01472 L
s
.42736 .01472 m
.42736 .01472 L
s
.4435 .01472 m
.4435 .01472 L
s
.45964 .01472 m
.45964 .01472 L
s
.47579 .01472 m
.47579 .01472 L
s
.49193 .01472 m
.49193 .01472 L
s
.50807 .01472 m
.50807 .01472 L
s
.52421 .01472 m
.52421 .01472 L
s
.54036 .01472 m
.54036 .01472 L
s
.5565 .01472 m
.5565 .01472 L
s
.57264 .01472 m
.57264 .01472 L
s
.58878 .01472 m
.58878 .01472 L
s
.60492 .01472 m
.60492 .01472 L
s
.62107 .01472 m
.62107 .01472 L
s
.63721 .01472 m
.63721 .01472 L
s
.65335 .01472 m
.65335 .01472 L
s
.66949 .01472 m
.66949 .01472 L
s
.68563 .01472 m
.68563 .01472 L
s
.70178 .01472 m
.70178 .01472 L
s
.71792 .01472 m
.71792 .01472 L
s
.73406 .01472 m
.73406 .01472 L
s
.7502 .01472 m
.7502 .01472 L
s
.76634 .01472 m
.76634 .01472 L
s
.78249 .01472 m
.78249 .01472 L
s
.79863 .01472 m
.79863 .01472 L
s
.81477 .01472 m
.81477 .01472 L
s
.83091 .01472 m
.83091 .01472 L
s
.84705 .01472 m
.84705 .01472 L
s
.8632 .01472 m
.8632 .01472 L
s
.87934 .01472 m
.87934 .01472 L
s
.89548 .01472 m
.89548 .01472 L
s
.91162 .01472 m
.91162 .01472 L
s
.92776 .01472 m
.92776 .01472 L
s
.94391 .01472 m
.94391 .60332 L
s
.96005 .01472 m
.96005 .01472 L
s
.97619 .01472 m
.97619 .01472 L
s
.015 w
.02381 .01472 Mdot
.03995 .01472 Mdot
.05609 .01472 Mdot
.07224 .60332 Mdot
.08838 .01472 Mdot
.10452 .01472 Mdot
.12066 .01472 Mdot
.1368 .01472 Mdot
.15295 .01472 Mdot
.16909 .01472 Mdot
.18523 .01472 Mdot
.20137 .01472 Mdot
.21751 .01472 Mdot
.23366 .01472 Mdot
.2498 .01472 Mdot
.26594 .01472 Mdot
.28208 .01472 Mdot
.29822 .01472 Mdot
.31437 .01472 Mdot
.33051 .01472 Mdot
.34665 .01472 Mdot
.36279 .01472 Mdot
.37893 .01472 Mdot
.39508 .01472 Mdot
.41122 .01472 Mdot
.42736 .01472 Mdot
.4435 .01472 Mdot
.45964 .01472 Mdot
.47579 .01472 Mdot
.49193 .01472 Mdot
.50807 .01472 Mdot
.52421 .01472 Mdot
.54036 .01472 Mdot
.5565 .01472 Mdot
.57264 .01472 Mdot
.58878 .01472 Mdot
.60492 .01472 Mdot
.62107 .01472 Mdot
.63721 .01472 Mdot
.65335 .01472 Mdot
.66949 .01472 Mdot
.68563 .01472 Mdot
.70178 .01472 Mdot
.71792 .01472 Mdot
.73406 .01472 Mdot
.7502 .01472 Mdot
.76634 .01472 Mdot
.78249 .01472 Mdot
.79863 .01472 Mdot
.81477 .01472 Mdot
.83091 .01472 Mdot
.84705 .01472 Mdot
.8632 .01472 Mdot
.87934 .01472 Mdot
.89548 .01472 Mdot
.91162 .01472 Mdot
.92776 .01472 Mdot
.94391 .60332 Mdot
.96005 .01472 Mdot
.97619 .01472 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0161421 0.309017 0.0983632 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18523 -0.0125 -6 -9 ]
[.18523 -0.0125 6 0 ]
[.34665 -0.0125 -6 -9 ]
[.34665 -0.0125 6 0 ]
[.50807 -0.0125 -6 -9 ]
[.50807 -0.0125 6 0 ]
[.66949 -0.0125 -6 -9 ]
[.66949 -0.0125 6 0 ]
[.83091 -0.0125 -6 -9 ]
[.83091 -0.0125 6 0 ]
[.99233 -0.0125 -6 -9 ]
[.99233 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01393 -12 -4.5 ]
[-0.0125 .01393 0 4.5 ]
[-0.0125 .11229 -12 -4.5 ]
[-0.0125 .11229 0 4.5 ]
[-0.0125 .21065 -12 -4.5 ]
[-0.0125 .21065 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40738 -6 -4.5 ]
[-0.0125 .40738 0 4.5 ]
[-0.0125 .50574 -6 -4.5 ]
[-0.0125 .50574 0 4.5 ]
[-0.0125 .60411 -6 -4.5 ]
[-0.0125 .60411 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18523 0 m
.18523 .00625 L
s
[(10)] .18523 -0.0125 0 1 Mshowa
.34665 0 m
.34665 .00625 L
s
[(20)] .34665 -0.0125 0 1 Mshowa
.50807 0 m
.50807 .00625 L
s
[(30)] .50807 -0.0125 0 1 Mshowa
.66949 0 m
.66949 .00625 L
s
[(40)] .66949 -0.0125 0 1 Mshowa
.83091 0 m
.83091 .00625 L
s
[(50)] .83091 -0.0125 0 1 Mshowa
.99233 0 m
.99233 .00625 L
s
[(60)] .99233 -0.0125 0 1 Mshowa
.125 Mabswid
.05609 0 m
.05609 .00375 L
s
.08838 0 m
.08838 .00375 L
s
.12066 0 m
.12066 .00375 L
s
.15295 0 m
.15295 .00375 L
s
.21751 0 m
.21751 .00375 L
s
.2498 0 m
.2498 .00375 L
s
.28208 0 m
.28208 .00375 L
s
.31437 0 m
.31437 .00375 L
s
.37893 0 m
.37893 .00375 L
s
.41122 0 m
.41122 .00375 L
s
.4435 0 m
.4435 .00375 L
s
.47579 0 m
.47579 .00375 L
s
.54036 0 m
.54036 .00375 L
s
.57264 0 m
.57264 .00375 L
s
.60492 0 m
.60492 .00375 L
s
.63721 0 m
.63721 .00375 L
s
.70178 0 m
.70178 .00375 L
s
.73406 0 m
.73406 .00375 L
s
.76634 0 m
.76634 .00375 L
s
.79863 0 m
.79863 .00375 L
s
.8632 0 m
.8632 .00375 L
s
.89548 0 m
.89548 .00375 L
s
.92776 0 m
.92776 .00375 L
s
.96005 0 m
.96005 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01393 m
.00625 .01393 L
s
[(-3)] -0.0125 .01393 1 0 Mshowa
0 .11229 m
.00625 .11229 L
s
[(-2)] -0.0125 .11229 1 0 Mshowa
0 .21065 m
.00625 .21065 L
s
[(-1)] -0.0125 .21065 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .40738 m
.00625 .40738 L
s
[(1)] -0.0125 .40738 1 0 Mshowa
0 .50574 m
.00625 .50574 L
s
[(2)] -0.0125 .50574 1 0 Mshowa
0 .60411 m
.00625 .60411 L
s
[(3)] -0.0125 .60411 1 0 Mshowa
.125 Mabswid
0 .0336 m
.00375 .0336 L
s
0 .05327 m
.00375 .05327 L
s
0 .07295 m
.00375 .07295 L
s
0 .09262 m
.00375 .09262 L
s
0 .13196 m
.00375 .13196 L
s
0 .15164 m
.00375 .15164 L
s
0 .17131 m
.00375 .17131 L
s
0 .19098 m
.00375 .19098 L
s
0 .23033 m
.00375 .23033 L
s
0 .25 m
.00375 .25 L
s
0 .26967 m
.00375 .26967 L
s
0 .28934 m
.00375 .28934 L
s
0 .32869 m
.00375 .32869 L
s
0 .34836 m
.00375 .34836 L
s
0 .36803 m
.00375 .36803 L
s
0 .38771 m
.00375 .38771 L
s
0 .42705 m
.00375 .42705 L
s
0 .44673 m
.00375 .44673 L
s
0 .4664 m
.00375 .4664 L
s
0 .48607 m
.00375 .48607 L
s
0 .52542 m
.00375 .52542 L
s
0 .54509 m
.00375 .54509 L
s
0 .56476 m
.00375 .56476 L
s
0 .58443 m
.00375 .58443 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18523 .61178 m
.18523 .61803 L
s
.34665 .61178 m
.34665 .61803 L
s
.50807 .61178 m
.50807 .61803 L
s
.66949 .61178 m
.66949 .61803 L
s
.83091 .61178 m
.83091 .61803 L
s
.99233 .61178 m
.99233 .61803 L
s
.125 Mabswid
.05609 .61428 m
.05609 .61803 L
s
.08838 .61428 m
.08838 .61803 L
s
.12066 .61428 m
.12066 .61803 L
s
.15295 .61428 m
.15295 .61803 L
s
.21751 .61428 m
.21751 .61803 L
s
.2498 .61428 m
.2498 .61803 L
s
.28208 .61428 m
.28208 .61803 L
s
.31437 .61428 m
.31437 .61803 L
s
.37893 .61428 m
.37893 .61803 L
s
.41122 .61428 m
.41122 .61803 L
s
.4435 .61428 m
.4435 .61803 L
s
.47579 .61428 m
.47579 .61803 L
s
.54036 .61428 m
.54036 .61803 L
s
.57264 .61428 m
.57264 .61803 L
s
.60492 .61428 m
.60492 .61803 L
s
.63721 .61428 m
.63721 .61803 L
s
.70178 .61428 m
.70178 .61803 L
s
.73406 .61428 m
.73406 .61803 L
s
.76634 .61428 m
.76634 .61803 L
s
.79863 .61428 m
.79863 .61803 L
s
.8632 .61428 m
.8632 .61803 L
s
.89548 .61428 m
.89548 .61803 L
s
.92776 .61428 m
.92776 .61803 L
s
.96005 .61428 m
.96005 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01393 m
1 .01393 L
s
.99375 .11229 m
1 .11229 L
s
.99375 .21065 m
1 .21065 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .40738 m
1 .40738 L
s
.99375 .50574 m
1 .50574 L
s
.99375 .60411 m
1 .60411 L
s
.125 Mabswid
.99625 .0336 m
1 .0336 L
s
.99625 .05327 m
1 .05327 L
s
.99625 .07295 m
1 .07295 L
s
.99625 .09262 m
1 .09262 L
s
.99625 .13196 m
1 .13196 L
s
.99625 .15164 m
1 .15164 L
s
.99625 .17131 m
1 .17131 L
s
.99625 .19098 m
1 .19098 L
s
.99625 .23033 m
1 .23033 L
s
.99625 .25 m
1 .25 L
s
.99625 .26967 m
1 .26967 L
s
.99625 .28934 m
1 .28934 L
s
.99625 .32869 m
1 .32869 L
s
.99625 .34836 m
1 .34836 L
s
.99625 .36803 m
1 .36803 L
s
.99625 .38771 m
1 .38771 L
s
.99625 .42705 m
1 .42705 L
s
.99625 .44673 m
1 .44673 L
s
.99625 .4664 m
1 .4664 L
s
.99625 .48607 m
1 .48607 L
s
.99625 .52542 m
1 .52542 L
s
.99625 .54509 m
1 .54509 L
s
.99625 .56476 m
1 .56476 L
s
.99625 .58443 m
1 .58443 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .30902 m
.02381 .30902 L
s
.03995 .30902 m
.03995 .30902 L
s
.05609 .30902 m
.05609 .30902 L
s
.07224 .30902 m
.07224 .30902 L
s
.08838 .30902 m
.08838 .30902 L
s
.10452 .30902 m
.10452 .30902 L
s
.12066 .30902 m
.12066 .30902 L
s
.1368 .30902 m
.1368 .30902 L
s
.15295 .30902 m
.15295 .30902 L
s
.16909 .30902 m
.16909 .30902 L
s
.18523 .30902 m
.18523 .30902 L
s
.20137 .30902 m
.20137 .30902 L
s
.21751 .30902 m
.21751 .30902 L
s
.23366 .30902 m
.23366 .30902 L
s
.2498 .30902 m
.2498 .30902 L
s
.26594 .30902 m
.26594 .30902 L
s
.28208 .30902 m
.28208 .30902 L
s
.29822 .30902 m
.29822 .30902 L
s
.31437 .30902 m
.31437 .30902 L
s
.33051 .30902 m
.33051 .30902 L
s
.34665 .30902 m
.34665 .30902 L
s
.36279 .30902 m
.36279 .30902 L
s
.37893 .30902 m
.37893 .30902 L
s
.39508 .30902 m
.39508 .30902 L
s
.41122 .30902 m
.41122 .30902 L
s
.42736 .30902 m
.42736 .30902 L
s
.4435 .30902 m
.4435 .30902 L
s
.45964 .30902 m
.45964 .30902 L
s
.47579 .30902 m
.47579 .30902 L
s
.49193 .30902 m
.49193 .30902 L
s
.50807 .30902 m
.50807 .30902 L
s
.52421 .30902 m
.52421 .30902 L
s
.54036 .30902 m
.54036 .30902 L
s
.5565 .30902 m
.5565 .30902 L
s
.57264 .30902 m
.57264 .30902 L
s
.58878 .30902 m
.58878 .30902 L
s
.60492 .30902 m
.60492 .30902 L
s
.62107 .30902 m
.62107 .30902 L
s
.63721 .30902 m
.63721 .30902 L
s
.65335 .30902 m
.65335 .30902 L
s
.66949 .30902 m
.66949 .30902 L
s
.68563 .30902 m
.68563 .30902 L
s
.70178 .30902 m
.70178 .30902 L
s
.71792 .30902 m
.71792 .30902 L
s
.73406 .30902 m
.73406 .30902 L
s
.7502 .30902 m
.7502 .30902 L
s
.76634 .30902 m
.76634 .30902 L
s
.78249 .30902 m
.78249 .30902 L
s
.79863 .30902 m
.79863 .30902 L
s
.81477 .30902 m
.81477 .30902 L
s
.83091 .30902 m
.83091 .30902 L
s
.84705 .30902 m
.84705 .30902 L
s
.8632 .30902 m
.8632 .30902 L
s
.87934 .30902 m
.87934 .30902 L
s
.89548 .30902 m
.89548 .30902 L
s
.91162 .30902 m
.91162 .30902 L
s
.92776 .30902 m
.92776 .30902 L
s
.94391 .30902 m
.94391 .30902 L
s
.96005 .30902 m
.96005 .30902 L
s
.97619 .30902 m
.97619 .30902 L
s
.015 w
.02381 .30902 Mdot
.03995 .30902 Mdot
.05609 .30902 Mdot
.07224 .30902 Mdot
.08838 .30902 Mdot
.10452 .30902 Mdot
.12066 .30902 Mdot
.1368 .30902 Mdot
.15295 .30902 Mdot
.16909 .30902 Mdot
.18523 .30902 Mdot
.20137 .30902 Mdot
.21751 .30902 Mdot
.23366 .30902 Mdot
.2498 .30902 Mdot
.26594 .30902 Mdot
.28208 .30902 Mdot
.29822 .30902 Mdot
.31437 .30902 Mdot
.33051 .30902 Mdot
.34665 .30902 Mdot
.36279 .30902 Mdot
.37893 .30902 Mdot
.39508 .30902 Mdot
.41122 .30902 Mdot
.42736 .30902 Mdot
.4435 .30902 Mdot
.45964 .30902 Mdot
.47579 .30902 Mdot
.49193 .30902 Mdot
.50807 .30902 Mdot
.52421 .30902 Mdot
.54036 .30902 Mdot
.5565 .30902 Mdot
.57264 .30902 Mdot
.58878 .30902 Mdot
.60492 .30902 Mdot
.62107 .30902 Mdot
.63721 .30902 Mdot
.65335 .30902 Mdot
.66949 .30902 Mdot
.68563 .30902 Mdot
.70178 .30902 Mdot
.71792 .30902 Mdot
.73406 .30902 Mdot
.7502 .30902 Mdot
.76634 .30902 Mdot
.78249 .30902 Mdot
.79863 .30902 Mdot
.81477 .30902 Mdot
.83091 .30902 Mdot
.84705 .30902 Mdot
.8632 .30902 Mdot
.87934 .30902 Mdot
.89548 .30902 Mdot
.91162 .30902 Mdot
.92776 .30902 Mdot
.94391 .30902 Mdot
.96005 .30902 Mdot
.97619 .30902 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 311.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0001=b000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`008?ooool3o`0000Cooooo0_l0000[ooooo`?o0000
;?ooool2o`0002oooooo0ol0000[ooooo`?o00001?ooool2o`0002oooooo0ol00004ooooo`;o0000
;?ooool3o`0002cooooo0_l0000^ooooo`?o0000;?ooool3o`0000Cooooo0_l0000Booooo`008Ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002Wooooo00Go0000oooooooooooo
ooooo`00000Zooooo`04o`000?ooooooooooo`0002gooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000;oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0002[ooooo00Go0000ooooooooooooooooo`00000Zooooo`04
o`000?ooooooooooo`0002cooooo00Go0000ooooooooooooooooo`00000/ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00004Oooool001Wooooo1Ol00003ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00008oooool5o`0000Gooooo00?o0000ooooooooool0:?oo
ool01?l0003oooooooooool0000aooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool0000Wooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0002Cooooo1Ol00005ooooo`03o`000?oooooooooo02Sooooo00Co0000oooo
oooooooo0000<?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00004Oooool0027ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
000]ooooo`03o`000?oooooooooo02Sooooo00Co0000oooooooooooo0000<Oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000;oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool0:?ooool01?l0
003oooooooooool0000`ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Aooooo`008Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0002Wooooo1?l0000[ooooo`04o`000?ooooooooooo`0002gooooo1?l0000/ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo0000;oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0002[ooooo1?l0000[ooooo`04o`000?ooooooooooo`0002cooooo1?l0000]
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004Oooool0023ooooo0_l00004
ooooo`04o`000?ooooooooooo`0002Wooooo00?o0000ooooooooool0;?ooool01?l0003ooooooooo
ool0000]ooooo`03o`000?oooooooooo02cooooo0_l00004ooooo`04o`000?ooooooooooo`0002ko
oooo0_l00004ooooo`04o`000?ooooooooooo`0002[ooooo00?o0000ooooooooool0;?ooool01?l0
003oooooooooool0000/ooooo`03o`000?oooooooooo02gooooo0_l00004ooooo`04o`000?oooooo
ooooo`00017ooooo000Qooooo`03o`000?oooooooooo00?ooooo0_l0000Zooooo`Go0000:oooool2
o`0002kooooo1Ol0000[ooooo`03o`000?oooooooooo00?ooooo0_l0000`ooooo`03o`000?oooooo
oooo00?ooooo0_l0000[ooooo`Go0000:oooool2o`0002gooooo1Ol0000/ooooo`03o`000?oooooo
oooo00?ooooo0_l0000Booooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooo
oooiooooo`007Oooooo@o`0002[ooooodOl0000@ooooo`005_ooool2o`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Qooooo`?o00001?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00kooooo000Eooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool01?ooool6ool00003oooooooo003oo`0000[oo`0000?oooooool00?oo00001ooo00000ooo
ooooo`00ool0000:ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00001ooo00000ooo
ooooo`00ool0000:ool00003oooooooo003oo`0000Ooo`001?ooool9ool00003oooooooo003oo`00
00Coo`001?ooool<ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00001ooo00000ooo
ooooo`00ool0000:ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00002_oo00000ooo
ooooo`00ool00007ool00003oooooooo003oo`0000Ooo`000oooool00ol0003oooooooooo`0Poooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool03_ooool001Gooooo00Co0000oooooooooooo00001?ooool2
o`0000?ooooo00?o003ooooooooo00001Ooo00000oooooooo`00ool0000:ool00003oooooooo003o
o`0000Ooo`0000?oooooool00?oo00002_oo00000oooooooo`00ool00007ool00003oooooooo003o
o`0000Ooo`0000?oooooool00?oo00002_oo00000oooooooo`00ool00007ool000;ooooo00?oo`00
oooooooo00002?oo00000oooooooo`00ool00004ool00004oooooooo003oooooooooo`coo`0000?o
ooooool00?oo00001ooo00000oooooooo`00ool00007ool00003oooooooo003oo`0000[oo`0000?o
ooooool00?oo00001ooo00000oooooooo`00ool0000:ool00003oooooooo003oo`0000Ooo`0000?o
ooooool00?oo00001ooo0002ooooo`;o00007?ooool5o`0000Gooooo00Go0000oooooooooooooooo
o`00001Wooooo`03o`000?oooooooooo00[ooooo00?o003oooooooooool0F?ooool00ol0003ooooo
ooooo`0>ooooo`005Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo
00?o003ooooooooo00001Ooo00000oooooooo`00ool0000:ool00003oooooooo003oo`0000Ooo`00
00?oooooool00?oo00002_oo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Ooo`00
00?oooooool00?oo00002_oo00000oooooooo`00ool00007ool000;ooooo00?oo`00oooooooo0000
2?oo00000oooooooo`00ool00004ool00004oooooooo003oooooooooo`coo`0000?oooooool00?oo
00001ooo00000oooooooo`00ool00007ool00003oooooooo003oo`0000[oo`0000?oooooool00?oo
00001ooo00000oooooooo`00ool0000:ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo
00001ooo0003ooooo`03o`000?oooooooooo02;ooooo0_l00004ooooo`?o0000G_ooool00ol00?oo
ooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o003oooooooooool0E_ooool3o`00013o
oooo000Eooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol00?oo
ooooooooo`02o`00o`;ooooo00Co003oooooool00?oo003o0_ooool2o`00o`04ooooool00?oooooo
ooooo`;o003o0_ooool2o`00o`05ooooool00?ooooooooooool00?l00_ooool2o`00o`;ooooo00?o
003oooooooooool01?ooool01?l00?ooooooooooool00?l2ooooo`;o003o00?oooooo`00ool00?l0
0_ooool01?l00?ooooooooooool00?l2ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol0
0?ooooooooooo`02o`00o`;ooooo00Co003ooooooooooooo003o0_ooool01Ol00?oooooooooooooo
ooooo`0000;ooooo00Co003ooooooooooooo003o0_ooool01Ol0003o003ooooooooooooo003o00;o
oooo00Co003oooooooooooooo`000oooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooo
oooo00;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooooooo00;o003o0_oo
ool00ol00?ooooooooooo`03ooooo`;o003o00?oooooo`00ool00?l00_ooool00ol00?oooooooooo
o`02o`00o`Cooooo0_l00?l2ooooo`;o003o0_ooool01?l00?ooooooo`00ool00?l2ooooo`;o003o
00?oooooo`00ool00?l01?ooool00ol00?ooooooo`00o`07ooooo`;o003o0_ooool00ol00?oooooo
ooooo`02ooooo`03o`000?oooooooooo02Cooooo00Go0000ooooooooooooooooo`00001Pooooo`03
o`00oooooooooooo00Cooooo00?o0000ooooooooool03_ooool00ol00?ooooooooooo`1Dooooo`03
o`000?oooooooooo00kooooo000Eooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool00oooool01Ol00?ooooooooooool00?oooooo00;o003o00?oooooo`00ooooool00oooool2o`00
o`Cooooo00?o003oooooool00?l01?ooool4o`00o`;ooooo00?o003oooooool00?l00oooool2o`00
o`04ooooool00?oo003oooooo`;o003o0_ooool2o`00o`04ooooool00?oo003oooooo`;o003o0_oo
ool00ol00?ooooooooooo`02o`00o`;ooooo00Co003oooooool00?oo003o0_ooool00ol00?oooooo
ooooo`02o`00o`;ooooo00Co003ooooooooooooo003o1_ooool01?oo003oooooooooool00?l2oooo
o`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o0_ooool01Ooo003ooooooooo
oooooooo003o00Gooooo00?o003oooooooooool00_l00?l2ooooo`04o`00ooooooooooooo`00o`?o
oooo00Co003oooooool00?oo003o0_ooool00ol00?ooooooooooo`02o`00o`05ooooool00?oooooo
ooooool00?l00oooool2o`00o`;ooooo00Ko003oooooool00?oo003oooooool00?l4ooooo`03o`00
oooooooo003o00Cooooo1?l00?l01_oooooo003ooooooooooooo003oooooo`;o003o0oooool01Ol0
0?ooooooooooool00?oooooo00;o003o00?oooooo`00ool00?l01Oooool00ol0003oooooooooo`0P
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`1Nooooo`03o`00oooo
oooooooo00Cooooo00?o0000ooooooooool02_ooool00ol00?ooooooooooo`02o`00oeKooooo00?o
0000ooooooooool03_ooool001Kooooo0_l00005ooooo`;o00001?ooool2o`00o`04ooooool00?oo
003oooooo`;o003o0_ooool2o`00o`;ooooo00Co003ooooooooooooo003o0_ooool00ol00?oooooo
ooooo`02o`00o`03ooooool00?oooooo00;ooooo1Ol00?l01_oooooo003ooooooooooooo003ooooo
o`;o003o00Goooooo`00ooooooooooooo`00o`04ooooo`08o`00ooooooooooooo`00oooooooo003o
ooooool00?l4ooooo`;o003o1Oooool01?l00?ooooooooooool00?l2ooooo`05o`00oooooooooooo
ooooool00?l00_ooool01Ol00?ooooooooooooooooooo`0000;ooooo00Co003ooooooooooooo003o
0_ooool5o`00o`;ooooo00Co003oooooooooooooo`000oooool01?l00?ooooooooooool00?l2oooo
o`04o`00ooooooooooooo`00o`;ooooo0_l00?l2ooooo`03o`00oooooooooooo00;o003o00?ooooo
o`00ooooool01Oooool2o`00o`06ooooool00?oo003oooooool00?oooooo0_l00?l3ooooo`;o003o
00Coooooo`00oooooooo003o0_ooool2o`00o`03ooooool00?oo003o00Co003o00Coooooo`00oooo
oooooooo0_l00?l2ooooo`;o003o00Coooooo`00ool00?oooooo0_l00?l2ooooo`;o003o00?ooooo
o`00ooooool00_ooool00ol00?ooooooooooo`02ooooo`;o00008oooool3o`0000Cooooo00?o0000
ooooooooool0G_ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o003o
ooooooooool00_l00?l2ooooo`03o`00oooooooooooo057ooooo00?o0000ooooooooool03_ooool0
01gooooo00?o0000ooooooooool06_ooool2o`00o`Gooooo00Co003ooooooooooooo003o0_ooool2
o`00o`;ooooo00?o003oooooooooool00_l00?l01?oooooo003oooooooooool2o`00o`?ooooo00Go
003ooooooooooooo003oooooo`02o`00o`03ooooool00?oooooo00;o003o0_ooool01?l00?oooooo
ooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00Co003ooooooooooooo003o0oooool0
1?oo003oooooooooool00?l3ooooo`;o003o00?o0000ooooool00?l00_l00?l5ooooo`03ool00?oo
oooooooo00;o003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Co003ooooooooooooo
003o0_ooool2o`00o`03ooooool00?oo003o00;ooooo00Co003oooooool00?oooooo0_l00?l01?oo
oooo003oooooooooool2o`00o`;ooooo00Go003oooooooooooooooooo`00o`02ooooo`;o003o00Co
ooooo`00ool00?oooooo0_l00?l2ooooo`04o`00ooooooooooooo`00ob3ooooo00?o0000oooooooo
ool0:?ooool2o`0005oooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`0:ooooo`04
o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003oCoooool2o`00013ooooo000Moooo
o`03o`000?oooooooooo037ooooo0_l00?l00ooooooo003oo`00o`02ooooo`;o003o00Coooooo`00
oooooooooooo0_l00?l01?oooooo003oooooool00?l3ooooo`06o`00oooooooo003oooooool00?oo
oooo0_l00?l00ooooooo003oo`00o`02ooooo`04o`00ooooooooooooo`00o`?ooooo00Coo`00oooo
oooooooo003o0_ooool3o`00o`04o`000?oooooo003oo`00o`?ooooo00Co003oooooooooooooo`00
0oooool01?l00?ooooooooooool00?l2ooooo`;o003o00Coooooo`00ool00?oooooo0_l00?l00ooo
oooo003oooooo`02ooooo`05o`00ooooooooooooo`00ooooool00_l00?l00ooooooo003oo`00o`02
ooooo`;o003o00Coooooo`00oooooooooooo0_l00?l2ooooo`03o`00oooooooooooo02kooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`1Nooooo`05o`00ooooooooooooooooool00?l0
0_ooool00ol0003oooooooooo`0:ooooo`05o`00ooooooooooooooooool00?l00_ooool01?l00?oo
ooooooooool00?l2ooooo`03o`00oooooooooooo04_ooooo00?o0000ooooooooool03_ooool001go
oooo00?o0000ooooooooool0>?ooool00ol00?ooooooooooo`02o`00o`05ooooool00?oo003ooooo
ool00?l00_ooool01?l00?ooooooo`00ooooool2o`00o`03ooooool00?oooooo00;o003o00?ooooo
o`00ool00?l00_ooool00ol00?ooooooooooo`04ooooo`04ool00?ooooooooooo`00o`;ooooo0_l0
0?l00ooooooo0000ooooo`02ooooo`04o`00ooooooooooooo`00o`;ooooo00Coo`00oooooooooooo
003o1_ooool2o`00o`05ooooool00?oo003oooooool00?l01?ooool01ol00?ooooooooooool00?oo
ooooo`00ooooool00_l00?l00ooooooo003oooooo`02ooooo`03o`00oooooooooooo03Sooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`1Nooooo`05o`00ooooooooooooooooool00?l0
0_ooool00ol0003oooooooooo`0:ooooo`05o`00ooooooooooooooooool00?l00_ooool01?l00?oo
ooooooooool00?l2ooooo`05o`00ooooooooooooooooool00?l0BOooool00ol0003oooooooooo`0>
ooooo`007Oooool2o`0004?ooooo00?o003oooooooooool00_l00?l2ooooo`05o`00oooooooooooo
ooooool00?l00_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003ooooooooooooooooo
ool00002ooooo`03o`00oooooooo003o00?ooooo00Go0000ooooooooooooooooo`00o`02ooooo`04
o`00ooooooooooooool000;ooooo0_l00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo00Go003o
oooooooooooo003oooooo`02o`00o`03ooooool00?oo003o00;ooooo00?o003oooooooooool0@Ooo
ool2o`0002[ooooo00?o0000ooooooooool0G_ooool00ol00?ooooooooooo`04ooooo`03o`000?oo
oooooooo00[ooooo00?o003oooooooooool00_l00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo
00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo04Cooooo00?o0000oooooooo
ool03_ooool001gooooo00?o0000ooooooooool0AOooool2o`00o`Cooooo00Co003ooooooooooooo
003o0_ooool01?l00?ooooooooooool00?l2ooooo`05o`00oooooooooooooooooooo00000_ooool0
0ol00?ooooooooooo`03ooooo`05o`000?ooooooooooooooool00?l01Oooool00ooo003ooooooooo
o`02o`00o`;ooooo00Go003oooooooooooooooooo`00o`02ooooo`04o`00ooooooooooooooooo`;o
003o00?oooooo`00ool00?l0Aoooool00ol0003oooooooooo`0Xooooo`;o0000Goooool01Ol00?oo
oooooooooooooooo003o00;ooooo00?o0000ooooooooool02_ooool01?l00?ooooooooooool00?l2
ooooo`;o003o0_ooool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo
00?o003oooooooooool0@?ooool2o`00013ooooo000Mooooo`03o`000?oooooooooo04Sooooo0_l0
0?l01_oooooo003oo`00oooooooo003oooooo`;o003o0_ooool01?l00?ooooooooooool00?l3oooo
o`06ool00?ooooooooooo`00oooooooo003o0oooool00ol0003oooooooooo`04ooooo`04o`00oooo
ooooooooool000?ooooo00Co003oooooool00?oo003o0_ooool2o`00o`06ooooool00?oo003ooooo
ool00?oooooo0_l00?m:ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0G_ooool0
1Ol00?oooooooooooooooooo003o00;ooooo00?o0000ooooooooool02_ooool00ol00?oooooooooo
o`02o`00o`03ooooool00?oo003o00;ooooo00Co003ooooooooooooo003o0oooool01?l00?oooooo
ooooool00?l2ooooo`03o`00oooooooooooo047ooooo00?o0000ooooooooool03_ooool001gooooo
00?o0000ooooooooool0B?ooool2o`00o`06ooooool00?oo003oooooool00?oooooo0_l00?l00ooo
oooo003oooooo`06ooooo`03ool00?oooooooooo00;ooooo00Go003oooooooooooooooooo`000004
ooooo`03o`00oooooooo003o00;ooooo00Coo`00oooooooooooo003o0oooool00ol00?oooooooooo
o`02o`00o`03ooooool00?oooooo00;o003oCOooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo05kooooo00?o003oooooooooool00_l00?l2ooooo`03o`000?oooooooooo00[ooooo00Oo
003oooooooooooooooooo`00oooooooo003o00?ooooo00Co003ooooooooooooo003o0_ooool2o`00
o`;ooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool00?llooooo`03o`000?oo
oooooooo00kooooo000Mooooo`;o0000COooool01Ol00?oooooooooooooooooo003o00;ooooo0_l0
0?l2ooooo`;o003o0_ooool01_oo003oooooo`00ool00?ooooooo`00o`?ooooo00?o0000oooooooo
ool00_ooool00ol00?ooooooo`00o`02ooooo`03ool00?oooooooooo00;o003o00Goooooo`00oooo
ooooooooo`00o`02ooooo`;o003o00?oooooo`00ool00?l0C?ooool2o`0002[ooooo00?o0000oooo
ooooool0G_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o0000ooooooooool02_ooool0
0ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooooooooooo003o0_ooool01?l00?oooooooooo
ool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l2ooooo`03o`00oooooooooooo03[o
oooo00?o0000ooooooooool03_ooool001gooooo00?o0000ooooooooool0Coooool00ol00?oooooo
o`00o`02ooooo`03o`00oooooooooooo00;o003o0_ooool01?oo003oooooo`00ool00?l5ooooo`03
o`000?oooooooooo00;ooooo00?o003oooooooooool00_ooool00ooo003oooooooooo`02o`00o`04
ooooool00?ooooooo`00oeGooooo00?o0000ooooooooool0:?ooool2o`0005oooooo00Co003ooooo
oooooooo003o0oooool00ol0003oooooooooo`0:ooooo`04o`00ooooooooooooo`00o`;ooooo0_l0
0?l2ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l2ooooo`04o`00ooooooooooooo`00o`;o
oooo0_l00?l2ooooo`04o`00ooooooooooooo`00ocSooooo0_l0000@ooooo`007Oooool00ol0003o
ooooooooo`1?ooooo`03o`00oooooooooooo00;o003o00?oooooo`00ooooool00_l00?l2ooooo`06
ool00?oooooo003oo`00oooooooo003o0oooool00ol0003oooooooooo`03ooooo`;o003o0_ooool0
2?oo003ooooooooooooooooo003oooooool00?oooooo0_l00?l00ooooooo003oo`00o`1Aooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool0G_ooool00ol00?ooooooooooo`02o`00o`;o
oooo00?o0000ooooooooool02Oooool01?l00?ooooooooooooooool2o`00o`03ooooool00?oo003o
00;ooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool00?l2ooooo`04o`00oooo
ooooooooo`00o`?ooooo00Co003ooooooooooooo003o0_ooool00ol00?ooooooooooo`0dooooo`03
o`000?oooooooooo00kooooo000Mooooo`03o`000?oooooooooo04oooooo00?o003oooooooooool0
0_l00?l7ooooo`03ool00?oooooooooo00;ooooo00Go003oooooooooooooooooo`000004ooooo`?o
003o0_ooool00ooo003oooooooooo`05ooooo`;o003o00?oooooo`00ool00?l0DOooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo05kooooo00?o003oooooooooool00_l00?l2ooooo`03
o`000?oooooooooo00gooooo0_l00?l00ooooooo003oooooo`02ooooo`04o`00ooooooooooooo`00
o`;ooooo0_l00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l2ooooo`04o`00oooooooo
ooooo`00o`;ooooo00Go003oooooooooooooooooo`00o`0booooo`03o`000?oooooooooo00kooooo
000Mooooo`;o0000E?ooool01?l00?ooooooo`00ooooool2o`00o`;ooooo00Coo`00ooooool00?oo
oooo0_l00?l3ooooo`03o`000?oooooooooo00;ooooo0ol00?l2ooooo`03ool00?oooooooooo00;o
003o00Goooooo`00ooooooooooooo`00o`1Cooooo`;o0000:_ooool00ol0003oooooooooo`1Noooo
o`05o`00ooooooooooooooooool00?l00_ooool00ol0003oooooooooo`09ooooo`;o003o0oooool0
1_l00?ooooooooooool00?ooooooo`00o`?ooooo00Co003ooooooooooooo003o0_ooool2o`00o`;o
oooo00?o003oooooooooool00_l00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo00Go003ooooo
ooooooooooooo`00o`02ooooo`03o`00oooooooooooo02gooooo00?o0000ooooooooool03_ooool0
01gooooo00?o0000ooooooooool0D_ooool01Ol00?ooooooooooool00?oooooo00;o003o0_ooool0
1Ooo003oooooo`00oooooooo003o00Cooooo00?o0000ooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03ool00?oooooooooo00;o003o00Coooooo`00oooooooo003oEOooool00ol0003ooooo
ooooo`0Xooooo`;o0000Goooool01?l00?ooooooooooool00?l3ooooo`03o`000?oooooooooo00Wo
oooo0_l00?l2ooooo`03o`00oooooooooooo00;o003o0_ooool01?l00?ooooooooooool00?l2oooo
o`;o003o00?oooooo`00ooooool00_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003o
ooooooooool00oooool01Ol00?oooooooooooooooooo003o00;ooooo00Co003ooooooooooooo003o
:oooool2o`00013ooooo000Eooooo`?o00001Oooool00ol0003oooooooooo`1Booooo`;o003o00?o
ooooo`00ooooool00_l00?l2ooooo`05ool00?oooooo003oooooool00?l01?ooool00ol0003ooooo
ooooo`03ooooo`;o003o0_ooool00ooo003oooooooooo`02o`00o`03ooooool00?oooooo00;o003o
E?ooool00ol0003oooooooooo`0Pooooo`Go00000oooool00ol0003oooooooooo`1Nooooo`03o`00
oooooooooooo00;o003o0_ooool00ol0003oooooooooo`09ooooo`;o003o0_ooool00ol00?oooooo
ooooo`02o`00o`03ooooool00?oo003o00;ooooo00Ko003oooooooooooooooooo`00ooooool2o`00
o`;ooooo00?o003oooooooooool01?ooool01?l00?ooooooooooool00?l6ooooo`04o`00oooooooo
ooooo`00o`;ooooo00Go003oooooooooooooooooo`00o`0Xooooo`03o`000?oooooooooo00kooooo
000Dooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1Booooo`;o003o
1oooool01Ooo003ooooooooooooooooo003o00Cooooo00?o0000ooooooooool00oooool2o`00o`;o
oooo00?oo`00ooooooooool01Oooool2o`00oeCooooo00?o0000ooooooooool08Oooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo05kooooo00?o003oooooooooool00_l00?l2oooo
o`03o`000?oooooooooo00gooooo0_l00?l01?oooooo003oooooooooool2o`00o`;ooooo00?o003o
ooooooooool00_l00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo00Co003ooooooooooooo003o
0oooool01?l00?ooooooooooool00?l2ooooo`;o003o0_ooool01?l00?ooooooooooool00?l3oooo
o`04o`00ooooooooooooo`00obGooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000oooo
ooooool00_ooool2o`0005Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03ool00?oooooo
003o00Kooooo00?o0000ooooooooool01Oooool00ol00?ooooooool00002ooooo`;o003o00Gooooo
o`00ooooooooooooo`00o`1Cooooo`;o00007?ooool5o`0000?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Mooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo0000
2oooool2o`00o`?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00;o
oooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooooooo00;o003o0_ooool01?l00?oo
ooooooooool00?l2ooooo`03o`00oooooooooooo00;o003o0_ooool01?l00?ooooooooooool00?l2
ooooo`;o003o0_ooool01?l00?ooooooooooool00?lRooooo`03o`000?oooooooooo00kooooo000H
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0EOooool01?l00?ooooooo`00ool0
0?l2ooooo`03ool00?oooooo003o00Kooooo00?o0000ooooooooool01oooool00ooo003ooooooooo
o`02o`00o`03ooooool00?oooooo05Kooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`02ooooo`?o0000GOooool2o`00o`;ooooo00Go003oooooooooooooooooo`00000;ooooo`;o003o
00Goooooo`00oooooooo003oooooo`02o`00o`;ooooo00Co003oooooool00?oo003o0_ooool2o`00
o`03ooooool00?oooooo00;ooooo00?o003oooooooooool00_l00?l00ooooooo003oo`00o`05oooo
o`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o0oooool00ol00?oooooooooo
o`03ooooo`04o`00ooooooooooooo`00oagooooo0ol0000@ooooo`005?ooool4o`0000Gooooo00?o
0000ooooooooool0EOooool01?l00?ooooooo`00ool00?l2ooooo`03ool00?oooooo003o00Kooooo
00?o0000ooooooooool01Oooool00ol00?ooooooool00002ooooo`;o003o00?oooooo`00ooooool0
E_ooool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`1Mooooo`;o003o0_ooool2o`00o`;ooooo00?o0000ooooooooool02Oooool2o`00o`03
ooooool00?oooooo00;ooooo0_l00?l01?oooooo003oo`00ooooool2o`00o`?ooooo00?o003ooooo
ool00?l00oooool01_l00?oooooooooooooooooo003oooooo`;o003o0_ooool00ol00?oooooooooo
o`04ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool00_l00?l2ooooo`04o`00
ooooooooooooo`00o`;ooooo00?o003oooooooooool07Oooool00ol0003oooooooooo`0>ooooo`00
5?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Gooooo00Co003ooooooooooooo
003o0_ooool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o003ooooooooo
00000oooool00ol00?ooooooooooo`1Gooooo`03o`000?oooooooooo023ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo05kooooo00?o003oooooooooool00_l00?l2oooo
o`03o`000?oooooooooo00cooooo00Co003oooooool00?oooooo0_l00?l00ooooooo003oo`00o`05
ooooo`;o003o0_ooool00ol00?ooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00Co
003ooooooooooooo003o0_ooool2o`00o`;ooooo00Co003ooooooooooooo003o0_ooool01Ol00?oo
oooooooooooooooo003o00;ooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool0
0?lHooooo`03o`000?oooooooooo00kooooo000Dooooo`Go00001?ooool2o`0005Sooooo00Oo003o
ooooooooooooooooool00?oooooo003o00Kooooo00?o0000ooooooooool01Oooool00ol00?oooooo
ool00002ooooo`04o`00ooooooooooooo`00oeKooooo0_l0000Sooooo`?o00001?ooool00ol0003o
ooooooooo`1Mooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo00002oooool2o`00
o`?ooooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`02o`00o`;ooooo00?o003ooooo
ooooool00_l00?l00ooooooo003oo`00o`02ooooo`;o003o0_ooool01?l00?ooooooo`00ool00?l2
ooooo`03o`00oooooooooooo00;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o0_oo
ool01?l00?ooooooooooool00?l2ooooo`05o`00ooooooooooooooooool00?l00_ooool01?l00?oo
ooooooooool00?lEooooo`03o`000?oooooooooo00kooooo000Mooooo`03o`000?oooooooooo05Go
oooo00Co003oooooool00?oo003o0_ooool00ooo003oooooo`00o`06ooooo`03o`000?oooooooooo
00Oooooo00?oo`00ooooooooool00_l00?l00ooooooo003oooooo`1Fooooo`03o`000?oooooooooo
02Sooooo0_l0001Nooooo`05o`00ooooooooooooooooool00?l00oooool00ol0003oooooooooo`09
ooooo`;o003o00Coooooo`00oooooooo003o0_ooool01Ol00?ooooooo`00ool00?oooooo00;o003o
0_ooool00ol00?ooooooooooo`02o`00o`;ooooo00?o003oooooooooool00_l00?l00ooooooo003o
o`00o`05ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o0oooool00ol0
0?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`Kooooo00Co003ooooooooooooo003o5?oo
ool2o`00013ooooo000Mooooo`03o`000?oooooooooo05Gooooo0_l00?l01ooooooo003ooooooooo
ooooo`00ooooool00?l01_ooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo00;o003o
00?oooooo`00ooooool0E_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo05gooooo
0_l00?l2ooooo`;o003o0_ooool00ol0003oooooooooo`09ooooo`;o003o00?oooooo`00ooooool0
0_ooool2o`00o`;ooooo00Co003oooooool00?oo003o0_ooool2o`00o`04ooooool00?oooooooooo
o`;o003o0oooool01?l00?ooooooo`00ool00?l2ooooo`04o`00ooooooooooooo`00o`?ooooo00?o
003oooooool00?l00oooool00ol00?ooooooooooo`02o`00o`03ooooool00?oo003o00;ooooo00Co
003ooooooooooooo003o0oooool01?l00?ooooooooooool00?l2ooooo`05o`00oooooooooooooooo
ool00?l04Oooool00ol0003oooooooooo`0>ooooo`007Oooool00ol0003oooooooooo`1Eooooo`04
o`00ooooooooooooo`00o`;ooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`00ooooooooo`0000?ooooo00?o003oooooooooool0Eoooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo05kooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`000?oooooo
oooo00cooooo00Co003oooooool00?oooooo0_l00?l00ooooooo003oo`00o`06ooooo`06o`00oooo
oooo003oo`00oooooooo003o0oooool01?l00?ooooooooooool00?l2ooooo`;o003o0_ooool00ol0
0?ooooooooooo`02o`00o`;ooooo00Co003ooooooooooooo003o0_ooool00ol00?ooooooooooo`02
o`00o`;ooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool00?l2ooooo`05o`00
ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0<ooooo`03o`000?oooooooooo00ko
oooo000Mooooo`03o`000?oooooooooo05Kooooo00?o003oooooooooool00_ooool00ooo003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o003ooooooooo00000_ooool01?l00?oooooo
ooooool00?mGooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0GOooool2o`00o`?o
oooo00Co003ooooooooooooo00002oooool2o`00o`03ooooool00?oooooo00;o003o0oooool00ol0
0?ooooooooooo`02o`00o`;ooooo0_l00?l2ooooo`04o`00oooooooo003oo`00o`;ooooo0_l00?l2
ooooo`04o`00oooooooo003oo`00o`;ooooo00?o003oooooooooool00_l00?l00ooooooo003oo`00
o`02ooooo`03o`00oooooooooooo00;o003o00?oooooo`00ool00?l00_ooool00ol00?oooooooooo
o`03ooooo`;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o0_ooool01?l00?oooooo
ooooool00?l;ooooo`03o`000?oooooooooo00kooooo000Mooooo`;o0000E_ooool2o`00o`07oooo
ool00?oooooooooooooo003oooooo`00o`06ooooo`03o`000?oooooooooo00Gooooo00?o003ooooo
oooo00000_ooool01?l00?ooooooo`00ool00?mFooooo`;o0000:_ooool2o`0005kooooo00Co003o
oooooooooooo003o1?ooool00ol0003oooooooooo`09ooooo`;o003o0oooool01Ol00?oooooooooo
ool00?oooooo00;o003o00?oooooo`00ool00?l00_ooool00ol00?ooooooooooo`02o`00o`;ooooo
00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooo003o00?ooooo00Co003ooooooooooooo
003o0_ooool2o`00o`;ooooo00Go003oooooooooooooooooo`00o`05ooooo`04o`00oooooooooooo
o`00o`Kooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool00?l2ooooo`04o`00
ooooooooooooo`00o`Oooooo0_l0000@ooooo`007Oooool00ol0003oooooooooo`1Eooooo`;o003o
00Ooooooo`00ooooooooooooool00?oooooo003o00Kooooo00?o0000ooooooooool01oooool01_oo
003oooooooooool00?ooooooo`00oeSooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`1Mooooo`;o003o00Coooooo`00oooooooo003o0_ooool00ol0003oooooooooo`09ooooo`;o003o
00Ooooooo`00ooooooooooooo`00oooooooo003o00;ooooo00[o003oooooool00?oo003oooooool0
0?ooooooo`00oooooooo003o0_ooool2o`00o`?ooooo00Co003oooooool00?oo003o0_ooool01?l0
0?ooooooooooool00?l3ooooo`03o`00oooooooo003o00?ooooo00?o003oooooooooool00_l00?l0
0ooooooo003oo`00o`02ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l2ooooo`04o`00oooo
ooooooooo`00o`;ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00;o
003o0_ooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00kooooo000Mooooo`03o`00
0?oooooooooo05Kooooo00?o003oooooool00?l00_ooool00ooo003oooooo`00o`06ooooo`03o`00
0?oooooooooo00Gooooo00?o003ooooooooo00001?ooool00ol00?ooooooooooo`1Fooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`1Eooooo`05o`00
oooooooo003oooooool00?l00_ooool00ol00?ooooooooooo`0<ooooo`07o`00oooooooo003oo`00
oooooooo003oooooo`02o`00o`Kooooo00Ko003oooooool00?oo003oooooool00?l2ooooo`05o`00
ooooooooooooooooool00?l00_ooool2o`00o`;ooooo00?o003oooooooooool00_l00?l2ooooo`04
o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool00_l00?l5ooooo`03o`00oooooooooooo
00;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o0_ooool01?l00?ooooooooooool0
0?l2ooooo`;o003o0_ooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00kooooo000M
ooooo`03o`000?oooooooooo05_ooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`00ooooooooo`0000;ooooo00?o003oooooooooool0F?ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo00Kooooo00Co003ooooooooooooo003oDoooool2o`00o`?ooooo00Co
003ooooooooooooo003o2_ooool01_l00?ooooooo`00oooooooo003oooooo`;o003o0oooool2o`00
o`07ooooool00?oo003oooooool00?ooooooo`00o`02ooooo`09o`00oooooooo003oo`00oooooooo
003oooooool00?oooooo00;o003o00Coooooo`00ool00?oooooo0_l00?l2ooooo`;o003o00?ooooo
o`00ool00?l00_ooool00ol00?ooooooooooo`02o`00o`03ooooool00?oo003o00;ooooo00?o003o
ooooooooool00oooool2o`00o`;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`;ooooo00Co
003ooooooooooooo003o0oooool01?l00?ooooooooooool00?l4ooooo`03o`000?oooooooooo00ko
oooo000Mooooo`;o0000FOooool01_l00?oooooooooooooo003oooooo`00o`Kooooo00?o0000oooo
ooooool01Oooool00ol00?ooooooool00002ooooo`03o`00oooooooooooo05Oooooo0_l0000Zoooo
o`;o00001_ooool2o`00o`;ooooo00Co003ooooooooooooo003oD?ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooool00?l00oooool01_l00?ooooooooooool0
0?ooooooo`00o`;ooooo0_l00?l00ooooooo003oooooo`02ooooo`;o003o0_ooool01Ol00?oooooo
o`00oooooooo003o00;ooooo00?o003oooooool00?l00_ooool2o`00o`;ooooo00?o003ooooooooo
ool00_l00?l00ooooooo003oo`00o`03ooooo`03o`00oooooooo003o00;ooooo0_l00?l2ooooo`03
o`00oooooooooooo00Cooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool00?l2
ooooo`04o`00ooooooooooooo`00o`Oooooo0_l0000@ooooo`007Oooool00ol0003oooooooooo`1H
ooooo`06o`00ooooooooooooool00?oooooo003o1_ooool00ol0003oooooooooo`07ooooo`04ool0
0?ooooooooooo`00oe[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`05ooooo`05
o`00ooooooooooooooooool00?l00_ooool01?l00?ooooooooooool00?m=ooooo`;o003o00Cooooo
o`00oooooooo003o0_ooool00ol0003oooooooooo`08ooooo`05o`00oooooooo003oooooool00?l0
0_ooool00ol00?ooooooo`00o`02ooooo`0:o`00oooooooo003oo`00oooooooo003oooooool00?oo
ooooo`00o`;ooooo0_l00?l3ooooo`04o`00oooooooo003oo`00o`;ooooo00?o003oooooool00?l0
1?ooool00ol00?ooooooo`00o`02ooooo`;o003o0_ooool2o`00o`;ooooo00Co003oooooool00?oo
003o0_ooool00ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooooooooooo003o0_ooool01Ol0
0?oooooooooooooooooo003o00;ooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooo
oooo00;ooooo00?o0000ooooooooool03_ooool001gooooo00?o0000ooooooooool0F?ooool01_l0
0?oooooooooooooo003oooooo`00o`Kooooo00?o0000ooooooooool01Oooool00ol00?ooooooool0
001Mooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01Oooool2o`00o`;ooooo00Co
003ooooooooooooo003o0_ooool01Ol00?oooooooooooooooooo003o04[ooooo00Ko003oooooool0
0?ooooooo`00ooooool2o`00o`[ooooo00Ko003oooooooooooooooooo`00ooooool2o`00o`05oooo
ool00?oo003oooooool00?l01_ooool01_l00?ooooooo`00ool00?ooooooo`00o`;ooooo00Go003o
ooooooooooooooooo`00o`02ooooo`;o003o0_ooool00ol00?ooooooooooo`02o`00o`;ooooo00?o
003oooooool00?l00oooool00ol00?ooooooooooo`02o`00o`Gooooo00?o003oooooooooool00_l0
0?l00ooooooo003oo`00o`02ooooo`03o`00oooooooooooo00;o003o00?oooooo`00ool00?l00_oo
ool00ol00?ooooooooooo`02o`00o`;ooooo00?o003oooooooooool00_ooool00ol0003ooooooooo
o`0>ooooo`007Oooool00ol0003oooooooooo`1Kooooo`03ool00?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol00?ooooooool00002ooooo`03o`00oooooooooooo05Sooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`06ooooo`04o`00ooooooooooooo`00o`;ooooo00Co
003ooooooooooooo003o0oooool01?l00?ooooooooooool00?m5ooooo`08o`00oooooooo003ooooo
ool00?ooooooo`00ooooool2o`00o`cooooo00Co003oooooool00?oooooo0_l00?l2ooooo`04o`00
oooooooo003oooooo`;o003o00Coooooo`00oooooooo003o0_ooool01ol00?ooooooo`00ool00?oo
ooooo`00ooooool00_l00?l00ooooooo003oooooo`02o`00o`03ooooool00?oo003o00;ooooo0_l0
0?l00ooooooo003oo`00o`02ooooo`03o`00oooooooooooo00;o003o00Coooooo`00ool00?oooooo
0_l00?l5ooooo`;o003o00?oooooo`00ool00?l00_ooool00ol00?ooooooooooo`02o`00o`03oooo
ool00?oooooo00;ooooo00Oo003oooooooooooooooooo`00oooooooo003o00Gooooo00?o0000oooo
ooooool03_ooool001gooooo0_l0001Iooooo`06o`00ooooooooooooool00?oooooo003o1_ooool0
0ol0003oooooooooo`05ooooo`03o`00ooooooooo`0000;ooooo00?o003oooooooooool0Eoooool2
o`0002[ooooo0_l00006ooooo`;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`05o`00oooo
ooooooooooooool00?l00_ooool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo00Gooooo
0_l00?l:ooooo`03o`00oooooooo003o00?ooooo00?o003oooooooooool00_l00?l3ooooo`;o003o
00Ooooooo`00ooooooooooooo`00oooooooo003o00;ooooo00Go003oooooool00?ooooooo`00o`02
ooooo`03o`00oooooooo003o00;ooooo0_l00?l2ooooo`03o`00oooooooooooo00;o003o00?ooooo
o`00ool00?l00_ooool2o`00o`04ooooool00?oo003oooooo`;o003o0_ooool00ol00?oooooooooo
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooo`00ool00?l2ooooo`05
o`00ooooooooooooooooool00?l01_ooool2o`00013ooooo000?ooooo`?o00001?ooool2o`0000Go
oooo00?o0000ooooooooool0F?ooool01_l00?oooooooooooooo003oooooo`00o`Kooooo00?o0000
ooooooooool01oooool01?oo003oooooooooool00?mJooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool01Oooool01Ol00?oooooooooooooooooo003o00;ooooo00Co003ooooooooooooo
003o0oooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooooooo043ooooo00Go003ooooo
ool00?ooooooo`00o`04ooooo`03o`000?oooooooooo00Sooooo00Go003oooooool00?ooooooo`00
o`02ooooo`03o`00oooooooo003o00;ooooo00Oo003oooooool00?oo003oooooool00?oooooo00;o
003o0oooool2o`00o`?ooooo0_l00?l01ooooooo003ooooooooooooo003oooooool00?l01?ooool0
0ol00?ooooooo`00o`02ooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`;o003o0_ooool0
0ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`;ooooo00Co
003ooooooooooooo003o0_ooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo00kooooo
000@ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`1Hooooo`06o`00ooooooooooooool00?oooooo003o1_ooool00ol0003oooooooooo`05oooo
o`03o`00ooooooooo`0005gooooo00?o0000ooooooooool08Oooool3o`0000Cooooo00?o0000oooo
ooooool01Oooool2o`00o`03ooooool00?oooooo00;ooooo00Co003ooooooooooooo003o0_ooool2
o`00o`;ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0nooooo`06o`00oooo
oooo003oooooool00?oooooo0_l00?l:ooooo`06o`00ooooooooooooooooool00?oooooo0_l00?l0
1Ooooooo003oo`00oooooooo003o00;ooooo00Co003ooooooooooooooooo0_l00?l00ooooooo003o
ooooo`02o`00o`05ooooool00?ooooooooooool00?l00oooool2o`00o`;ooooo00Go003oooooool0
0?ooooooo`00o`02ooooo`03o`00oooooooo003o00;ooooo00Co003ooooooooooooooooo0_l00?l4
ooooo`;o003o0_ooool2o`00o`03ooooool00?oo003o00;ooooo00Co003ooooooooooooo003o0_oo
ool2o`00o`;ooooo00?o003oooooooooool00_l00?l00ooooooo003oooooo`04ooooo`03o`000?oo
oooooooo00kooooo000@ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`1Kooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol00?ooooooool00002ooooo`03o`00oooooooooooo05Sooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00Co003oooooool00?oo003o
0_ooool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00Go003ooooo
ooooooooooooo`00o`02ooooo`03o`00oooooooooooo03_ooooo00Ko003oooooool00?ooooooo`00
ooooool2o`00o`cooooo0_l00?l2ooooo`;o003o0_ooool01Ol00?ooooooo`00oooooooo003o00;o
oooo00?o003oooooool00?l00_ooool00ol00?ooooooo`00o`02ooooo`07o`00oooooooo003oo`00
oooooooo003oooooo`02o`00o`08ooooool00?oo003oooooool00?ooooooo`00ooooool2o`00o`;o
oooo00Ko003oooooool00?ooooooo`00ooooool2o`00o`03ooooool00?oo003o00Gooooo0_l00?l0
0ooooooo003oo`00o`02ooooo`03o`00oooooooooooo00;o003o00?oooooo`00ooooool01Oooool2
o`00o`03ooooool00?oooooo00Cooooo00?o0000ooooooooool03_ooool0013ooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00004ooooo`;o0000FOooool01_l00?oooooooooooooo
003oooooo`00o`Kooooo00?o0000ooooooooool01Oooool00ol00?ooooooool00002ooooo`03o`00
oooooooooooo05Oooooo0_l0000Looooo`Go00000oooool00ol0003oooooooooo`03ooooo`?o0000
1_ooool01?l00?ooooooo`00ool00?l2ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooo
oooooooo003o0_ooool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00ocSooooo
00?o003oooooooooool00oooool01?l00?ooooooo`00ool00?l:ooooo`03o`00oooooooo003o00?o
oooo00?o003oooooooooool00_l00?l3ooooo`;o003o00Ooooooo`00ooooooooooooo`00oooooooo
003o00;ooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00;ooooo0_l0
0?l00ooooooo003oooooo`02ooooo`;o003o0_ooool01_l00?ooooooo`00oooooooo003oooooo`;o
003o00Coooooo`00ool00?oooooo0_l00?l5ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00
o`03ooooool00?oo003o00;ooooo00Oo003oooooooooooooooooo`00oooooooo003o00?ooooo0ol0
000@ooooo`004?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool0F?ooool01_l00?oooooooooooooo003oooooo`00o`Kooooo00?o0000oooooooo
ool01oooool01?oo003oooooooooool00?mJooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`05ooooo`05o`00ooooooooooooooooool00?l00_ooool0
1?l00?ooooooooooool00?l2ooooo`05o`00ooooooooooooooooool00?l00_ooool01?l00?oooooo
ooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool0<oooool01Ol0
0?ooooooo`00oooooooo003o00Cooooo00?o0000ooooooooool02?ooool01?l00?ooooooo`00ool0
0?l3ooooo`03o`00oooooooo003o00;ooooo0_l00?l01Ooooooo003oooooool00?oooooo00;o003o
0_ooool00ol00?ooooooo`00o`03ooooo`;o003o00Ooooooo`00ooooooooooooo`00oooooooo003o
00Cooooo00?o003oooooool00?l00_ooool2o`00o`?ooooo00?o003oooooooooool00_ooool2o`00
o`03ooooool00?oo003o00;ooooo0_l00?l2ooooo`03o`00oooooooo003o00Cooooo00Co003ooooo
oooooooo003o0_ooool01?l00?ooooooooooool00?l8ooooo`03o`000?oooooooooo00kooooo000?
ooooo`;o00001?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo05Sooooo00Ko
003oooooooooooooo`00ooooool00?l6ooooo`03o`000?oooooooooo00Gooooo00?o003ooooooooo
00000_ooool00ol00?ooooooooooo`1Hooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`05ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooo
oooooooo003o0_ooool2o`00o`;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`;ooooo00Co
003ooooooooooooo003o0_ooool01Ol00?oooooooooooooooooo003o037ooooo00Ko003oooooool0
0?ooooooo`00ooooool2o`00o`03ooooool00?oooooo00Wooooo00Co003oooooool00?oo003o0_oo
ool2o`00o`05ooooool00?oo003oooooool00?l00_ooool01?l00?ooooooooooooooool2o`00o`07
ooooool00?oo003oooooool00?ooooooo`00o`02ooooo`06o`00oooooooo003oo`00oooooooo003o
0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooool00?l00_ooool01?l00?oo
ooooooooooooool2o`00o`Cooooo0_l00?l2ooooo`;o003o00Coooooo`00ool00?oooooo0_l00?l2
ooooo`06o`00ooooooooooooooooool00?oooooo0_l00?l2ooooo`;o003o00?oooooo`00ooooool0
1?ooool00ol0003oooooooooo`0>ooooo`004?ooool00ol0003oooooooooo`03ooooo`;o00001Ooo
ool00ol0003oooooooooo`1Kooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol00?ooooooool0001Mooooo`03o`000?oooooooooo027ooooo0_l00005ooooo`03o`000?oo
oooooooo00Gooooo0_l00?l00ooooooo003oo`00o`02ooooo`04o`00ooooooooooooo`00o`;ooooo
0_l00?l2ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o0_ooool00ol0
0?ooooooooooo`04ooooo`04o`00ooooooooooooo`00oc3ooooo00Co003oooooool00?oooooo0_l0
0?l00ooooooo003oooooo`0<ooooo`03o`00oooooooooooo00;o003o0_ooool01?l00?ooooooo`00
ool00?l3ooooo`03o`00oooooooo003o00;ooooo0_l00?l3ooooo`04o`00oooooooo003oo`00o`;o
oooo00Co003oooooool00?oooooo0_l00?l01?oooooo003oooooool00?l2ooooo`06o`00oooooooo
003oo`00oooooooo003o0oooool2o`00o`03ooooool00?oooooo00Gooooo0_l00?l00ooooooo003o
o`00o`02ooooo`03o`00oooooooooooo00;o003o00?oooooo`00ooooool01Oooool2o`00o`03oooo
ool00?oooooo00Cooooo00?o0000ooooooooool03_ooool001gooooo0_l0001Iooooo`06o`00oooo
ooooooooool00?oooooo003o1_ooool00ol0003oooooooooo`05ooooo`03o`00ooooooooo`0000;o
oooo00?o003oooooooooool0Eoooool2o`0002Cooooo00?o0000ooooooooool00oooool2o`0000Oo
oooo00Co003oooooool00?oo003o0_ooool01?l00?ooooooooooool00?l3ooooo`04o`00oooooooo
ooooo`00o`;ooooo00?o003oooooooooool00_l00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo
00?o003oooooooooool01?ooool01?l00?ooooooooooool00?l[ooooo`03o`00oooooooooooo00?o
oooo0_l00?l00ooooooo003oooooo`09ooooo`03o`00oooooooo003o00?ooooo00?o003ooooooooo
ool00_l00?l2ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`02oooo
o`05o`00oooooooo003oooooool00?l00_ooool2o`00o`03ooooool00?oooooo00;o003o00Oooooo
o`00ooooooooooooo`00oooooooo003o00;ooooo00Co003oooooool00?oooooo0_l00?l00ooooooo
003oooooo`02o`00o`03ooooool00?oo003o00Gooooo00?o003oooooooooool00_l00?l2ooooo`;o
003o00Goooooo`00ool00?ooooooo`00o`04ooooo`03o`00oooooooo003o00Cooooo0_l0000@oooo
o`007Oooool00ol0003oooooooooo`1Hooooo`06o`00ooooooooooooool00?oooooo003o1_ooool0
0ol0003oooooooooo`07ooooo`04ool00?ooooooooooo`00oe[ooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`05ooooo`;o003o0_ooool01?l00?ooooooo`00ool00?l2ooooo`04o`00
ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o0_ooool01Ol00?oooooooooooooooooo
003o00;ooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool00?l2ooooo`05o`00
ooooooooooooooooool00?l09oooool01?l00?ooooooo`00ool00?l5ooooo`03o`000?oooooooooo
00Sooooo00Co003oooooool00?oo003o0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o00Go
ooooo`00oooooooo003oooooo`02o`00o`;ooooo00?o003oooooool00?l00oooool2o`00o`03oooo
ool00?oooooo00?ooooo0_l00?l00ooooooo003oooooo`02o`00o`?ooooo0_l00?l3ooooo`03o`00
oooooooooooo00;ooooo0_l00?l02?oooooo003oo`00oooooooo003oooooool00?oooooo0_l00?l0
0ooooooo003oooooo`03ooooo`05o`00oooooooo003oo`00ooooool00_l00?l2ooooo`03o`00oooo
oooooooo00Kooooo00?o0000ooooooooool03_ooool001gooooo00?o0000ooooooooool0F?ooool0
1_l00?oooooooooooooo003oooooo`00o`Kooooo00?o0000ooooooooool01Oooool00ol00?oooooo
ool00002ooooo`03o`00oooooooooooo05Sooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`05ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o0_ooool2o`00
o`03ooooool00?oooooo00;ooooo00?o003oooooooooool00_l00?l2ooooo`04o`00oooooooooooo
o`00o`;ooooo00Go003oooooooooooooooooo`00o`02ooooo`04o`00ooooooooooooo`00o`?ooooo
00?o003oooooooooool09Oooool01?l00?ooooooo`00ool00?l2ooooo`;o003o00?oooooo`00oooo
ool02Oooool01?l00?ooooooo`00ool00?l2ooooo`03o`00oooooooooooo00;o003o00Goooooo`00
ooooooooooooo`00o`03ooooo`;o003o00Goooooo`00ool00?ooooooo`00o`04ooooo`06o`00oooo
oooo003oo`00oooooooo003o1_ooool2o`00o`04ooooool00?ooooooo`00o`;ooooo00Ko003ooooo
ool00?oo003oooooool00?l2ooooo`08o`00oooooooo003oo`00oooooooo003oooooool00?l2oooo
o`04o`00oooooooo003oo`00o`;ooooo00Ko003oooooooooooooooooo`00ooooool2o`00o`;ooooo
0_l00?l00ooooooo003oooooo`04ooooo`03o`000?oooooooooo00kooooo000Mooooo`03o`000?oo
oooooooo05_ooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00oooo
ooooo`0005gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`05ooooo`;o003o00Go
ooooo`00ool00?ooooooo`00o`03ooooo`03o`00oooooooooooo00;o003o00?oooooo`00ool00?l0
0_ooool01_l00?oooooooooooooooooo003oooooo`;o003o0_ooool00ol00?ooooooooooo`03oooo
o`;o003o0_ooool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00?o
003oooooooooool08Oooool2o`00o`;ooooo0_l00?l00ooooooo003oooooo`0<ooooo`04o`00oooo
ooooooooo`00o`?ooooo00Co003oooooool00?oo003o0_ooool01?l00?ooooooooooool00?l2oooo
o`;o003o0oooool01?l00?ooooooooooool00?l2ooooo`04o`00oooooooo003oooooo`;o003o00Co
ooooo`00oooooooo003o0_ooool01_l00?ooooooo`00ool00?ooooooo`00o`;ooooo00Go003ooooo
ool00?ooooooo`00o`05ooooo`04o`00oooooooo003oooooo`;o003o0_ooool00ol00?oooooooooo
o`02o`00o`03ooooool00?oooooo00;ooooo00Oo003oooooool00?ooooooo`00oooooooo003o00Go
oooo00?o0000ooooooooool03_ooool001gooooo0_l0001Looooo`03ool00?oooooo003o00Kooooo
00?o0000ooooooooool01Oooool00ol00?ooooooool00002ooooo`03o`00oooooooooooo05Oooooo
0_l0000Zooooo`;o00001oooool01Ol00?ooooooo`00ool00?oooooo00;o003o0_ooool01_l00?oo
oooooooooooooooo003oooooo`;o003o0_ooool00ol00?ooooooooooo`02o`00o`;ooooo00Co003o
oooooooooooo003o0_ooool00ol00?ooooooooooo`04ooooo`04o`00ooooooooooooo`00o`?ooooo
00Co003ooooooooooooo003o0_ooool01Ol00?oooooooooooooooooo003o01gooooo00?o003ooooo
ooooool00oooool2o`00o`03ooooool00?oooooo00Wooooo00?o003oooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00;ooooo00Co003oooooool00?oo003o0oooool00ol00?ooooooo`00
o`02ooooo`05o`00oooooooo003oooooool00?l00_ooool2o`00o`03ooooool00?oooooo00;o003o
00?oooooo`00ooooool00_l00?l02?oooooo003ooooooooooooo003oooooool00?oooooo0_l00?l0
0ooooooo003oooooo`02o`00o`03ooooool00?oooooo00?ooooo00Go003oooooool00?oo003ooooo
o`02o`00o`05ooooool00?ooooooo`00ooooool00_l00?l00ooooooo003oooooo`03ooooo`03o`00
oooooooo003o00Cooooo0_l0000@ooooo`007Oooool00ol0003oooooooooo`1Hooooo`06o`00oooo
ooooooooool00?oooooo003o1_ooool00ol0003oooooooooo`07ooooo`04ool00?ooooooooooo`00
oe[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`05ooooo`;o003o0_ooool01?l0
0?ooooooo`00ool00?l2ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o
0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Co003ooooooooooooo003o0_ooool2o`00
o`;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`;ooooo00Co003ooooooooooooo003o0_oo
ool2o`00oagooooo00Co003oooooool00?oo003o1Oooool00ol0003oooooooooo`08ooooo`04o`00
oooooooo003oo`00o`;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`03ooooool00?oo003o
00;ooooo0_l00?l2ooooo`04o`00oooooooo003oo`00o`;ooooo0_l00?l00ooooooo003oooooo`02
ooooo`05o`00oooooooo003oooooool00?l00_ooool01?l00?ooooooooooooooool2o`00o`?ooooo
00?o003oooooooooool00_ooool2o`00o`05ooooool00?oo003oooooool00?l00oooool01?l00?oo
ooooooooool00?l4ooooo`05o`00oooooooo003oo`00ooooool00_l00?l00ooooooo003oooooo`08
ooooo`03o`000?oooooooooo00kooooo000Mooooo`03o`000?oooooooooo05Sooooo00Ko003ooooo
ooooooooo`00ooooool00?l6ooooo`03o`000?oooooooooo00Gooooo00?o003ooooooooo00000_oo
ool00ol00?ooooooooooo`1Hooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01Ooo
ool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l00ooooooo
003oooooo`02ooooo`03o`00oooooooooooo00;o003o00?oooooo`00ooooool00_ooool01?l00?oo
ooooooooool00?l2ooooo`;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`05o`00oooooooo
ooooooooool00?l00_ooool00ol00?ooooooooooo`02o`00o`;ooooo00?o003oooooooooool06?oo
ool01?l00?ooooooo`00ool00?l2ooooo`;o003o00?oooooo`00ooooool02?ooool00ol00?oooooo
ooooo`02o`00o`;ooooo00?o003oooooooooool00_l00?l01Ooooooo003oo`00oooooooo003o00?o
oooo0_l00?l2ooooo`03o`00oooooooo003o00?ooooo0_l00?l01Ooooooo003oo`00oooooooo003o
00Kooooo0_l00?l01?oooooo003oooooool00?l2ooooo`06o`00oooooooo003oo`00oooooooo003o
0_ooool02?l00?ooooooo`00ool00?ooooooo`00oooooooo003o0_ooool01_l00?ooooooo`00ool0
0?ooooooo`00o`Cooooo00[o003oooooool00?oo003oooooool00?ooooooo`00oooooooo003o1Ooo
ool00ol0003oooooooooo`0>ooooo`007Oooool00ol0003oooooooooo`1Hooooo`04o`00oooooooo
ooooool000Sooooo00?o0000ooooooooool01Oooool00ol00?ooooooool0001Mooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool01?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo
00?o003oooooooooool00_l00?l2ooooo`;o003o00Coooooo`00ool00?oooooo0_l00?l3ooooo`04
o`00oooooooo003oo`00o`;ooooo00?o003oooooooooool00oooool2o`00o`;ooooo00Co003ooooo
oooooooo003o0_ooool2o`00o`;ooooo00Co003ooooooooooooo003o0oooool01?l00?oooooooooo
ool00?lLooooo`;o003o0_ooool2o`00o`03ooooool00?oooooo00cooooo00Co003ooooooooooooo
003o0_ooool2o`00o`03ooooool00?oooooo00;ooooo00Co003ooooooooooooo003o0_ooool2o`00
o`;ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooo003o00;ooooo00Go003o
ooooool00?ooooooo`00o`02ooooo`;o003o00Coooooo`00oooooooo003o0_ooool01?l00?oooooo
o`00ool00?l4ooooo`06o`00oooooooo003oooooool00?oooooo0_l00?l2ooooo`07o`00oooooooo
003oooooool00?ooooooo`00o`03ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`05oooo
o`03o`000?oooooooooo00kooooo000Mooooo`;o0000G?ooool00ooo003oooooo`00o`06ooooo`03
o`000?oooooooooo00Gooooo00?o003ooooooooo00000_ooool00ol00?ooooooooooo`1Gooooo`;o
0000:_ooool2o`0000Oooooo00Go003oooooool00?oo003oooooo`02o`00o`;ooooo00Ko003ooooo
ooooooooooooo`00ooooool2o`00o`03ooooool00?oooooo00;ooooo0_l00?l00ooooooo003oo`00
o`02ooooo`04o`00ooooooooooooo`00o`Kooooo00Co003ooooooooooooo003o0oooool01?l00?oo
ooooooooool00?l2ooooo`05o`00ooooooooooooooooool00?l00_ooool01?l00?ooooooooooool0
0?lGooooo`03o`00oooooooo003o00?ooooo0_l00?l00ooooooo003oooooo`08ooooo`04o`00oooo
ooooooooo`00o`?ooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooo`00ool00?l2oooo
o`03o`00oooooooooooo00;o003o00?oooooo`00ool00?l00_ooool00ol00?ooooooooooo`02o`00
o`08ooooool00?oo003oooooool00?ooooooo`00ooooool2o`00o`08ooooool00?ooooooooooool0
0?ooooooo`00ooooool2o`00o`07ooooool00?oo003oooooool00?ooooooo`00o`02ooooo`04o`00
oooooooo003oooooo`;o003o00Soooooo`00ool00?ooooooo`00oooooooo003oooooo`;o003o00?o
ooooo`00ooooool00oooool00ol00?ooooooo`00o`04ooooo`;o00004?ooool001gooooo00?o0000
ooooooooool0F?ooool01_l00?oooooooooooooo003oooooo`00o`Kooooo00?o0000ooooooooool0
1oooool01?oo003oooooooooool00?mJooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool01?ooool00ol00?ooooooo`00o`02ooooo`06o`00oooooooo003oo`00oooooooo003o0oooool2
o`00o`;ooooo00Co003oooooool00?oo003o0_ooool01_l00?oooooooooooooooooo003oooooo`;o
003o0_ooool00ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooooooooooo003o0_ooool2o`00
o`;ooooo00Co003ooooooooooooo003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Co
003ooooooooooooo003o0oooool00ol00?ooooooooooo`0>ooooo`04o`00ooooooooooooo`00o`Go
oooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooooooo
oooo003o0_ooool2o`00o`03ooooool00?oo003o00;ooooo00Co003ooooooooooooo003o0_ooool2
o`00o`;ooooo0_l00?l00ooooooo003oooooo`02ooooo`05o`00oooooooo003oooooool00?l00_oo
ool01_l00?ooooooo`00ool00?ooooooo`00o`?ooooo00So003oooooooooooooooooo`00oooooooo
003oooooo`;o003o1?ooool01Ol00?oooooooooooooooooo003o00Cooooo0_l00?l00ooooooo003o
ooooo`02o`00o`03ooooool00?oooooo00Sooooo00?o0000ooooooooool03_ooool001gooooo00?o
0000ooooooooool0F?ooool01_l00?oooooooooooooo003oooooo`00o`Kooooo00?o0000oooooooo
ool01oooool01?oo003oooooooooool00?mJooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool01?ooool01?l00?ooooooooooooooool2o`00o`04ooooool00?oo003oooooo`;o003o0_oo
ool00ol00?ooooooooooo`02o`00o`;ooooo00?o003oooooooooool00_l00?l00ooooooo003ooooo
o`02ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l2ooooo`04o`00ooooooooooooo`00o`;o
oooo00Go003oooooooooooooooooo`00o`02ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003o
oooooooooooo003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooooooooooo00000_ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00;o003o0_ooool01?l00?ooooooooooool00?l2oooo
o`;o003o00?oooooo`00ool00?l00_ooool01ol00?oooooooooooooooooo003oooooool00?l00ooo
ool2o`00o`04ooooool00?ooooooooooo`;o003o0oooool01?l00?ooooooo`00ool00?l2ooooo`06
o`00oooooooo003oooooool00?oooooo0_l00?l01_oooooo003ooooooooooooo003oooooo`;o003o
00Coooooo`00oooooooo003o0_ooool01_l00?ooooooo`00ool00?ooooooo`00o`;ooooo00Co003o
ooooool00?oooooo0_l00?l00ooooooo003oooooo`02o`00o`Kooooo00?o0000ooooooooool03_oo
ool001gooooo00?o0000ooooooooool0F?ooool01?l00?oooooooooooooo0008ooooo`03o`000?oo
oooooooo00Gooooo00?o003ooooooooo0000GOooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00Cooooo00Go003oooooool00?ooooooo`00o`05ooooo`;o003o0_ooool2o`00o`04oooo
ool00?ooooooooooo`;o003o0_ooool2o`00o`05ooooool00?oo003oooooool00?l01_ooool2o`00
o`03ooooool00?oo003o00;ooooo00?o003oooooooooool00_l00?l00ooooooo003oo`00o`02oooo
o`03o`00oooooooooooo00;o003o0_ooool00ol00?ooooooooooo`03ooooo`05o`00oooooooooooo
ooooool00?l00_ooool00ol00?ooooooooooo`0=ooooo`;o003o0_ooool2o`00o`05ooooool00?oo
ooooooooool00?l02_ooool01?l00?ooooooooooool00?l2ooooo`04o`00ooooooooooooo`00o`Ko
oooo00?o003oooooooooool00_l00?l2ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003ooooo
ool00?l00_ooool01Ol00?ooooooo`00oooooooo003o00;ooooo0_l00?l3ooooo`05o`00oooooooo
ooooo`00ooooool00_l00?l3ooooo`;o003o00?oooooo`00ooooool00_l00?l02Ooooooo003ooooo
oooooooo003oooooool00?ooooooo`00o`05ooooo`04o`00oooooooo003oooooo`;o003o1_ooool0
0ol0003oooooooooo`0>ooooo`007Oooool2o`0005cooooo00?oo`00ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`05o`00ooooooooo`00ooooool00?l0F_ooool2o`0002[ooooo0_l00007
ooooo`;o003o00Coooooo`00oooooooo003o0oooool01_l00?oooooooooooooooooo003oooooo`;o
003o00?oooooo`00ooooool00oooool01Ol00?ooooooo`00ool00?oooooo00;o003o0_ooool00ol0
0?ooooooooooo`03ooooo`;o003o0_ooool00ol00?ooooooooooo`02o`00o`03ooooool00?oooooo
00;ooooo00Ko003oooooooooooooooooo`00ooooool2o`00o`;ooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Oooooo00Co003ooooooooooooo003o
0oooool2o`00o`05ooooool00?ooooooooooool00?l01_ooool00ol00?ooooooooooo`02o`00o`;o
oooo00Co003ooooooooooooo003o0oooool01?l00?ooooooo`00ool00?l2ooooo`03o`00oooooooo
oooo00;o003o00?oooooo`00ool00?l00_ooool00ol00?ooooooooooo`02o`00o`05ooooool00?oo
003oooooool00?l00oooool2o`00o`08ooooool00?ooooooooooool00?ooooooo`00ooooool2o`00
o`05ooooool00?oo003oooooool00?l01?ooool01_l00?ooooooo`00ool00?ooooooo`00o`;ooooo
00Co003oooooool00?oooooo0_l00?l01?oooooo003oooooool00?l4ooooo`;o003o1Oooool2o`00
013ooooo000?ooooo`?o00000oooool3o`0000Gooooo00?o0000ooooooooool0F?ooool01Ol00?oo
oooooooooooo003o003o00Oooooo00?o0000ooooooooool01Oooool01Ol00?ooooooool00?oooooo
003o05_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`04ooooo`03o`00oooooooo
003o00;ooooo00Ko003oooooool00?oo003oooooool00?l2ooooo`03o`00oooooooo003o00;ooooo
00Co003oooooool00?oo003o0_ooool01_l00?oooooooooooooooooo003oooooo`;o003o0_ooool0
0ol00?ooooooooooo`02o`00o`03ooooool00?oooooo00;ooooo00Ko003oooooooooooooooooo`00
ooooool2o`00o`;ooooo00?o003oooooooooool00_l00?l2ooooo`04o`00ooooooooooooo`00o`;o
oooo00Go003oooooooooooooooooo`00o`02ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003o
ooooooooool00oooool01Ol00?oooooooooooooooooo003o00;ooooo00Co003ooooooooooooo003o
2Oooool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l00ooo
oooo003oo`00o`02ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l2ooooo`03o`00oooooooo
oooo00;o003o0_ooool01?l00?ooooooo`00ool00?l3ooooo`06o`00oooooooo003oo`00oooooooo
003o0oooool02?l00?oooooooooooooooooo003oooooool00?oooooo0_l00?l4ooooo`04o`00oooo
ooooooooooooo`;o003o0oooool2o`00o`03ooooool00?oooooo00;o003o00?oooooo`00ooooool0
2?ooool00ol0003oooooooooo`0>ooooo`004?ooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Hooooo`05o`00ooooooooooooool00?l0
0?l01oooool00ol0003oooooooooo`07ooooo`03ool00?oooooo003o05_ooooo00?o0000oooooooo
ool08_ooool2o`0000Cooooo00?o0000ooooooooool01?ooool01ol00?ooooooooooool00?oooooo
o`00ooooool00_l00?l01Ooooooo003ooooooooooooo003o00?ooooo0_l00?l2ooooo`03o`00oooo
oooooooo00;o003o00?oooooo`00ooooool00_ooool01?l00?ooooooooooool00?l2ooooo`;o003o
0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o0_ooool01?l00?ooooooooooool00?l2oooo
o`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o0_ooool2o`00o`;ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;o003o0_oo
ool01?l00?ooooooooooool00002ooooo`03o`00oooooooooooo00Cooooo00Co003ooooooooooooo
003o0oooool01?l00?ooooooooooool00?l2ooooo`;o003o00?oooooo`00ool00?l00_ooool01ol0
0?oooooooooooooooooo003oooooool00?l00oooool01?l00?ooooooooooool00?l2ooooo`;o003o
0_ooool00ol00?ooooooooooo`02o`00o`;ooooo00Co003oooooool00?oo003o0_ooool2o`00o`04
ooooool00?oo003oooooo`;o003o00Koooooo`00oooooooo003oooooool00?l2ooooo`03o`00oooo
oooo003o00;ooooo00Oo003ooooooooooooo003oooooool00?oooooo00;o003o00?oooooo`00oooo
ool00_l00?l6ooooo`03o`000?oooooooooo00kooooo000@ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Hooooo`05o`00ooooooooooooool00?l0
0?l01oooool00ol0003oooooooooo`05ooooo`03o`00ooooooooo`0005gooooo00?o0000oooooooo
ool08Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Cooooo00?o003oool0
0?oo00002_oo00000ol00?ooo`00ool00007ool00003o`00oooo003oo`0000[oo`0000?oooooool0
0?oo00001ooo00000oooooooo`00ool00007ool00003oooooooo003oo`0000[oo`0000?oooooool0
0?oo00001ooo00000oooooooo`00ool0000:ool00003oooooooo003oo`0000Ooo`0000?oooooool0
0?oo00001ooo00000oooooooo`00ool0000:ool00003oooooooo003oo`0000Ooo`0000?oooooool0
0?oo00002_oo00000oooooooo`00ool00007ool00003oooooooo003oo`0000[oo`0000?o003oool0
0?oo00001ooo00000ol00?ooo`00ool00007ool00003o`00oooo003oo`0000Coo`000oooool00ol0
003oooooooooo`0>ooooo`004?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo0_l0001Looooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol00?oo
ooooool00?oooooo003o05[ooooo0_l0000Sooooo`04o`000?ooooooooooo`0000?ooooo2?l0000<
ool00003o`000?oo003oo`0000Ooo`0000?o0000ool00?oo00002_oo00000ol0003oo`00ool00007
ool00003o`000?oo003oo`0000Ooo`0000?o0000ool00?oo00002_oo00000ol0003oo`00ool00007
ool00003o`000?oo003oo`0000[oo`0000?o0000ool00?oo00001ooo00000ol0003oo`00ool00007
ool00003o`000?oo003oo`0000[oo`0000?o0000ool00?oo00001ooo00000ol0003oo`00ool0000:
ool00003o`000?oo003oo`0000Ooo`0000?o0000ool00?oo00002_oo00000ol00?ooo`00ool00007
ool00003o`00oooo003oo`0000Ooo`0000?o0000ool00?oo00001?oo0004o`00013ooooo000@oooo
o`04o`000?ooooooooooooooo`Co00001Oooool00ol0003oooooooooo`1Hooooo`05o`00oooooooo
ooooool00?l00?l01oooool00ol0003oooooooooo`05ooooo`05o`00ooooooooo`00ooooool00?l0
Foooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool01?ooool00ol00?ooo`00ool0000:ool00003o`00oooo003oo`0000Ooo`0000?o003oool00?oo
00002_oo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo
00002_oo00000oooooooo`00ool00007ool00003oooooooo003oo`0000[oo`0000?oooooool00?oo
00001ooo00000oooooooo`00ool00007ool00003oooooooo003oo`0000[oo`0000?oooooool00?oo
00001ooo00000oooooooo`00ool0000:ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo
00002_oo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Ooo`0000?o003oool00?oo
00001?oo0003ooooo`03o`000?oooooooooo00kooooo000?ooooo`;o00000oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo05Wooooo00Co003ooooooooo003o003o1oooool00ol0003o
ooooooooo`07ooooo`03ool00?oooooo003o05_ooooo00?o0000ooooooooool08Oooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00Cooooo00Oo003ooooooooooooo003oooooool0
0?oooooo00;o003o00Goooooo`00ooooooooooooo`00o`03ooooo`;o003o00Woooooo`00ool00?oo
ooooo`00oooooooo003oooooool00?l00oooool01?l00?ooooooo`00ool00?l2ooooo`;o003o0_oo
ool00ol00?ooooooo`00o`03ooooo`;o003o0_ooool01?l00?ooooooo`00ool00?l2ooooo`03o`00
oooooooooooo00;o003o00?oooooo`00ool00?l00_ooool00ol00?ooooooooooo`02o`00o`;ooooo
00?o003oooooooooool00oooool2o`00o`;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`;o
oooo00Co003ooooooooooooo00000_ooool00ol00?ooooooooooo`04ooooo`04o`00oooooooooooo
o`00o`?ooooo00Co003ooooooooooooo003o0_ooool00ol00?ooooooooooo`02o`00o`;ooooo00Co
003ooooooooooooo003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003ooooooooo
ool00_l00?l2ooooo`03o`00oooooooooooo00;o003o0_ooool01?l00?ooooooo`00ool00?l2oooo
o`06o`00ooooooooooooooooool00?oooooo0_l00?l01_oooooo003oooooool00?ooooooo`00o`;o
oooo0_l00?l3ooooo`05o`00ooooooooooooo`00ooooool00_l00?l01?oooooo003oooooool00?l2
ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool03_ooool0013ooooo00Co0000oooo
oooooooooooo1Ol00004ooooo`03o`000?oooooooooo05Wooooo00Co003ooooooooo003o003o1ooo
ool00ol0003oooooooooo`05ooooo`03o`00ooooooooo`0005gooooo00?o0000ooooooooool08Ooo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Cooooo00Co003oooooool00?oo
003o1?ooool02_l00?ooooooo`00ool00?ooooooo`00oooooooo003oooooool00?l3ooooo`06o`00
oooooooo003oooooool00?oooooo0_l00?l00ooooooo003oooooo`05ooooo`;o003o00?oooooo`00
ool00?l01Oooool00ol00?ooooooooooo`02o`00o`;ooooo00?o003oooooooooool00_l00?l00ooo
oooo003oooooo`05ooooo`03o`00oooooooooooo00;o003o00?oooooo`00ool00?l00_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00Go003oooooooooooooooooo`00o`02
ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l2ooooo`03o`00oooooooooooo00Cooooo00Co
003ooooooooooooo003o0_ooool00ol00?ooooooooooo`04ooooo`04o`00ooooooooooooo`00o`?o
oooo00Co003ooooooooooooo003o0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o0_ooool0
0ol00?ooooooooooo`02o`00o`;ooooo00Oo003oooooooooooooooooo`00oooooooo003o00?ooooo
00Ko003oooooool00?ooooooo`00ooooool2o`00o`07ooooool00?oo003oooooool00?ooooooo`00
o`04ooooo`07o`00ooooooooooooo`00oooooooo003oooooo`02o`00o`Kooooo00?o0000oooooooo
ool03_ooool001gooooo0_l0001Looooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool01Ol00?ooooooool00?oooooo003o05[ooooo0_l0000Tooooo`;o00001?ooool2o`0000Oo
oooo0_l00?l00ooooooo003oo`00o`04ooooo`04o`00ooooooooooooooooo`;o003o00?oooooo`00
ooooool00_l00?l3ooooo`05o`00oooooooo003oo`00ooooool00_l00?l00ooooooo003oo`00o`02
ooooo`03o`00oooooooooooo00;o003o00?oooooo`00ool00?l00_ooool2o`00o`04ooooool00?oo
ooooooooo`;o003o0oooool01Ol00?ooooooo`00ool00?oooooo00;o003o0_ooool01?l00?oooooo
ooooool00?l2ooooo`;o003o0_ooool01?l00?ooooooooooool00?l3ooooo`04o`00oooooooooooo
o`00o`Kooooo00Co003ooooooooooooo003o0_ooool00ol00?ooooooooooo`02o`00o`Wooooo00Co
003ooooooooooooo003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Co003ooooooooo
oooo003o0_ooool2o`00o`;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`03ooooool00?oo
oooo00;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`;ooooo00?o003oooooooooool00_l0
0?l00ooooooo003oooooo`02ooooo`03o`00oooooooooooo00;o003o00Soooooo`00oooooooooooo
o`00oooooooo003oooooo`;o003o0_ooool00ol00?ooooooooooo`03ooooo`;o003o1Oooool2o`00
013ooooo000Mooooo`03o`000?oooooooooo05Wooooo00Co003ooooooooo003o003o1oooool00ol0
003oooooooooo`06ooooo`04o`00oooo003oooooo`00oe_ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`04ooooo`03o`00oooooooo003o00;ooooo0_l00?l00ooooooo003oooooo`02
o`00o`04ooooool00?ooooooo`00o`;ooooo00?o003oooooool00?l00_ooool00ol00?oooooooooo
o`02ooooo`05o`00oooooooo003oo`00ooooool00_l00?l5ooooo`03o`00oooooooooooo00;o003o
0oooool00ol00?ooooooo`00o`02ooooo`04o`00ooooooooooooooooo`;o003o00Coooooo`00ool0
0?oooooo0_l00?l2ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooooooo`02
o`00o`03ooooool00?oo003o00;ooooo00?o003oooooooooool01?ooool01?l00?ooooooooooool0
0?l5ooooo`;o003o0_ooool00ol00?ooooooooooo`07ooooo`04o`00ooooooooooooo`00o`;ooooo
0_l00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l2ooooo`04o`00ooooooooooooo`00
o`?ooooo00Co003oooooool00?oo003o0_ooool00ol00?ooooooooooo`02o`00o`03ooooool00?oo
003o00;ooooo00?o003oooooooooool00_l00?l01Ooooooo003oo`00oooooooo003o00Cooooo00Ko
003ooooooooooooo003oooooool00?l3ooooo`;o003o00Goooooo`00ool00?ooooooo`00o`03oooo
o`03o`00oooooooooooo00Gooooo00?o0000ooooooooool03_ooool001gooooo00?o0000oooooooo
ool0FOooool01?l00?ooooooool00?l00?l7ooooo`03o`000?oooooooooo00Oooooo00?oo`00oooo
ool00?l0Foooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Cooooo00?o003ooooo
ooooool00_ooool2o`00o`04ooooool00?ooooooo`00o`;ooooo00?o003oooooooooool00_ooool0
1ol00?ooooooo`00ool00?ooooooo`00ooooool00_l00?l3ooooo`;o003o00Ooooooo`00ool00?oo
ooooo`00oooooooo003o00;ooooo00Co003oooooool00?oo003o0_ooool2o`00o`;ooooo00Co003o
ooooool00?oo003o0_ooool01_l00?oooooooooooooooooo003oooooo`;o003o0_ooool00ol00?oo
ooooooooo`02o`00o`03ooooool00?oo003o00Gooooo0_l00?l2ooooo`04o`00ooooooooooooo`00
o`Wooooo00Co0000ooooool00?oo003o1_ooool00ol00?ooooooooooo`0:ooooo`04o`00oooooooo
ooooo`00o`?ooooo00Co003ooooooooooooo003o0_ooool01Ol00?oooooooooooooooooo003o00;o
oooo00?o003oooooooooool00_l00?l2ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003ooooo
ool00?l00oooool01_l00?oooooooooooooooooo003oooooo`;o003o00?oooooo`00ool00?l00_oo
ool00ol00?ooooooooooo`02o`00o`;ooooo00?o003oooooooooool00_l00?l01?oooooo003oo`00
ooooool2o`00o`[ooooo00?o0000ooooooooool03_ooool001gooooo00?o0000ooooooooool0FOoo
ool01?l00?ooooooool00?l00?l7ooooo`03o`000?oooooooooo00Kooooo00?o003oool00?ooool0
G?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Cooooo00Co003oooooool00?oo
003o1?ooool01ol00?ooooooo`00ool00?ooooooo`00ooooool00_l00?l4ooooo`04o`00oooooooo
003oooooo`;o003o00?oooooo`00ooooool00oooool2o`00o`05ooooool00?ooooooo`00ooooool0
0_l00?l5ooooo`03o`00oooooooooooo00;o003o0_ooool00ol00?ooooooooooo`02o`00o`03oooo
ool00?oooooo00Gooooo00?o003oooooooooool00_l00?l00ooooooo003oo`00o`02ooooo`05o`00
ooooooooooooooooool00?l03?ooool01Ol00?ooooooooooool00?oooooo00;o003o0_ooool2o`00
o`;ooooo00?o003oooooooooool03Oooool01Ol00?oooooooooooooooooo003o00;ooooo00Co003o
oooooooooooo003o0oooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooooooo00;o003o
0_ooool00ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooooooooooo003o0_ooool01_l00?oo
oooooooooooooooo003oooooo`;o003o0_ooool2o`00o`04ooooool00?oo003oooooo`;o003o1Ooo
ool00ol00?ooooooooooo`02o`00o`;ooooo0_l00?l6ooooo`03o`000?oooooooooo00kooooo000M
ooooo`;o0000G?ooool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00Co003o
ool00?oooooo003oF_ooool2o`0002[ooooo0_l00007ooooo`;o003o00?oooooo`00ool00?l01?oo
ool01?l00?ooooooooooooooool2o`00o`03ooooool00?oooooo00;o003o0oooool2o`00o`04oooo
ool00?ooooooo`00o`Gooooo00Co003oooooool00?oooooo0_l00?l02?oooooo003oo`00oooooooo
003oooooool00?oooooo0_l00?l00ooooooo003oo`00o`03ooooo`05o`00oooooooo003oo`00oooo
ool00_l00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l2ooooo`04o`00oooooooooooo
o`00o`;ooooo0_l00?l9ooooo`05o`00ooooooooooooo`00ooooool00_l00?l2ooooo`;o003o5_oo
ool01?l00?ooooooooooool00?l2ooooo`05o`00ooooooooooooooooool00?l00_ooool01?l00?oo
ooooooooool00?l2ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`02
o`00o`;ooooo00?o003oooooooooool00_l00?l00ooooooo003oooooo`02ooooo`03o`00oooooooo
oooo00;o003o00Coooooo`00oooooooooooo0_l00?l2ooooo`;o003o1Oooool00ol00?oooooooooo
o`02o`00o`Gooooo0_l0000@ooooo`007Oooool00ol0003oooooooooo`1Iooooo`04o`00oooooooo
o`00o`00o`Oooooo00?o0000ooooooooool01_ooool01?l00?ooo`00ooooool00?mKooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool01_ooool2o`00o`04ooooool00?oo003oooooo`;o
003o00?oooooo`00ooooool00_ooool2o`00o`04ooooool00?ooooooo`00o`;ooooo00?o003ooooo
ooooool00_ooool01Ol00?ooooooo`00ool00?oooooo00;o003o1Oooool00ol00?ooooooooooo`02
o`00o`?ooooo00?o003oooooool00?l00_ooool01ol00?ooooooooooool00?ooooooo`00ooooool0
0_l00?l01Ooooooo003oo`00oooooooo003o00Cooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`02o`00o`03ooooool00?oo003o00;ooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`03ooooo`;o003o00?oooooo`00ooooool05_ooool01?l00?ooooooooooool00?l3oooo
o`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool00_l00?l2ooooo`04o`00oooooooo
ooooo`00o`;ooooo0_l00?l2ooooo`03o`00oooooooooooo00;o003o00Goooooo`00ool00?oooooo
o`00o`04ooooo`05o`00ooooooooooooo`00ooooool00_l00?l2ooooo`;o003o00Goooooo`00ool0
0?ooooooo`00o`03ooooo`;o003o1_ooool00ol0003oooooooooo`0>ooooo`007Oooool00ol0003o
ooooooooo`1Iooooo`04o`00ooooooooo`00o`00o`Oooooo00?o0000ooooooooool01oooool00ooo
003oooooo`00o`1Kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool00oooool00ol0
0?ooooooooooo`03ooooo`;o003o00?oooooo`00ool00?l00oooool00ol00?ooooooooooo`02oooo
o`06o`00oooooooo003oo`00oooooooo003o0_ooool01?l00?ooooooooooooooool2o`00o`07oooo
ool00?oo003oooooool00?ooooooo`00o`02ooooo`08o`00oooooooo003oo`00oooooooo003ooooo
ool00?l2ooooo`06o`00oooooooo003oo`00oooooooo003o1?ooool01Ol00?ooooooo`00ool00?oo
oooo00;o003o0oooool01?l00?ooooooo`00ool00?l5ooooo`;o003o00?oooooo`00ool00?l00_oo
ool00ol00?ooooooooooo`07ooooo`04o`000?oooooo003oo`00o`Gooooo00?o003oooooooooool0
6?ooool01Ol00?oooooooooooooooooo003o00;ooooo00Co003ooooooooooooo003o0oooool01?l0
0?ooooooooooool00?l2ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o
0_ooool2o`00o`03ooooool00?oo003o00;ooooo00?o003oooooooooool00_l00?l5ooooo`;o003o
00Coooooo`00ool00?oooooo0_l00?l:ooooo`03o`000?oooooooooo00kooooo000Mooooo`03o`00
0?oooooooooo05Wooooo00Co003ooooooooo003o003o1oooool00ol0003oooooooooo`06ooooo`04
o`00oooo003oooooo`00oe_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`03oooo
o`05o`00ooooooooooooooooool00?l01?ooool2o`00o`05ooooool00?ooooooo`00ooooool00_l0
0?l4ooooo`04o`00oooooooo003oooooo`;o003o1?ooool02Ol00?ooooooo`00ool00?ooooooo`00
oooooooo003oooooo`02o`00o`Cooooo00Co003ooooooooooooooooo0_l00?l2ooooo`07o`00oooo
oooo003oooooool00?ooooooo`00o`05ooooo`;o003o0_ooool2o`00o`04ooooool00?oo003ooooo
o`;o003o0oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Oooooo00Co003ooooo
ool00?oo003o0_ooool2o`00o`03ooooool00?oooooo01Wooooo00Go003oooooooooooooooooo`00
o`02ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o0_ooool01Ol00?oo
oooooooooooooooo003o00;ooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooo`00ool0
0?l2ooooo`03o`00oooooooooooo00;o003o00?oooooo`00ool00?l01Oooool2o`00o`03ooooool0
0?oo003o00;ooooo0_l00?l6ooooo`03o`000?oooooooooo00kooooo000Mooooo`;o0000G?ooool0
0ooo003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o003oool00?ooool0Foooool2
o`0002[ooooo0_l00004ooooo`03o`00oooooooooooo00;o003o00?oooooo`00ool00?l01?ooool0
1?l00?ooooooo`00ooooool2o`00o`05ooooool00?oo003oooooool00?l00oooool2o`00o`03oooo
ool00?oo003o00Kooooo00Co003oooooool00?oooooo0_l00?l2ooooo`06o`00oooooooo003ooooo
ool00?oooooo0_l00?l00ooooooo003oo`00o`03ooooo`06o`00oooooooo003oo`00oooooooo003o
0oooool01?l00?ooooooooooool00?l2ooooo`;o003o00?oooooo`00ool00?l00_ooool00ol00?oo
ooooooooo`02o`00o`cooooo00Co003oooooool00?oo003o0_ooool2o`00ob3ooooo00Co003ooooo
oooooooo003o0_ooool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo
0_l00?l2ooooo`04o`00ooooooooooooo`00o`Kooooo00Co003ooooooooooooo003o0_ooool00ol0
0?ooooooooooo`02o`00o`;ooooo00?o003oooooooooool00oooool2o`00o`;ooooo0_l00?l5oooo
o`;o00004?ooool001gooooo00?o0000ooooooooool0FOooool01?l00?ooooooool00?l00?l7oooo
o`03o`000?oooooooooo00Kooooo00Co003oool00?oooooo003oFoooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool00_l00?l01?oooooo003oo`00oooo
ool2o`00o`03ooooool00?oooooo00;ooooo0_l00?l00ooooooo003oo`00o`03ooooo`03o`00oooo
oooo003o00;ooooo0_l00?l00ooooooo003oooooo`02o`00o`Cooooo00Co003ooooooooooooooooo
0_l00?l3ooooo`?o003o0_ooool01ol00?ooooooooooool00?ooooooo`00ooooool00_l00?l00ooo
oooo003oo`00o`05ooooo`;o003o1?ooool2o`00o`;ooooo0_l00?l01Ooooooo003oo`00oooooooo
003o00[ooooo00?o003oooooooooool00oooool2o`00o`03ooooool00?oooooo023ooooo00Co003o
oooooooooooo003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool0
0_l00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l00ooooooo003oooooo`02ooooo`06
o`00ooooooooooooooooool00?oooooo0_l00?l2ooooo`03o`00oooooooooooo00;o003o1Oooool0
0ol00?ooooooooooo`05ooooo`03o`000?oooooooooo00kooooo000Mooooo`03o`000?oooooooooo
05Wooooo00Co003ooooooooo003o003o1oooool00ol0003oooooooooo`07ooooo`03ool00?oooooo
003o05_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`03ooooo`04o`00oooooooo
ooooo`00o`;ooooo0_l00?l00ooooooo003oo`00o`03ooooo`03o`00oooooooooooo00;ooooo0_l0
0?l01?oooooo003oooooool00?l2ooooo`07o`00oooooooo003oo`00oooooooo003oooooo`02o`00
o`04ooooool00?ooooooo`00o`;ooooo00So003oooooool00?oo003oooooool00?ooooooo`00o`;o
oooo00Ko003oooooool00?oo003oooooool00?l4ooooo`05o`00oooooooo003oo`00ooooool00_l0
0?l3ooooo`04o`00oooooooo003oo`00o`Gooooo0_l00?l01Ooooooo003oo`00oooooooo003o00[o
oooo00Co0000ooooool00?oo003o1Oooool00ol00?ooooooooooo`0Rooooo`04o`00oooooooooooo
o`00o`?ooooo00Co003ooooooooooooo003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo
00?o003oooooooooool00_l00?l00ooooooo003oo`00o`02ooooo`03o`00oooooooooooo00;o003o
1Oooool00ol00?ooooooooooo`02o`00o`03ooooool00?oo003o00[ooooo00?o0000ooooooooool0
3_ooool001gooooo00?o0000ooooooooool0FOooool01?l00?ooooooool00?l00?l7ooooo`03o`00
0?oooooooooo00Kooooo00Co003oool00?oooooo003oFoooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo00?ooooo00Co003ooooooooooooo003o1Oooool2o`00o`05ooooool00?oooooo
o`00ooooool00_l00?l4ooooo`04o`00oooooooo003oooooo`;o003o1?ooool02?l00?ooooooo`00
ool00?ooooooo`00oooooooo003o0_ooool00ol00?ooooooo`00o`02ooooo`06o`00oooooooooooo
o`00oooooooo003o0_ooool01?l00?ooooooo`00ooooool2o`00o`Cooooo00Co003oooooool00?oo
003o0_ooool2o`00o`05ooooool00?oo003oooooool00?l00oooool2o`00o`Cooooo00?o003ooooo
ooooool02?ooool01?l00?ooooooo`00ool00?l3ooooo`03o`00oooooooo003o02Oooooo00Go003o
ooooooooooooooooo`00o`02ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo
003o0_ooool2o`00o`03ooooool00?oo003o00;ooooo00?o003oooooooooool00_l00?l00ooooooo
003oo`00o`05ooooo`;o003o00?oooooo`00ool00?l00_ooool00ol00?ooooooooooo`05ooooo`03
o`000?oooooooooo00kooooo000Mooooo`;o0000G?ooool00ooo003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o003oool00?ooool0Foooool2o`0002[ooooo0_l00004ooooo`04o`00
ooooooooooooo`00o`;ooooo0_l00?l4ooooo`;o003o0_ooool2o`00o`05ooooool00?oo003ooooo
ool00?l00oooool2o`00o`03ooooool00?oo003o00Kooooo00Ko003oooooool00?oo003oooooool0
0?l2ooooo`04o`00oooooooo003oooooo`;o003o00?oooooo`00ooooool00_l00?l3ooooo`;o003o
00?oooooo`00ooooool00oooool2o`00o`;ooooo00?o003oooooooooool00_l00?l00ooooooo003o
o`00o`05ooooo`03o`00oooooooooooo00_ooooo00Co003oooooool00?oo003o0_ooool2o`00obWo
oooo00Go003oooooooooooooooooo`00o`02ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003o
oooooooooooo003o1_ooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooooooo00;o003o
0_ooool00ol00?ooooooooooo`03ooooo`;o003o0_ooool00ol00?ooooooooooo`04ooooo`;o0000
4?ooool001gooooo00?o0000ooooooooool0Foooool00ooo003o003oooooo`06ooooo`03o`000?oo
oooooooo00Kooooo00Co003oool00?oooooo003oFoooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo00Kooooo00?o003oooooooooool00_l00?l01Ooooooo003ooooooooooooo003o00?o
oooo0_l00?l00ooooooo003oo`00o`02ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l00ooo
oooo003oooooo`02o`00o`Cooooo00Co003ooooooooooooooooo0_l00?l3ooooo`;o003o0oooool2
o`00o`03ooooool00?oooooo00;o003o00?oooooo`00ooooool00_l00?l4ooooo`03o`00oooooooo
oooo00Cooooo0_l00?l2ooooo`;o003o00Goooooo`00ool00?ooooooo`00o`0:ooooo`03o`00oooo
oooooooo00?ooooo0_l00?l00ooooooo003oooooo`0Zooooo`04o`00ooooooooooooo`00o`;ooooo
00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00;o003o1Oooool01?l00?oo
ooooooooool00?l2ooooo`;o003o0_ooool00ol00?ooooooooooo`02o`00o`Gooooo00?o003ooooo
ooooool01Oooool00ol0003oooooooooo`0>ooooo`003_ooool5o`0000?ooooo0_l00005ooooo`03
o`000?oooooooooo05Wooooo00Co003ooooooooo003o003o1oooool00ol0003oooooooooo`07oooo
o`03ool00?oooooo003o05_ooooo00?o0000ooooooooool08Oooool3o`0000Cooooo00?o0000oooo
ooooool00oooool01?l00?ooooooooooool00?l2ooooo`;o003o00?oooooo`00ool00?l00_ooool0
0ol00?ooooooooooo`03ooooo`;o003o00?oooooo`00ool00?l01Oooool2o`00o`03ooooool00?oo
oooo00;o003o00?oooooo`00ooooool00_l00?l00ooooooo003oooooo`02o`00o`04ooooool00?oo
ooooo`00o`;ooooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`02ooooo`05o`00oooo
oooo003oo`00ooooool00_l00?l3ooooo`05o`00oooooooo003oo`00ooooool00_l00?l2ooooo`;o
003o00Goooooo`00ool00?ooooooo`00o`0:ooooo`03o`000?oooooo003o00?ooooo00Co003ooooo
oooooooo003o<Oooool01Ol00?oooooooooooooooooo003o00;ooooo00Co003ooooooooooooo003o
0_ooool2o`00o`;ooooo00Co003ooooooooooooo003o1_ooool00ol00?ooooooooooo`02o`00o`03
ooooool00?oo003o00[ooooo00?o0000ooooooooool03_ooool000oooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo05Wooooo00Co003ooooo
oooo003o003o1oooool00ol0003oooooooooo`06ooooo`04o`00oooo003oooooo`00oe_ooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Co
003ooooooooooooo003o0_ooool00ol00?ooooooooooo`02o`00o`03ooooool00?oo003o00?ooooo
00?o003oooooooooool00_ooool2o`00o`;ooooo0_l00?l4ooooo`;o003o00Koooooo`00oooooooo
003oooooool00?l2ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool00_ooool01ol0
0?ooooooooooool00?ooooooo`00ooooool00_l00?l3ooooo`;o003o00Soooooo`00ool00?oooooo
o`00oooooooo003oooooo`;o003o1?ooool01?l00?ooooooo`00ooooool2o`00o`03ooooool00?oo
oooo00Wooooo00Co003oooooool00?oo003o0oooool00ol00?ooooooo`00o`0eooooo`04o`00oooo
ooooooooo`00o`;ooooo00?o003oooooooooool00_l00?l2ooooo`04o`00ooooooooooooo`00o`;o
oooo0_l00?l5ooooo`03o`00oooooooooooo00;o003o0_ooool00ol00?ooooooooooo`05ooooo`03
o`000?oooooooooo00kooooo000@ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00001?ooool2o`0005[ooooo00?o003ooooooooo00002?ooool00ol0003oooooooooo`06ooooo`03
o`00oooo003ooooo05_ooooo0_l0000Tooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`04
o`00ooooooooooooo`00o`?ooooo00Go003ooooooooooooo003oooooo`02o`00o`;ooooo0_l00?l2
ooooo`03o`00oooooooo003o00?ooooo0_l00?l00ooooooo003oo`00o`06ooooo`06o`00oooooooo
003oo`00oooooooo003o0_ooool01?l00?ooooooo`00ooooool2o`00o`05ooooool00?oooooooooo
ool00?l00oooool2o`00o`03ooooool00?oooooo00?ooooo0_l00?l01Ooooooo003oooooool00?oo
oooo00;o003o00?oooooo`00ool00?l01Oooool00ol00?ooooooooooo`0;ooooo`;o003o00Kooooo
o`00oooooooo003oooooool00?ljooooo`03o`00oooooooooooo00?ooooo0_l00?l2ooooo`04o`00
ooooooooooooo`00o`;ooooo0_l00?l2ooooo`03o`00oooooooooooo00?ooooo0_l00?l2ooooo`03
o`00oooooooooooo00?ooooo0ol0000@ooooo`004Oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Kooooo`03ool00?l00?oooooo00Ko
oooo00?o0000ooooooooool01_ooool01?l00?ooo`00ooooool00?mKooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo
00;o003o00Goooooo`00ooooooooooooo`00o`03ooooo`;o003o00?oooooo`00ool00?l00_ooool0
0ol00?ooooooooooo`02o`00o`04ooooool00?oo003oooooo`;o003o00?oooooo`00ooooool00ooo
ool01_l00?ooooooo`00ool00?ooooooo`00o`?ooooo0_l00?l2ooooo`03o`00oooooooo003o00?o
oooo0_l00?l01Ooooooo003oo`00oooooooo003o00Cooooo00?o003oooooooooool01?ooool2o`00
o`04ooooool00?ooooooo`00o`;ooooo00?o003oooooool00?l02_ooool02_l00?ooooooooooool0
0?ooooooo`00oooooooo003oooooool00?lhooooo`04o`00ooooooooooooo`00o`?ooooo00Co003o
oooooooooooo003o0_ooool00ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooooooooooo003o
1_ooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo00kooooo000>ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo05Wo
oooo00Co003ooooooooo003o003o1oooool00ol0003oooooooooo`06ooooo`04o`00oooo003ooooo
o`00oe_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00Co003ooooooooooooo003o0_ooool00ol00?ooooooooooo`02o`00o`;ooooo00Co
003ooooooooooooo003o0_ooool2o`00o`03ooooool00?oo003o00Gooooo0_l00?l02?oooooo003o
o`00oooooooo003oooooool00?oooooo0_l00?l2ooooo`06o`00oooooooo003oooooool00?oooooo
0_l00?l00ooooooo003oo`00o`03ooooo`03o`00oooooooo003o00;ooooo0_l00?l00ooooooo003o
ooooo`02o`00o`?ooooo0_l00?l00ooooooo003oooooo`02o`00o`05ooooool00?ooooooo`00oooo
ool00_l00?l00ooooooo003oooooo`09ooooo`03o`00oooooooooooo00;ooooo00Go003oooooool0
0?ooooooo`00o`0kooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o1_oo
ool01?l00?ooooooooooool00?l2ooooo`;o003o2_ooool00ol0003oooooooooo`0>ooooo`003_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`1Iooooo`04o`00ooooooooo`00o`00o`Oooooo00?o0000ooooooooool01oooool00ooo
003oooooo`00o`1Kooooo`03o`000?oooooooooo027ooooo0_l00005ooooo`03o`000?oooooooooo
00?ooooo00Co003ooooooooooooo003o0_ooool00ol00?ooooooooooo`02o`00o`03ooooool00?oo
003o00;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`;ooooo0_l00?l4ooooo`;o003o00Ko
ooooo`00oooooooo003oooooool00?l2ooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`;o
003o00Coooooo`00oooooooo003o0_ooool01ol00?ooooooooooool00?ooooooo`00ooooool00_l0
0?l00ooooooo003oooooo`02o`00o`03ooooool00?oooooo00?ooooo00Co003oooooool00?oooooo
0_l00?l00ooooooo003oooooo`09ooooo`04o`000?l00?ooooooo`00o`Gooooo00?o003ooooooooo
ool0??ooool2o`00o`;ooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool00?l2
ooooo`03o`00oooooooooooo00;o003o0_ooool00ol00?ooooooooooo`05ooooo`03o`000?oooooo
oooo00kooooo000?ooooo`?o00001?ooool2o`0000Gooooo0_l0001Jooooo`04o`00ooooooooo`00
o`00o`Oooooo00?o0000ooooooooool01_ooool00ol00?ooo`00ooooo`1Kooooo`;o00009?ooool0
0ol0003oooooooooo`03ooooo`;o00001?ooool01?l00?ooooooooooool00?l5ooooo`;o003o00?o
ooooo`00ool00?l00_ooool01_l00?oooooooooooooooooo003oooooo`;o003o0_ooool2o`00o`03
ooooool00?oo003o00Gooooo00?o003oooooooooool00_l00?l01ooooooo003ooooooooooooo003o
ooooool00?l00_ooool00ol00?ooooooo`00o`02ooooo`04o`00oooooooo003oooooo`;o003o00?o
ooooo`00ooooool00oooool2o`00o`03ooooool00?oooooo00;o003o00?oooooo`00ooooool00_l0
0?l4ooooo`03o`00oooooooooooo00cooooo0_l00?l01_oooooo003oooooool00?ooooooo`00odCo
oooo00Co003ooooooooooooo003o0_ooool2o`00o`;ooooo00?o003oooooooooool00oooool01Ol0
0?oooooooooooooooooo003o00Kooooo0_l0000@ooooo`007Oooool00ol0003oooooooooo`1Koooo
o`03ool00?oooooooooo00Kooooo00?o0000ooooooooool01_ooool01?l00?ooo`00ooooool00?mK
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool01?l00?ooooooooooool0
0?l5ooooo`05o`00ooooooooooooooooool00?l00_ooool2o`00o`Gooooo00?o003oooooooooool0
0_l00?l01Ooooooo003oo`00oooooooo003o00Cooooo00Wo003oooooool00?oo003oooooool00?oo
ooooo`00ooooool00_l00?l2ooooo`03o`00oooooooo003o00?ooooo0_l00?l01Ooooooo003oo`00
oooooooo003o00Cooooo00?o003oooooooooool00_ooool02?l00?ooooooo`00ool00?ooooooo`00
oooooooo003o0_ooool00ol00?ooooooo`00o`0:ooooo`;o003o00Soooooo`00oooooooo003ooooo
ool00?ooooooo`00odGooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool00?l6
ooooo`03o`00oooooooooooo00Gooooo00?o0000ooooooooool03_ooool001gooooo00?o0000oooo
ooooool0FOooool01?l00?ooooooool00?l00?l7ooooo`03o`000?oooooooooo00Kooooo00Co003o
ool00?oooooo003oFoooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00?ooooo00Co
003ooooooooooooo003o0_ooool00ol00?ooooooooooo`02o`00o`03ooooool00?oo003o00;ooooo
00?o003oooooooooool00_l00?l00ooooooo003oo`00o`05ooooo`;o003o00Coooooo`00ool00?oo
oooo0_l00?l2ooooo`;o003o0_ooool00ol00?ooooooo`00o`03ooooo`;o003o00?oooooo`00ool0
0?l00oooool00ol00?ooooooo`00o`02ooooo`;o003o00?oooooo`00ooooool00_l00?l3ooooo`;o
003o0oooool2o`00o`03ooooool00?oooooo00;o003o00Coooooo`00oooooooo003o2_ooool00ol0
0?ooooooooooo`02ooooo`05o`00oooooooo003oooooool00?l0B?ooool01Ol00?oooooooooooooo
oooo003o00;ooooo00Co003ooooooooooooo003o2oooool00ol0003oooooooooo`0>ooooo`007Ooo
ool00ol0003oooooooooo`1Iooooo`04o`00ooooooooo`00o`00o`Oooooo00?o0000ooooooooool0
1oooool00ooo003oooooo`00o`1Kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
0oooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooooooo00;o003o0_ooool01?l00?oo
ooooooooool00?l2ooooo`03o`00oooooooooooo00;o003o0_ooool00ol00?ooooooooooo`03oooo
o`;o003o00?oooooo`00ool00?l00_ooool00ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooo
oooooooo003o0_ooool2o`00o`04ooooool00?ooooooo`00o`;ooooo00Oo003oooooool00?oo003o
ooooool00?oooooo00;o003o00?oooooo`00ooooool00_l00?l00ooooooo003oooooo`03ooooo`08
o`00oooooooo003oo`00oooooooo003oooooool00?l:ooooo`04o`000?l00?ooooooo`00o`Cooooo
00?o003oooooooooool0Boooool01?l00?ooooooooooool00?l2ooooo`05o`00oooooooooooooooo
ool00?l01oooool00ol0003oooooooooo`0>ooooo`007Oooool2o`0005[ooooo00Co003ooooooooo
003o003o1oooool00ol0003oooooooooo`06ooooo`03o`00oooo003ooooo05_ooooo0_l0000Zoooo
o`03o`000?oooooooooo00;ooooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o00?ooooo
o`00ool00?l00_ooool00ol00?ooooooooooo`03ooooo`;o003o0_ooool00ol00?ooooooooooo`02
o`00o`Gooooo00?o003oooooooooool00_l00?l01?oooooo003oooooooooool2o`00o`?ooooo00?o
003oooooool00?l00_ooool2o`00o`;ooooo0_l00?l5ooooo`06o`00oooooooo003oooooool00?oo
oooo0_l00?l00ooooooo003oooooo`02o`00o`Cooooo00?o003oooooooooool03?ooool2o`00o`06
ooooool00?ooooooo`00oooooooo003oE?ooool01Ol00?oooooooooooooooooo003o00Oooooo00?o
0000ooooooooool03_ooool001gooooo00?o0000ooooooooool0Foooool00ooo003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00Co003oool00?oooooo003oFoooool00ol0003ooooooooo
o`0Xooooo`;o00001oooool01?l00?ooooooooooool00?l5ooooo`05o`00ooooooooooooooooool0
0?l00_ooool2o`00o`03ooooool00?oooooo00;ooooo00?o003oooooooooool00_l00?l01Ooooooo
003oo`00oooooooo003o00Cooooo00Go003oooooool00?oo003oooooo`02o`00o`;ooooo0_l00?l2
ooooo`03o`00oooooooo003o00?ooooo0_l00?l01Ooooooo003oo`00oooooooo003o00;ooooo00?o
003oooooool00?l01?ooool02?l00?ooooooo`00ool00?ooooooo`00oooooooo003o0_ooool00ol0
0?ooooooo`00o`0:ooooo`;o003o00Goooooo`00oooooooo003oooooo`02o`00oeOooooo00?o003o
ooooooooool01?ooool2o`00013ooooo000Mooooo`03o`000?oooooooooo05Wooooo00Co003ooooo
oooo003o003o1oooool00ol0003oooooooooo`06ooooo`04o`00oooo003oooooo`00oe_ooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o0_ooool00ol00?ooooooooooo`02o`00o`;o
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`02o`00o`03ooooool00?oo003o00;o
oooo0_l00?l2ooooo`03o`00oooooooo003o00?ooooo0_l00?l00ooooooo003oo`00o`02ooooo`04
o`00ooooooooooooo`00o`;ooooo0_l00?l00ooooooo003oo`00o`05ooooo`;o003o0_ooool01_l0
0?ooooooo`00oooooooo003oooooo`;o003o00Coooooo`00oooooooo003o2_ooool00ol00?oooooo
ooooo`02ooooo`04o`00oooooooo003oo`00oeoooooo00?o0000ooooooooool03_ooool001gooooo
00?o0000ooooooooool0FOooool01?l00?ooooooool00?l00?l7ooooo`03o`000?oooooooooo00Oo
oooo00?oo`00ooooool00?l0Foooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`02ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003o
oooooooooooo003o0_ooool00ol00?ooooooooooo`02o`00o`;ooooo00?o003oooooooooool00ooo
ool2o`00o`03ooooool00?oo003o00;ooooo00?o003oooooooooool00_l00?l2ooooo`04o`00oooo
ooooooooo`00o`;ooooo0_l00?l00ooooooo003oo`00o`03ooooo`05o`00oooooooo003oo`00oooo
ool00_l00?l01Ooooooo003oooooool00?oooooo00;o003o00?oooooo`00ooooool00oooool01Ol0
0?ooooooo`00ool00?oooooo00;o003o2oooool01?l00?ooooooooooool00?l4ooooo`03o`00oooo
oooooooo05gooooo00?o0000ooooooooool03_ooool001gooooo0_l0001Jooooo`04o`00oooooooo
o`00o`00o`Oooooo00?o0000ooooooooool01_ooool00ol00?ooo`00ooooo`1Kooooo`;o0000:_oo
ool00ol0003oooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?oooooo
ooooo`02o`00o`;ooooo00?o003oooooooooool00oooool2o`00o`;ooooo00Co003ooooooooooooo
003o1_ooool01?l00?ooooooooooool00?l2ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooo`00o`02ooooo`;o003o0_ooool2o`00o`Gooooo00Ko003oooooool00?ooooooo`00
ooooool2o`00o`05ooooool00?oo003oooooool00?l00oooool2o`00o`kooooo00Oo003ooooooooo
oooo003oooooool00?oooooo00;o003oGoooool00ol0003oooooooooo`0>ooooo`007Oooool00ol0
003oooooooooo`1Kooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool01_ooool01?l0
0?ooo`00ooooool00?mKooooo`03o`000?oooooooooo02Sooooo0_l00007ooooo`04o`00oooooooo
ooooo`00o`Gooooo00Go003oooooooooooooooooo`00o`02ooooo`04o`00ooooooooooooo`00o`?o
oooo00Co003ooooooooooooo003o0_ooool2o`00o`;ooooo00Co003ooooooooooooo003o0_ooool2
o`00o`03ooooool00?oo003o00;ooooo0_l00?l2ooooo`03o`00oooooooo003o00?ooooo00?o003o
ooooooooool00_l00?l01ooooooo003ooooooooooooo003oooooool00?l00_ooool02?l00?oooooo
o`00ool00?ooooooo`00oooooooo003o1?ooool2o`00o`_ooooo00So0000oooooooooooo003ooooo
ool00?ooooooo`00oeoooooo0_l0000@ooooo`007Oooool00ol0003oooooooooo`1Iooooo`04o`00
ooooooooo`00o`00o`Oooooo00?o0000ooooooooool01_ooool01?l00?ooo`00ooooool00?mKoooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02Oooool01?l00?ooooooooooool00?l2
ooooo`;o003o0_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool00_l00?l00ooooooo003oooooo`02ooooo`07o`00ooooooooooooooooool00?oo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00_ooool01?l00?ooooooooooool00?l2
ooooo`;o003o00?oooooo`00ool00?l01Oooool02_l00?oooooooooooooooooo003oooooool00?oo
ooooo`00ooooool2o`00o`03ooooool00?oo003o00_ooooo00?o0000ooooooooool00_ooool01?l0
0?ooooooo`00ool00?mOooooo`03o`000?oooooooooo00kooooo000Mooooo`03o`000?oooooooooo
05Wooooo00Co003ooooooooo003o003o1oooool00ol0003oooooooooo`07ooooo`03ool00?oooooo
003o05_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0<ooooo`05o`00oooooooo
ooooooooool00?l01Oooool00ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooooooooooo003o
0_ooool2o`00o`03ooooool00?oo003o00;ooooo00?o003oooooooooool00_l00?l00ooooooo003o
o`00o`02ooooo`03o`00oooooooooooo00;o003o00?oooooo`00ool00?l01Oooool2o`00o`04oooo
ool00?oo003oooooo`;o003o0_ooool2o`00o`03ooooool00?oooooo00?ooooo00Go003oooooool0
0?oo003oooooo`02o`00o`_ooooo00Co0000oooooooooooo003o1?ooool00ol00?ooooooooooo`1M
ooooo`03o`000?oooooooooo00kooooo000Mooooo`;o0000F_ooool01?l00?ooooooool00?l00?l7
ooooo`03o`000?oooooooooo00Kooooo00?o003oool00?ooool0Foooool2o`0002[ooooo00?o0000
ooooooooool03oooool01Ol00?oooooooooooooooooo003o00Gooooo00Go003ooooooooooooooooo
o`00o`02ooooo`06o`00ooooooooooooooooool00?oooooo0_l00?l2ooooo`04o`00oooooooooooo
o`00o`?ooooo00Co003ooooooooooooo003o0_ooool00ol00?ooooooooooo`02o`00o`;ooooo00?o
003oooooooooool01?ooool01?l00?ooooooo`00ool00?l2ooooo`;o003o00Goooooo`00ool00?oo
ooooo`00o`03ooooo`;o003o3_ooool00ol0003oooooooooo`02o`00o`;ooooo0_l00?mOooooo`03
o`000?oooooooooo00kooooo000Mooooo`03o`000?oooooooooo05_ooooo00?oo`00ooooooooool0
1_ooool00ol0003oooooooooo`06ooooo`04o`00oooo003oooooo`00oe_ooooo00?o0000oooooooo
ool0:?ooool2o`0001Cooooo00Co003ooooooooooooo003o0_ooool01Ol00?oooooooooooooooooo
003o00;ooooo00?o003oooooooooool01?ooool01?l00?ooooooooooool00?l2ooooo`03o`00oooo
oooooooo00;o003o0_ooool00ol00?ooooooooooo`02o`00o`03ooooool00?oooooo00;ooooo00?o
003oooooooooool00_l00?l01?oooooo003oooooooooool2o`00o`?ooooo00Go003oooooool00?oo
003oooooo`02o`00o`Gooooo00?o003oooooooooool02_ooool00ol0003oooooooooo`02o`00o`;o
oooo00?o003oooooooooool0GOooool2o`00013ooooo000>ooooo`Go00000_ooool3o`0000Gooooo
00?o0000ooooooooool0FOooool01?l00?ooooooool00?l00?l7ooooo`03o`000?oooooooooo00Ko
oooo00Co003oool00?oooooo003oFoooool00ol0003oooooooooo`0Pooooo`Go00000oooool00ol0
003oooooooooo`0Fooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o0_oo
ool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool00_l00?l0
0ooooooo003oo`00o`05ooooo`06o`00ooooooooooooooooool00?oooooo0_l00?l2ooooo`;o003o
00?oooooo`00ool00?l02oooool01Ol0003ooooooooooooooooo003o00;ooooo0_l00?mOooooo`03
o`000?oooooooooo00kooooo000?ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo05Wooooo00Co003ooooooooo003o003o1oooool0
0ol0003oooooooooo`07ooooo`03ool00?oooooo003o05_ooooo00?o0000ooooooooool08Oooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo01Wooooo00Go003ooooooooooooooooo
o`00o`02ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l2ooooo`04o`00ooooooooooooo`00
o`;ooooo0_l00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l5ooooo`;o003o00Gooooo
o`00ool00?ooooooo`00o`03ooooo`;o003o00?oooooo`00ooooool00_ooool00ol00?oooooooooo
o`02o`00o`03ooooool00?oo003o00_ooooo00Co0000oooooooooooo003o1?ooool00ol00?oooooo
ooooo`1Mooooo`03o`000?oooooooooo00kooooo000@ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool2o`0005[ooooo00?o003ooooooooo00002?ooool00ol0003ooooooooo
o`06ooooo`04o`00oooo003oooooo`00oe[ooooo0_l0000Tooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool07Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;o003o
0_ooool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003ooooo
ooooool00_l00?l2ooooo`03o`00oooooooooooo00Cooooo00Co003oooooool00?oo003o0_ooool2
o`00o`05ooooool00?oo003oooooool00?l00oooool2o`00o`;ooooo00?o003oooooooooool02Ooo
ool00ol0003oooooooooo`02o`00o`;ooooo0_l00?mOooooo`03o`000?oooooooooo00kooooo000A
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1K
ooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol00?ooo`00ooooo`1L
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00_ooool3o`00023ooooo00?o003o
ooooooooool01?ooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooooooo00;o003o0_oo
ool01?l00?ooooooooooool00?l2ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oo
ooooooooo`03ooooo`;o003o0oooool01Ol00?ooooooo`00ool00?oooooo00;o003o1Oooool00ol0
0?ooooooooooo`0:ooooo`03o`000?oooooooooo00;o003o0_ooool00ol00?ooooooooooo`1Loooo
o`?o00004?ooool000kooooo00Ko0000ooooooooooooooooo`000?ooool4o`0000Gooooo00?o0000
ooooooooool0FOooool00ol00?ooooooool00008ooooo`03o`000?oooooooooo00Kooooo00?o003o
ool00?l00?l0G?ooool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`0Pooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo
003o0_ooool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003o
oooooooooooo003o0_ooool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`?o
oooo00Co003oooooool00?oo003o0_ooool00ol00?ooooooooooo`02o`00o`_ooooo00Go0000oooo
ooooooooooooo`00o`02ooooo`;o003oGoooool00ol0003oooooooooo`0>ooooo`003_ooool01ol0
003ooooooooooooooooo0000ooooool000002?ooool00ol0003oooooooooo`1Iooooo`03o`00oooo
ooooo`0000Sooooo00?o0000ooooooooool01oooool00ooo003o003oooooo`1Kooooo`03o`000?oo
oooooooo023ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo02?ooooo
00Go003oooooooooooooooooo`00o`02ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l2oooo
o`04o`00ooooooooooooo`00o`;ooooo0_l00?l5ooooo`03o`00oooooooooooo00;o003o00?ooooo
o`00ooooool00_ooool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo
0_l00?l;ooooo`04o`000?ooooooooooo`00o`Cooooo00?o003oooooooooool0GOooool00ol0003o
ooooooooo`0>ooooo`003oooool3o`0000;ooooo1Ol00004ooooo`03o`000?oooooooooo05Wooooo
00?o003ooooooooo00002?ooool00ol0003oooooooooo`06ooooo`03o`00oooo003o003o05cooooo
00?o0000ooooooooool08Oooool3o`0000Cooooo00?o0000ooooooooool09oooool01?l00?oooooo
ooooool00?l2ooooo`05o`00ooooooooooooooooool00?l00_ooool01?l00?ooooooooooool00?l2
ooooo`;o003o0_ooool00ol00?ooooooooooo`03ooooo`;o003o00?oooooo`00ool00?l00_ooool0
0ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooooooooooo003o0oooool00ol00?oooooooooo
o`09ooooo`04o`000?ooooooooooo`00o`?ooooo0_l00?mOooooo`03o`000?oooooooooo00kooooo
000Mooooo`;o0000F_ooool00ol00?ooooooool00008ooooo`03o`000?oooooooooo00Kooooo00?o
003oool00?ooool0Foooool2o`0002[ooooo0_l0000[ooooo`04o`00ooooooooooooo`00o`;ooooo
00Go003oooooooooooooooooo`00o`02ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooo
oooooooo003o0oooool01?l00?ooooooo`00ool00?l2ooooo`03o`00oooooooooooo00;o003o00?o
ooooo`00ooooool00_ooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo00;o003o0_oo
ool00ol00?ooooooooooo`1Mooooo`;o00004?ooool001gooooo00?o0000ooooooooool0Foooool0
0ooo003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?oo`00o`00ooooool0Foooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo033ooooo00Go003oooooooooooooooooo`00
o`02ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o0_ooool01Ol00?oo
oooooooooooooooo003o00Kooooo00Co003oooooool00?oo003o0_ooool00ol00?ooooooooooo`02
o`00o`_ooooo00?o0000ooooooooool00_l00?l2ooooo`03o`00oooooooooooo05kooooo00?o0000
ooooooooool03_ooool001gooooo00?o0000ooooooooool0F_ooool00ol00?ooo`00ooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?oo`00o`00ooooool0Foooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo033ooooo00Go003oooooooooooooooooo`00o`02ooooo`04o`00oooooooo
ooooo`00o`Kooooo00Co003ooooooooooooo003o0_ooool01Ol00?oooooooooooooooooo003o00;o
oooo0_l00?l00ooooooo003oo`00o`02ooooo`03o`00oooooooooooo00;o003o2oooool01Ol0003o
oooooooooooooooo003o00;ooooo00?o003oooooooooool0G_ooool00ol0003oooooooooo`0>oooo
o`007Oooool00ol0003oooooooooo`1Jooooo`03o`00oooo003ooooo00Oooooo00?o0000oooooooo
ool01oooool00ooo003o003oooooo`1Kooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool0=oooool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003o
ooooooooool00_l00?l2ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o
0_ooool2o`00o`_ooooo00Co0000oooooooooooo003o0oooool00ol00?ooooooooooo`1Nooooo`03
o`000?oooooooooo00kooooo000Mooooo`;o0000Foooool00ol00?ooo`00ooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?oo`00ooooooooool0F_ooool2o`0002[ooooo0_l0000hooooo`04o`00
ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o0_ooool00ol00?ooooooooooo`02o`00
o`;ooooo00Co003ooooooooooooo003o0_ooool01Ol00?oooooooooooooooooo003o00oooooo00?o
0000ooooooooool00_l00?l2ooooo`03o`00oooooooooooo05gooooo0_l0000@ooooo`007Oooool0
0ol0003oooooooooo`1Kooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ooo003o003oooooo`1Kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0>_ooool0
1Ol00?oooooooooooooooooo003o00;ooooo00Co003ooooooooooooo003o0oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00;o003o0_ooool01?l00?ooooooooooool00?l<ooooo`03
o`000?oooooooooo00;o003o0_ooool00ol00?ooooooooooo`1Nooooo`03o`000?oooooooooo00ko
oooo000Mooooo`03o`000?oooooooooo05[ooooo00?o003oool00?ooool01oooool00ol0003ooooo
ooooo`07ooooo`03ool00?l00?oooooo05_ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0nooooo`04o`00ooooooooooooo`00o`;ooooo00Co003ooooooooooooo003o0oooool01?l0
0?ooooooooooool00?l2ooooo`;o003o0_ooool01?l00?ooooooooooool00?l<ooooo`05o`000?oo
ooooooooooooool00?l00_ooool00ol00?ooooooooooo`1Nooooo`03o`000?oooooooooo00kooooo
000Mooooo`03o`000?oooooooooo05[ooooo00?o003oool00?ooool01oooool00ol0003ooooooooo
o`07ooooo`03ool00?l00?oooooo05_ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`11ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l2ooooo`04o`00ooooooooooooo`00o`?o
oooo00Co003ooooooooooooo003o0_ooool00ol00?ooooooooooo`0:ooooo`04o`000?oooooooooo
o`00o`?ooooo00?o003oooooooooool0G_ooool00ol0003oooooooooo`0>ooooo`007Oooool2o`00
05_ooooo00?o003oool00?ooool01oooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo
05[ooooo0_l0000Zooooo`;o0000AOooool00ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooo
oooooooo003o0_ooool01Ol00?oooooooooooooooooo003o00oooooo00Co0000oooooooooooo003o
0oooool00ol00?ooooooooooo`1Mooooo`;o00004?ooool001gooooo00?o0000ooooooooool0Fooo
ool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?oo`00o`00ooooool0Fooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo04Oooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooooooooooo003o3?ooool01?l0003ooooo
ooooool00?l3ooooo`03o`00oooooooooooo05kooooo00?o0000ooooooooool03_ooool001gooooo
00?o0000ooooooooool0F_ooool00ol00?ooo`00ooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?oo`00o`00ooooool0Foooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo04_ooooo
00Co003ooooooooooooo003o0_ooool2o`00o`;ooooo00Co003ooooooooooooo003o3?ooool01?l0
003oooooooooool00?l3ooooo`03o`00oooooooooooo05kooooo00?o0000ooooooooool03_ooool0
01gooooo00?o0000ooooooooool0F_ooool00ol00?ooo`00ooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?oo`00o`00ooooool0Foooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
04_ooooo00Co003ooooooooooooo003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o
003oooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo05kooooo00?o
0000ooooooooool03_ooool001gooooo0_l0001Kooooo`03o`00oooo003ooooo00Oooooo00?o0000
ooooooooool01oooool00ooo003oooooooooo`1Jooooo`;o0000:_ooool2o`0004oooooo00Co003o
oooooooooooo003o0oooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o
003oooooooooool0GOooool2o`00013ooooo000?ooooo`?o00001?ooool2o`0000Gooooo00?o0000
ooooooooool0Foooool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?oo`00
o`00ooooool0Foooool00ol0003oooooooooo`0Qooooo`?o00001?ooool00ol0003oooooooooo`1A
ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0:ooooo`03o`000?oo
oooooooo00Cooooo00?o003oooooooooool0G_ooool00ol0003oooooooooo`0>ooooo`003_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`1Jooooo`03o`00oooo003ooooo00Oooooo00?o0000ooooooooool01oooool00ooo003o003o
ooooo`1Kooooo`03o`000?oooooooooo023ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo057ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo
00[ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`1Nooooo`03o`000?oooooooooo
00kooooo000Booooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1Jooooo`?oo`001oooool00ol0003oooooooooo`06ooooo`?oo`00G?ooool00ol0
003oooooooooo`0Tooooo`05o`000?ooooooooooooooool00000Eoooool01?l00?ooooooooooool0
0?l<ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0G_ooool00ol0003ooooooooo
o`0>ooooo`004?ooool2o`0000?ooooo00Co0000oooooooooooo00001?ooool2o`0005_ooooo0ooo
0007ooooo`03o`000?oooooooooo00Kooooo0ooo001Kooooo`;o00009?ooool2o`0000Cooooo0ol0
001Uooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0G?ooool3o`00013ooooo000B
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1Jooooo`?oo`001oooool00ol0003oooooooooo`06ooooo`?oo`00G?ooool00ol0003ooooooooo
o`0Tooooo`05o`000?ooooooooooooooool00000Ioooool00ol0003oooooooooo`1Uooooo`03o`00
0?oooooooooo00kooooo000>ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08?ooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool000oooooo0ol00004ooooo`;o
00001Oooooo@o`0002?ooooo0ol00004ooooom7o00004?ooool00?oooooonOooool00?oooooonOoo
ool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOoo
ool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOoo
ool00?oooooonOooool00?oooooonOooool00?oooooonOooool001oooooo0_l0000Looooo`?o0000
1?ooool2o`0001Oooooo1Ol00003ooooo`;o00006?ooool3o`0000Cooooo0_l0000Jooooo`?o0000
0oooool2o`0001Sooooo0ol00004ooooo`;o00006Oooool3o`0000Cooooo0_l0000]ooooo`;o0000
6oooool3o`0000Cooooo0_l0000Hooooo`Go00000oooool2o`0001Sooooo0ol00004ooooo`;o0000
6Oooool3o`0000?ooooo0_l0000Iooooo`?o00001?ooool2o`0001Sooooo0ol00004ooooo`;o0000
4Oooool001kooooo00Co0000oooooooooooo00007?ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0001Oooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000F
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Jooooo`05o`00
0?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Dooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool0000Gooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool0000[ooooo`04o`000?ooooooooooo`0001_ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool0000Hooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00005_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00006Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool05Oooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00005_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00004?ooool001kooooo00Co0000oooooooooooo
00007?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Sooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool0000Jooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool05Oooool5o`0000;ooooo00Co0000oooooooooooo00006_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo01Gooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0002_ooooo00Co0000oooooooooooo00006oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0001Wooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000Jooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool05?ooool5o`00
00;ooooo00Co0000oooooooooooo00006oooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo01Cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00013o
oooo000Nooooo`04o`000?ooooooooooo`0001cooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000Iooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0F
ooooo`;o00000oooool01?l0003oooooooooool0000Gooooo`04o`000?ooooooooooo`0000?ooooo
00Co0000oooooooooooo00006_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
01Gooooo1?l00003ooooo`04o`000?ooooooooooo`0002_ooooo00Co0000oooooooooooo00006ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001[ooooo00Go0000oooooooooooo
ooooo`000002ooooo`03o`000?oooooooooo01Kooooo0_l00003ooooo`04o`000?ooooooooooo`00
01Kooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0000Kooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool05?ooool4o`0000?ooooo00Co0000oooooooooooo
00004?ooool001kooooo00Co0000oooooooooooo00007?ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0001Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0001[ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooo000000?ooooo00Co0000oooooooooooo00005_ooool4o`0000?ooooo00Co0000oooooooo
oooo00005oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0002_ooooo00Co0000
oooooooooooo00006oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Oooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001[ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo000000?ooooo00Co0000
oooooooooooo00005oooool4o`0000?ooooo00Co0000oooooooooooo00005_ooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooo`00013ooooo000Nooooo`04o`000?ooooooooooo`0001_o
oooo0_l00004ooooo`04o`000?ooooooooooo`0001Kooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0001Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0001Wooooo0_l00003ooooo`04o`000?ooooooooooo`0001Kooooo00?o0000oooo
ooooool01?ooool01?l0003oooooooooool0000Hooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooo0000:oooool01?l0003oooooooooool0000Jooooo`;o00001?ooool01?l0003ooooo
ooooool0000Gooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000F
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Hooooo`;o0000
0oooool01?l0003oooooooooool0000Gooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooo
oooo00005oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00013ooooo000Ooooo
o`;o00007Oooool00ol0003oooooooooo`03ooooo`;o00006?ooool3o`0000Cooooo0_l0000Hoooo
o`?o00001?ooool2o`0001_ooooo00?o0000ooooooooool00_ooool2o`0001Oooooo1Ol00003oooo
o`;o00006_ooool2o`0000Cooooo0_l0000]ooooo`;o00007?ooool00ol0003oooooooooo`03oooo
o`;o00006Oooool3o`0000Cooooo0_l0000Hooooo`?o00001?ooool2o`0001[ooooo00?o0000oooo
ooooool00_ooool2o`0001Sooooo1Ol00003ooooo`;o00006Oooool2o`0000Cooooo0_l0000Aoooo
o`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`005Oooool2o`00
00Coooood?l0000Tooooo`?o00001?ooooo@o`0001;ooooo000Dooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool2o`0002?ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000004_ooool001Cooooo00Co0000oooo
oooooooo00000oooool01?l0003oooooooooooooool3ool00003oooooooo003oo`0000Coo`001?oo
ool9ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00001ooo00000oooooooo`00ool0
0007ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00001ooo00000oooooooo`00ool0
0007ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00001ooo00000oooooooo`00ool0
0007ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00001ooo00000oooooooo`00ool0
0007ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00001ooo00000oooooooo`00ool0
0007ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00001?oo0004ooooo`Koo`000ooo
ool00ol0003oooooooooo`0Kooooo`Go00001Oooool01Ol0003ooooooooooooooooo00000<kooooo
00?o0000ooooooooool04?ooool001Cooooo00Co0000oooooooooooo00000oooool3o`000005oooo
oooo003oo`00ool00?ooool01_oo00001?ooooooo`00ooooooooool9ool00003oooooooo003oo`00
00Ooo`0000?oooooool00?oo00001ooo00000oooooooo`00ool00007ool00003oooooooo003oo`00
00Ooo`0000?oooooool00?oo00001ooo00000oooooooo`00ool00007ool00003oooooooo003oo`00
00Ooo`0000?oooooool00?oo00001ooo00000oooooooo`00ool00007ool00003oooooooo003oo`00
00Ooo`0000?oooooool00?oo00001ooo00000oooooooo`00ool00007ool00003oooooooo003oo`00
00Ooo`0000?oooooool00?oo00001ooo00000oooooooo`00ool00007ool00003oooooooo003oo`00
00Ooo`0000?oooooool00?oo00001?oo00001?ooooooo`00ooooooooool6ool000;ooooo0_l0000U
ooooo`;o00001?ooool2o`000<_ooooo0ol0000Booooo`005?ooool01?l0003oooooooooool00003
ooooo`04o`000?ooooooooooooooo`?oo`0000?oooooool00?oo00001?oo00001?ooooooo`00oooo
ooooool9ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00001ooo00000oooooooo`00
ool00007ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00001ooo00000oooooooo`00
ool00007ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00001ooo00000oooooooo`00
ool00007ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00001ooo00000oooooooo`00
ool00007ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00001ooo00000oooooooo`00
ool00007ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00001?oo00001?ooooooo`00
ooooooooool6ool000?ooooo00?o0000ooooooooool09Oooool01Ol0003ooooooooooooooooo0000
0<kooooo00?o0000ooooooooool04?ooool001Cooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`0<ooooo`03ool00?oooooooooo0;7ooooo00?oo`00ooooooooool02Oooool00ol0
003oooooooooo`0Qooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`3<
ooooo`03o`000?oooooooooo013ooooo000Eooooo`;o00001?ooool00ol0003oooooooooo`0<oooo
o`03ool00?oooooooooo0;7ooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0Roooo
o`?o00001?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo013ooooo000Kooooo`;o
00003Oooool00ooo003oooooooooo`2aooooo`03ool00?oooooooooo00Sooooo0_l0000[ooooo`;o
0000c?ooool2o`0001;ooooo000Kooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0
/Oooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
c?ooool00ol0003oooooooooo`0@ooooo`006oooool00ol0003oooooooooo`0<ooooo`03ool00?oo
oooooooo0;7ooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo0<cooooo00?o0000ooooooooool04?ooool001_ooooo00?o0000ooooooooool03?ooool0
0ooo003oooooooooo`2aooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`3<ooooo`03o`000?oooooooooo013ooooo000Kooooo`;o00003Oooool00ooo
003oooooooooo`2aooooo`03ool00?oooooooooo00Sooooo0_l0000[ooooo`;o0000c?ooool2o`00
01;ooooo000Kooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0/Oooool00ooo003o
ooooooooo`09ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003o
ooooooooo`0@ooooo`006oooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo0;7ooooo
00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0<cooooo
00?o0000ooooooooool04?ooool001_ooooo00?o0000ooooooooool03?ooool00ooo003ooooooooo
o`2aooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`3<ooooo`03o`000?oooooooooo013ooooo000Kooooo`;o00003Oooool00ooo003oooooooooo`2a
ooooo`03ool00?oooooooooo00Sooooo0_l0000[ooooo`;o0000c?ooool2o`0001;ooooo000Koooo
o`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0/Oooool00ooo003oooooooooo`09oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0@oooo
o`006oooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo0;7ooooo00?oo`00oooooooo
ool02Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0<cooooo00?o0000oooooooo
ool04?ooool001_ooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`2aooooo`03ool0
0?oooooooooo00Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`00
0?oooooooooo013ooooo000Kooooo`;o00003Oooool00ooo003oooooooooo`2aooooo`03ool00?oo
oooooooo00Sooooo0_l0000[ooooo`;o0000c?ooool2o`0001;ooooo000Kooooo`03o`000?oooooo
oooo00cooooo00?oo`00ooooooooool0/Oooool00ooo003oooooooooo`09ooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0@ooooo`005?ooool3o`00
00Cooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`2aooooo`03ool00?oooooooooo
00Wooooo00?o0000ooooooooool08Oooool5o`0000?ooooo00?o0000ooooooooool0c?ooool00ol0
003oooooooooo`0@ooooo`004oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool03?ooool00ooo003oooooooooo`2aooooo`03ool00?oooooooooo00Wooooo00?o0000oooo
ooooool08_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo0<cooooo00?o0000
ooooooooool04?ooool001Oooooo00Co0000oooooooooooooooo0ol0000<ooooo`03ool00?oooooo
oooo0;7ooooo00?oo`00ooooooooool02?ooool2o`0001gooooo1Ol00003ooooo`03o`000?oooooo
oooo00?ooooo0_l0003;ooooo`?o00004_ooool001Oooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ool00?oooooooooo0;7ooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0@
ooooo`004oooool4o`0000Cooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`2aoooo
o`03ool00?oooooooooo00Wooooo00?o0000ooooooooool08Oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0@ooooo`004oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0/Oooool00ooo
003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool04?ooool001?ooooo1Ol00003oooo
o`;o00003Oooool00ooo003oooooooooo`2aooooo`03ool00?oooooooooo00Sooooo0_l0000Toooo
o`?o00001?ooool2o`000<cooooo0_l0000Booooo`006oooool00ol0003oooooooooo`0<ooooo`03
ool00?oooooooooo0;7ooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo0<cooooo00?o0000ooooooooool04?ooool001_ooooo00?o0000ooooooooool0
3?ooool00ooo003oooooooooo`2aooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo013ooooo000Kooooo`03o`000?oo
oooooooo00cooooo00?oo`00ooooooooool0/Oooool00ooo003oooooooooo`09ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0@ooooo`006oooool2
o`0000gooooo00?oo`00ooooooooool0/Oooool00ooo003oooooooooo`08ooooo`;o0000:oooool2
o`000<cooooo0_l0000Booooo`006oooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo
0;7ooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
0<cooooo00?o0000ooooooooool04?ooool001_ooooo00?o0000ooooooooool03?ooool00ooo003o
ooooooooo`2aooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`3<ooooo`03o`000?oooooooooo013ooooo000Kooooo`03o`000?oooooooooo00cooooo
00?oo`00ooooooooool0/Oooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0@ooooo`006oooool2o`0000gooooo00?o
o`00ooooooooool0/Oooool00ooo003oooooooooo`08ooooo`;o0000:oooool2o`000<cooooo0_l0
000Booooo`006oooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo0;7ooooo00?oo`00
ooooooooool02Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0<cooooo00?o0000
ooooooooool04?ooool001_ooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`2aoooo
o`03ool00?oooooooooo00Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<oooo
o`03o`000?oooooooooo013ooooo000Kooooo`03o`000?oooooooooo00cooooo00?oo`00oooooooo
ool0/Oooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool0c?ooool00ol0003oooooooooo`0@ooooo`006oooool2o`0000gooooo00?oo`00ooooooooool0
/Oooool00ooo003oooooooooo`08ooooo`;o0000:oooool2o`000<cooooo0_l0000Booooo`006ooo
ool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo0;7ooooo00?oo`00ooooooooool02Ooo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool04?oo
ool000kooooo0ol00004ooooo`;o00001?ooool00ol0003oooooooooo`0<ooooo`03ool00?oooooo
oooo0;7ooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`?o00001?ooool0
0ol0003oooooooooo`3<ooooo`03o`000?oooooooooo013ooooo000?ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0<ooooo`03ool00?oooooo
oooo0;7ooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0@ooooo`003oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool03?ooool0
0ooo003oooooooooo`2aooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool06oooool5
o`0000?ooooo00?o0000ooooooooool00oooool2o`000<_ooooo0ol0000Booooo`003oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo0ol0000<ooooo`03ool00?oooooo
oooo0;7ooooo00?oo`00ooooooooool02?ooool2o`0002Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`3<ooooo`03o`000?oooooooooo013ooooo000?ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0<ooooo`03ool00?oooooo
oooo0;7ooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0@ooooo`003_ooool2o`00
00Cooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0<ooooo`03ool00?oooooo
oooo0;7ooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`;o00001Oooool0
0ol0003oooooooooo`3<ooooo`03o`000?oooooooooo013ooooo000?ooooo`03o`000?oooooooooo
00?ooooo0_l00004ooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0/Oooool00ooo
003oooooooooo`09ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00oooool2o`00
0<cooooo0_l0000Booooo`006oooool2o`0000gooooo00?oo`00ooooooooool0/Oooool00ooo003o
ooooooooo`08ooooo`;o0000:oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo013o
oooo000Kooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0/Oooool00ooo003ooooo
ooooo`09ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003ooooo
ooooo`0@ooooo`006oooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo0;7ooooo00?o
o`00ooooooooool02Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0<cooooo00?o
0000ooooooooool04?ooool001_ooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`2a
ooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<
ooooo`03o`000?oooooooooo013ooooo000Kooooo`;o00003Oooool00ooo003oooooooooo`2aoooo
o`03ool00?oooooooooo00Sooooo0_l0000[ooooo`;o0000c?ooool2o`0001;ooooo000Kooooo`03
o`000?oooooooooo00cooooo00?oo`00ooooooooool0/Oooool00ooo003oooooooooo`09ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0@ooooo`00
6oooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo0;7ooooo00?oo`00ooooooooool0
2Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool0
4?ooool001_ooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`2aooooo`03ool00?oo
oooooooo00Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oo
oooooooo013ooooo000Kooooo`;o00003Oooool00ooo003oooooooooo`2aooooo`03ool00?oooooo
oooo00Sooooo0_l0000[ooooo`;o0000c?ooool2o`0001;ooooo000Kooooo`03o`000?oooooooooo
00cooooo00?oo`00ooooooooool0/Oooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0@ooooo`006oooool00ol0003o
ooooooooo`0<ooooo`03ool00?oooooooooo0;7ooooo00?oo`00ooooooooool02Oooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool04?ooool001_ooooo
00?o0000ooooooooool03?ooool00ooo003oooooooooo`2aooooo`03ool00?oooooooooo00Wooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo013ooooo
000Kooooo`;o00003Oooool00ooo003oooooooooo`2aooooo`03ool00?oooooooooo00Sooooo0_l0
000[ooooo`;o0000c?ooool2o`0001;ooooo000>ooooo`?o00000oooool3o`0000Cooooo00?o0000
ooooooooool03?ooool00ooo003oooooooooo`2aooooo`03ool00?oooooooooo00Wooooo00?o0000
ooooooooool08oooool2o`0000Cooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0@
ooooo`003oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ool00?oooooooooo0;7ooooo00?oo`00ooooooooool02Oooool00ol0003ooooooooo
o`0Rooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0c?ooool00ol0003ooooo
ooooo`0@ooooo`003oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000
3_ooool00ooo003oooooooooo`2aooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool0
8_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooooooo`Koo`0000?oooooool0
0?oo00001ooo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Ooo`0000?oooooool0
0?oo00001ooo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Ooo`0000?oooooool0
0?oo00001ooo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Ooo`0000?oooooool0
0?oo00001ooo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Ooo`0000?oooooool0
0?oo00001ooo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Ooo`0000?oooooool0
0?oo00001ooo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Ooo`0000?oooooool0
0?oo00001ooo00001?ooooooo`00ool00?oo0003ooooo`03o`000?oooooooooo013ooooo000?oooo
o`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo0ol0000<ooooo`03ool00?oooooo
oooo0;7ooooo00?oo`00ooooooooool02?ooool2o`0002Cooooo00Co0000oooooooooooo00000ooo
ool2o`0000;ooooo1_oo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Ooo`0000?o
ooooool00?oo00001ooo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Ooo`0000?o
ooooool00?oo00001ooo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Ooo`0000?o
ooooool00?oo00001ooo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Ooo`0000?o
ooooool00?oo00001ooo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Ooo`0000?o
ooooool00?oo00001ooo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Ooo`0000?o
ooooool00?oo00001ooo00000oooooooo`00ool00007ool00005oooooooo003oo`00ool00?ooool0
0ol0000Booooo`003oooool01?l0003oooooooooooooool4o`0000Cooooo00?o0000ooooooooool0
3?ooool00ooo003oooooooooo`2aooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool0
8_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooooooo`Koo`0000?oooooool0
0?oo00001ooo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Ooo`0000?oooooool0
0?oo00001ooo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Ooo`0000?oooooool0
0?oo00001ooo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Ooo`0000?oooooool0
0?oo00001ooo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Ooo`0000?oooooool0
0?oo00001ooo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Ooo`0000?oooooool0
0?oo00001ooo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Ooo`0000?oooooool0
0?oo00001ooo00001?ooooooo`00ool00?oo0003ooooo`03o`000?oooooooooo013ooooo000>oooo
o`;o00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?oo`00oooo
ooooool0/Oooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo013ooooo000?oooo
o`04o`000?ooooooooooooooo`Go00000oooool00ol0003oooooooooo`0<ooooo`03ool00?oooooo
oooo0;7ooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0Sooooo`;o00001?ooool0
0ol0003oooooooooo`3<ooooo`03o`000?oooooooooo013ooooo000Kooooo`;o00003Oooool00ooo
003oooooooooo`2aooooo`03ool00?oooooooooo00Sooooo0_l0000[ooooo`;o0000c?ooool2o`00
01;ooooo000Kooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0/Oooool00ooo003o
ooooooooo`09ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003o
ooooooooo`0@ooooo`006oooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo0;7ooooo
00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0<cooooo
00?o0000ooooooooool04?ooool001_ooooo00?o0000ooooooooool03?ooool00ooo003ooooooooo
o`2aooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`3<ooooo`03o`000?oooooooooo013ooooo000Kooooo`;o00003Oooool00ooo003oooooooooo`2a
ooooo`03ool00?oooooooooo00Sooooo0_l0000[ooooo`;o0000c?ooool2o`0001;ooooo000Koooo
o`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0/Oooool00ooo003oooooooooo`09oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0@oooo
o`006oooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo0;7ooooo00?oo`00oooooooo
ool02Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0<cooooo00?o0000oooooooo
ool04?ooool001_ooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`2aooooo`03ool0
0?oooooooooo00Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`00
0?oooooooooo013ooooo000Kooooo`;o00003Oooool00ooo003oooooooooo`2aooooo`03ool00?oo
oooooooo00Sooooo0_l0000[ooooo`;o0000c?ooool2o`0001;ooooo000Kooooo`03o`000?oooooo
oooo00cooooo00?oo`00ooooooooool0/Oooool00ooo003oooooooooo`09ooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0@ooooo`006oooool00ol0
003oooooooooo`0<ooooo`03ool00?oooooooooo0;7ooooo00?oo`00ooooooooool02Oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool04?ooool001_o
oooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`2aooooo`03ool00?oooooooooo00Wo
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo013o
oooo000Kooooo`;o00003Oooool00ooo003oooooooooo`2aooooo`03ool00?oooooooooo00Sooooo
0_l0000[ooooo`;o0000c?ooool2o`0001;ooooo000Kooooo`03o`000?oooooooooo00cooooo00?o
o`00ooooooooool0/Oooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool0c?ooool00ol0003oooooooooo`0@ooooo`003Oooool5o`0000?ooooo0_l00004
ooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0/Oooool00ooo003oooooooooo`09
ooooo`03o`000?oooooooooo02;ooooo0ol00004ooooo`03o`000?oooooooooo0<cooooo00?o0000
ooooooooool04?ooool000kooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0/Oooool00ooo003ooooooooo
o`09ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`3<ooooo`03o`000?oooooooooo013ooooo000?ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000oooool3o`0000cooooo00?oo`00ooooooooool0/Oooool00ooo003ooooooooo
o`08ooooo`;o00009Oooool00ol0003oooooooooo`03ooooo`;o0000boooool3o`0001;ooooo000@
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000kooooo
00?oo`00ooooooooool0/Oooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo013ooooo
000=ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00cooooo00?oo`00ooooooooool0/Oooool00ooo003oooooooooo`09ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3<ooooo`03
o`000?oooooooooo013ooooo000=ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0/Oooool00ooo
003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo0_l00005ooooo`03o`000?oooooooooo
0<cooooo00?o0000ooooooooool04?ooool000kooooo0ol00004ooooo`;o00001?ooool2o`0000go
oooo00?oo`00ooooooooool0/Oooool00ooo003oooooooooo`08ooooo`;o00009Oooool00ol0003o
ooooooooo`03ooooo`;o0000c?ooool2o`0001;ooooo000Kooooo`03o`000?oooooooooo00cooooo
00?oo`00ooooooooool0/Oooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0@ooooo`006oooool00ol0003ooooooooo
o`0<ooooo`03ool00?oooooooooo0;7ooooo00?oo`00ooooooooool02Oooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool04?ooool001_ooooo00?o0000
ooooooooool03?ooool00ooo003oooooooooo`2aooooo`03ool00?oooooooooo00Wooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo013ooooo000Koooo
o`;o00003Oooool00ooo003oooooooooo`2aooooo`03ool00?oooooooooo00Sooooo0_l0000[oooo
o`;o0000c?ooool2o`0001;ooooo000Kooooo`03o`000?oooooooooo00cooooo00?oo`00oooooooo
ool0/Oooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool0c?ooool00ol0003oooooooooo`0@ooooo`006oooool00ol0003oooooooooo`0<ooooo`03ool0
0?oooooooooo0;7ooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo0<cooooo00?o0000ooooooooool04?ooool001_ooooo00?o0000ooooooooool03?oo
ool00ooo003oooooooooo`2aooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo013ooooo000Kooooo`;o00003Oooool0
0ooo003oooooooooo`2aooooo`03ool00?oooooooooo00Sooooo0_l0000[ooooo`;o0000c?ooool2
o`0001;ooooo000Kooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0/Oooool00ooo
003oooooooooo`09ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0
003oooooooooo`0@ooooo`006oooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo0;7o
oooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0<co
oooo00?o0000ooooooooool04?ooool001_ooooo00?o0000ooooooooool03?ooool00ooo003ooooo
ooooo`2aooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`3<ooooo`03o`000?oooooooooo013ooooo000Kooooo`;o00003Oooool00ooo003ooooooooo
o`2aooooo`03ool00?oooooooooo00Sooooo0_l0000[ooooo`;o0000c?ooool2o`0001;ooooo000K
ooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0/Oooool00ooo003oooooooooo`09
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0@
ooooo`003Oooool5o`0000;ooooo0ol00004ooooo`03o`000?oooooooooo00cooooo00?oo`00oooo
ooooool0/Oooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo1Ol00003oooo
o`03o`000?oooooooooo0<cooooo00?o0000ooooooooool04?ooool000kooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`05o`000?ooooooooooooooool000003_ooool00ooo003ooooooooo
o`2aooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool08_ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool04?ooool000oooooo00?o
0000ooooooooool01Oooool01?l0003oooooooooooooool3o`0000cooooo00?oo`00ooooooooool0
/Oooool00ooo003oooooooooo`08ooooo`;o00009Oooool00ol0003oooooooooo`03ooooo`;o0000
boooool3o`0001;ooooo000@ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ool00?oooooooooo0;7ooooo00?oo`00ooooooooool02Oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0c?ooool00ol0003ooooo
ooooo`0@ooooo`003Oooool01_l0003ooooooooooooooooo0000ooooo`Co00001?ooool00ol0003o
ooooooooo`0<ooooo`03ool00?oooooooooo0;7ooooo00?oo`00ooooooooool02Oooool00ol0003o
ooooooooo`0Qooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`3<oooo
o`03o`000?oooooooooo013ooooo000=ooooo`07o`000?ooooooooooooooool0003oooooo`000007
ooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0/Oooool00ooo003oooooooooo`09
ooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo0<cooooo00?o0000ooooooooool04?ooool000kooooo0ol00002ooooo`Go00000oooool2
o`0000gooooo00?oo`00ooooooooool0/Oooool00ooo003oooooooooo`08ooooo`;o00009?ooool3
o`0000Cooooo0_l0003<ooooo`;o00004_ooool001_ooooo00?o0000ooooooooool03?ooool00ooo
003oooooooooo`2aooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`3<ooooo`03o`000?oooooooooo013ooooo000Kooooo`03o`000?oooooooooo00co
oooo00?oo`00ooooooooool0/Oooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0@ooooo`006oooool00ol0003ooooo
ooooo`0<ooooo`03ool00?oooooooooo0;7ooooo00?oo`00ooooooooool02Oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool04?ooool001_ooooo0_l0
000=ooooo`03ool00?oooooooooo0;7ooooo00?oo`00ooooooooool02?ooool2o`0002_ooooo0_l0
003<ooooo`;o00004_ooool001_ooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`2a
ooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<
ooooo`03o`000?oooooooooo013ooooo000Kooooo`03o`000?oooooooooo00cooooo00?oo`00oooo
ooooool0/Oooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0c?ooool00ol0003oooooooooo`0@ooooo`006oooool00ol0003oooooooooo`0<ooooo`03
ool00?oooooooooo0;7ooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo0<cooooo00?o0000ooooooooool04?ooool001_ooooo00?o0000ooooooooool0
3?ooool00ooo003oooooooooo`2aooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo013ooooo000Kooooo`;o00003Ooo
ool00ooo003oooooooooo`2aooooo`03ool00?oooooooooo00Sooooo0_l0000[ooooo`;o0000c?oo
ool2o`0001;ooooo000Kooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0/Oooool0
0ooo003oooooooooo`09ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool0
0ol0003oooooooooo`0@ooooo`006oooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo
0;7ooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
0<cooooo00?o0000ooooooooool04?ooool001_ooooo00?o0000ooooooooool03?ooool00ooo003o
ooooooooo`2aooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`3<ooooo`03o`000?oooooooooo013ooooo000Kooooo`;o00003Oooool00ooo003ooooo
ooooo`2aooooo`03ool00?oooooooooo00Sooooo0_l0000[ooooo`;o0000c?ooool2o`0001;ooooo
000>ooooo`?o00001?ooool2o`0000Cooooo00?o0000ooooooooool03?ooool00ooo003ooooooooo
o`2aooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool08_ooool3o`0000Cooooo00?o
0000ooooooooool0c?ooool00ol0003oooooooooo`0@ooooo`003Oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0<ooooo`03ool0
0?oooooooooo0;7ooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo013o
oooo000Aooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`00000=oooo
o`?oo`00/Oooool3ool000[ooooo00?o0000ooooooooool09Oooool01Ol0003ooooooooooooooooo
00000<kooooo00?o0000ooooooooool04?ooool000oooooo0_l00003ooooo`04o`000?oooooooooo
o`0000?ooooo0ol0000;ooooo`?oo`00/Oooool3ool000Wooooo0_l0000Uooooo`;o00001?ooool2
o`000<_ooooo0ol0000Booooo`004Oooool01?l0003oooooooooool00002ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`06ooooo`?oo`005_ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo01?ooooo0ooo0009ooooo`;o00009oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooool000004_ooool000gooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool2o`0002?o
oooo00Go0000ooooooooooooooooo`000003ooooom3o00004_ooool000kooooo0ol00004ooooo`;o
00001?ooooo@o`0002Cooooo0ol0003Vooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 503}, {310.438, 0}} -> {-0.0514703, -0.0309082, \
0.0041808, 0.0041808}, {{12.3125, 240.062}, {303, 162.25}} -> {-13.4621, \
-5.44775, 0.101255, 0.2467}, {{262.875, 490.688}, {303, 162.25}} -> \
{-38.8291, -4.12962, 0.101237, 0.0496193}, {{12.3125, 240.062}, {148.125, \
7.375}} -> {-9.85604, -43.6432, 0.299806, 0.24666}, {{262.875, 490.688}, \
{148.125, 7.375}} -> {-85.1316, -11.7081, 0.300191, 0.0492634}}]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["DTFT vs. DFT: Example #3: (1+1/6)Hz cosine wave", "Section"],

Cell[CellGroupData[{

Cell["Sampled sequence", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(x[t_] := Cos[\ 2  \[Pi]\ \((1 + 1/6)\) t];\)\), "\n", 
    \(\(xd = \ sampler[x, fs = 10, {0, 3}];\)\), "\[IndentingNewLine]", 
    \(\(If[OddQ[Length[xd]], \ xd\  = \ Drop[xd, \(-1\)]];\)\), "\n", 
    \(\(gx\  = \ 
        DiscreteListPlot2[xd, \ Blue, \ Frame \[Rule] True, 
          Axes \[Rule] {True, False}, \ ImageSize \[Rule] 504, \ 
          AspectRatio \[Rule] 1/3];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
%%ImageSize: 504 168 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0328407 0.166231 0.159166 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18801 -0.0125 -3 -9 ]
[.18801 -0.0125 3 0 ]
[.35222 -0.0125 -6 -9 ]
[.35222 -0.0125 6 0 ]
[.51642 -0.0125 -6 -9 ]
[.51642 -0.0125 6 0 ]
[.68062 -0.0125 -6 -9 ]
[.68062 -0.0125 6 0 ]
[.84483 -0.0125 -6 -9 ]
[.84483 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00706 -12 -4.5 ]
[-0.0125 .00706 0 4.5 ]
[-0.0125 .08665 -24 -4.5 ]
[-0.0125 .08665 0 4.5 ]
[-0.0125 .16623 -6 -4.5 ]
[-0.0125 .16623 0 4.5 ]
[-0.0125 .24581 -18 -4.5 ]
[-0.0125 .24581 0 4.5 ]
[-0.0125 .3254 -6 -4.5 ]
[-0.0125 .3254 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18801 0 m
.18801 .00625 L
s
[(5)] .18801 -0.0125 0 1 Mshowa
.35222 0 m
.35222 .00625 L
s
[(10)] .35222 -0.0125 0 1 Mshowa
.51642 0 m
.51642 .00625 L
s
[(15)] .51642 -0.0125 0 1 Mshowa
.68062 0 m
.68062 .00625 L
s
[(20)] .68062 -0.0125 0 1 Mshowa
.84483 0 m
.84483 .00625 L
s
[(25)] .84483 -0.0125 0 1 Mshowa
.125 Mabswid
.05665 0 m
.05665 .00375 L
s
.08949 0 m
.08949 .00375 L
s
.12233 0 m
.12233 .00375 L
s
.15517 0 m
.15517 .00375 L
s
.22085 0 m
.22085 .00375 L
s
.25369 0 m
.25369 .00375 L
s
.28654 0 m
.28654 .00375 L
s
.31938 0 m
.31938 .00375 L
s
.38506 0 m
.38506 .00375 L
s
.4179 0 m
.4179 .00375 L
s
.45074 0 m
.45074 .00375 L
s
.48358 0 m
.48358 .00375 L
s
.54926 0 m
.54926 .00375 L
s
.5821 0 m
.5821 .00375 L
s
.61494 0 m
.61494 .00375 L
s
.64778 0 m
.64778 .00375 L
s
.71346 0 m
.71346 .00375 L
s
.74631 0 m
.74631 .00375 L
s
.77915 0 m
.77915 .00375 L
s
.81199 0 m
.81199 .00375 L
s
.87767 0 m
.87767 .00375 L
s
.91051 0 m
.91051 .00375 L
s
.94335 0 m
.94335 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00706 m
.00625 .00706 L
s
[(-1)] -0.0125 .00706 1 0 Mshowa
0 .08665 m
.00625 .08665 L
s
[(-0.5)] -0.0125 .08665 1 0 Mshowa
0 .16623 m
.00625 .16623 L
s
[(0)] -0.0125 .16623 1 0 Mshowa
0 .24581 m
.00625 .24581 L
s
[(0.5)] -0.0125 .24581 1 0 Mshowa
0 .3254 m
.00625 .3254 L
s
[(1)] -0.0125 .3254 1 0 Mshowa
.125 Mabswid
0 .02298 m
.00375 .02298 L
s
0 .0389 m
.00375 .0389 L
s
0 .05481 m
.00375 .05481 L
s
0 .07073 m
.00375 .07073 L
s
0 .10256 m
.00375 .10256 L
s
0 .11848 m
.00375 .11848 L
s
0 .1344 m
.00375 .1344 L
s
0 .15031 m
.00375 .15031 L
s
0 .18215 m
.00375 .18215 L
s
0 .19806 m
.00375 .19806 L
s
0 .21398 m
.00375 .21398 L
s
0 .2299 m
.00375 .2299 L
s
0 .26173 m
.00375 .26173 L
s
0 .27765 m
.00375 .27765 L
s
0 .29356 m
.00375 .29356 L
s
0 .30948 m
.00375 .30948 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.02381 .32708 m
.02381 .33333 L
s
.18801 .32708 m
.18801 .33333 L
s
.35222 .32708 m
.35222 .33333 L
s
.51642 .32708 m
.51642 .33333 L
s
.68062 .32708 m
.68062 .33333 L
s
.84483 .32708 m
.84483 .33333 L
s
.125 Mabswid
.05665 .32958 m
.05665 .33333 L
s
.08949 .32958 m
.08949 .33333 L
s
.12233 .32958 m
.12233 .33333 L
s
.15517 .32958 m
.15517 .33333 L
s
.22085 .32958 m
.22085 .33333 L
s
.25369 .32958 m
.25369 .33333 L
s
.28654 .32958 m
.28654 .33333 L
s
.31938 .32958 m
.31938 .33333 L
s
.38506 .32958 m
.38506 .33333 L
s
.4179 .32958 m
.4179 .33333 L
s
.45074 .32958 m
.45074 .33333 L
s
.48358 .32958 m
.48358 .33333 L
s
.54926 .32958 m
.54926 .33333 L
s
.5821 .32958 m
.5821 .33333 L
s
.61494 .32958 m
.61494 .33333 L
s
.64778 .32958 m
.64778 .33333 L
s
.71346 .32958 m
.71346 .33333 L
s
.74631 .32958 m
.74631 .33333 L
s
.77915 .32958 m
.77915 .33333 L
s
.81199 .32958 m
.81199 .33333 L
s
.87767 .32958 m
.87767 .33333 L
s
.91051 .32958 m
.91051 .33333 L
s
.94335 .32958 m
.94335 .33333 L
s
.97619 .32958 m
.97619 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .00706 m
1 .00706 L
s
.99375 .08665 m
1 .08665 L
s
.99375 .16623 m
1 .16623 L
s
.99375 .24581 m
1 .24581 L
s
.99375 .3254 m
1 .3254 L
s
.125 Mabswid
.99625 .02298 m
1 .02298 L
s
.99625 .0389 m
1 .0389 L
s
.99625 .05481 m
1 .05481 L
s
.99625 .07073 m
1 .07073 L
s
.99625 .10256 m
1 .10256 L
s
.99625 .11848 m
1 .11848 L
s
.99625 .1344 m
1 .1344 L
s
.99625 .15031 m
1 .15031 L
s
.99625 .18215 m
1 .18215 L
s
.99625 .19806 m
1 .19806 L
s
.99625 .21398 m
1 .21398 L
s
.99625 .2299 m
1 .2299 L
s
.99625 .26173 m
1 .26173 L
s
.99625 .27765 m
1 .27765 L
s
.99625 .29356 m
1 .29356 L
s
.99625 .30948 m
1 .30948 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
0 .16623 m
1 .16623 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .16623 m
.02381 .3254 L
s
.05665 .16623 m
.05665 .28451 L
s
.08949 .16623 m
.08949 .18287 L
s
.12233 .16623 m
.12233 .07268 L
s
.15517 .16623 m
.15517 .01054 L
s
.18801 .16623 m
.18801 .02839 L
s
.22085 .16623 m
.22085 .11705 L
s
.25369 .16623 m
.25369 .23097 L
s
.28654 .16623 m
.28654 .31164 L
s
.31938 .16623 m
.31938 .31761 L
s
.35222 .16623 m
.35222 .24581 L
s
.38506 .16623 m
.38506 .13314 L
s
.4179 .16623 m
.4179 .03746 L
s
.45074 .16623 m
.45074 .00794 L
s
.48358 .16623 m
.48358 .05973 L
s
.51642 .16623 m
.51642 .16623 L
s
.54926 .16623 m
.54926 .27273 L
s
.5821 .16623 m
.5821 .32452 L
s
.61494 .16623 m
.61494 .295 L
s
.64778 .16623 m
.64778 .19932 L
s
.68062 .16623 m
.68062 .08665 L
s
.71346 .16623 m
.71346 .01485 L
s
.74631 .16623 m
.74631 .02083 L
s
.77915 .16623 m
.77915 .10149 L
s
.81199 .16623 m
.81199 .21542 L
s
.84483 .16623 m
.84483 .30407 L
s
.87767 .16623 m
.87767 .32192 L
s
.91051 .16623 m
.91051 .25979 L
s
.94335 .16623 m
.94335 .14959 L
s
.97619 .16623 m
.97619 .04795 L
s
.005 w
.02381 .3254 Mdot
.05665 .28451 Mdot
.08949 .18287 Mdot
.12233 .07268 Mdot
.15517 .01054 Mdot
.18801 .02839 Mdot
.22085 .11705 Mdot
.25369 .23097 Mdot
.28654 .31164 Mdot
.31938 .31761 Mdot
.35222 .24581 Mdot
.38506 .13314 Mdot
.4179 .03746 Mdot
.45074 .00794 Mdot
.48358 .05973 Mdot
.51642 .16623 Mdot
.54926 .27273 Mdot
.5821 .32452 Mdot
.61494 .295 Mdot
.64778 .19932 Mdot
.68062 .08665 Mdot
.71346 .01485 Mdot
.74631 .02083 Mdot
.77915 .10149 Mdot
.81199 .21542 Mdot
.84483 .30407 Mdot
.87767 .32192 Mdot
.91051 .25979 Mdot
.94335 .14959 Mdot
.97619 .04795 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 168},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000Z2000`400?l00000o`00003ooooooooi
ooooo`00<?ooool2o`0004Sooooo0ol00015ooooo`?o00001?ooool2o`00047ooooo0ol00003oooo
o`?o0000@Oooool5o`0000?ooooo0_l00010ooooo`Go00000_ooool3o`0004kooooo000_ooooo`04
o`000?ooooooooooo`0004Kooooo00Go0000ooooooooooooooooo`000015ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo0000@Oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool0?oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
043ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo04_ooooo000_
ooooo`04o`000?ooooooooooo`0004[ooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`00047ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`10ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000@Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo04_ooooo000_ooooo`04o`000?ooooooooooo`0004[o
oooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
047ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`11ooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0Boooool002oooooo00Co0000oooooooooooo0000A_ooool4o`0004Kooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00011ooooo`04o`000?ooooooooooooooo`Co0000
@Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000?oooool01_l0
003ooooooooooooooooo0000ooooo`Co0000C_ooool002oooooo00Co0000oooooooooooo0000A_oo
ool00ol0003oooooooooo`16ooooo`;o00001?ooool01?l0003oooooooooool00010ooooo`;o0000
0oooool00ol0003oooooooooo`12ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool0000oooooo`07o`000?ooooooooooooooool0003oooooo`00001Aooooo`00<?ooool2
o`0004Oooooo1Ol00015ooooo`03o`000?oooooooooo00?ooooo0_l00012ooooo`04o`000?oooooo
ooooooooo`Go0000@Oooool3o`0000Cooooo0_l00011ooooo`?o00000_ooool5o`0004gooooo003o
ooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003o
ooooooWooooo003oooooooWooooo000Woooooooo0000b?l0000:ooooo`007?ooool3o`0000Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`007Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool001Gooooo1Ol00003
ooooo`03o`000?oooooooooo00Oooooo0ol00007ooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`0Yooooo`;o003o7?ooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0@Oooool4o`0000[ooooo000Moooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0bOooool2o`00ooSooooo00?o0000oooo
ooooool02?ooool001gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`13ooooo`;o
003oQ?ooool00ol00?ooooooooooo`3gooooo`03o`000?oooooooooo00Sooooo000Looooo`;o0000
2Oooool00ol0003oooooooooo`13ooooo`;o003oQ?ooool00ol00?ooooooooooo`3gooooo`03o`00
0?oooooooooo00Sooooo000Mooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@ooo
ool00ol00?ooooooooooo`23ooooo`03o`00oooooooooooo07Cooooo0_l00?n1ooooo`03o`000?oo
oooooooo00Sooooo000Wooooo`03o`000?oooooooooo04?ooooo00?o003oooooooooool0Poooool0
0ol00?ooooooooooo`1dooooo`;o003oPOooool00ol0003oooooooooo`08ooooo`009oooool00ol0
003oooooooooo`13ooooo`03o`00oooooooooooo08?ooooo00?o003oooooooooool0MOooool00ol0
0?ooooooooooo`0;ooooo`;o003oL_ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003o
ooooooooo`13ooooo`03o`00oooooooooooo08?ooooo00?o003oooooooooool0MOooool00ol00?oo
ooooooooo`0;ooooo`;o003oL_ooool00ol0003oooooooooo`08ooooo`009oooool2o`0004Cooooo
00?o003oooooooooool0Poooool00ol00?ooooooooooo`1eooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool0K_ooool3o`0000[ooooo000Wooooo`03o`000?oooooooooo04?ooooo00?o
003oooooooooool0Poooool00ol00?ooooooooooo`1eooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0L?ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`13
ooooo`03o`00oooooooooooo00_ooooo0_l00?mfooooo`03o`00oooooooooooo07Gooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`1`ooooo`03o`000?oooooooooo00Sooooo000Woooo
o`03o`000?oooooooooo04?ooooo00?o003oooooooooool02oooool2o`00ogKooooo00?o003ooooo
ooooool0MOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo073ooooo00?o0000oooo
ooooool02?ooool002Oooooo00?o0000ooooooooool0@oooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo07Cooooo00?o003oooooooooool0MOooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo073ooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0
@oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo07Cooooo00?o003oooooooooool0
MOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo073ooooo00?o0000ooooooooool0
2?ooool002Oooooo00?o0000ooooooooool0@oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo06Gooooo0_l00?l=ooooo`03o`00oooooooooooo07Gooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`1`ooooo`03o`000?oooooooooo00Sooooo000Wooooo`;o0000A?ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo06Gooooo0_l00?l=ooooo`03o`00oooooooo
oooo07Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1^ooooo`?o00002_ooool0
02Oooooo00?o0000ooooooooool0@oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
06Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1eooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool0L?ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003o
ooooooooo`13ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0IOooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo07Gooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`1`ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo04?ooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Uooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool0MOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo073ooooo
00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0@oooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`1eooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0I?ooool2o`00o`[ooooo00?o
0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0@oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1e
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0I?ooool2o`00o`[ooooo00?o0000
ooooooooool02?ooool002Oooooo00?o0000ooooooooool0@oooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo06Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1eoooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool0IOooool00ol00?ooooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo000Wooooo`;o0000A?ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo06Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1eooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool0IOooool00ol00?ooooooooooo`06ooooo`?o
00002_ooool002Oooooo00?o0000ooooooooool0@oooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo06Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1eooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool0IOooool00ol00?ooooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo04?ooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`1Uooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?oo
ool2o`00ofOooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Uooooo`03o`00oooo
oooooooo00Sooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0@oooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0<ooooo`;o003oIoooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo06Gooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`08ooooo`009oooool00ol0
003oooooooooo`13ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0IOooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0I_ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool02?ooool00ol0
003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`13ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool0IOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool0I_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo06Go
oooo00?o003oooooooooool02?ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003ooooo
ooooo`13ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0IOooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0I_ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool02?ooool00ol0003ooooo
ooooo`08ooooo`009oooool2o`0004Cooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`1Uooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`1Vooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0IOooool00ol00?oooooooooo
o`06ooooo`?o00002_ooool002Oooooo00?o0000ooooooooool0=?ooool2o`00o`gooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`1Uooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`1Vooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool0IOooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000Woooo
o`03o`000?oooooooooo03Cooooo0_l00?l=ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool0IOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool0I_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo06Gooooo00?o003ooooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`0dooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Uooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Vooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool0IOooool00ol00?ooooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo03Cooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo06Kooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`1Uooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool0
2?ooool0017ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00008ooooo`03o`000?oo
oooooooo03Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo06Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo06Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Uooooo`03o`00oooo
oooooooo00Sooooo00?o0000ooooooooool02?ooool0013ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0=?ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0IOooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0I_ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool02?ooool00ol0003ooooo
ooooo`08ooooo`002Oooool5o`0000;ooooo00Co0000oooooooooooo00002oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo03Cooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo05Kooooo0_l00?l>ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool0IOooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Sooooo
000@ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool01Oooool3o`0003Cooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo06Gooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Kooooo
0_l00?l>ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0IOooool00ol00?oooooo
ooooo`05ooooo`Co00002_ooool0013ooooo00Co0000oooooooooooo00001oooool4o`0000Sooooo
00?o0000ooooooooool0=?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool0IOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool0Eoooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool0IOooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Sooooo
000@ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0dooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`1Uooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`1Gooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`1Uooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02?ooool0017ooooo0_l0
0008ooooo`Go00001oooool00ol0003oooooooooo`0dooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`1Uooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`1Gooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`1Uooooo`03o`00oooooooooooo00Sooooo00?o
0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0=?ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0IOooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0Eoooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0IOooool00ol00?ooooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo03Cooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo06Gooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Oooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo06Gooooo00?o003ooooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`0dooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Uooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Gooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`;o
003oF?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000Wooooo`;o0000
=Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
IOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
Eoooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
2oooool2o`00oeSooooo00?o003oooooooooool01_ooool3o`0000[ooooo000Wooooo`03o`000?oo
oooooooo03Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo06Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo05Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo000Wooooo`03o`000?oooooooooo03Cooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Oooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0E_ooool0
0ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo
03Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
06Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
05Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo000Wooooo`03o`000?oooooooooo03Cooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo05Oooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0E_ooool00ol00?oo
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo03Cooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo06Gooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Oooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool0E_ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Sooooo
000Wooooo`03o`000?oooooooooo03Cooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00_ooooo0_l00?mHooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`1Gooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Kooooo00?o
003oooooooooool02?ooool00ol0003oooooooooo`08ooooo`009oooool2o`0003Gooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00_ooooo0_l00?mH
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1G
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool01_ooool3o`0000[ooooo000Woooo
o`03o`000?oooooooooo03Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool0Eoooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Foooo
o`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000oooooooo
ool0=?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`1Gooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Kooooo00?o003ooooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`0dooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo05Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo05Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo03Cooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0E_oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0Eooo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02?oo
ool002Oooooo00?o0000ooooooooool0=?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Gooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo05Kooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`08ooooo`009oooool00ol0
003oooooooooo`0dooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo04Oooooo0_l00?l=ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Gooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
05Kooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`08ooooo`009oooool2o`0003Go
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool0Aoooool2o`00o`gooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo05Oooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0E_ooool00ol00?oo
ooooooooo`06ooooo`?o00002_ooool002Oooooo00?o0000ooooooooool0=?ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`18ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo05Oooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0E_ooool00ol00?oooooo
ooooo`08ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo03Cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0B?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`1Gooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Kooooo00?o
003oooooooooool02?ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`0d
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo04Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0Eoooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1F
ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000oooo
ooooool0=?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`18ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Oooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool0E_ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03
o`000?oooooooooo03Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool0B?ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Gooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo05Kooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`08ooooo`00
9oooool00ol0003oooooooooo`0dooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo04Sooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
Eoooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool0
2?ooool002Oooooo0_l0000eooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo04Sooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0Eooo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`17ooooo`;o003o3Oooool00ol00?ooooooooooo`06ooooo`?o00002_oo
ool002Oooooo00?o0000ooooooooool0=?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`18ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo05Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool0Aoooool2o`00o`gooooo00?o003oooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`0dooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
04Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool0Eoooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`17ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003o
ooooooooo`0dooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo04Sooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0Eoooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`17ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`009oooool00ol0003oooooooooo`0dooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo04Sooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool0Eoooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`17ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool02?ooool00ol0003oooooooooo`08ooooo`007Oooool2o`0000Sooooo00?o
0000ooooooooool0=?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`18ooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Oooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0Aoooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Sooooo00?o
0000ooooooooool02?ooool001cooooo00Co0000oooooooooooo00001oooool00ol0003ooooooooo
o`0dooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo04Sooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0Eoooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`17ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`007?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo03Cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0B?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`;o003oBOooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`17ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`007?ooool01?l0003oooooooooool00007ooooo`[o000000?o003oo`000?l000003?l0
00000ol00?oo0000o`00000<o`000003o`00ool0003o000000co000000?o003oo`000?l000003?l0
00000ol00?oo0000o`00000<o`000003o`00ool0003o000000co000000?o003oo`000?l000003?l0
00000ol00?oo0000o`00000<o`000003o`00ool0003o000000co000000?o003oo`000?l000003?l0
00000ol00?oo0000o`00000<o`000003o`00ool0003o000000_o000000?o003oo`000?l000003?l0
00000ol00?oo0000o`00000<o`000003o`00ool0003o000000co00000_l00?l=o`000003o`00ool0
003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000o`00000<o`000003o`00ool0
003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000o`00000<o`000003o`00ool0
003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000o`00000;o`000003o`00ool0
003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000o`00000<o`000003o`00ool0
003o000000co000000?o003oo`000?l000002Ol0000:ooooo`007?ooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo04Sooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0E_ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`18ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo02Kooooo00?o0000ooooooooool02?ooool001cooooo00Co0000
oooooooooooo00001oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`18ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Kooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0B?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo000M
ooooo`;o00002?ooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`18ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Kooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool0B?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo000Woooo
o`03o`000?oooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo04Sooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`18oooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo02Kooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000oooooooo
ool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool0B?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo04Sooooo00?o003ooooooooo
ool02oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool09_ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`07ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`18ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo05Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool0B?ooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Vooooo`03o`00
0?oooooooooo00Sooooo000Wooooo`;o00002?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00cooooo0_l00?m9ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0B?oo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0Tooooo`?o00002_ooool002Oooooo00?o0000ooooooooool01oooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo0_l00?m9ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo05Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool0B?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Vooooo`03o`000?oooooo
oooo00Sooooo000Wooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`1Gooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0B?ooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo00Oo
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Gooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Ko
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool0B?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Vooooo`03o`000?oooooooooo00So
oooo000Wooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`1Gooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0B?ooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0Vooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo00Oooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`1Gooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Kooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0B?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo000W
ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1G
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0B?ooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0V
ooooo`03o`000?oooooooooo00Sooooo000Wooooo`;o00002?ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo05Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool02oooool2o`00od[ooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool09?ooool3o`0000[ooooo000Wooooo`03o`000?oooooooooo00Oooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`1Gooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Kooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00_ooooo0_l00?m:ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo02Kooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0
1oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Oooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
E_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
Eoooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oo
oooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Gooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo05Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo05Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool09_ooool00ol0003oooooooooo`08ooooo`009oooool0
0ol0003oooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0Eoooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`1Gooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo02Kooooo00?o0000ooooooooool02?ooool0
02Oooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
05Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool0Eoooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Vooooo`03o`000?oooooooooo
00Sooooo000Wooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`1Gooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo05Oooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool09_ooool00ol0003o
ooooooooo`08ooooo`009oooool2o`0000Sooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`1Gooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo05Oooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool09?ooool3o`0000[ooooo
000Wooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`1Gooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo05Kooooo0_l00?l=ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo000W
ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1G
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo05Kooooo0_l00?l=ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo000Woooo
o`03o`000?oooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Goooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo05Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo06Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo02Kooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000oooooooo
ool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Oooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool0E_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool0IOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool09_ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`07ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool0Eoooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Fooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Uooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Vooooo`03o`00
0?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`1Gooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo02Kooooo00?o0000ooooooooool02?oo
ool002Oooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo05Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool0IOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool09_ooool00ol0003oooooooooo`08ooooo`009oooool2o`00
00Sooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Fooooo`;o003o3_ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0E_ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0IOooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool09?ooool3o`00
00[ooooo000Wooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`1Fooooo`;o003o3_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool0IOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool09_ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003ooooo
ooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0I_ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0E_ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0IOooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool09_ooool00ol0003ooooo
ooooo`08ooooo`009oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0I_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0E_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0IOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool09_ooool00ol0003oooooooooo`08ooooo`004Oooool2o`0000Cooooo00?o0000
ooooooooool00_ooool3o`0000Sooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo06Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo02Kooooo00?o0000ooooooooool02?ooool0013ooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool01ooo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo06Kooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo02Kooooo00?o0000ooooooooool02?oo
ool0013ooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Vooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool02oooool2o`00oeSooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo02Kooooo00?o0000ooooooooool02?oo
ool0013ooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`05ooooo`?o00001ooo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo06Kooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0;ooooo`;o003oF?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool0IOooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool08oooool4o`0000[ooooo000@ooooo`04o`000?oooooo
ooooo`0000Oooooo1?l00008ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`1Vooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0IOoo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0IOoo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool09_oo
ool00ol0003oooooooooo`08ooooo`004?ooool01?l0003oooooooooool00007ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo06Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Uooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Uooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Vooooo`03o`000?oo
oooooooo00Sooooo000Aooooo`;o00002?ooool5o`0000Oooooo00?o0000ooooooooool01oooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo06Kooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`1Uooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`1Uooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo
00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Vooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool0IOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool0IOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool09_ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003o
ooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0I_ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo02Kooooo00?o0000ooooooooool02?ooool002Oooooo
00?o0000ooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo06Kooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Uooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Uooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool03?ooool2o`00obOooooo00?o0000ooooooooool02?ooool002Oooooo0_l0
0008ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0I_ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0<ooooo`;o003o9Oooool3o`0000[ooooo000Wooooo`03o`000?oooooooooo00Oooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`1Vooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool0IOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool0IOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Gooooo00?o0000
ooooooooool02?ooool002Oooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo06Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Uoooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Uoooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool0=Oooool00ol0003oooooooooo`08oooo
o`009oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool0I_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo06Gooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo06Gooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`0eooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`00
0?oooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Vooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool0IOooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool0IOooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo03Gooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool01ooo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo06Kooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`1Uooooo`;o003o3Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo06Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0eooooo`03o`000?oo
oooooooo00Sooooo000Wooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`1Vooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0IOooool2
o`00o`gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Uooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool0=Oooool00ol0003oooooooooo`08ooooo`009oooool2o`00
00Sooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Vooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool0M?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
06Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0cooooo`?o00002_ooool002Oo
oooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo06Ko
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1dooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool0IOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Go
oooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool01oooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo06Kooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`1dooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0IOooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo03Gooooo00?o0000ooooooooool02?ooool002Oooooo00?o
0000ooooooooool01oooool00ol00?ooooooooooo`0<ooooo`;o003oIoooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo07Cooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`1Uooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0=Oooool00ol0003ooooooooo
o`08ooooo`009oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00cooooo0_l00?mW
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0M?ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0e
ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo00Oooooo00?o003ooooo
ooooool0MOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo07Cooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`1Uooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool0=Oooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`07ooooo`03
o`00oooooooooooo07Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1dooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool0IOooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo03Gooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0
1oooool00ol00?ooooooooooo`1eooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
M?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0eooooo`03o`000?oooooooooo00Sooooo000Wooooo`;o00002?oo
ool00ol00?ooooooooooo`1eooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0M?oo
ool00ol00?ooooooooooo`0;ooooo`;o003oIoooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo03?ooooo0ol0000:ooooo`009oooool00ol0003oooooooooo`07ooooo`03o`00oooooooo
oooo07Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1dooooo`03o`00oooooooo
oooo00_ooooo0_l00?mWooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0=Oooool0
0ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo
07Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1dooooo`03o`00oooooooooooo
07Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0eooooo`03o`000?oooooooooo
00Sooooo000Wooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool0MOooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo07Cooooo00?o003oooooooooool0M?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo03Gooooo00?o0000ooooooooool02?ooool002Oooooo
00?o0000ooooooooool01oooool00ol00?ooooooooooo`1eooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool0M?ooool00ol00?ooooooooooo`1dooooo`;o003o3Oooool00ol00?oooooo
ooooo`0eooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo00Oooooo00?o
003oooooooooool0MOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo07Cooooo00?o
003oooooooooool0M?ooool2o`00o`gooooo00?o003oooooooooool0=Oooool00ol0003ooooooooo
o`08ooooo`009oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo07Gooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`1dooooo`03o`00oooooooooooo08?ooooo00?o003o
ooooooooool0=Oooool00ol0003oooooooooo`08ooooo`009oooool2o`0000Sooooo00?o003ooooo
ooooool0M?ooool2o`00o`kooooo00?o003oooooooooool0M?ooool00ol00?ooooooooooo`23oooo
o`03o`00oooooooooooo03?ooooo0ol0000:ooooo`009oooool00ol0003oooooooooo`07ooooo`03
o`00oooooooooooo07Cooooo0_l00?l>ooooo`03o`00oooooooooooo07Cooooo00?o003ooooooooo
ool0Poooool00ol00?ooooooooooo`0eooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`00
0?oooooooooo00Oooooo00?o003oooooooooool0Q?ooool00ol00?ooooooooooo`1dooooo`03o`00
oooooooooooo08?ooooo00?o003oooooooooool0=Oooool00ol0003oooooooooo`08ooooo`009ooo
ool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo08?ooooo0_l00?mfooooo`03o`00oooo
oooooooo08?ooooo00?o003oooooooooool0=Oooool00ol0003oooooooooo`08ooooo`007?ooool3
o`0000Sooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`23ooooo`;o003oM_ooool0
0ol00?ooooooooooo`23ooooo`03o`00oooooooooooo03Gooooo00?o0000ooooooooool02?ooool0
01gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo
0?_ooooo00?o003oooooooooool0Poooool2o`00ocKooooo00?o0000ooooooooool02?ooool001go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo0?[o
oooo0_l00?n5ooooo`;o003o=_ooool00ol0003oooooooooo`08ooooo`007Oooool00ol0003ooooo
ooooo`07ooooo`?o00001oooool2o`00oo_ooooo0_l00?njooooo`Co00002_ooool001gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`;o003oBOooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0B?ooool00ol0003ooooooooo
o`17ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool02?ooool001cooooo0_l00009
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool001gooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000Woooooooo
0000b?l0000:ooooo`00\
\>"],
  ImageRangeCache->{{{0, 503}, {167, 0}} -> {-3.34862, -1.24741, 0.0670304, \
0.0138304}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Magnitude plot of DTFT as a function of frequency", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(X\[Theta]\  = DTFT[xd, \[Theta]]\  // \ Simplify; 
    g1 = Plot[
        Abs[X\[Theta]\  /. \ \[Theta] \[Rule] \ 2  \[Pi]\ f/fs], {f, \(-fs\)/
            2, fs/2}, \ PlotStyle \[Rule] {Blue, \ Dashing[{ .01}]}, \ 
        PlotRange \[Rule] All, PlotPoints \[Rule] 200];\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.014681 0.0391627 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01468 -6 -4.5 ]
[-0.0125 .01468 0 4.5 ]
[-0.0125 .09301 -6 -4.5 ]
[-0.0125 .09301 0 4.5 ]
[-0.0125 .17133 -6 -4.5 ]
[-0.0125 .17133 0 4.5 ]
[-0.0125 .24966 -6 -4.5 ]
[-0.0125 .24966 0 4.5 ]
[-0.0125 .32798 -6 -4.5 ]
[-0.0125 .32798 0 4.5 ]
[-0.0125 .40631 -12 -4.5 ]
[-0.0125 .40631 0 4.5 ]
[-0.0125 .48463 -12 -4.5 ]
[-0.0125 .48463 0 4.5 ]
[-0.0125 .56296 -12 -4.5 ]
[-0.0125 .56296 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01468 m
.00625 .01468 L
s
[(0)] -0.0125 .01468 1 0 Mshowa
0 .09301 m
.00625 .09301 L
s
[(2)] -0.0125 .09301 1 0 Mshowa
0 .17133 m
.00625 .17133 L
s
[(4)] -0.0125 .17133 1 0 Mshowa
0 .24966 m
.00625 .24966 L
s
[(6)] -0.0125 .24966 1 0 Mshowa
0 .32798 m
.00625 .32798 L
s
[(8)] -0.0125 .32798 1 0 Mshowa
0 .40631 m
.00625 .40631 L
s
[(10)] -0.0125 .40631 1 0 Mshowa
0 .48463 m
.00625 .48463 L
s
[(12)] -0.0125 .48463 1 0 Mshowa
0 .56296 m
.00625 .56296 L
s
[(14)] -0.0125 .56296 1 0 Mshowa
.125 Mabswid
0 .03426 m
.00375 .03426 L
s
0 .05384 m
.00375 .05384 L
s
0 .07342 m
.00375 .07342 L
s
0 .11259 m
.00375 .11259 L
s
0 .13217 m
.00375 .13217 L
s
0 .15175 m
.00375 .15175 L
s
0 .19091 m
.00375 .19091 L
s
0 .21049 m
.00375 .21049 L
s
0 .23008 m
.00375 .23008 L
s
0 .26924 m
.00375 .26924 L
s
0 .28882 m
.00375 .28882 L
s
0 .3084 m
.00375 .3084 L
s
0 .34756 m
.00375 .34756 L
s
0 .36714 m
.00375 .36714 L
s
0 .38673 m
.00375 .38673 L
s
0 .42589 m
.00375 .42589 L
s
0 .44547 m
.00375 .44547 L
s
0 .46505 m
.00375 .46505 L
s
0 .50421 m
.00375 .50421 L
s
0 .5238 m
.00375 .5238 L
s
0 .54338 m
.00375 .54338 L
s
0 .58254 m
.00375 .58254 L
s
0 .60212 m
.00375 .60212 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01468 m
1 .01468 L
s
.99375 .09301 m
1 .09301 L
s
.99375 .17133 m
1 .17133 L
s
.99375 .24966 m
1 .24966 L
s
.99375 .32798 m
1 .32798 L
s
.99375 .40631 m
1 .40631 L
s
.99375 .48463 m
1 .48463 L
s
.99375 .56296 m
1 .56296 L
s
.125 Mabswid
.99625 .03426 m
1 .03426 L
s
.99625 .05384 m
1 .05384 L
s
.99625 .07342 m
1 .07342 L
s
.99625 .11259 m
1 .11259 L
s
.99625 .13217 m
1 .13217 L
s
.99625 .15175 m
1 .15175 L
s
.99625 .19091 m
1 .19091 L
s
.99625 .21049 m
1 .21049 L
s
.99625 .23008 m
1 .23008 L
s
.99625 .26924 m
1 .26924 L
s
.99625 .28882 m
1 .28882 L
s
.99625 .3084 m
1 .3084 L
s
.99625 .34756 m
1 .34756 L
s
.99625 .36714 m
1 .36714 L
s
.99625 .38673 m
1 .38673 L
s
.99625 .42589 m
1 .42589 L
s
.99625 .44547 m
1 .44547 L
s
.99625 .46505 m
1 .46505 L
s
.99625 .50421 m
1 .50421 L
s
.99625 .5238 m
1 .5238 L
s
.99625 .54338 m
1 .54338 L
s
.99625 .58254 m
1 .58254 L
s
.99625 .60212 m
1 .60212 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .05384 m
.02395 .05384 L
.02408 .05383 L
.02423 .05381 L
.02437 .05378 L
.02462 .05372 L
.02489 .05362 L
.02519 .05348 L
.02551 .05329 L
.02608 .05286 L
.02722 .05164 L
.02847 .04976 L
.02973 .04731 L
.03109 .04412 L
.03355 .03703 L
.03593 .02892 L
.03718 .02428 L
.03852 .01917 L
.03884 .01793 L
.03919 .01658 L
.03935 .01596 L
.03952 .0153 L
.03967 .01474 L
.03982 .01523 L
.04101 .01981 L
.04331 .02848 L
.04586 .03724 L
.04819 .04401 L
.04934 .04682 L
.0506 .0494 L
.05177 .05134 L
.05288 .05271 L
.05342 .05322 L
.05401 .05364 L
.05433 .05382 L
.05467 .05396 L
.05495 .05405 L
.05511 .05408 L
.05526 .05411 L
.05542 .05412 L
.05551 .05413 L
.05559 .05413 L
.05575 .05412 L
.05582 .05412 L
.05591 .05411 L
.05605 .05409 L
.05621 .05406 L
.05649 .05398 L
.05666 .05391 L
.05684 .05383 L
Mistroke
.05717 .05365 L
.0578 .0532 L
.05844 .05258 L
.05905 .05186 L
.06017 .05016 L
.06271 .04477 L
.06513 .03782 L
.06736 .03023 L
.06855 .02583 L
.06983 .02095 L
.07045 .01853 L
.07075 .01734 L
.07103 .01624 L
.07129 .01523 L
.07142 .01473 L
.07156 .0152 L
.07213 .01744 L
.07672 .03465 L
.07925 .04267 L
.08036 .04567 L
.08157 .04852 L
.08267 .0507 L
.08385 .05256 L
.0845 .05337 L
.08509 .05396 L
.08568 .05443 L
.08624 .05475 L
.08653 .05486 L
.0868 .05494 L
.08696 .05497 L
.0871 .05499 L
.08718 .055 L
.08726 .055 L
.08742 .05501 L
.08757 .055 L
.08765 .055 L
.08773 .05499 L
.08789 .05496 L
.08806 .05492 L
.08838 .05482 L
.08866 .05469 L
.08918 .05438 L
.08975 .05392 L
.09089 .05262 L
.09213 .05067 L
.09325 .04841 L
.09578 .04187 L
.09828 .03366 L
.10059 .02501 L
.10176 .02041 L
Mistroke
.10233 .01812 L
.10284 .01602 L
.10298 .01547 L
.10313 .01488 L
.10326 .01504 L
.10339 .01556 L
.10398 .01795 L
.10523 .02298 L
.10995 .04038 L
.11254 .04786 L
.11372 .0506 L
.11497 .05297 L
.11612 .05465 L
.11678 .05538 L
.11739 .0559 L
.11768 .05609 L
.11795 .05625 L
.1182 .05636 L
.11847 .05645 L
.1186 .05649 L
.11875 .05652 L
.11889 .05654 L
.11902 .05656 L
.11917 .05656 L
.11931 .05656 L
.11946 .05655 L
.11954 .05654 L
.11962 .05653 L
.11978 .05649 L
.11993 .05645 L
.12026 .05633 L
.12055 .05619 L
.12086 .056 L
.1214 .05557 L
.12199 .05497 L
.12329 .05316 L
.12451 .05087 L
.12696 .04471 L
.1292 .0375 L
.13169 .02811 L
.1329 .02318 L
.134 .0186 L
.13455 .01625 L
.1347 .01561 L
.13479 .01526 L
.13486 .01493 L
.135 .01502 L
.13515 .01565 L
.13623 .02025 L
.13861 .03012 L
Mistroke
.14331 .04687 L
.14454 .05029 L
.14588 .05343 L
.14714 .05578 L
.14771 .05662 L
.14831 .05739 L
.14892 .05801 L
.14948 .05844 L
.14974 .0586 L
.15003 .05874 L
.15017 .05879 L
.15031 .05884 L
.15044 .05887 L
.15057 .0589 L
.15065 .05892 L
.15074 .05893 L
.15089 .05894 L
.15098 .05894 L
.15107 .05894 L
.15116 .05894 L
.15124 .05893 L
.15139 .05891 L
.15148 .05889 L
.15156 .05888 L
.15187 .05878 L
.15214 .05866 L
.15244 .05849 L
.15305 .05803 L
.15365 .05743 L
.15427 .05664 L
.15539 .05483 L
.15659 .05231 L
.1579 .04894 L
.16279 .03167 L
.16505 .02195 L
.16567 .01919 L
.16601 .01766 L
.16632 .01623 L
.16646 .01561 L
.16659 .01501 L
.16675 .01504 L
.16688 .01566 L
.1675 .01846 L
.17007 .02996 L
.1725 .04006 L
.17492 .04878 L
.17711 .0551 L
.17834 .05785 L
.17949 .05988 L
.18008 .0607 L
Mistroke
.18071 .06139 L
.18103 .06169 L
.18139 .06195 L
.18172 .06214 L
.18202 .06228 L
.18217 .06233 L
.18233 .06237 L
.18247 .0624 L
.18263 .06242 L
.18271 .06243 L
.18279 .06243 L
.18287 .06243 L
.18296 .06242 L
.18312 .06241 L
.1832 .06239 L
.18328 .06238 L
.18344 .06234 L
.18359 .06229 L
.18386 .06218 L
.18416 .06201 L
.18448 .06179 L
.18504 .06127 L
.18564 .06057 L
.18672 .0589 L
.18786 .05657 L
.18908 .05346 L
.19129 .04638 L
.19368 .03694 L
.19627 .02512 L
.19748 .01927 L
.19809 .01627 L
.19826 .01544 L
.19835 .01497 L
.19844 .01481 L
.1986 .0156 L
.19877 .01643 L
.20107 .02782 L
.20567 .04836 L
.20803 .05672 L
.20934 .06046 L
.21055 .06325 L
.21178 .0654 L
.21243 .06624 L
.21277 .06659 L
.21312 .0669 L
.21343 .06712 L
.21372 .06728 L
.21386 .06734 L
.21401 .0674 L
.21415 .06744 L
Mistroke
.21428 .06747 L
.21436 .06748 L
.21445 .0675 L
.2146 .06751 L
.21468 .06751 L
.21477 .0675 L
.21485 .0675 L
.21494 .06749 L
.21509 .06746 L
.21518 .06744 L
.21526 .06742 L
.21555 .0673 L
.21583 .06715 L
.21613 .06695 L
.21675 .06638 L
.21732 .06568 L
.21785 .06487 L
.21906 .06254 L
.22036 .05923 L
.22277 .05106 L
.22532 .04006 L
.22773 .02793 L
.22878 .02229 L
.22933 .01926 L
.22963 .01759 L
.22992 .01602 L
.23006 .01522 L
.23022 .01501 L
.23031 .01551 L
.23039 .01598 L
.23055 .01686 L
.23113 .02012 L
.23228 .02651 L
.23481 .04014 L
.23942 .06112 L
.2418 .06873 L
.24249 .07042 L
.24313 .07178 L
.2437 .0728 L
.24433 .07371 L
.24463 .07407 L
.24494 .07439 L
.24522 .07462 L
.24551 .07482 L
.24569 .07492 L
.24585 .07499 L
.246 .07504 L
.24608 .07507 L
.24617 .07509 L
.24631 .07511 L
Mistroke
.24645 .07513 L
.24653 .07513 L
.24661 .07513 L
.24676 .07511 L
.2469 .07509 L
.24703 .07506 L
.24717 .07501 L
.24731 .07495 L
.24756 .07482 L
.24782 .07463 L
.24843 .07406 L
.24899 .07334 L
.25016 .07123 L
.25126 .06855 L
.25375 .06003 L
.2562 .04871 L
.25844 .03634 L
.26074 .0222 L
.26137 .01816 L
.26169 .01611 L
.26177 .01554 L
.26187 .01493 L
.26196 .01501 L
.26204 .01554 L
.26324 .0234 L
.26802 .05338 L
.27042 .06626 L
.27261 .07577 L
.27374 .07969 L
.27497 .08309 L
.27565 .08455 L
.27627 .08563 L
.27687 .08642 L
.27717 .08673 L
.2775 .087 L
.2778 .08717 L
.27797 .08724 L
.27813 .08729 L
.27828 .08732 L
.27841 .08733 L
.27857 .08733 L
.27872 .08731 L
.27886 .08728 L
.279 .08723 L
.27912 .08718 L
.27926 .08711 L
.27956 .08691 L
.27984 .08667 L
.28048 .0859 L
.28106 .08495 L
Mistroke
.28236 .08195 L
.28356 .07815 L
.28466 .07378 L
.28717 .06107 L
.28961 .04541 L
.29081 .0368 L
.29191 .02849 L
.29298 .02009 L
.29324 .01802 L
.29351 .01579 L
.29367 .01486 L
.29382 .01603 L
.2941 .01833 L
.29646 .03763 L
.30129 .07445 L
.3035 .08827 L
.30476 .09484 L
.30593 .1 L
.30709 .10406 L
.30768 .10573 L
.30833 .10721 L
.30868 .10787 L
.30901 .10838 L
.30935 .10881 L
.30966 .10911 L
.3098 .10922 L
.30996 .10932 L
.31011 .1094 L
.31024 .10945 L
.31039 .10948 L
.31055 .1095 L
.31063 .1095 L
.31071 .10949 L
.31087 .10946 L
.31102 .10941 L
.3111 .10937 L
.31118 .10933 L
.31151 .10909 L
.31179 .10881 L
.3121 .10842 L
.3128 .10719 L
.31344 .10566 L
.31468 .10158 L
.31587 .09637 L
.31826 .08203 L
.32047 .06454 L
.32274 .04315 L
.32393 .03074 L
.32458 .0237 L
.3249 .0202 L
Mistroke
.32519 .01698 L
.32535 .0152 L
.3255 .01585 L
.32566 .01764 L
.32583 .0196 L
.32654 .02763 L
.32777 .04195 L
.33021 .07017 L
.33254 .09613 L
.33512 .12176 L
.33757 .14145 L
.33866 .14844 L
.33986 .15456 L
.34043 .1569 L
.34104 .15893 L
.34138 .15985 L
.34169 .16056 L
.342 .16115 L
.34229 .16157 L
.34256 .16186 L
.34269 .16197 L
.34284 .16206 L
.34299 .16212 L
.34308 .16214 L
.34315 .16215 L
.3433 .16214 L
.34344 .16211 L
.34357 .16205 L
.34371 .16196 L
.34384 .16185 L
.34396 .16173 L
.34425 .16135 L
.34452 .16087 L
.34509 .15954 L
.3457 .15753 L
.34635 .15481 L
.34695 .15169 L
.34803 .14468 L
.34918 .13516 L
.35175 .10649 L
.35417 .07017 L
.35534 .04973 L
.35598 .03777 L
.35658 .02608 L
.35683 .02111 L
.35696 .01837 L
.35709 .01581 L
.35722 .01637 L
.35737 .01946 L
.35764 .02496 L
Mistroke
.3588 .05031 L
.36352 .16496 L
.36853 .29691 L
.37335 .41778 L
.378 .51366 L
.3804 .5514 L
.38163 .56698 L
.38294 .58073 L
.38418 .59076 L
.38531 .59739 L
.38585 .59971 L
.38613 .6007 L
.38644 .60158 L
.3867 .6022 L
.38685 .60248 L
.387 .60273 L
.38714 .60292 L
.38726 .60307 L
.38739 .60317 L
.38752 .60325 L
.38766 .60331 L
.38775 .60332 L
.38782 .60332 L
.38797 .60328 L
.38812 .60321 L
.38825 .6031 L
.38838 .60297 L
.38866 .60256 L
.38897 .60193 L
.38926 .6012 L
.38989 .599 L
.39044 .59651 L
.39103 .59316 L
.39211 .5854 L
.39335 .57384 L
.39448 .56106 L
.39701 .52502 L
.40184 .4326 L
.4065 .32481 L
.41144 .20461 L
.41621 .09724 L
.4186 .05001 L
.41965 .03123 L
.41994 .0263 L
.42024 .02116 L
.4205 .01686 L
.42065 .01491 L
.42079 .01715 L
.422 .0357 L
.42314 .0516 L
Mistroke
.42567 .08075 L
.42685 .0916 L
.4281 .10106 L
.42927 .1081 L
.43033 .11301 L
.43089 .11502 L
.43148 .11678 L
.43181 .11757 L
.43212 .11818 L
.43243 .1187 L
.43272 .11908 L
.43296 .11934 L
.43309 .11945 L
.43323 .11954 L
.43338 .11962 L
.43352 .11967 L
.43366 .1197 L
.43379 .11971 L
.43394 .1197 L
.43408 .11967 L
.43421 .11962 L
.43434 .11956 L
.43449 .11946 L
.43465 .11933 L
.43493 .11905 L
.43524 .11864 L
.43553 .11818 L
.43608 .11708 L
.43731 .11366 L
.43837 .10969 L
.43952 .10444 L
.44444 .07369 L
.44689 .05547 L
.44919 .038 L
.45031 .02956 L
.45139 .02173 L
.45198 .01752 L
.45214 .01638 L
.45223 .01576 L
.45231 .01518 L
.45239 .01473 L
.45247 .01531 L
.45262 .01633 L
.45375 .02389 L
.45611 .03812 L
.45869 .05087 L
.45988 .05559 L
.46115 .05979 L
.46236 .06294 L
.46345 .06512 L
Mistroke
.46403 .066 L
.46465 .06673 L
.46517 .06719 L
.46547 .06738 L
.46575 .06752 L
.4659 .06758 L
.46606 .06763 L
.46614 .06765 L
.46623 .06767 L
.46638 .06769 L
.46654 .0677 L
.46668 .06769 L
.46681 .06768 L
.46696 .06765 L
.46711 .06762 L
.46729 .06756 L
.46763 .0674 L
.46796 .0672 L
.46826 .06697 L
.46886 .06637 L
.46951 .06554 L
.4707 .06352 L
.47294 .0582 L
.47531 .05071 L
.47784 .04119 L
.48025 .0312 L
.48152 .02578 L
.48286 .02004 L
.48344 .01757 L
.48376 .01622 L
.48392 .01556 L
.48406 .01495 L
.48415 .01476 L
.48423 .01513 L
.48442 .01591 L
.48475 .01726 L
.48538 .01987 L
.4877 .02891 L
.49008 .03714 L
.49226 .04345 L
.49459 .04869 L
.49582 .05074 L
.49649 .05166 L
.49711 .05235 L
.49766 .05287 L
.49826 .0533 L
.49859 .05349 L
.49889 .05363 L
.49919 .05372 L
.49933 .05376 L
Mistroke
.49949 .0538 L
.49964 .05382 L
.49978 .05384 L
.49991 .05384 L
.50004 .05384 L
.50019 .05384 L
.50035 .05382 L
.50049 .0538 L
.50064 .05377 L
.5009 .0537 L
.50119 .05359 L
.50171 .05332 L
.5023 .0529 L
.50286 .05239 L
.50412 .05083 L
.50535 .0488 L
.50666 .04608 L
.50923 .03927 L
.51166 .03124 L
.51387 .02289 L
.51447 .02047 L
.51512 .01781 L
.51544 .01651 L
.51559 .01586 L
.51574 .01526 L
.51586 .01472 L
.516 .01523 L
.5163 .01646 L
.51869 .02669 L
.52123 .03741 L
.52363 .0469 L
.52624 .0558 L
.52746 .05929 L
.52876 .06241 L
.52986 .06455 L
.53107 .06629 L
.53171 .06694 L
.53202 .06718 L
.5323 .06737 L
.53256 .0675 L
.53284 .0676 L
.53298 .06764 L
.53312 .06767 L
.53327 .06769 L
.53343 .0677 L
.53358 .06769 L
.53373 .06767 L
.53382 .06766 L
.53389 .06764 L
.53407 .06759 L
Mistroke
.53423 .06753 L
.53441 .06745 L
.53474 .06725 L
.53505 .06701 L
.53537 .06671 L
.53595 .06602 L
.53709 .06413 L
.53831 .0613 L
.54052 .05409 L
.54307 .04253 L
.5455 .02869 L
.54666 .02123 L
.54699 .01899 L
.5473 .01685 L
.54744 .01591 L
.54759 .01491 L
.54774 .01555 L
.54789 .01657 L
.55011 .03272 L
.5547 .06741 L
.55725 .08547 L
.55958 .0997 L
.56074 .10567 L
.56199 .11113 L
.56318 .11517 L
.56375 .11669 L
.56428 .11782 L
.56484 .11875 L
.56513 .11912 L
.56528 .11927 L
.56544 .11941 L
.56558 .11951 L
.56571 .11959 L
.56584 .11964 L
.56596 .11968 L
.56611 .11971 L
.56624 .11971 L
.56638 .1197 L
.56653 .11966 L
.56669 .11959 L
.56683 .11951 L
.56699 .11938 L
.56715 .11924 L
.56742 .11892 L
.56772 .11847 L
.56839 .11709 L
.56902 .11533 L
.57018 .11082 L
.57127 .10508 L
.57246 .09705 L
Mistroke
.57375 .08632 L
.57617 .06041 L
.57739 .04434 L
.57807 .0347 L
.57871 .02508 L
.579 .02054 L
.57916 .01802 L
.57931 .01563 L
.57938 .01499 L
.57947 .01634 L
.57964 .01925 L
.57995 .02446 L
.58109 .04434 L
.5833 .0871 L
.58828 .19791 L
.59307 .31422 L
.59768 .42214 L
.60025 .47589 L
.60258 .51832 L
.60504 .55501 L
.6073 .58026 L
.60843 .58955 L
.60963 .59682 L
.61025 .59954 L
.61082 .60142 L
.61116 .60222 L
.61146 .60275 L
.61163 .60297 L
.61171 .60307 L
.61181 .60315 L
.61189 .60321 L
.61198 .60326 L
.61214 .60331 L
.61229 .60332 L
.61242 .60328 L
.61257 .6032 L
.61266 .60314 L
.61273 .60307 L
.61289 .60289 L
.61305 .60265 L
.61336 .60207 L
.61364 .60137 L
.61394 .60046 L
.61447 .5984 L
.61509 .59533 L
.61567 .59179 L
.61699 .58138 L
.61825 .56845 L
.61944 .55359 L
.62167 .51931 L
Mistroke
.62629 .42599 L
.6312 .30404 L
.63593 .17934 L
.63834 .11779 L
.63961 .08692 L
.64095 .05582 L
.64216 .02934 L
.64249 .02236 L
.64267 .01857 L
.64276 .01672 L
.64284 .01502 L
.64292 .01593 L
.643 .01761 L
.64317 .02113 L
.64348 .02719 L
.64579 .06963 L
.64818 .10545 L
.65036 .13073 L
.65156 .14147 L
.6527 .14959 L
.6539 .15593 L
.65458 .15853 L
.65491 .15953 L
.65521 .16031 L
.65551 .16093 L
.65583 .16146 L
.65598 .16166 L
.65615 .16184 L
.65624 .16192 L
.65632 .16198 L
.6564 .16203 L
.65649 .16208 L
.65664 .16213 L
.65678 .16215 L
.65694 .16214 L
.65702 .16211 L
.6571 .16208 L
.65725 .16201 L
.65739 .16191 L
.65769 .16159 L
.65796 .16121 L
.65821 .16076 L
.65878 .15943 L
.65934 .15772 L
.65993 .15546 L
.66117 .14942 L
.66251 .14095 L
.66494 .12122 L
.66987 .0693 L
.67232 .04082 L
Mistroke
.67352 .02694 L
.67409 .02044 L
.67437 .01731 L
.67449 .01595 L
.67462 .01487 L
.67476 .01638 L
.67488 .0178 L
.67516 .02089 L
.67575 .02732 L
.67682 .03867 L
.67919 .06156 L
.68155 .08065 L
.6828 .08898 L
.68414 .0964 L
.68543 .10202 L
.68661 .10578 L
.68717 .10713 L
.68747 .10772 L
.68779 .10825 L
.68806 .10864 L
.68837 .10898 L
.68865 .10922 L
.68878 .10931 L
.68891 .10938 L
.68905 .10943 L
.6892 .10948 L
.68934 .1095 L
.68947 .1095 L
.68963 .10948 L
.68977 .10944 L
.68993 .10938 L
.69009 .10929 L
.6904 .10906 L
.69069 .10877 L
.69134 .10782 L
.69191 .10671 L
.69242 .10546 L
.69358 .10185 L
.69588 .09166 L
.69838 .0767 L
.70071 .05999 L
.70329 .03963 L
.70446 .03005 L
.70508 .02501 L
.70573 .0197 L
.70601 .01746 L
.70616 .01623 L
.7063 .01508 L
.70638 .01494 L
.70647 .01565 L
Mistroke
.70662 .01689 L
.70692 .0193 L
.70802 .02794 L
.71037 .04528 L
.71295 .06176 L
.71413 .06814 L
.7154 .07406 L
.71659 .07868 L
.7177 .08211 L
.71892 .08491 L
.71956 .08596 L
.71989 .08638 L
.72025 .08675 L
.72041 .08689 L
.72059 .08702 L
.72075 .08712 L
.7209 .08719 L
.72105 .08725 L
.7212 .08729 L
.72128 .08731 L
.72137 .08732 L
.72152 .08733 L
.72166 .08733 L
.72181 .0873 L
.72193 .08727 L
.72207 .08723 L
.72222 .08716 L
.72238 .08707 L
.72267 .08687 L
.72296 .08661 L
.72327 .08626 L
.72383 .08548 L
.72449 .08428 L
.72509 .08294 L
.7264 .07924 L
.72763 .07483 L
.73228 .05169 L
.73463 .03723 L
.73587 .02919 L
.73656 .02471 L
.73721 .02045 L
.73751 .0185 L
.73783 .01644 L
.73792 .01582 L
.73801 .01525 L
.73809 .01473 L
.73817 .01519 L
.73849 .01727 L
.73967 .02476 L
.74196 .03869 L
Mistroke
.74433 .05137 L
.74692 .06262 L
.74811 .0667 L
.74939 .07021 L
.75001 .07158 L
.75059 .07268 L
.75116 .07355 L
.75169 .07419 L
.75224 .07468 L
.75254 .07487 L
.7527 .07495 L
.75286 .07502 L
.75301 .07507 L
.7531 .07509 L
.75319 .0751 L
.75327 .07512 L
.75335 .07512 L
.7535 .07513 L
.75365 .07512 L
.75379 .0751 L
.75394 .07506 L
.75409 .07501 L
.75436 .07489 L
.75464 .07472 L
.75515 .07429 L
.75576 .07359 L
.75632 .07277 L
.75751 .07042 L
.75862 .06759 L
.76112 .05903 L
.76585 .03665 L
.76701 .03041 L
.76823 .02368 L
.76927 .01789 L
.76955 .0163 L
.76971 .01543 L
.76986 .01476 L
.76999 .01552 L
.77014 .01635 L
.7704 .0178 L
.77273 .03036 L
.77525 .0427 L
.7776 .05248 L
.77884 .0568 L
.78018 .0607 L
.78146 .06364 L
.78263 .06562 L
.7832 .06632 L
.7835 .06663 L
.78381 .0669 L
Mistroke
.78412 .06712 L
.78439 .06727 L
.78453 .06734 L
.78467 .06739 L
.7848 .06743 L
.78493 .06746 L
.78508 .06749 L
.78522 .0675 L
.78537 .06751 L
.78545 .0675 L
.78553 .0675 L
.78565 .06748 L
.78579 .06745 L
.78594 .06741 L
.78608 .06737 L
.7864 .06722 L
.78669 .06704 L
.78734 .06649 L
.78793 .0658 L
.78858 .06485 L
.78988 .06233 L
.79225 .05585 L
.79478 .0466 L
.79718 .03611 L
.79845 .03014 L
.79978 .02361 L
.80098 .01769 L
.80131 .01606 L
.8014 .0156 L
.80149 .01515 L
.80157 .01475 L
.80166 .01504 L
.80174 .01546 L
.80182 .01583 L
.80199 .01667 L
.8023 .01818 L
.80461 .02928 L
.80713 .04033 L
.80945 .04896 L
.81172 .05557 L
.81286 .05811 L
.8135 .05929 L
.81411 .06024 L
.8147 .061 L
.81535 .06164 L
.81563 .06187 L
.81593 .06206 L
.81619 .0622 L
.81647 .06231 L
.81664 .06236 L
Mistroke
.81672 .06238 L
.8168 .06239 L
.81694 .06242 L
.8171 .06243 L
.81719 .06243 L
.81727 .06243 L
.81743 .06241 L
.81751 .0624 L
.81759 .06239 L
.81777 .06235 L
.81792 .0623 L
.81806 .06225 L
.81837 .0621 L
.81867 .06191 L
.819 .06166 L
.81963 .06104 L
.82022 .06029 L
.82156 .05806 L
.82273 .05547 L
.82398 .05215 L
.82854 .03587 L
.83107 .02493 L
.83217 .01994 L
.83276 .01729 L
.83291 .01658 L
.83308 .01582 L
.83324 .01511 L
.83339 .01492 L
.83353 .01556 L
.83369 .01627 L
.834 .01771 L
.83456 .02023 L
.83566 .02507 L
.83805 .03508 L
.84059 .04435 L
.84292 .05111 L
.84406 .05375 L
.84532 .05603 L
.84589 .05686 L
.8465 .0576 L
.84708 .05815 L
.8476 .05852 L
.84788 .05867 L
.84819 .0588 L
.84834 .05885 L
.84851 .05889 L
.84867 .05892 L
.84881 .05894 L
.84895 .05894 L
.84908 .05894 L
Mistroke
.84923 .05893 L
.84938 .05891 L
.84952 .05889 L
.84964 .05885 L
.84992 .05876 L
.85023 .05862 L
.85056 .05842 L
.85113 .05796 L
.85176 .05731 L
.85244 .05642 L
.85368 .05432 L
.85481 .0519 L
.85733 .04489 L
.85985 .03614 L
.86216 .02697 L
.86333 .0221 L
.86442 .01749 L
.8647 .01629 L
.86484 .0157 L
.86497 .01515 L
.86512 .01484 L
.86519 .01517 L
.86528 .01552 L
.86556 .01671 L
.86681 .02197 L
.87136 .03941 L
.87369 .04654 L
.87489 .04955 L
.8762 .05228 L
.87745 .05427 L
.87805 .05501 L
.87861 .05558 L
.87892 .05584 L
.87926 .05607 L
.87954 .05623 L
.87984 .05637 L
.88 .05643 L
.88018 .05648 L
.88027 .0565 L
.88036 .05652 L
.88045 .05654 L
.88053 .05655 L
.88068 .05656 L
.88076 .05656 L
.88085 .05656 L
.88093 .05656 L
.88101 .05655 L
.88116 .05654 L
.8813 .05651 L
.88145 .05648 L
Mistroke
.88172 .05639 L
.88204 .05625 L
.88234 .05608 L
.88298 .0556 L
.88358 .055 L
.88465 .05358 L
.88581 .05156 L
.8882 .04594 L
.89073 .03812 L
.89311 .0295 L
.89529 .02092 L
.89587 .01854 L
.89642 .01631 L
.89657 .01574 L
.8967 .01519 L
.89685 .0148 L
.89699 .01537 L
.89762 .0179 L
.90014 .02783 L
.90478 .04347 L
.90718 .04932 L
.90839 .05154 L
.90907 .05256 L
.90971 .05337 L
.9103 .05397 L
.91061 .05423 L
.91094 .05446 L
.91125 .05465 L
.91152 .05478 L
.9118 .05488 L
.91194 .05492 L
.91206 .05495 L
.91221 .05498 L
.91229 .05499 L
.91237 .055 L
.91246 .055 L
.91254 .05501 L
.91269 .05501 L
.91284 .055 L
.91297 .05498 L
.91312 .05496 L
.91327 .05492 L
.91359 .05481 L
.9139 .05468 L
.91423 .05449 L
.91458 .05424 L
.91521 .05367 L
.9158 .05301 L
.91713 .05105 L
.9183 .04879 L
Mistroke
.91955 .04589 L
.92457 .0301 L
.92579 .02553 L
.92708 .02054 L
.92761 .01845 L
.92818 .01621 L
.92835 .01555 L
.92851 .01492 L
.92865 .01501 L
.92881 .01562 L
.9294 .01792 L
.93404 .03513 L
.93638 .04233 L
.93762 .04558 L
.93896 .04855 L
.94023 .05083 L
.94079 .05164 L
.9414 .05241 L
.94194 .05297 L
.94252 .05345 L
.94284 .05366 L
.94313 .05382 L
.94342 .05394 L
.94369 .05403 L
.94383 .05407 L
.94398 .0541 L
.94412 .05411 L
.94425 .05412 L
.9444 .05413 L
.94449 .05413 L
.94457 .05412 L
.94471 .05411 L
.94487 .05409 L
.94503 .05405 L
.9452 .054 L
.94552 .05389 L
.94582 .05374 L
.94611 .05357 L
.94662 .05318 L
.94719 .05264 L
.94833 .05119 L
.94956 .0491 L
.95069 .04675 L
.95321 .0401 L
.95571 .03197 L
.95802 .02352 L
.95918 .01909 L
.95975 .0169 L
.95999 .01593 L
.96014 .01539 L
Mistroke
.96027 .01488 L
.96039 .01498 L
.96053 .01551 L
.96081 .0166 L
.9614 .01887 L
.96265 .02365 L
.96505 .03239 L
.96766 .04071 L
.96888 .04404 L
.97017 .0471 L
.97129 .04933 L
.97248 .05124 L
.97349 .05245 L
.97396 .0529 L
.9744 .05323 L
.97484 .05349 L
.97507 .0536 L
.97532 .0537 L
.97554 .05376 L
.97574 .0538 L
.97585 .05382 L
.97596 .05383 L
.97607 .05384 L
.97619 .05384 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<oooool3o`0002kooooo1Ol0000]ooooo`;o0000;_ooool5o`00033ooooo0ol0000Roooo
o`00=?ooool00ol0003oooooooooo`0^ooooo`04o`000?ooooooooooo`0002cooooo00Co0000oooo
oooooooo0000;_ooool01?l0003oooooooooool0000aooooo`03o`000?oooooooooo027ooooo000[
ooooo`Go000000?oooooo`000?l000000ol0000Xooooo`Go00000oooool00ol0003oooooooooo`0/
ooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool0;_ooool5o`0002;ooooo000a
ooooo`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool0:oooool01?l0003ooooooooo
ool0000`ooooo`03o`000?oooooooooo02gooooo00Co0000oooooooooooo00008oooool003;ooooo
00?o0000ooooool00000;oooool01Ol0003ooooooooooooooooo000002cooooo00Co0000oooooooo
oooo0000;Oooool01Ol0003ooooooooooooooooo000002oooooo00?o0000ooooool000008oooool0
03?ooooo0_l0000_ooooo`05o`000?ooooooooooooooool00000;?ooool01?l0003oooooooooool0
000]ooooo`05o`000?ooooooooooooooool00000<?ooool2o`0002?ooooo000dooooo`03o`000?oo
oooooooo02kooooo0ol0000^ooooo`;o0000;oooool3o`0003;ooooo00?o0000ooooooooool08Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0017oooooool0
000=o`0000?ooooo000:ooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo007ooooo0009ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00Oooool0
00Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`23ooooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool3
o`0000Sooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Nooooo`;o003o0oooool0
1Ol0003ooooooooooooooooo003o00Oooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`0>ooooo`03o`00oooooooooooo00Kooooo0ol00003ooooo`002Oooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01Oooool2o`00o`Oooooo00?o
003oooooooooool01Oooool2o`00o`Kooooo0_l00?l7ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01_ooool01Ol00?oooooooooooooooooo000000;ooooo0_l00?l7ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Gooooo0_l00?l7ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1Oooool2o`00o`Kooooo0_l00?l7ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool0
0Oooool000Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`07ooooo`03o`00
oooooooo003o00Kooooo0_l00?l7ooooo`03o`00oooooooooooo00gooooo0_l00?l8ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01Oooool2o`00o`Oooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo0_l00?l7ooooo`03o`00
oooooooooooo00Kooooo00Go003oooooooooooooooooo`00000Dooooo`03o`00oooooooooooo00go
oooo0_l00?l7ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`05ooooo`;o003o1oooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00Cooooo0_l00?l8ooooo`03o`00oooooooooooo00Oo
oooo00?o0000ooooooooool00Oooool000[ooooo0_l00005ooooo`03o`000?oooooooooo00Oooooo
00?o003oooooool00?l01_ooool2o`00o`Oooooo00?o003oooooooooool03Oooool00ol00?oooooo
o`00o`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool2o`00o`Kooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`;o003o3oooool2o`00o`Kooooo
0_l00?l7ooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol00?oooooo
ooooo`0=ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool2o`00o`Kooooo
00?o003oooooooooool01_ooool2o`00o`Sooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool02Oooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooool00?l01_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo00?o
003oooooool00?l01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool00oooool01_l0003oooooooooool00?ooooooo`00o`Kooooo0_l00?l7ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooo003o00Gooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooo003o00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`09ooooo`03
o`000?oooooooooo007ooooo000Aooooo`;o00001oooool01?l00?ooooooooooool00?l>ooooo`03
o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o3Oooool00ol00?ooooooo`00o`06oooo
o`03o`00oooooooo003o00Oooooo00?o003oooooooooool01?ooool2o`00o`Oooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00gooooo00Co003ooooo
oooooooo003o0_ooool01_l0003oooooooooool00?ooooooo`00o`Kooooo0_l00?l6ooooo`;o003o
3oooool2o`00o`Oooooo0_l00?l6ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l0
1_ooool2o`00o`Kooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00
oooooooo003o00kooooo00?o003oooooool00?l02?ooool2o`0000?ooooo000Aooooo`03o`000?oo
oooooooo00Kooooo00?o003oooooooooool01_ooool01?l00?ooooooooooool00?l4ooooo`03o`00
oooooooooooo00Kooooo00Co003ooooooooooooo003o1oooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooool00?l01_ooool2o`00oa3ooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`08ooooo`06o`00ooooooooooooo`000?oooooo003o0_ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Kooooo0_l00?l?ooooo`;o003o1oooool0
0ol00?ooooooooooo`05ooooo`;o003o1_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooool00?l02?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00Kooooo00Co003ooooooooooooo003o1oooool00ol00?ooooooooooo`02ooooo`04o`00oooo
ooooooooo`00o`Wooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01_oo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`07ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l8oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`07oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01oooool00ol00?ooooooooooo`0=oooo
o`;o003o1_ooool00ol00?ooooooo`00o`08ooooo`06o`00ooooooooooooo`000?oooooo003o2_oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01Ooo
ool01?l00?ooooooooooool00?l7ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo
003o1?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`07ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool01_ooool01?l00?ooooooooooooooool2o`00o`;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool01_ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooooooool01_ooool2o`00o`oooooo0_l00?l6ooooo`03o`00oooooooo003o00Cooooo00?o003o
ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`;o003o4?ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`03
ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool01_ooool01?l00?oooooooooo
ool00?l8ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l03?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`0;ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool2
o`00o`;ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool01Oooool00ol00?ooooooo`00o`06ooooo`;o003o3oooool2o`00o`Kooooo00Co
003ooooooooooooo003o0oooool00ol00?ooooooooooo`04ooooo`03o`000?l00?oooooo00?ooooo
00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l6ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Wo
oooo00Go003oooooooooooooooooo`00o`08ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool02_ooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1ooo
ool00ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00001Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Oooooo0_l00?l7ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00Co
003ooooooooooooo003o1oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`03ooooo`;o003o1Oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00oooool2o`00o`oooooo0_l00?l6ooooo`03
o`00oooooooo003o00Gooooo00?o003oooooooooool01Oooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l01oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Gooooo0ol00?l7
ooooo`;o003o1Oooool2o`00o`Gooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`0Eoooo
o`03o`00oooooooooooo00Gooooo0_l00?l6ooooo`;o003o1_ooool00ol00?ooooooooooo`05oooo
o`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`0;ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool01?ooool2o`00oa3ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00Co003ooooooooooooo003o
0oooool00ol00?ooooooooooo`03ooooo`;o003o3oooool2o`00o`Kooooo00?o003oooooooooool0
1Oooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00[ooooo00Co003ooooooooo
oooo003o1Oooool00ol00?ooooooooooo`05ooooo`?o003o2?ooool00ol00?ooooooooooo`04oooo
o`;o003o5_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Uooooo`;o
003o1_ooool2o`00o`Kooooo00?o003oooooooooool01Oooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o
00Oooooo00?o003oooooooooool03Oooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`0:
ooooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool01?l00?ooooooooooool0
0?l4ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol00?ooooooooooo`06ooooo`?o003o
1_ooool2o`00obOooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0;_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00Go003ooooooooooooooooo
o`00o`04ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0=ooooo`;o003o1Oooool00ol00?ooooooooooo`02ooooo`?o003o1oooool00ol0003o
ooooooooo`05ooooo`03o`00oooooooooooo00Wooooo0_l00?l?ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`03ooooo`;o003o1oooool00ol00?ooooooooooo`0^oooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo03Kooooo0_l00?l=ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`;o
003o3oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo0_l00?l8ooooo`03
o`000?oooooooooo00Gooooo0_l00?l;ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`03ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol0
0?ooooooo`00o`06ooooo`;o003o>?ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0003oo
oooo00?o003oooooooooool01Oooool01?l00?ooooooooooool00?l;ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Cooooo`03o`000?oooooooooo
00_ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0<ooooo`;o003o1_ooool01?l0
0?ooooooooooool00?l4ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool0
0ol00?ooooooo`00o`0oooooo`;o00000oooool0017ooooo00?o0000ooooooooool0?oooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool04Oooool00ol0
003oooooooooo`0;ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l03_ooool00ol0
0?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool00_ooool0
1?l00?ooooooooooool00?m8ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo04kooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool03oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00Co
003ooooooooooooo003oB?ooool00ol0003oooooooooo`01ooooo`002?ooool5o`0000Cooooo00?o
0000ooooooooool0A_ooool3o`00o`Gooooo00Go003oooooooooooooooooo`00o`0:ooooo`03o`00
oooooooooooo00cooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`0<ooooo`03
o`000?oooooooooo013ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooool00?l0B?ooool00ol0003oooooooooo`01ooooo`00
2Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04Oooooo0_l00?l9ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l3oooo
o`03o`00oooooooooooo00gooooo00?o0000ooooooooool04oooool00ol00?ooooooooooo`0>oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`18oooo
o`03o`000?oooooooooo007ooooo000:ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0D_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`0Dooooo`03o`000?oooooooooo00cooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo04kooooo00?o0000ooooooooool00Oooool000_ooooo00?o0000oooo
ooooool00oooool3o`0004oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo017ooooo00?o003oooooooooool04Oooool00ol0003oooooooooo`0<oooo
o`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo04cooooo0ol0
0003ooooo`002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0Cooo
ool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l04Ooo
ool01Ol00?oooooooooooooooooo003o00oooooo00?o0000ooooooooool03?ooool01Ol00?oooooo
oooooooooooo003o017ooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo04oooooo00?o0000ooooooooool00Oooool000Sooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo04oooooo00?o003oooooool00?l01?ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00cooooo00Co003ooooooooooooo003o0oooool00ol0
0?ooooooooooo`0=ooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool03oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0DOooool00ol0
003oooooooooo`01ooooo`002Oooool3o`0000Gooooo00?o0000ooooooooool0Coooool00ol00?oo
ooooo`00o`09ooooo`04o`00ooooooooooooo`00o`gooooo00Oo003oooooooooooooooooo`00oooo
oooo003o013ooooo00?o0000ooooooooool04?ooool01?l00?ooooooooooool00?l@ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool0DOooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`1Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool01?l00?ooooooooooool00?l=ooooo`03o`00oooooooooooo01Cooooo00?o0000ooooooooool0
3Oooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`03ooooo`;o003oDOooool00ol0003oooooooooo`01ooooo`004Ooo
ool2o`0005Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo01Cooooo00?o0000ooooooooool03Oooool00ol00?ooooooo`00o`03ooooo`03o`00oooo
oooooooo00_ooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`1Eooooo`;o0000
0oooool0017ooooo00?o0000ooooooooool0Eoooool01Ol00?oooooooooooooooooo003o00;ooooo
00?o003oooooooooool03oooool3o`00oa3ooooo00?o0000ooooooooool03Oooool2o`00o`Cooooo
00?o003oooooooooool02oooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo05Ko
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Eoooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o003oooooooooool04?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo05Kooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool0G_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01Cooooo00?o
0000ooooooooool04oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo05kooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Foooool01?l00?ooooooooooool0
0?l=ooooo`03o`00oooooooooooo01Cooooo00?o0000ooooooooool04oooool00ol00?oooooooooo
o`0?ooooo`03o`00oooooooooooo05[ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001H
ooooo`05o`00ooooooooooooooooool00?l04?ooool00ol00?ooooooooooo`0Dooooo`03o`000?oo
oooooooo01?ooooo00?o003oooooooooool02oooool01Ol00?oooooooooooooooooo003o00;ooooo
00?o003oooooooooool0E_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo05Oooooo00Co
003ooooooooooooo003o:?ooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo00_ooooo
00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo05Oooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool0Eoooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo02;ooooo00?o0000ooooooooool08Oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo05Oooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0G_oo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01Cooooo00?o0000ooooooooool08Ooo
ool00ol00?ooooooooooo`1Nooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo05[ooooo00Go003oooooooooooooooooo`00o`0=ooooo`03o`00oooooooooooo01Cooooo00?o
0000ooooooooool04oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo05[ooooo00?o
0000ooooooooool00Oooool0017ooooo0_l0001Iooooo`03o`00oooooooo003o017ooooo00?o003o
ooooooooool05?ooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo00oooooo00?o003o
ooooool00?l0FOooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo05Sooooo00?o003ooooo
ool00?l0:?ooool00ol0003oooooooooo`0Dooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool00_ooool2o`00oe[ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0F?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo02;ooooo00?o0000oooooooo
ool08Oooool00ol00?ooooooooooo`02ooooo`;o003oF_ooool00ol0003oooooooooo`01ooooo`00
2_ooool3o`0000Cooooo00?o0000ooooooooool0G_ooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo01Gooooo00?o0000ooooooooool08Oooool00ol00?ooooooooooo`1Nooooo`03o`00
0?oooooooooo007ooooo000;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0G_oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01Gooooo00?o0000ooooooooool05?oo
ool00ol00?ooooooooooo`1[ooooo`03o`000?oooooooooo007ooooo0008ooooo`Go00001?ooool0
0ol0003oooooooooo`1Nooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool05Oooool0
0ol0003oooooooooo`0Dooooo`03o`00oooooooooooo06_ooooo00?o0000ooooooooool00Oooool0
00Sooooo00Co0000oooooooooooo00001Oooool3o`0006_ooooo00?o003oooooooooool05Oooool0
0ol0003oooooooooo`0Dooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0G?ooool3
o`0000?ooooo0009ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0G_ooool00ol0
0?ooooooooooo`0Rooooo`03o`000?oooooooooo01Cooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`1Nooooo`03o`000?oooooooooo007ooooo000:ooooo`;o00001Oooool00ol0003o
ooooooooo`1Nooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool05Oooool00ol0003o
ooooooooo`0Qooooo`03o`00oooooooooooo05kooooo00?o0000ooooooooool00Oooool000_ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1Nooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool05Oooool00ol0003oooooooooo`0Dooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool0G_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`1Nooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool05Oooool00ol0003ooooooooo
o`0Dooooo`03o`00oooooooooooo06_ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001/
ooooo`03o`00oooooooooooo01Gooooo00?o0000ooooooooool05?ooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo05gooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`23oooo
o`03o`000?oooooooooo01Cooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`1Noooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo05oooooo00?o003ooooooooo
ool08Oooool00ol0003oooooooooo`0Qooooo`03o`00oooooooooooo05kooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool0Goooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo01Gooooo00?o0000ooooooooool08Oooool00ol00?ooooooooooo`1Nooooo`03o`00
0?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo05oooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo00?o003oooooooooool0Jooo
ool00ol0003oooooooooo`01ooooo`004Oooool2o`0006cooooo00?o003oooooooooool05Oooool0
0ol0003oooooooooo`0Dooooo`03o`00oooooooooooo06[ooooo0_l00003ooooo`004Oooool00ol0
003oooooooooo`23ooooo`03o`000?oooooooooo01Cooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`1Oooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo05oo
oooo00?o003oooooooooool08Oooool00ol0003oooooooooo`0Pooooo`03o`00oooooooooooo05oo
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Goooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo01Gooooo00?o0000ooooooooool08?ooool00ol00?oooooo
ooooo`1Oooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo05oooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo00?o
003oooooooooool0Joooool00ol0003oooooooooo`01ooooo`004Oooool2o`00063ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo00?o003o
ooooooooool0J_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo06_ooooo00?o003ooooo
ooooool05Oooool00ol0003oooooooooo`0Dooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool0Goooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Oooooo`03
o`00oooooooooooo027ooooo00?o0000ooooooooool05?ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo05oooooo00?o0000ooooooooool00Oooool000Wooooo0ol00005ooooo`03o`00
0?oooooooooo05oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Eooooo`03o`00
0?oooooooooo023ooooo00?o003oooooooooool0Goooool00ol0003oooooooooo`01ooooo`002?oo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0Goooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo01Gooooo00?o0000ooooooooool05Oooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo05oooooo00?o0000ooooooooool00Oooool000Sooooo00Go
0000ooooooooooooooooo`000004ooooo`?o0000Goooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo01Kooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`1Xooooo`?o0000
0oooool000Sooooo1?l00005ooooo`03o`000?oooooooooo06[ooooo00?o003oooooooooool05_oo
ool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0Gooo
ool00ol0003oooooooooo`01ooooo`002?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo08?ooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo05oooooo00?o0000ooooooooool00Oooool000Wooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Oooooo`03o`00oooooooooooo027ooooo00?o0000ooooooooool08?ooool00ol0
0?ooooooooooo`1Oooooo`03o`000?oooooooooo007ooooo000:ooooo`;o00001Oooool00ol0003o
ooooooooo`1Oooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool05_ooool00ol0003o
ooooooooo`0Pooooo`03o`00oooooooooooo05oooooo00?o0000ooooooooool00Oooool0017ooooo
00?o0000ooooooooool0Goooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01Kooooo
00?o0000ooooooooool05Oooool00ol00?ooooooooooo`1Zooooo`03o`000?oooooooooo007ooooo
000Aooooo`;o0000Joooool00ol00?ooooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?o
003oooooooooool0JOooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo08?ooooo00?o0000
ooooooooool05Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo05oooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Goooool00ol00?ooooooooooo`0Qoooo
o`03o`000?oooooooooo023ooooo00?o003oooooooooool0Goooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`1Oooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool05_ooool00ol0003oooooooooo`0Pooooo`03o`00oooooooooooo05oooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool0Goooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo01Kooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`1Zooooo`03o`00
0?oooooooooo007ooooo000Aooooo`;o0000H?ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo01Kooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`1Yooooo`;o00000ooo
ool0017ooooo00?o0000ooooooooool0J_ooool00ol00?ooooooooooo`0Fooooo`03o`000?oooooo
oooo01Gooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo063ooooo00?o003oooooooooool08?ooool00ol0
003oooooooooo`0Eooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0Goooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Pooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool05_ooool00ol0003oooooooooo`0Pooooo`03o`00oooooooooooo05oo
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0H?ooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo01Kooooo00?o0000ooooooooool05Oooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo05oooooo00?o0000ooooooooool00Oooool0017ooooo0_l0
001Qooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool05_ooool00ol0003ooooooooo
o`0Eooooo`03o`00oooooooooooo06Wooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1Z
ooooo`03o`00oooooooooooo01Kooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo063ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool0Poooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool0H?ooool00ol0003oooooooooo`01ooooo`002Oooool3o`0000Gooooo00?o0000oooooooo
ool0H?ooool00ol00?ooooooooooo`0Pooooo`03o`000?oooooooooo01oooooo00?o003ooooooooo
ool0H?ooool00ol0003oooooooooo`01ooooo`002?ooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool0H?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01Ko
oooo00?o0000ooooooooool07oooool00ol00?ooooooooooo`1Pooooo`03o`000?oooooooooo007o
oooo0008ooooo`05o`000?ooooooooooooooool000001?ooool3o`00063ooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`0Fooooo`03o`000?oooooooooo01Kooooo00?o003ooooooooo
ool0Ioooool3o`0000?ooooo0009ooooo`?o00001Oooool00ol0003oooooooooo`1Zooooo`03o`00
oooooooooooo01Kooooo00?o0000ooooooooool05_ooool00ol00?ooooooooooo`1Yooooo`03o`00
0?oooooooooo007ooooo0008ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`23ooooo`03o`000?oooooooooo01Kooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`1Pooooo`03o`000?oooooooooo007ooooo0008ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`1Pooooo`03o`00oooooooooooo023ooooo00?o0000ooooooooool0
7oooool00ol00?ooooooooooo`1Pooooo`03o`000?oooooooooo007ooooo0009ooooo`?o00001Ooo
ool00ol0003oooooooooo`1Pooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05ooo
ool00ol0003oooooooooo`0Oooooo`03o`00oooooooooooo063ooooo00?o0000ooooooooool00Ooo
ool0017ooooo0_l0001Qooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05oooool0
0ol0003oooooooooo`0Fooooo`03o`00oooooooooooo06Sooooo0_l00003ooooo`004Oooool00ol0
003oooooooooo`1Pooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05oooool00ol0
003oooooooooo`0Fooooo`03o`00oooooooooooo06Wooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool0JOooool00ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo01Ko
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`1Pooooo`03o`000?oooooooooo007o
oooo000Aooooo`03o`000?oooooooooo063ooooo00?o003oooooooooool08?ooool00ol0003ooooo
ooooo`0Fooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0H?ooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`1Pooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool05oooool00ol0003oooooooooo`0Oooooo`03o`00oooooooooooo063ooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0H?ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo01Oooooo00?o0000ooooooooool05_ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo063ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001Qoooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool05oooool00ol0003oooooooooo`0Foooo
o`03o`00oooooooooooo06Sooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1Yooooo`03
o`00oooooooooooo01Oooooo00?o0000ooooooooool05_ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo063ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
Poooool00ol0003oooooooooo`0Fooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
H?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Pooooo`03o`00oooo
oooooooo023ooooo00?o0000ooooooooool07oooool00ol00?ooooooooooo`1Pooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo063ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo01oooooo00?o003oooooooooool0H?ooool0
0ol0003oooooooooo`01ooooo`004Oooool2o`0006;ooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo00?o003oooooooooool0J?ooool2o`00
00?ooooo000Aooooo`03o`000?oooooooooo06Wooooo00?o003oooooooooool05oooool00ol0003o
ooooooooo`0Fooooo`03o`00oooooooooooo06Wooooo00?o0000ooooooooool00Oooool0017ooooo
00?o0000ooooooooool0Poooool00ol0003oooooooooo`0Fooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool0H?ooool00ol0003oooooooooo`01ooooo`000oooool3o`0000Cooooo0_l0
0005ooooo`03o`000?oooooooooo067ooooo00?o003oooooooooool07oooool00ol0003ooooooooo
o`0Oooooo`03o`00oooooooooooo063ooooo00?o0000ooooooooool00Oooool000Cooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo067ooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo01kooooo00?o
003oooooooooool0HOooool00ol0003oooooooooo`01ooooo`001?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Cooooo0ol0001Qooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool05oooool00ol0003oooooooooo`0Fooooo`03o`00oooooooooooo06Oooooo0ol0
0003ooooo`001?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool0JOooool00ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo00?o
003oooooooooool0JOooool00ol0003oooooooooo`01ooooo`001?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0JOooool00ol00?oooooooooo
o`0Gooooo`03o`000?oooooooooo01Kooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`1Qooooo`03o`000?oooooooooo007ooooo0003ooooo`;o00001?ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo067ooooo00?o003oooooooooool07oooool00ol0003ooooooooo
o`0Fooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0HOooool00ol0003ooooooooo
o`01ooooo`001?ooool00ol0003oooooooooo`03ooooo`;o00001Oooool00ol0003oooooooooo`1Q
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool05oooool00ol0003oooooooooo`0N
ooooo`03o`00oooooooooooo067ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001Roooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool05oooool00ol0003oooooooooo`0Goooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool0H?ooool2o`0000?ooooo000Aooooo`03
o`000?oooooooooo067ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Hooooo`03
o`000?oooooooooo01Oooooo00?o003oooooooooool0J?ooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`1Xooooo`03o`00oooooooooooo01Sooooo00?o0000ooooooooool0
5oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo067ooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool0HOooool00ol00?ooooooooooo`0Oooooo`03o`000?oo
oooooooo01Oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Qooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo067ooooo00?o003oooooooooool07oooool0
0ol0003oooooooooo`0Nooooo`03o`00oooooooooooo067ooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool0HOooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
01Sooooo00?o0000ooooooooool07_ooool00ol00?ooooooooooo`1Qooooo`03o`000?oooooooooo
007ooooo000Aooooo`;o0000H_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01So
oooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`1Wooooo`;o00000oooool0017ooooo
00?o0000ooooooooool0J?ooool00ol00?ooooooooooo`0Hooooo`03o`000?oooooooooo01Oooooo
00?o003oooooooooool0J?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`23ooooo`03o`000?oooooooooo01Oooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`1Qooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo067ooooo00?o003o
ooooooooool07oooool00ol0003oooooooooo`0Nooooo`03o`00oooooooooooo067ooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0HOooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo01Sooooo00?o0000ooooooooool07_ooool00ol00?ooooooooooo`1Qoooo
o`03o`000?oooooooooo007ooooo000Aooooo`;o0000H_ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo01Sooooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`1Wooooo`;o
00000oooool0017ooooo00?o0000ooooooooool0J?ooool00ol00?ooooooooooo`0Hooooo`03o`00
0?oooooooooo01Oooooo00?o003oooooooooool0J?ooool00ol0003oooooooooo`01ooooo`000ooo
ool3o`0000;ooooo1Ol00004ooooo`03o`000?oooooooooo06Sooooo00?o003oooooooooool06?oo
ool00ol0003oooooooooo`0Gooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0HOoo
ool00ol0003oooooooooo`01ooooo`001?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0H_ooool00ol00?ooooooooooo`0Nooooo`03o`000?oo
oooooooo01Oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Qooooo`03o`000?oo
oooooooo007ooooo0004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Rooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool06?ooool0
0ol0003oooooooooo`0Mooooo`03o`00oooooooooooo06;ooooo00?o0000ooooooooool00Oooool0
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`?o0000H_ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo01Sooooo00?o0000ooooooooool05oooool00ol0
0?ooooooooooo`1Vooooo`?o00000oooool000Cooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H_ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo01Sooooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`1Xoooo
o`03o`000?oooooooooo007ooooo0003ooooo`;o00000oooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool0J?ooool00ol00?ooooooooooo`0Hooooo`03o`000?oooooooooo
01Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Rooooo`03o`000?oooooooooo
007ooooo0004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo06;o
oooo00?o003oooooooooool07_ooool00ol0003oooooooooo`0Hooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool0H_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`1Rooooo`03o`00oooooooooooo01kooooo00?o0000ooooooooool07Oooool00ol00?oooooo
ooooo`1Rooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000Hoooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo01Wooooo00?o0000ooooooooool07Oooool00ol00?oooooooooo
o`1Qooooo`;o00000oooool0017ooooo00?o0000ooooooooool0H_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol00?ooooooooooo`1W
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06Oooooo00?o003ooooo
ooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool0H_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`23ooooo`03
o`000?oooooooooo01Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Rooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06;ooooo00?o003oooooooooool0
7_ooool00ol0003oooooooooo`0Mooooo`03o`00oooooooooooo06;ooooo00?o0000ooooooooool0
0Oooool0017ooooo0_l0001Sooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06Ooo
ool00ol0003oooooooooo`0Mooooo`03o`00oooooooooooo067ooooo0_l00003ooooo`004Oooool0
0ol0003oooooooooo`1Rooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06Oooool0
0ol0003oooooooooo`0Hooooo`03o`00oooooooooooo06Oooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool0Ioooool00ol00?ooooooooooo`0Iooooo`03o`000?oooooooooo
01Sooooo00?o003oooooooooool0Ioooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`1Wooooo`03o`00oooooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo06;ooooo00?o0000ooooooooool00Oooool0017ooooo
00?o0000ooooooooool0H_ooool00ol00?ooooooooooo`0Nooooo`03o`000?oooooooooo01Sooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Rooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo06;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0Iooooo`03o`000?oooooooooo01gooooo00?o003oooooooooool0H_ooool00ol0003ooooooooo
o`01ooooo`004Oooool2o`0006Cooooo00Go003oooooooooooooooooo`00o`0Kooooo`03o`000?oo
oooooooo01Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Qooooo`;o00000ooo
ool0017ooooo00?o0000ooooooooool0Hoooool01Ol00?oooooooooooooooooo003o01_ooooo00?o
0000ooooooooool06?ooool00ol00?ooooooooooo`1Wooooo`03o`000?oooooooooo007ooooo0003
ooooo`?o00001?ooool3o`0000Cooooo00?o0000ooooooooool0Ioooool00ol00?ooooooooooo`0I
ooooo`03o`000?oooooooooo01Wooooo00Co003ooooooooooooo003oIOooool00ol0003ooooooooo
o`01ooooo`001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0Hoooool00ol00?ooooooooooo`0Mooooo`03o`000?oooooooooo01Wooooo00Co003o
oooooooooooo003oIOooool00ol0003oooooooooo`01ooooo`001?ooool01?l0003ooooooooooooo
ool5o`0000Cooooo00?o0000ooooooooool0Hoooool00ol00?ooooooooooo`0Mooooo`03o`000?oo
oooooooo01cooooo00?o003oooooooooool0Hoooool00ol0003oooooooooo`01ooooo`001?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00oooool3o`0006?ooooo00Co
003ooooooooooooo003o7?ooool00ol0003oooooooooo`0Looooo`03o`00oooooooooooo067ooooo
0ol00003ooooo`001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Gooooo00?o
0000ooooooooool0Hoooool01?l00?ooooooooooool00?lLooooo`03o`000?oooooooooo01Wooooo
00?o003oooooooooool0I_ooool00ol0003oooooooooo`01ooooo`000oooool2o`0000Gooooo0_l0
0005ooooo`03o`000?oooooooooo06Kooooo00?o003oooooooooool06_ooool00ol0003ooooooooo
o`0Iooooo`03o`00oooooooooooo06Kooooo00?o0000ooooooooool00Oooool000Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08?ooooo00?o0000
ooooooooool06Oooool01?l00?ooooooooooool00?mUooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo06?ooooo00?o003oooooooooool07Oooool00ol0003oooooooooo`0L
ooooo`03o`00oooooooooooo06?ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001Toooo
o`04o`00ooooooooooooo`00oacooooo00?o0000ooooooooool07?ooool00ol00?ooooooooooo`1R
ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0I?ooool00ol00?ooooooo`00o`0Loooo
o`03o`000?oooooooooo01Wooooo00?o003oooooooooool0I_ooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`1Vooooo`03o`00oooooooooooo01[ooooo00?o0000oooooooo
ool06Oooool00ol00?ooooooooooo`1Vooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo08?ooooo00?o0000ooooooooool06_ooool2o`00ofKooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool0I?ooool00ol00?ooooooooooo`0Looooo`03o`000?oo
oooooooo01_ooooo00?o003oooooooooool0I?ooool00ol0003oooooooooo`01ooooo`004Oooool2
o`0006Gooooo0_l00?lMooooo`03o`000?oooooooooo01_ooooo00?o003oooooooooool0Hoooool2
o`0000?ooooo000Aooooo`03o`000?oooooooooo06Gooooo00?o003oooooooooool06oooool00ol0
003oooooooooo`0Kooooo`03o`00oooooooooooo06Cooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo007o
oooo000Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00Oooool0017oooooool0
000=o`0000?ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.95693, -1.55698, \
0.0394232, 0.0958716}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Phase plot of DTFT as a function of index k", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(g2 = 
        Plot[Arg[
            X\[Theta]\  /. \ \[Theta] \[Rule] \ 2  \[Pi]\ f/fs], {f, \(-fs\)/
              2, fs/2}, \ PlotStyle \[Rule] {Blue, \ Dashing[{ .01}]}, \ 
          PlotRange \[Rule] All, PlotPoints \[Rule] 200];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309222 0.0998921 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00955 -12 -4.5 ]
[-0.0125 .00955 0 4.5 ]
[-0.0125 .10944 -12 -4.5 ]
[-0.0125 .10944 0 4.5 ]
[-0.0125 .20933 -12 -4.5 ]
[-0.0125 .20933 0 4.5 ]
[-0.0125 .30922 -6 -4.5 ]
[-0.0125 .30922 0 4.5 ]
[-0.0125 .40911 -6 -4.5 ]
[-0.0125 .40911 0 4.5 ]
[-0.0125 .50901 -6 -4.5 ]
[-0.0125 .50901 0 4.5 ]
[-0.0125 .6089 -6 -4.5 ]
[-0.0125 .6089 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00955 m
.00625 .00955 L
s
[(-3)] -0.0125 .00955 1 0 Mshowa
0 .10944 m
.00625 .10944 L
s
[(-2)] -0.0125 .10944 1 0 Mshowa
0 .20933 m
.00625 .20933 L
s
[(-1)] -0.0125 .20933 1 0 Mshowa
0 .30922 m
.00625 .30922 L
s
[(0)] -0.0125 .30922 1 0 Mshowa
0 .40911 m
.00625 .40911 L
s
[(1)] -0.0125 .40911 1 0 Mshowa
0 .50901 m
.00625 .50901 L
s
[(2)] -0.0125 .50901 1 0 Mshowa
0 .6089 m
.00625 .6089 L
s
[(3)] -0.0125 .6089 1 0 Mshowa
.125 Mabswid
0 .02952 m
.00375 .02952 L
s
0 .0495 m
.00375 .0495 L
s
0 .06948 m
.00375 .06948 L
s
0 .08946 m
.00375 .08946 L
s
0 .12942 m
.00375 .12942 L
s
0 .14939 m
.00375 .14939 L
s
0 .16937 m
.00375 .16937 L
s
0 .18935 m
.00375 .18935 L
s
0 .22931 m
.00375 .22931 L
s
0 .24929 m
.00375 .24929 L
s
0 .26927 m
.00375 .26927 L
s
0 .28924 m
.00375 .28924 L
s
0 .3292 m
.00375 .3292 L
s
0 .34918 m
.00375 .34918 L
s
0 .36916 m
.00375 .36916 L
s
0 .38914 m
.00375 .38914 L
s
0 .42909 m
.00375 .42909 L
s
0 .44907 m
.00375 .44907 L
s
0 .46905 m
.00375 .46905 L
s
0 .48903 m
.00375 .48903 L
s
0 .52899 m
.00375 .52899 L
s
0 .54896 m
.00375 .54896 L
s
0 .56894 m
.00375 .56894 L
s
0 .58892 m
.00375 .58892 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00955 m
1 .00955 L
s
.99375 .10944 m
1 .10944 L
s
.99375 .20933 m
1 .20933 L
s
.99375 .30922 m
1 .30922 L
s
.99375 .40911 m
1 .40911 L
s
.99375 .50901 m
1 .50901 L
s
.99375 .6089 m
1 .6089 L
s
.125 Mabswid
.99625 .02952 m
1 .02952 L
s
.99625 .0495 m
1 .0495 L
s
.99625 .06948 m
1 .06948 L
s
.99625 .08946 m
1 .08946 L
s
.99625 .12942 m
1 .12942 L
s
.99625 .14939 m
1 .14939 L
s
.99625 .16937 m
1 .16937 L
s
.99625 .18935 m
1 .18935 L
s
.99625 .22931 m
1 .22931 L
s
.99625 .24929 m
1 .24929 L
s
.99625 .26927 m
1 .26927 L
s
.99625 .28924 m
1 .28924 L
s
.99625 .3292 m
1 .3292 L
s
.99625 .34918 m
1 .34918 L
s
.99625 .36916 m
1 .36916 L
s
.99625 .38914 m
1 .38914 L
s
.99625 .42909 m
1 .42909 L
s
.99625 .44907 m
1 .44907 L
s
.99625 .46905 m
1 .46905 L
s
.99625 .48903 m
1 .48903 L
s
.99625 .52899 m
1 .52899 L
s
.99625 .54896 m
1 .54896 L
s
.99625 .56894 m
1 .56894 L
s
.99625 .58892 m
1 .58892 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30922 m
1 .30922 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .30922 m
.02847 .26492 L
.03355 .21661 L
.03602 .19312 L
.03723 .18166 L
.03832 .17124 L
.03887 .16604 L
.03916 .1633 L
.03932 .1618 L
.03946 .1604 L
.03959 .15918 L
.03973 .47169 L
.03988 .47023 L
.04002 .46889 L
.04054 .46398 L
.04291 .44142 L
.0477 .39589 L
.05231 .3521 L
.05721 .3055 L
.06193 .26064 L
.06434 .23774 L
.06694 .21296 L
.06817 .20133 L
.06946 .18904 L
.07056 .17855 L
.07087 .17567 L
.07103 .17409 L
.07119 .17259 L
.07134 .1712 L
.0715 .4835 L
.07164 .48212 L
.07178 .48085 L
.07651 .43583 L
.08106 .39256 L
.08591 .34647 L
.09058 .30212 L
.09554 .25496 L
.09802 .23143 L
.10032 .20954 L
.10146 .19868 L
.10254 .18842 L
.10283 .18567 L
.10299 .18416 L
.10314 .18275 L
.10322 .49584 L
.1033 .49505 L
.10348 .49337 L
.10379 .49042 L
.10492 .47968 L
.10989 .43237 L
Mistroke
.11469 .3868 L
.1193 .34297 L
.12421 .29633 L
.12894 .25144 L
.13135 .2285 L
.13262 .21645 L
.13331 .20987 L
.13396 .20373 L
.13454 .19821 L
.1347 .19662 L
.13486 .19512 L
.135 .50759 L
.13516 .50612 L
.13648 .4936 L
.13879 .47159 L
.14372 .4248 L
.14846 .37976 L
.15302 .33646 L
.15788 .29035 L
.16255 .24598 L
.16497 .22299 L
.16556 .2174 L
.16619 .21143 L
.16637 .20967 L
.16646 .2088 L
.16655 .208 L
.1667 .52033 L
.16679 .51954 L
.16688 .51871 L
.16752 .51263 L
.17209 .46919 L
.17696 .42294 L
.18165 .37844 L
.18664 .33113 L
.19144 .28556 L
.19363 .26474 L
.19488 .25288 L
.19606 .24174 L
.1972 .23087 L
.19752 .22789 L
.19785 .22475 L
.19813 .22207 L
.19821 .22134 L
.19829 .22055 L
.19844 .53296 L
.19852 .53217 L
.19861 .53134 L
.19876 .52985 L
.19912 .52649 L
.19976 .52037 L
Mistroke
.20097 .50893 L
.20554 .46562 L
.2104 .41952 L
.21508 .37515 L
.22005 .32799 L
.22484 .28257 L
.22726 .25965 L
.22831 .24968 L
.22945 .23889 L
.22976 .23595 L
.22993 .23435 L
.23009 .23285 L
.23022 .5454 L
.23037 .54403 L
.23067 .54112 L
.23182 .53021 L
.23435 .50624 L
.23934 .45896 L
.24415 .41342 L
.24878 .36962 L
.2537 .32304 L
.25614 .2999 L
.25844 .2782 L
.26063 .25745 L
.26123 .25177 L
.26156 .24867 L
.26172 .24716 L
.26186 .24579 L
.262 .55834 L
.26212 .55714 L
.2624 .5545 L
.26299 .54892 L
.26763 .50502 L
.27257 .45833 L
.27733 .41339 L
.2819 .37019 L
.28676 .32422 L
.28901 .30305 L
.29145 .27999 L
.29209 .27392 L
.29278 .26747 L
.29311 .26433 L
.29327 .26279 L
.29342 .26138 L
.29356 .26009 L
.2937 .57255 L
.29385 .57119 L
.294 .56969 L
.29643 .54681 L
.30131 .50074 L
Mistroke
.30601 .45642 L
.31101 .40934 L
.31583 .36401 L
.32046 .32043 L
.3228 .29838 L
.32405 .28668 L
.32473 .28023 L
.32507 .27705 L
.32523 .2755 L
.32538 .27409 L
.32554 .58648 L
.32568 .58513 L
.326 .58217 L
.32666 .57589 L
.32783 .5649 L
.33013 .54333 L
.33478 .49969 L
.33972 .45332 L
.34448 .4087 L
.34906 .36584 L
.35161 .342 L
.35393 .32026 L
.35509 .30948 L
.35569 .3038 L
.35634 .29776 L
.35661 .29522 L
.3569 .29249 L
.35699 .29173 L
.35707 .29093 L
.35723 .60332 L
.35737 .60198 L
.35753 .60051 L
.35862 .59026 L
.36351 .54465 L
.36822 .5008 L
.37322 .45428 L
.37805 .40953 L
.38268 .36657 L
.38762 .32097 L
.39237 .27716 L
.39693 .23515 L
.4018 .19056 L
.40648 .14778 L
.41146 .10248 L
.41394 .07992 L
.41625 .05903 L
.41848 .03887 L
.41913 .03307 L
.41973 .02762 L
.42027 .02273 L
Mistroke
.42042 .02139 L
.42058 .01997 L
.42071 .33259 L
.42086 .33126 L
.42574 .28749 L
.43044 .24561 L
.43543 .20142 L
.44024 .15921 L
.44487 .11898 L
.44721 .09877 L
.44979 .07662 L
.45097 .06657 L
.45159 .0613 L
.45193 .05844 L
.45209 .05704 L
.45224 .05577 L
.45238 .05456 L
.45252 .36724 L
.45266 .36604 L
.45281 .36474 L
.45344 .35944 L
.45453 .35017 L
.45947 .30878 L
.46423 .26955 L
.4688 .23245 L
.47367 .19367 L
.47836 .15706 L
.48075 .13869 L
.482 .12907 L
.48269 .12381 L
.48334 .11888 L
.48362 .11678 L
.48391 .11457 L
.48407 .11341 L
.48415 .42658 L
.48423 .42597 L
.48453 .42374 L
.48584 .41388 L
.48814 .39659 L
.49285 .36171 L
.49785 .32499 L
.50266 .28972 L
.5073 .25567 L
.50964 .23832 L
.51223 .21909 L
.51341 .21025 L
.51406 .20536 L
.51468 .2007 L
.51525 .19638 L
.51541 .19519 L
Mistroke
.51558 .19393 L
.51573 .19274 L
.51588 .50547 L
.51602 .5044 L
.51615 .50342 L
.51644 .5012 L
.51697 .49716 L
.52174 .46064 L
.52632 .42486 L
.53119 .38603 L
.53589 .34795 L
.54088 .30677 L
.54337 .28591 L
.54447 .27668 L
.54568 .26647 L
.54624 .26176 L
.54684 .25668 L
.54711 .25434 L
.54726 .25307 L
.5474 .25188 L
.54752 .25086 L
.54765 .5636 L
.54779 .56239 L
.54792 .56129 L
.55031 .54099 L
.55513 .49949 L
.55977 .45915 L
.5647 .41583 L
.56946 .37376 L
.57403 .33303 L
.57657 .31026 L
.57778 .29944 L
.57836 .29417 L
.57889 .28939 L
.57903 .28815 L
.57918 .28681 L
.57932 .28555 L
.57945 .5982 L
.57959 .59696 L
.57974 .59561 L
.58004 .59287 L
.5813 .58157 L
.58358 .56098 L
.58846 .51673 L
.59316 .47396 L
.59815 .42832 L
.60297 .38419 L
.6076 .34161 L
.61252 .29619 L
.61727 .25235 L
Mistroke
.62183 .21011 L
.62668 .16504 L
.63135 .12159 L
.63632 .07531 L
.6388 .05218 L
.64001 .04091 L
.64111 .03067 L
.64166 .02553 L
.64226 .01997 L
.64253 .01742 L
.64268 .01602 L
.64282 .01472 L
.64294 .32742 L
.64307 .32623 L
.64334 .3237 L
.64571 .3015 L
.6507 .25488 L
.6555 .20992 L
.66012 .16663 L
.66504 .12052 L
.66977 .07608 L
.67214 .05379 L
.67318 .04402 L
.67377 .03848 L
.67405 .03583 L
.67432 .03333 L
.67446 .03203 L
.67461 .34445 L
.67474 .34317 L
.67487 .34199 L
.67545 .33648 L
.67665 .32523 L
.67916 .30158 L
.68391 .2569 L
.68848 .2139 L
.69334 .16809 L
.69802 .12398 L
.7004 .10154 L
.703 .07706 L
.7042 .0657 L
.70486 .05947 L
.70548 .0536 L
.70576 .05093 L
.70606 .04812 L
.70622 .04664 L
.70631 .04581 L
.70639 .35885 L
.70654 .35748 L
.70669 .35601 L
.70779 .34566 L
Mistroke
.71278 .29853 L
.71759 .25312 L
.72221 .20941 L
.72714 .16289 L
.73188 .11808 L
.73425 .09559 L
.73643 .07499 L
.73702 .06941 L
.73757 .06422 L
.73785 .0616 L
.738 .06014 L
.73814 .37263 L
.7383 .37116 L
.73846 .36958 L
.73877 .36671 L
.74128 .3429 L
.74622 .29616 L
.75098 .25115 L
.75555 .20785 L
.76042 .16174 L
.7651 .11735 L
.76633 .10576 L
.76766 .09313 L
.76827 .08735 L
.76892 .0812 L
.76923 .07821 L
.76953 .0754 L
.76966 .07417 L
.7698 .07287 L
.76995 .38527 L
.77008 .38397 L
.77467 .34047 L
.77956 .29417 L
.78426 .24958 L
.78926 .20219 L
.79407 .15652 L
.79871 .11258 L
.79994 .10086 L
.80055 .09513 L
.8011 .08989 L
.80124 .08854 L
.8014 .08706 L
.80154 .08567 L
.80168 .39819 L
.80184 .39669 L
.80198 .39532 L
.80231 .39226 L
.80363 .37965 L
.80847 .3338 L
.81311 .28969 L
Mistroke
.81806 .24276 L
.82282 .19756 L
.8274 .15409 L
.82995 .12988 L
.83116 .11841 L
.83227 .10781 L
.83283 .10249 L
.83312 .09981 L
.83319 .09908 L
.83328 .09828 L
.83343 .41067 L
.83358 .40922 L
.83375 .40764 L
.83408 .40445 L
.83468 .39875 L
.83697 .37707 L
.84186 .33063 L
.84657 .28591 L
.85157 .23838 L
.85639 .19259 L
.86103 .14852 L
.86343 .12575 L
.86401 .12022 L
.86464 .11427 L
.86482 .11253 L
.86491 .11166 L
.86499 .11086 L
.86515 .42319 L
.86523 .42241 L
.86532 .42157 L
.86596 .41546 L
.87099 .36776 L
.87582 .3218 L
.88048 .27757 L
.88543 .23052 L
.8902 .18521 L
.8926 .1624 L
.89478 .14163 L
.89536 .13612 L
.89599 .13012 L
.89628 .12738 L
.89644 .12587 L
.89659 .12446 L
.89672 .12327 L
.89685 .4358 L
.897 .43436 L
.89714 .43305 L
.89966 .40907 L
.90445 .36359 L
.90905 .31985 L
Mistroke
.91395 .2733 L
.91866 .22849 L
.92367 .18086 L
.92619 .15697 L
.92729 .14649 L
.92787 .14093 L
.92819 .13787 L
.92835 .13636 L
.9285 .13497 L
.92864 .44744 L
.92879 .44601 L
.92911 .44299 L
.92967 .4377 L
.93076 .42733 L
.93314 .40463 L
.93769 .3614 L
.94254 .31534 L
.9472 .27103 L
.95216 .2239 L
.95463 .2004 L
.95693 .17851 L
.95807 .16767 L
.95915 .15742 L
.95975 .15175 L
.95991 .1502 L
.96008 .14856 L
.96023 .14715 L
.96031 .14635 L
.96039 .45942 L
.96054 .45804 L
.96068 .45672 L
.96094 .45425 L
.96152 .44868 L
.96613 .40487 L
.97103 .35825 L
.97575 .31337 L
.97619 .30922 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00=?ooool3o`0002gooooo1Ol0000]ooooo`;o0000;_ooool5o`0002oooooo0ol0000Soooo
o`00=Oooool00ol0003oooooooooo`0]ooooo`04o`000?ooooooooooo`0002cooooo00Co0000oooo
oooooooo0000;_ooool01?l0003oooooooooool0000`ooooo`03o`000?oooooooooo02;ooooo000/
ooooo`Go000000?oooooo`000?l000000ol0000Wooooo`Go00000oooool00ol0003oooooooooo`0/
ooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool0;Oooool5o`0002?ooooo000b
ooooo`04o`000?ooooooooooo`00037ooooo00?o0000ooooooooool0:oooool01?l0003ooooooooo
ool0000`ooooo`03o`000?oooooooooo02cooooo00Co0000oooooooooooo00009?ooool003?ooooo
00?o0000ooooool00000;_ooool01Ol0003ooooooooooooooooo000002cooooo00Co0000oooooooo
oooo0000;Oooool01Ol0003ooooooooooooooooo000002kooooo00?o0000ooooool000009?ooool0
03Cooooo0_l0000^ooooo`05o`000?ooooooooooooooool00000;?ooool01?l0003oooooooooool0
000]ooooo`05o`000?ooooooooooooooool00000;oooool2o`0002Cooooo000eooooo`03o`000?oo
oooooooo02gooooo0ol0000^ooooo`;o0000;oooool3o`00037ooooo00?o0000ooooooooool08_oo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool000_ooooo0ol0
0005oooooooo00002Ol00005ooooo`002_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`001?ooool5o`0000Gooooo00?o0000
ooooooooool00_ooool3o`00087ooooo00?o0000ooooooooool0O_ooool3o`0000Gooooo000<oooo
o`;o00001Oooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo083ooooo00?o0000oooo
ooooool00oooool000kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`21ooooo`03
o`000?oooooooooo02;ooooo00?o003oooooooooool0Foooool00ol0003oooooooooo`03ooooo`00
2_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0POooool00ol0003o
ooooooooo`0Rooooo`03o`00oooooooooooo05_ooooo00?o0000ooooooooool00oooool000_ooooo
0ol00005ooooo`03o`000?oooooooooo06cooooo00?o003oooooooooool04_ooool00ol0003ooooo
ooooo`20ooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo06cooooo00?o
003oooooooooool04_ooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo00?ooooo000C
ooooo`;o0000K?ooool2o`00oaCooooo00?o0000ooooooooool08_ooool00ol00?ooooooooooo`1J
ooooo`;o00001Oooool001?ooooo00?o0000ooooooooool0Joooool2o`00oaCooooo00?o0000oooo
ooooool08_ooool00ol00?ooooooooooo`1Kooooo`03o`000?oooooooooo00?ooooo000Cooooo`03
o`000?oooooooooo06_ooooo00?o003oooooooooool04oooool00ol0003oooooooooo`0Qooooo`;o
003o1oooool00ol00?ooooooooooo`1Cooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`00
0?oooooooooo06cooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`0Zooooo`03o`00
oooooooooooo05?ooooo00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool0K?oo
ool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo02[ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`1:ooooo`03o`000?oooooooooo00?ooooo000Cooooo`;o0000K?ooool2
o`00oaCooooo00?o0000ooooooooool08Oooool2o`00oa3ooooo00?o003oooooooooool0BOooool2
o`0000Gooooo000Cooooo`03o`000?oooooooooo06_ooooo0_l00?l7ooooo`03o`00oooooooooooo
00[ooooo00?o0000ooooooooool08Oooool2o`00oa3ooooo00?o003oooooooooool0B_ooool00ol0
003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`1[ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool02_ooool00ol0003oooooooooo`0Qooooo`;o003o1oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo04[ooooo00?o0000ooooooooool00oooool001?ooooo
00?o0000ooooooooool0M?ooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo027ooooo
0_l00?l7ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`12ooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo06cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo02Wooooo0_l0
0?l7ooooo`;o003o1oooool00ol00?ooooooooooo`12ooooo`03o`000?oooooooooo00?ooooo000C
ooooo`;o0000Joooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00[ooooo00?o0000
ooooooooool08Oooool2o`00o`Oooooo00?o003oooooooooool01Oooool2o`00o`Oooooo00?o003o
ooooooooool0@Oooool2o`0000Gooooo000Cooooo`03o`000?oooooooooo06[ooooo00?o003ooooo
ool00?l01_ooool2o`00o`cooooo00?o0000ooooooooool08Oooool2o`00o`oooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo03Wooooo00?o0000oooo
ooooool00oooool001?ooooo00?o0000ooooooooool0J_ooool00ol00?ooooooooooo`06ooooo`;o
003o3?ooool00ol0003oooooooooo`0Pooooo`03o`00oooooooo003o00Kooooo0_l00?l8ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool2o`00oc_ooooo00?o0000oooooooo
ool00oooool001?ooooo00?o0000ooooooooool0J_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00_ooooo00?o0000ooooooooool08?ooool00ol00?ooooooo`00o`06ooooo`;o003o
2?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
>Oooool00ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`1/ooooo`03o`00oooo
oooooooo00Cooooo0_l00?l<ooooo`03o`000?oooooooooo02Wooooo0_l00?l7ooooo`;o003o1ooo
ool00ol00?ooooooooooo`12ooooo`03o`000?oooooooooo00?ooooo000Cooooo`;o0000Joooool0
0ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool08?ooool0
0ol00?ooooooo`00o`06ooooo`;o003o1oooool2o`00o`Kooooo00?o003oooooooooool01_ooool2
o`00o`Oooooo00?o003oooooooooool0<?ooool2o`0000Gooooo000Cooooo`03o`000?oooooooooo
06[ooooo00?o003oooooool00?l01_ooool2o`00o`cooooo00?o0000ooooooooool08?ooool00ol0
0?ooooooo`00o`0>ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool2o`00
o`Oooooo00?o003oooooooooool0<Oooool00ol0003oooooooooo`03ooooo`004oooool00ol0003o
ooooooooo`1Yooooo`03o`00oooooooooooo00Oooooo0_l00?l<ooooo`03o`000?oooooooooo023o
oooo00?o003oooooool00?l01_ooool2o`00oa3ooooo00?o003oooooooooool01Oooool2o`00o`Oo
oooo00?o003oooooooooool0<Oooool00ol0003oooooooooo`03ooooo`002_ooool5o`0000Cooooo
00?o0000ooooooooool0JOooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo
00?o0000ooooooooool08?ooool00ol00?ooooooo`00o`06ooooo`;o003o2?ooool00ol00?oooooo
ooooo`04ooooo`;o003o2?ooool00ol00?ooooooooooo`04ooooo`;o003o1oooool00ol00?oooooo
ooooo`0Yooooo`03o`000?oooooooooo00?ooooo000;ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0K?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00_ooooo
00?o0000ooooooooool0:?ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Kooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02Wooooo
00?o0000ooooooooool00oooool000Cooooo1Ol00003ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0JOooool01?l00?ooooooooooool00?l7ooooo`03o`00oooooooooooo00[ooooo
00?o0000ooooooooool0:?ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Kooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0jooooo`03o`000?oooooooooo00?ooooo
000=ooooo`03o`000?oooooooooo00?ooooo0ol0001Yooooo`04o`00ooooooooooooo`00o`Oooooo
00?o003oooooooooool02_ooool00ol0003oooooooooo`0Oooooo`04o`00ooooooooooooo`00o`ko
oooo00?o003oooooooooool01_ooool2o`00o`Oooooo0_l00?l6ooooo`;o003o1oooool00ol00?oo
ooooooooo`0Wooooo`?o00001Oooool000[ooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo06Wooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`07oooo
o`03o`00oooooooooooo00;ooooo00?o0000ooooooooool07oooool01?l00?ooooooooooool00?l5
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooo003o00Kooooo0_l00?l7ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool08?ooool00ol0003oooooooooo`03ooooo`002_ooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool0JOooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`0Oooooo`04o`00oooooooo
ooooo`00o`Gooooo00?o003oooooool00?l02?ooool00ol00?ooooooooooo`04ooooo`;o003o2?oo
ool00ol00?ooooooooooo`04ooooo`;o003o1oooool00ol00?ooooooooooo`05ooooo`;o003o8_oo
ool00ol0003oooooooooo`03ooooo`002oooool3o`0000Gooooo00?o0000ooooooooool0K?ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool00_ooool0
0ol0003oooooooooo`0Xooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l01_ooool2
o`00o`oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`;o003o8_ooool0
0ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`1/ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo
02Sooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool06?ooool00ol0003oooooooooo`03ooooo`004oooool2o`0006Wo
oooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool00_ooool00ol0003oooooooooo`0Oooooo`04o`00ooooooooooooo`00o`gooooo00Co003o
oooooooooooo003o1Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Oooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01Oooooo0_l0
0005ooooo`004oooool00ol0003oooooooooo`1Xooooo`05o`00ooooooooooooooooool00?l01Ooo
ool00ol00?ooooooo`00o`0<ooooo`03o`000?oooooooooo01oooooo00Co003ooooooooooooo003o
3Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l0
1_ooool2o`00o`Kooooo0_l00?l8ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
6?ooool00ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`1Xooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooool00?l01oooool00ol00?ooooooooooo`02ooooo`03o`000?oo
oooooooo01oooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`08ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`06ooooo`;o003o
1_ooool2o`00o`Oooooo0_l00?l7ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
4?ooool00ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`1aooooo`03o`00oooo
oooooooo00Oooooo0_l00?l4ooooo`03o`000?oooooooooo02;ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l0
2?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Kooooo0_l00?l7ooooo`;o003o
1oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool0
0oooool001?ooooo00?o0000ooooooooool0K?ooool00ol00?ooooooooooo`02ooooo`04o`00oooo
ooooooooo`00o`Kooooo0_l00?l4ooooo`03o`000?oooooooooo02Oooooo00Co003ooooooooooooo
003o1Oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool04?ooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo013ooooo00?o0000ooooooooool00oooool001?ooooo0_l0001Yooooo`05
o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00?ooooo00?o0000ooooooooool07_ooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003o
ooooooooool00oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00Gooooo00Co
003ooooooooooooo003o1oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo
0_l00005ooooo`004oooool00ol0003oooooooooo`1Xooooo`05o`00ooooooooooooooooool00?l0
1?ooool01?l00?ooooooooooool00?l6ooooo`03o`00oooooooooooo00?ooooo00?o0000oooooooo
ool07_ooool01Ol00?oooooooooooooooooo003o00gooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01_ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Cooooo0_l00?l7ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01oooool00ol0003oooooooooo`03ooooo`004oooool00ol0
003oooooooooo`1Xooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooooooo003o1oooool0
0ol00?ooooooooooo`02ooooo`03o`000?oooooooooo01kooooo00Go003oooooooooooooooooo`00
o`04ooooo`04o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`03ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01_ooool2o`00o`Ko
oooo00?o003oooooool00?l01oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Go
oooo0_l00?l9ooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo00Oooooo
00?o003oooooooooool0G_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo
0_l00?l4ooooo`03o`000?oooooooooo01kooooo00Go003oooooooooooooooooo`00o`04ooooo`04
o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l8
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06
ooooo`03o`00oooooooo003o00Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05
ooooo`;o003o2Oooool00ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`07oooo
o`03o`00oooooooooooo06;ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l6
ooooo`;o003o1?ooool00ol0003oooooooooo`0Wooooo`04o`00ooooooooooooo`00o`Gooooo00Co
003ooooooooooooo003o1?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo013ooooo
00?o003oooooooooool01?ooool00ol00?ooooooo`00o`06ooooo`;o003o1oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool00oooool001?ooooo0_l0
0008ooooo`03o`00oooooooooooo05gooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol0003ooooooooo
o`0Nooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooo
oooooooooooo003o00Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`;o
003o1oooool00ol00?ooooooooooo`07ooooo`;o00001Oooool001?ooooo00?o0000ooooooooool0
1oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo05Cooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`04ooooo`03o`000?oooooooooo01kooooo00Go003oooooooooooooooooo`00o`0<oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool03_ooool00ol00?ooooooo`00
o`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02?ooool00ol0003ooooooooo
o`03ooooo`004oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool0E?ooool00ol00?ooooooooooo`06ooooo`05o`00ooooooooooooooooool00?l01ooo
ool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo01gooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`03ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool00ol0
0?ooooooo`00o`08ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l03oooool2o`00
o`Wooooo00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool01oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo05Cooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooo003o00Cooooo00?o0000ooooooooool07Oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o2?ooool00ol00?ooooooooooo`02
ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00
o`07ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool2o`00o`Wooooo00?o
0000ooooooooool00oooool001?ooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo05[ooooo00Go003oooooooooooooooooo`00o`09ooooo`03o`00oooo
oooo003o00Cooooo00?o0000ooooooooool09_ooool01Ol00?oooooooooooooooooo003o00Cooooo
00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool0
0?l01_ooool2o`00o`Sooooo00?o003oooooooooool01oooool00ol0003oooooooooo`03ooooo`00
4oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`1<ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Cooooo00?o0000ooooooooool0
9_ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`04oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool2o`00o`Kooooo00?o003ooooo
ooooool02Oooool00ol0003oooooooooo`03ooooo`004oooool2o`0000Sooooo00?o003ooooooooo
ool01Oooool2o`00o`Oooooo00?o003oooooooooool0C?ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03
o`000?oooooooooo01gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Kooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo
003o00Cooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooo003o00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`08ooooo`;o00001Ooo
ool001?ooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`05ooooo`;o003o1oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`02ooooo`05o`000?ooooooooooooooool00?l06oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003o
ooooool00?l02?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00kooooo00?o003o
ooooool00?l02Oooool00ol0003oooooooooo`03ooooo`002oooool3o`0000Gooooo00?o0000oooo
ooooool01_ooool2o`00o`Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05oooo
o`;o003oAOooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool00_ooool00ol0003oooooooooo`02o`00oa_ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool01_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool01?l00?ooooooooooool00?l7oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`09oooo
o`03o`000?oooooooooo00?ooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01_ooool2o`00o`Oooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`19ooooo`05
o`00ooooooooooooooooool00?l02?ooool01?l00?ooooooooooool00?l4ooooo`05o`000?oooooo
ooooooooool00?l09?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`05ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o1Oooool0
0ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Sooooo00?o003oooooooooool01oooool0
0ol0003oooooooooo`03ooooo`001?ooool5o`0000?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo04Sooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o0000ooooooooool09_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00Sooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`03ooooo`04o`00
ooooooooooooo`00o`Gooooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`08ooooo`03
o`00oooooooooooo00Oooooo00?o0000ooooooooool00oooool000cooooo00?o0000ooooooooool0
1?ooool3o`0000Oooooo00?o003oooooooooool01Oooool2o`00o`Kooooo0_l00?l8ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool0>_ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`04o`00
0?ooooooooooo`00oacooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool03_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo003o00Kooooo00?o003o
ooooooooool01oooool3o`0000Gooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01oooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool2o`00o`Oooooo0_l00?l7oooo
o`03o`00oooooooooooo03[ooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l4
ooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool00_l00?lKooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
1?ooool01?l00?ooooooooooool00?l8ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooo
oooo003o3_ooool00ol00?ooooooo`00o`09ooooo`03o`000?oooooooooo00?ooooo000;ooooo`;o
00001_ooool00ol0003oooooooooo`06ooooo`;o003o2?ooool00ol00?ooooooooooo`04ooooo`;o
003o1oooool2o`00o`Oooooo00?o003oooooooooool0>_ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03
o`000?oooooooooo00;o003o6_ooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00
o`Cooooo00?o003oooooooooool01_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o1oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l02Oooool00ol0
003oooooooooo`03ooooo`003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Ko
oooo0_l00?l?ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool2o`00odGo
oooo00?o003oooooooooool01oooool01?l00?ooooooooooool00?l4ooooo`03o`000?oooooooooo
00;o003o8?ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool01_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l5oooo
o`04o`00ooooooooooooo`00o`Oooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`08
ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool00oooool001?ooooo00?o0000oooo
ooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool03Oooool2o`00o`Oooooo00?o003oooooooooool0>?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol0003oooooooooo`0U
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooo
ooooooooo`00o`Sooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo003o00So
oooo00?o003oooooooooool01oooool00ol0003oooooooooo`03ooooo`004oooool2o`0000Oooooo
00?o003oooooooooool01Oooool00ol00?ooooooo`00o`06ooooo`;o003o2?ooool00ol00?oooooo
ooooo`04ooooo`;o003o1oooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool01Oooool01Ol00?oooooooooooooooooo003o00Sooooo00?o0000ooooool0
0?l07?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool02Oooool2
o`0000Gooooo000Cooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool01?ooool00ol0
0?ooooooo`00o`06ooooo`;o003o1_ooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`03ooooo`04o`00oooooooooooo
o`00o`Cooooo00?o003oooooooooool02_ooool01Ol0003oooooo`00oooooooo003o01[ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00_ooool01?l00?oo
ooooooooool00?l5ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o2Oooool0
0ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`00oooooooo003o
00Sooooo00?o003oooooooooool01?ooool2o`00o`Kooooo00?o003oooooool00?l01oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0:?ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`02ooooo`05o`000?oooooo003oooooool00?l06_ooool00ol00?ooooooooooo`03
ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool03_ooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`Wooooo00?o
0000ooooooooool00oooool001?ooooo00?o0000ooooooooool01Oooool00ol00?ooooooo`00o`08
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00kooooo0_l00?lcooooo`03o`00oooooooooooo00Oooooo00Go003o
ooooooooooooooooo`00o`04ooooo`05o`000?oooooo003oooooool00?l06_ooool00ol00?oooooo
ooooo`03ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool01_ooool01?l00?oo
ooooooooool00?l4ooooo`03o`00oooooooooooo00Kooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l01oooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`So
oooo00?o003oooooooooool01oooool00ol0003oooooooooo`03ooooo`004oooool00ol0003ooooo
ooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`05ooooo`;o003o<Oooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`000?ooooooooooooooool00?l08_ooool00ol0
0?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o2?oo
ool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o2?ooool00ol0
0?ooooooooooo`07ooooo`03o`000?oooooooooo00?ooooo000Cooooo`;o00001_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooo003o00Oooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`04ooooo`;o003o1oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Go
oooo00Go003oooooooooooooooooo`00o`08ooooo`03o`000?oooooo003o01_ooooo00?o003ooooo
ooooool03?ooool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Sooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01Oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00Wooooo
0_l00005ooooo`004oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooool00?l01Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Oooooo00?o
003oooooooooool01?ooool2o`00o`Oooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0Pooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooo
oooooooo003o00Sooooo00Go0000ooooool00?ooooooo`00o`07ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_o
oooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003o
ooooooooooooooooo`00o`0@ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool00oooool001?ooooo00?o
0000ooooooooool01Oooool00ol00?ooooooo`00o`08ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooool00?l01_ooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00Cooooo0_l0
0?l8ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool08?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`02ooooo`05o`000?oooooo003oooooool00?l01oooool00ol00?ooooooooooo`0?ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooool00?l05_ooool01?l00?ooooooooooool00?l5ooooo`04
o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00Kooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00_ooooo00Co
003ooooooooooooo003o2Oooool00ol0003oooooooooo`03ooooo`004oooool00ol0003ooooooooo
o`05ooooo`03o`00oooooooo003o00Sooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool03oooool2o`00o`Oooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go
0000o`00ooooooooooooo`00o`07ooooo`03o`00oooooooooooo01Kooooo00?o003oooooool00?l0
1Oooool00ol00?ooooooooooo`06ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003ooooooooo
ool01_ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o2Oooool00ol0003ooooo
ooooo`03ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`00oooooooo003o00Gooooo00?o
003oooooooooool03oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00oooooo0_l0
0?l7ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool07oooool00ol00?ooooooo`00
o`08ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool01Ol0003ooooooooo
oooooooo003o00Oooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`03ooooo`04o`00
ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o4?ooool00ol00?ooooooooooo`0:oooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01?l00?ooooooooooool00?l8ooooo`03o`00oooooooooooo00Oooooo
00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool01Oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooo003o00Kooooo0_l00?l7ooooo`;o003o1_ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol0003ooooo
ooooo`09ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`03ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l02?ooool00ol00?oo
ooooooooo`0Cooooo`05o`00ooooooooooooooooool00?l02?ooool00ol00?ooooooooooo`06oooo
o`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool02oooool00ol0003oooooooooo`03
ooooo`004oooool2o`0000Sooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l5
ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00
o`06ooooo`;o003o1oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo027ooooo00?o
003oooooooooool01?ooool2o`00o`Kooooo00Co003ooooooooooooo003o2Oooool01Ol0003o003o
oooooooooooo003o00Kooooo0_l00?lAooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`0;ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?lAooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0:ooooo`;o00001Oooool001?ooooo00?o0000
ooooooooool01oooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`Gooooo00?o
003oooooool00?l01Oooool01?l00?ooooooooooool00?l7ooooo`03o`00oooooooooooo00Cooooo
0_l00?l8ooooo`03o`00oooooooooooo00Cooooo0_l00?l7ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00;ooooo00Go0000o`00ooooooooooooo`00o`06ooooo`03
o`00oooooooooooo013ooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`0Fooooo`04
o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l4ooooo`03o`00oooooooooooo00Kooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00[ooooo00Go003oooooooooooooooooo`00o`09ooooo`03o`000?oooooooooo00?o
oooo000Cooooo`03o`000?oooooooooo00Cooooo00Co003ooooooooooooo003o2?ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o1Oooool00ol0
0?ooooooo`00o`0@ooooo`03o`00oooooooooooo00Cooooo0_l00?l7ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`05o`000?l00?oooooo
ooooool00?l01_ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooooooool01_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l0
1?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00Wooooo00?o0000ooooooooool00oooool001?ooooo
00?o0000ooooooooool01?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooo003o00Oo
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Oo
oooo0_l00?l9ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool01Ol0003o
oooooooooooooooo003o00Kooooo0_l00?lIooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ool00?l01_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool0
1?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool00oooool001?ooooo00?o
0000ooooooooool01?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Gooooo0ol0
0?l6ooooo`03o`00oooooooo003o00Kooooo0_l00?l7ooooo`03o`00oooooooooooo00Gooooo0_l0
0?lHooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l01Oooool00ol00?oooooooooo
o`02ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00
o`06ooooo`03o`00oooooooo003o00Sooooo00?o003oooooooooool04oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Co003ooooooooooooo003o2?ooool01Ol00?oooooooooooooooooo003o
00Sooooo00?o003oooooooooool01oooool00ol0003oooooooooo`03ooooo`004oooool2o`0000So
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooo
oooooooo003o2?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooool00?l01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01Oooool00ol00?ooooooo`00o`0:ooooo`03o`00oooooooooooo00Sooooo0_l00?l7
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool0
0?l5ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool04Oooool00ol00?oooooooooo
o`06ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`0:ooooo`;o0000
1Oooool001?ooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00
o`Oooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`08ooooo`03o`00oooooooooooo
00Cooooo0_l00?l6ooooo`03o`00oooooooooooo00Kooooo0_l00?l7ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01Oooool2o`00o`Kooooo00?o003oooooooooool02_ooool01Ol0
0?oooooooooooooooooo003o00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooooooo003o1?ooool00ol00?oooooooooo
o`0:ooooo`05o`00ooooooooooooooooool00?l02Oooool00ol0003oooooooooo`03ooooo`004ooo
ool00ol0003oooooooooo`04ooooo`04o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool0
0_ooool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooo
oooooooo003o1Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo0_l00?l6
ooooo`;o003o1oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Kooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0>ooooo`;o003o1_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooo003o00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooo`00o`05ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Gooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo
00Oooooo00?o0000ooooooooool00oooool000cooooo0_l00005ooooo`03o`000?oooooooooo00Co
oooo00Co003ooooooooooooo003o3Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool03oooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo
00Cooooo0_l00?l7ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00_ooool01Ol0
003ooooooooooooooooo003o00Kooooo0_l00?l7ooooo`03o`00oooooooooooo00kooooo0_l00?l6
ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooooooo
ool00?l5ooooo`03o`00oooooooooooo00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol0003oooooooooo`03ooooo`00
2oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00_ooooo00Co003ooooooooo
oooo003o1Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Oooooo00?o003ooooo
ooooool01?ooool2o`00o`Oooooo0_l00?l7ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00;ooooo00?o0000oooo
ooooool02Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Kooooo0_l00?l8oooo
o`03o`00oooooooooooo00kooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l5
ooooo`04o`00ooooooooooooo`00o`Sooooo00Go003oooooooooooooooooo`00o`08ooooo`03o`00
oooooooooooo00Oooooo00?o0000ooooooooool00oooool000_ooooo00Co0000oooooooooooo0000
1?ooool?o`000005o`00ool0003o0000o`000?l00?l01?l000001?l00?oo0000o`000?l00?l8o`00
0003o`00ool0003o000000;o000000Co003oo`000?l0003o003o1Ol000000ol00?oo0000o`00o`05
o`000003o`00ool0003o000000Ko000000?o003oo`000?l000004?l000000ol00?oo0000o`000004
o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001_l000000ol00?oo0000o`000005
o`000003o`00ool0003o003o00[o000000?o003oo`000?l000001ol000000ol00?oo0000o`00o`07
o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001Ol000000ol00?oo0000o`000005
o`0000;o003o1ol00002o`00o`So000000?o003oo`000?l000001?l000000ol00?oo0000o`000005
o`000003o`00ool0003o003o00So000000?o003oo`000?l000001_l000000ol00?oo0000o`000005
o`000003o`00ool0003o000000;o000000Go003oo`000?l0003o0000o`00o`0?o`0000Gooooo000;
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`05
o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o
00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooo`00o`0@ooooo`03o`00oooooooooooo
00Cooooo0_l00?l7ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0:ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooo`00o`07
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00gooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooooooo00kooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooooooo
ool00?l8ooooo`03o`00oooooooooooo00cooooo00?o0000ooooooooool00oooool000_ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00Kooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`07ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l02?ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooo003o00Kooooo0_l00?l6ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01Oooool01_l00?oooooooooooooooooo003oo`0000?ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o
003oooooool00?l01_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Co
003ooooooooooooo003o1Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Gooooo00?o0000oooooooo
ool00oooool000_ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`07ooooo`03
o`00oooooooooooo00Kooooo00Go003oooooooooooooooooo`00o`08ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool03_ooool01?l00?ooooooooooool00?l7ooooo`03o`00oooooooo
oooo00Cooooo0_l00?l6ooooo`03o`00oooooooooooo00Kooooo0_l00?l@ooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool00oooool01_l00?oooooooooooooooooo003oo`0000?ooooo
00?o003oooooooooool00oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`;o003o1_ooool00ol00?oooooo
ooooo`06ooooo`;o003o1_ooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Go
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Ko
oooo00Go003oooooooooooooooooo`00o`05ooooo`03o`000?oooooooooo00?ooooo000<ooooo`;o
00001Oooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooo
oooo003o1Oooool01?l00?ooooooooooool00?l7ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooool00?l01_ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00;ooooo00Go0000
ooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo00Cooooo0_l00?l7ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool01Oooool2o`00o`Oooooo0_l00?l8ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l5ooooo`03o`00
oooooooo003o00Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`04o`00
ooooooooooooo`00o`Kooooo00?o0000ooooooooool00oooool001?ooooo0_l0000=ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Sooooo00?o003ooooo
ooooool00_ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01Oooool2o`00o`[ooooo00?o003oo`000?ooool02_ooool00ol00?oooooooooo
o`04ooooo`;o003o1oooool00ol00?ooooooooooo`0>ooooo`;o003o1oooool2o`00o`Sooooo00?o
003oooooooooool03?ooool00ol00?ooooooo`00o`08ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool02oooool01Ol00?oooooooooooooooooo003o00gooooo0_l00005ooooo`004ooo
ool00ol0003oooooooooo`07ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00Oooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`04ooooo`;o003o1oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo0_l00?l:ooooo`03o`00ool0003o
oooo00;ooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0=ooooo`;o003o1oooool2
o`00o`Kooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`04o`00oooooooo
ooooo`00o`Sooooo00?o003oooooooooool03?ooool00ol0003oooooooooo`03ooooo`004oooool0
0ol0003oooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00
oooooooooooo00;ooooo00Co003ooooooooooooo003o2?ooool00ol00?ooooooooooo`02ooooo`04
o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`07oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05oooo
o`06o`00ooooooooooooooooool00?oo00000oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Oooooo`;o003o1ooo
ool2o`00o`Kooooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooo
oooooooo00Gooooo00Co003ooooooooooooo003o1oooool00ol00?ooooooooooo`03ooooo`04o`00
ooooooooooooo`00o`Kooooo00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool0
1oooool00ol00?ooooooooooo`06ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l04Oooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01_ooool00ol00?oooooooooo
o`06ooooo`;o003o1oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00Ko
003oooooooooooooooooo`00ool00003ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`06ooooo`;o003o1_ooool00ol00?ooooooo`00o`05ooooo`03
o`00oooooooo003o00Kooooo00?o003oooooooooool01Oooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o1_ooool00ol0003ooooooooo
o`03ooooo`004oooool00ol0003oooooooooo`07ooooo`05o`00ooooooooooooooooool00?l04?oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00oooooo00Co003ooooooooooooo003o
1oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l0
1_ooool2o`00oaWooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`05o`00
0?ooooooooooooooool00?l01oooool00ol00?ooooooooooo`04ooooo`;o003o1oooool00ol00?oo
ooooooooo`0?ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01_ooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool01?l00?oo
ooooooooool00?l6ooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo00_o
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`06ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003o
ooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03ooo
ool2o`00o`Kooooo00Ko003ooooooooooooo003oooooool0000;ooooo`03o`00oooooooooooo00Co
oooo0_l00?l7ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l02?ooool00ol00?oo
ooooooooo`0;ooooo`04o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool01?ooool00ol0
003oooooooooo`03ooooo`004oooool2o`0000Sooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo
003o1?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo017ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00oooooo0_l00?l9ooooo`03
o`00oooooooo000000?ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l7oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`05oooo
o`;o003o1oooool2o`00o`Kooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool2o`0000Gooooo000Cooooo`03
o`000?oooooooooo00Oooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool01Ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`02ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01Oooool01?l00?oo
ooooooooool00?l7ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol0
0?ooooooooooo`05ooooo`06o`00ooooooooooooo`00oooooooo00000oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`0Gooooo`03o`00oooooooooooo00Gooooo0_l00?l7ooooo`;o003o1_ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`08ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o1_ooool00ol0003ooooo
ooooo`03ooooo`004oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00Co
003ooooooooooooo003o2?ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooo
oooo003o1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Gooooo00Ko003ooooo
oooooooo003oooooool00003ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`05ooooo`;o003o1_ooool00ol00?ooooooo`00o`06ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l5ooooo`03o`00
oooooooo003o00Oooooo00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool01ooo
ool01Ol00?oooooooooooooooooo003o013ooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0>ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`02ooooo`04
o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool01_ooool00ol00?ooooooo`00o`0Hoooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool01Ol0003ooooooooooooooooo
003o00Cooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`0Yooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooo003o00Kooooo0_l00?l6ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_oo
ool00ol00?ooooooo`00o`07ooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooo
oooo00_ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooo
oooo003o1Oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o0000
ooooooooool02Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Kooooo00?o003o
ooooooooool08?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo0_l00?l7
ooooo`;o003o3_ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Oooooo00?o
0000ooooooooool00oooool001?ooooo0_l0000;ooooo`03o`00oooooooooooo00?ooooo00Co003o
oooooooooooo003o1?ooool00ol00?ooooooooooo`06ooooo`04o`00ooooooooooooo`00o`Cooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00?ooooo00?o003oooooool0
0?l01_ooool00ol00?ooooooooooo`0Iooooo`04o`00ooooooooooooo`0000Oooooo00Go003ooooo
ooooooooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo00?o003oooooooooool08?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo0_l00?l@ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l>ooooo`;o00001Ooo
ool001?ooooo00?o0000ooooooooool01oooool01?l00?ooooooooooool00?l5ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00Go
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00Kooooo00Co003o
oooooooooooo003o1oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01[ooooo00Co
003ooooooooooooo00000oooool01Ol00?oooooooooooooooooo003o00_ooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo0_l00?l6ooooo`03
o`00oooooooo003o00Oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`07ooooo`03
o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool0
1_ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l0
0?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`06ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`04o`00
ooooooooooooo`00o`Gooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo01Sooooo00?o003oooooool00?l00_ooool01Ol0003ooooooooooooooooo003o
00?ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo
00Gooooo0_l00?l6ooooo`;o003o1oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo003o
00Gooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`07ooooo`03o`000?oooooooooo
00?ooooo000Cooooo`03o`000?oooooooooo00Oooooo00Co003ooooooooooooo003o1Oooool01?l0
0?ooooooooooool00?l7ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool0
1?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o
8?ooool00ol00?ooooooooooo`02ooooo`05o`000?ooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00Gooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Gooooo0_l00?l7ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo003o00Oooooo00?o0000oooo
ooooool00oooool001?ooooo00?o0000ooooooooool02_ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool01_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00;ooooo00Co003ooooooooooooo003o1Oooool01?l00?ooooooooooool00?l4ooooo`03o`00oooo
oooooooo027ooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`00oooo
oooooooo00;ooooo00Co003ooooooooooooo003o1_ooool00ol00?ooooooooooo`0aooooo`03o`00
oooooooooooo00Gooooo0_l00?l7ooooo`;o003o3_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooo003o00Oooooo00?o0000ooooooooool00oooool001?ooooo0_l0000;ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`06ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l02?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0Jooooo`04o`00ooooooooooooo`0000Oooooo00Go003o
ooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Kooooo00?o003oooooooooool0
<Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00oooooo0_l00005ooooo`004ooo
ool00ol0003oooooooooo`07ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l0
1Oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooo
oooo003o1?ooool00ol00?ooooooooooo`0:ooooo`05o`00ooooooooooooooooool00?l01?ooool0
0ol00?ooooooooooo`05ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?oooooooooo
ool00?l5ooooo`03o`00oooooooooooo01[ooooo00Co003ooooooooooooo00000oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo03;ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05oooo
o`;o003o2?ooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo000Cooooo`03
o`000?oooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooo`00o`05ooooo`04
o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool01Oooool01?l00?ooooooooooool00?l4
ooooo`03o`00oooooooooooo00Kooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool06?ooool2o`00o`?ooooo00Go0000oooooooooooo
ooooo`00o`02ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0booooo`03o`00oooooooooooo00Gooooo0_l00?l7ooooo`03o`00oooooooooooo00Go
oooo0_l00?l8ooooo`03o`00oooooooooooo00Cooooo0_l00?l8ooooo`03o`000?oooooooooo00?o
oooo000;ooooo`?o00001Oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooool00?l02?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00kooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooo
oooo003o8?ooool2o`00o`?ooooo00Go0000ooooooooooooooooo`00o`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0kooooo`03o`00oooooooo
oooo00Gooooo0_l00?l7ooooo`03o`00oooooooooooo00Gooooo0_l00?l6ooooo`03o`00oooooooo
oooo00Kooooo0_l00?l8ooooo`03o`000?oooooooooo00?ooooo000<ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003o
ooooooooool01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool08Oooool00ol00?oooooo
ooooo`02ooooo`05o`000?ooooooooooooooool00?l01oooool00ol00?ooooooooooo`02ooooo`04
o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool0>_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06oooo
o`;o003o2?ooool00ol0003oooooooooo`03ooooo`003?ooool00ol0003oooooooooo`04ooooo`?o
00002Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Gooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooo
ooooooooooooo`00o`07ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool06?ooool2
o`00o`?ooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`02ooooo`04o`00oooooooo
ooooo`00o`Gooooo00?o003oooooooooool0>_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00gooooo0_l00?l?ooooo`?o00001Oooool000cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`07ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l01Oooool0
1?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o
1?ooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003oooooooooool04oooool00ol00?oo
ooooooooo`02ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool06Oooool01Ol0
0?oooooooooooooooooo000000?ooooo00Co003ooooooooooooo003o1?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0@oooool00ol00?oooooooooo
o`05ooooo`;o003o1oooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo000<
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1Oooool00ol00?oooooooooo
o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool01_ooool01?l00?oooooo
ooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo01Sooooo0_l00?l3ooooo`05o`000?ooooooooooooooool00?l00_ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0@oooool00ol00?oooooooooo
o`05ooooo`;o003o1oooool00ol00?ooooooooooo`05ooooo`;o003o2?ooool00ol0003ooooooooo
o`03ooooo`002oooool2o`0000Kooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooo003o00Oooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`0@
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01Oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`05o`00oooo
ooooooooooooool00?l01?ooool00ol00?ooooooooooo`0Iooooo`;o003o0oooool01Ol0003ooooo
oooooooooooo003o00;ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`1<ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool2o`00o`Oooooo0_l00?l8ooooo`03
o`000?oooooooooo00?ooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool00ol00?ooooooo`00o`0@ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
3_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`02ooooo`05o`000?oooooo
ooooooooool00?l01oooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Gooooo
00?o003oooooooooool0@oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01_ooool2o`00o`Sooooo00?o0000ooooooooool00oooool001?ooooo00?o
0000ooooooooool02Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Go
oooo00Co003ooooooooooooo003o3?ooool00ol00?ooooooooooo`06ooooo`05o`00oooooooooooo
ooooool00?l02?ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo00;ooooo00?o0000
ooooooooool02Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`1Cooooo`;o003o2?ooool00ol00?ooooooooooo`06ooooo`03o`000?oo
oooooooo00?ooooo000Cooooo`;o00002?ooool00ol00?ooooooo`00o`06ooooo`;o003o1_ooool0
0ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o1?oo
ool01?l00?ooooooooooool00?l8ooooo`03o`00oooooooooooo01?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool07_ooool00ol0003o
ooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo04cooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0>ooooo`;o00001Oooool001?ooooo00?o0000ooooooooool01oooool00ol00?oooooo
o`00o`06ooooo`;o003o1_ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooool00?l01Oooool00ol00?ooooooooooo`06ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01kooooo00Oo0000
ooooooooooooooooo`00oooooooo003o00gooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`1<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`07ooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo00Oooooo00?o
003oooooooooool01_ooool2o`00o`Sooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooooooo00kooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l4ooooo`05o`00ooooooooooooooooool00?l03?ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo01kooooo00Oo0000ooooooooooooooooo`00oooooooo003o00Wooooo00?o
003oooooooooool0GOooool2o`00o`Oooooo00?o003oooooooooool01oooool00ol0003ooooooooo
o`03ooooo`004oooool00ol0003oooooooooo`07ooooo`;o003o4Oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`05
ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`08ooooo`05o`00
ooooooooooooooooool00?l09Oooool01Ol0003ooooooooooooooooo003o00Oooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo05Wooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`07ooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo
00Sooooo00?o003oooooooooool03Oooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo
003o00Gooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00Cooooo
00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo01oooooo00?o0000oooooooo
ool02Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`1Dooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol0
003oooooooooo`03ooooo`004oooool2o`0000Wooooo00?o003oooooooooool01Oooool2o`00o`Ko
oooo00?o003oooooooooool01_ooool2o`00o`Kooooo00?o003oooooool00?l01Oooool01?l00?oo
ooooooooool00?l7ooooo`03o`00oooooooooooo01Cooooo00Co003ooooooooooooo003o1?ooool0
1Ol00?oooooooooooooooooo003o027ooooo00?o0000ooooooooool00oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`1Dooooo`03o`00oooooooooooo00oooooo0_l00005ooooo`004oooool00ol0003oooooooooo`07
ooooo`;o003o1oooool2o`00o`Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooo`00o`05
ooooo`04o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`05ooooo`05o`00ooooooooooooooooool00?l08Oooool01ol0003ooooooooooooooooo003ooooo
ool00?l01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool0GOooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo00?ooooo000Cooooo`03
o`000?oooooooooo00Oooooo00?o003oooooooooool01_ooool2o`00o`Kooooo0_l00?l7ooooo`;o
003o1_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooool0
0?l01Oooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l03?ooool0
1Ol00?oooooooooooooooooo003o027ooooo00Co0000oooooooooooooooo0_l00?l9ooooo`03o`00
oooooooooooo06Oooooo00?o003oooooooooool01oooool00ol0003oooooooooo`03ooooo`004ooo
ool00ol0003oooooooooo`07ooooo`;o003o1oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Gooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00Oo
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Sooooo`04o`000?oooooooooooooo
o`;o003o1_ooool01?l00?ooooooooooool00?mYooooo`03o`00oooooooooooo00Oooooo00?o0000
ooooooooool00oooool001?ooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`0=oooo
o`;o003o2?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ool00?l01_ooool00ol00?ooooooooooo`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o1Oooool01?l00?ooooooooooool00?lZooooo`03o`000?oooooooooo00Wooooo
00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o06[ooooo00?o0000oooo
ooooool00oooool001?ooooo0_l00009ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool01Oooool2o`00o`Oooooo0_l00?l6ooooo`;o003o1_ooool00ol00?ooooooo`00o`08ooooo`03
o`00oooooooooooo01Cooooo00Co003ooooooooooooo003o2?ooool00ol00?ooooooooooo`0Ooooo
o`03o`000?oooooooooo00;ooooo00?o003oooooooooool01?ooool01?l00?ooooooooooool00?l4
ooooo`05o`00ooooooooooooooooool00?l0JOooool2o`0000Gooooo000Cooooo`03o`000?oooooo
oooo00Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01Oooool2o`00o`Kooooo00?o003oooooooooool02?ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Sooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`05ooooo`05o`00ooooooooooooooooool00?l08Oooool01?l0003ooooooooo
ooooool2o`00o`Kooooo00?o003oooooooooool01Oooool01Ol00?oooooooooooooooooo003o06[o
oooo00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool04?ooool00ol00?oooooo
ooooo`05ooooo`;o003o1oooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?oooooo
ooooool00?l=ooooo`05o`00ooooooooooooooooool00?l08Oooool01?l0003oooooooooooooool2
o`00o`Wooooo00?o003oooooooooool0LOooool00ol0003oooooooooo`03ooooo`004oooool00ol0
003oooooooooo`0@ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol0
0?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Sooooo`04o`000?ooooooooooooooo`;o003o1_ooool01?l00?oooooooooo
ool00?mcooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo01Wooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooool00?l01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo003o00Gooooo00Co
003ooooooooooooo003o1Oooool01?l00?ooooooooooool00?lZooooo`05o`000?oooooooooooooo
ool00?l01oooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l0J_ooool0
0ol0003oooooooooo`03ooooo`004oooool2o`0001Wooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`05ooooo`;o003o1_ooool2o`00o`Sooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooo003o00Sooooo00?o003oooooooooool08?ooool01Ol0
003ooooooooooooooooo003o00Oooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooo
oooo003o06Wooooo0_l00005ooooo`004oooool00ol0003oooooooooo`0Hooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01Oooool2o`00o`Kooooo0_l00?l8ooooo`03o`00oooooooo
oooo01Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?lRooooo`05o`000?oo
ooooooooooooool00?l01oooool00ol00?ooooooooooo`05ooooo`04o`00ooooooooooooo`00of_o
oooo00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool06?ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Gooooo0_l00?l6ooooo`03o`00oooooooooooo00Kooooo
0_l00?l6ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1Oooool00ol00?oo
ooooooooo`05ooooo`04o`00ooooooooooooo`00ob;ooooo00Go0000ooooooooooooooooo`00o`0?
ooooo`04o`00ooooooooooooo`00of_ooooo00?o0000ooooooooool00oooool000[ooooo1Ol00004
ooooo`03o`000?oooooooooo027ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool0
0?l7ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool08oooool01Ol0003ooooooooo
oooooooo003o00Wooooo00?o003oooooooooool0L_ooool00ol0003oooooooooo`03ooooo`002ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo027ooooo00?o003oooooooooool0
3_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo0_l00?l6ooooo`03o`00
oooooooo003o00Kooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`0Sooooo`05o`00
0?ooooooooooooooool00?l01oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00
of_ooooo00?o0000ooooooooool00oooool000cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Qooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool2o`00o`Oo
oooo0_l00?l>ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l02?ooool00ol00?oo
ooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o003oooooool00?l01Oooool01?l00?oo
ooooooooool00?m[ooooo`03o`000?oooooooooo00?ooooo000=ooooo`03o`000?oooooooooo00?o
oooo0ol0000Yooooo`03o`00oooooooooooo00Gooooo0_l00?l8ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00
ob;ooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`05ooooo`04o`00oooooooooooo
o`00ofWooooo0ol00005ooooo`002_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool0:Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool01Oooool2o`00o`oooooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`0S
ooooo`03o`000?oooooooooo017ooooo00Co003ooooooooooooo003oJoooool00ol0003ooooooooo
o`03ooooo`002_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0:Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Ooo
ool2o`00o`Kooooo00?o003oooooooooool03_ooool00ol00?ooooooo`00o`0Sooooo`03o`000?oo
oooooooo00_ooooo00?o003oooooooooool0L_ooool00ol0003oooooooooo`03ooooo`002oooool3
o`0000Gooooo00?o0000ooooooooool0<_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Gooooo0_l00?l6ooooo`03o`00oooooooo003o00Sooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0Sooooo`03o`000?oooooooooo00Wooooo00?o003oooooool00?l01Oooool0
0ol00?ooooooooooo`1/ooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo
037ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo
027ooooo00?o0000ooooooooool02Oooool2o`00o`Kooooo00Co003ooooooooooooo003oJoooool0
0ol0003oooooooooo`03ooooo`004oooool2o`0003;ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo0_l00?l8ooooo`03o`00oooooooooooo
027ooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`05ooooo`04o`00oooooooooooo
o`00of[ooooo0_l00005ooooo`004oooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01Oooool2o`00o`oooooo00?o003oooooooooool01Oooool00ol0
0?ooooooo`00o`0Sooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool01Oooool00ol0
0?ooooooo`00o`1/ooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo03[o
oooo00?o003oooooooooool01Oooool2o`00o`Kooooo00?o003oooooooooool03_ooool00ol00?oo
ooooo`00o`0Sooooo`03o`000?oooooooooo00[ooooo00?o003oooooooooool0Loooool00ol0003o
ooooooooo`03ooooo`004oooool00ol0003oooooooooo`0jooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01Oooool2o`00o`Sooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0Sooooo`03o`000?oooooooooo00Wooooo0_l00?meooooo`03o`000?oooooooooo00?ooooo
000Cooooo`03o`000?oooooooooo03[ooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`05ooooo`;o003o1oooool2o`00obcooooo00?o0000ooooooooool02Oooool2o`00o`Kooooo00?o
003oooooool00?l0K?ooool00ol0003oooooooooo`03ooooo`004oooool2o`0004cooooo00?o003o
ooooooooool01Oooool2o`00o`Sooooo00?o003oooooooooool08Oooool00ol0003oooooooooo`09
ooooo`;o003o1_ooool00ol00?ooooooo`00o`1[ooooo`;o00001Oooool001?ooooo00?o0000oooo
ooooool0@_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ool00?l08oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ool00?l0K?ooool00ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`12ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`;o
003o9?ooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo07Cooooo00?o0000oooooooo
ool00oooool001?ooooo00?o0000ooooooooool0@_ooool00ol00?ooooooooooo`05ooooo`;o003o
1oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02?ooooo00?o0000ooooooooool0
2Oooool00ol00?ooooooooooo`1dooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oo
oooooooo04[ooooo0_l00?l7ooooo`03o`00oooooooooooo02_ooooo00?o0000ooooooooool02Ooo
ool00ol00?ooooooooooo`05ooooo`;o003oKOooool00ol0003oooooooooo`03ooooo`004oooool2
o`0004_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo02;ooooo00?o0000ooooooooool04Oooool2o`00ofcooooo0_l00005ooooo`004oooool00ol0
003oooooooooo`1:ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool2o`00
obCooooo00?o0000ooooooooool04Oooool2o`00ofgooooo00?o0000ooooooooool00oooool001?o
oooo00?o0000ooooooooool0Doooool00ol00?ooooooooooo`05ooooo`;o003o9?ooool00ol0003o
ooooooooo`0Aooooo`;o003oKOooool00ol0003oooooooooo`03ooooo`004oooool00ol0003ooooo
ooooo`1Cooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool08oooool00ol0003ooooo
ooooo`20ooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo05?ooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0Sooooo`03o`000?oooooooooo017ooooo0_l0
0?m]ooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo05?ooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0Sooooo`03o`000?oooooooooo017ooooo0_l00?m]
ooooo`03o`000?oooooooooo00?ooooo000Cooooo`;o0000G?ooool00ol00?ooooooooooo`0Soooo
o`03o`000?oooooooooo017ooooo0_l00?m/ooooo`;o00001Oooool001?ooooo00?o0000oooooooo
ool0Foooool00ol00?ooooooooooo`0Sooooo`03o`000?oooooooooo017ooooo0_l00?m]ooooo`03
o`000?oooooooooo00?ooooo000;ooooo`?o00001Oooool00ol0003oooooooooo`1Kooooo`03o`00
oooooooooooo02?ooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`03ooooo`002_oo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0Foooool00ol00?oooooo
ooooo`0Sooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool00oooool000kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo083ooooo00?o
0000ooooooooool00oooool000cooooo0_l00005ooooo`?o0000POooool00ol0003oooooooooo`1n
ooooo`?o00001Oooool000kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo000:ooooo`05o`000?ooooooooooooooool000001?ooooooo`00
00Wo00001Oooool000_ooooo0ol0003ooooooa?ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-6.03148, -3.56329, \
0.0399221, 0.0380621}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Magnitude plot of DFT as a function of frequency", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fft\  = \ DFT[xd];\)\), "\n", 
    \(\(g3 = 
        DiscreteListPlot[\({#[\([1]\)], \ Abs[#[\([2]\)]]} &\)\  /@ \ fft, 
          Red, \ PlotRange \[Rule] All, \ Frame \[Rule] True, \ 
          Axes \[Rule] False];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0328407 0.0147151 0.058334 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18801 -0.0125 -3 -9 ]
[.18801 -0.0125 3 0 ]
[.35222 -0.0125 -6 -9 ]
[.35222 -0.0125 6 0 ]
[.51642 -0.0125 -6 -9 ]
[.51642 -0.0125 6 0 ]
[.68062 -0.0125 -6 -9 ]
[.68062 -0.0125 6 0 ]
[.84483 -0.0125 -6 -9 ]
[.84483 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13138 -6 -4.5 ]
[-0.0125 .13138 0 4.5 ]
[-0.0125 .24805 -6 -4.5 ]
[-0.0125 .24805 0 4.5 ]
[-0.0125 .36472 -6 -4.5 ]
[-0.0125 .36472 0 4.5 ]
[-0.0125 .48139 -6 -4.5 ]
[-0.0125 .48139 0 4.5 ]
[-0.0125 .59805 -12 -4.5 ]
[-0.0125 .59805 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18801 0 m
.18801 .00625 L
s
[(5)] .18801 -0.0125 0 1 Mshowa
.35222 0 m
.35222 .00625 L
s
[(10)] .35222 -0.0125 0 1 Mshowa
.51642 0 m
.51642 .00625 L
s
[(15)] .51642 -0.0125 0 1 Mshowa
.68062 0 m
.68062 .00625 L
s
[(20)] .68062 -0.0125 0 1 Mshowa
.84483 0 m
.84483 .00625 L
s
[(25)] .84483 -0.0125 0 1 Mshowa
.125 Mabswid
.05665 0 m
.05665 .00375 L
s
.08949 0 m
.08949 .00375 L
s
.12233 0 m
.12233 .00375 L
s
.15517 0 m
.15517 .00375 L
s
.22085 0 m
.22085 .00375 L
s
.25369 0 m
.25369 .00375 L
s
.28654 0 m
.28654 .00375 L
s
.31938 0 m
.31938 .00375 L
s
.38506 0 m
.38506 .00375 L
s
.4179 0 m
.4179 .00375 L
s
.45074 0 m
.45074 .00375 L
s
.48358 0 m
.48358 .00375 L
s
.54926 0 m
.54926 .00375 L
s
.5821 0 m
.5821 .00375 L
s
.61494 0 m
.61494 .00375 L
s
.64778 0 m
.64778 .00375 L
s
.71346 0 m
.71346 .00375 L
s
.74631 0 m
.74631 .00375 L
s
.77915 0 m
.77915 .00375 L
s
.81199 0 m
.81199 .00375 L
s
.87767 0 m
.87767 .00375 L
s
.91051 0 m
.91051 .00375 L
s
.94335 0 m
.94335 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13138 m
.00625 .13138 L
s
[(2)] -0.0125 .13138 1 0 Mshowa
0 .24805 m
.00625 .24805 L
s
[(4)] -0.0125 .24805 1 0 Mshowa
0 .36472 m
.00625 .36472 L
s
[(6)] -0.0125 .36472 1 0 Mshowa
0 .48139 m
.00625 .48139 L
s
[(8)] -0.0125 .48139 1 0 Mshowa
0 .59805 m
.00625 .59805 L
s
[(10)] -0.0125 .59805 1 0 Mshowa
.125 Mabswid
0 .04388 m
.00375 .04388 L
s
0 .07305 m
.00375 .07305 L
s
0 .10222 m
.00375 .10222 L
s
0 .16055 m
.00375 .16055 L
s
0 .18972 m
.00375 .18972 L
s
0 .21888 m
.00375 .21888 L
s
0 .27722 m
.00375 .27722 L
s
0 .30638 m
.00375 .30638 L
s
0 .33555 m
.00375 .33555 L
s
0 .39389 m
.00375 .39389 L
s
0 .42305 m
.00375 .42305 L
s
0 .45222 m
.00375 .45222 L
s
0 .51055 m
.00375 .51055 L
s
0 .53972 m
.00375 .53972 L
s
0 .56889 m
.00375 .56889 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18801 .61178 m
.18801 .61803 L
s
.35222 .61178 m
.35222 .61803 L
s
.51642 .61178 m
.51642 .61803 L
s
.68062 .61178 m
.68062 .61803 L
s
.84483 .61178 m
.84483 .61803 L
s
.125 Mabswid
.05665 .61428 m
.05665 .61803 L
s
.08949 .61428 m
.08949 .61803 L
s
.12233 .61428 m
.12233 .61803 L
s
.15517 .61428 m
.15517 .61803 L
s
.22085 .61428 m
.22085 .61803 L
s
.25369 .61428 m
.25369 .61803 L
s
.28654 .61428 m
.28654 .61803 L
s
.31938 .61428 m
.31938 .61803 L
s
.38506 .61428 m
.38506 .61803 L
s
.4179 .61428 m
.4179 .61803 L
s
.45074 .61428 m
.45074 .61803 L
s
.48358 .61428 m
.48358 .61803 L
s
.54926 .61428 m
.54926 .61803 L
s
.5821 .61428 m
.5821 .61803 L
s
.61494 .61428 m
.61494 .61803 L
s
.64778 .61428 m
.64778 .61803 L
s
.71346 .61428 m
.71346 .61803 L
s
.74631 .61428 m
.74631 .61803 L
s
.77915 .61428 m
.77915 .61803 L
s
.81199 .61428 m
.81199 .61803 L
s
.87767 .61428 m
.87767 .61803 L
s
.91051 .61428 m
.91051 .61803 L
s
.94335 .61428 m
.94335 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13138 m
1 .13138 L
s
.99375 .24805 m
1 .24805 L
s
.99375 .36472 m
1 .36472 L
s
.99375 .48139 m
1 .48139 L
s
.99375 .59805 m
1 .59805 L
s
.125 Mabswid
.99625 .04388 m
1 .04388 L
s
.99625 .07305 m
1 .07305 L
s
.99625 .10222 m
1 .10222 L
s
.99625 .16055 m
1 .16055 L
s
.99625 .18972 m
1 .18972 L
s
.99625 .21888 m
1 .21888 L
s
.99625 .27722 m
1 .27722 L
s
.99625 .30638 m
1 .30638 L
s
.99625 .33555 m
1 .33555 L
s
.99625 .39389 m
1 .39389 L
s
.99625 .42305 m
1 .42305 L
s
.99625 .45222 m
1 .45222 L
s
.99625 .51055 m
1 .51055 L
s
.99625 .53972 m
1 .53972 L
s
.99625 .56889 m
1 .56889 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .07305 L
s
.05665 .01472 m
.05665 .0926 L
s
.08949 .01472 m
.08949 .16568 L
s
.12233 .01472 m
.12233 .53849 L
s
.15517 .01472 m
.15517 .60332 L
s
.18801 .01472 m
.18801 .23052 L
s
.22085 .01472 m
.22085 .15519 L
s
.25369 .01472 m
.25369 .12268 L
s
.28654 .01472 m
.28654 .10464 L
s
.31938 .01472 m
.31938 .09335 L
s
.35222 .01472 m
.35222 .08581 L
s
.38506 .01472 m
.38506 .08063 L
s
.4179 .01472 m
.4179 .07709 L
s
.45074 .01472 m
.45074 .07478 L
s
.48358 .01472 m
.48358 .07347 L
s
.51642 .01472 m
.51642 .07305 L
s
.54926 .01472 m
.54926 .07347 L
s
.5821 .01472 m
.5821 .07478 L
s
.61494 .01472 m
.61494 .07709 L
s
.64778 .01472 m
.64778 .08063 L
s
.68062 .01472 m
.68062 .08581 L
s
.71346 .01472 m
.71346 .09335 L
s
.74631 .01472 m
.74631 .10464 L
s
.77915 .01472 m
.77915 .12268 L
s
.81199 .01472 m
.81199 .15519 L
s
.84483 .01472 m
.84483 .23052 L
s
.87767 .01472 m
.87767 .60332 L
s
.91051 .01472 m
.91051 .53849 L
s
.94335 .01472 m
.94335 .16568 L
s
.97619 .01472 m
.97619 .0926 L
s
.015 w
.02381 .07305 Mdot
.05665 .0926 Mdot
.08949 .16568 Mdot
.12233 .53849 Mdot
.15517 .60332 Mdot
.18801 .23052 Mdot
.22085 .15519 Mdot
.25369 .12268 Mdot
.28654 .10464 Mdot
.31938 .09335 Mdot
.35222 .08581 Mdot
.38506 .08063 Mdot
.4179 .07709 Mdot
.45074 .07478 Mdot
.48358 .07347 Mdot
.51642 .07305 Mdot
.54926 .07347 Mdot
.5821 .07478 Mdot
.61494 .07709 Mdot
.64778 .08063 Mdot
.68062 .08581 Mdot
.71346 .09335 Mdot
.74631 .10464 Mdot
.77915 .12268 Mdot
.81199 .15519 Mdot
.84483 .23052 Mdot
.87767 .60332 Mdot
.91051 .53849 Mdot
.94335 .16568 Mdot
.97619 .0926 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005oooool2o`0002Wooooo0ol0000Uooooo`?o00001?ooool2o`0002?ooooo0ol00003oooo
o`?o00008_ooool5o`0000?ooooo0_l0000Qooooo`Go00000_ooool3o`0002[ooooo000Fooooo`04
o`000?ooooooooooo`0002Oooooo00Go0000ooooooooooooooooo`00000Uooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00008oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool08?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
027ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo02Oooooo000F
ooooo`04o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02Oooooo000Fooooo`04o`000?ooooooooooo`0002_o
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
02?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Rooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool09oooool001Kooooo00Co0000oooooooooooo00009oooool4o`0002Kooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co0000
8_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0
003ooooooooooooooooo0000ooooo`Co0000:_ooool001Kooooo00Co0000oooooooooooo00009ooo
ool00ol0003oooooooooo`0Vooooo`;o00001?ooool01?l0003oooooooooool0000Rooooo`;o0000
0oooool00ol0003oooooooooo`0Sooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool0000Pooooo`07o`000?ooooooooooooooool0003oooooo`00000]ooooo`005oooool2
o`0002Sooooo1Ol0000Uooooo`03o`000?oooooooooo00?ooooo0_l0000Tooooo`04o`000?oooooo
ooooooooo`Go00008_ooool3o`0000Cooooo0_l0000Rooooo`?o00000_ooool5o`0002Wooooo003o
ooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Aoooooooo00003Ol0
0003ooooo`002_ooool2o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`01
ooooo`002Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3o
ooooo`Wooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool3
o`0000Cooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00;ooooo0ol00003ooooo`002Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00Cooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00Cooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`04ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooooooo`04ooooo`03o`000?oooooooooo007ooooo000:ooooo`;o00001Oooool00ol0
003oooooooooo`04ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo
003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo
003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo
003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo
003oooooooooo`04ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Co
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Go
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Go
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Go
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Co
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05
ooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool00Oooool0017ooooo0_l00005oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`03oooo
o`;o00000oooool0017ooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo00Cooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oo
oooooooo00Cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`05ooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool00Oooool0017ooooo
0_l00003ooooo`?oo`002?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool01?ooool3ool000Kooooo0ooo0006ooooo`?oo`001Oooool3ool000Kooooo
0ooo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`03ooooo`;o00000oooool0017ooooo00?o0000ooooooooool00_ooool3ool000Sooooo00?o
o`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`04ooooo`?oo`001_ooool3ool000Kooooo0ooo
0006ooooo`?oo`001Oooool3ool000Kooooo0ooo0006ooooo`?oo`001oooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`05ooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool00_ooool3ool000Sooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool3ool000Gooooo0ooo0006
ooooo`?oo`001_ooool3ool000Kooooo0ooo0005ooooo`?oo`001_ooool3ool000Kooooo0ooo0006
ooooo`?oo`001oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo00gooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05oooo
o`03ool00?oooooooooo00Gooooo0ooo0006ooooo`?oo`001Oooool3ool003;ooooo0ooo0006oooo
o`?oo`001Oooool3ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05oooo
o`03ool00?oooooooooo00Cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool03Oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo
ool01Oooool3ool000Kooooo0ooo0013ooooo`?oo`001Oooool3ool000Oooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Cooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool02oooool3ool000Oooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1?ooool3ool000Kooooo0ooo001Dooooo`?oo`001_ooool3ool000Oooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1?ooool3ool000Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool02ooo
ool3ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool01?ooool3ool006Kooooo0ooo0007ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00Cooooo0ooo0005ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo00_ooooo0ooo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Cooooo0ooo001Vooooo`?oo`001oooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`04ooooo`?oo`001Oooool00ol0003oooooooooo`01ooooo`004Oooool2o`00
01Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Cooooo0ooo001hooooo`?oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool02oooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo01Go
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Co
oooo0ooo001hooooo`?oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Go
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`0Eooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`04ooooo`?oo`00N?ooool3ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool05Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool0ROooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool03?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0E
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`29
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0<
ooooo`03o`000?oooooooooo007ooooo0008ooooo`Go00001?ooool00ol0003oooooooooo`0Eoooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Oooool3ool008Wooooo0ooo0007oooo
o`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`01oooo
o`002Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo01Gooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool01Oooool00ooo003oooooooooo`05ooooo`?oo`00ROooool3ool000Oooooo00?oo`00oooo
ooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo007ooooo000:ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo00Gooooo0ooo0029ooooo`?oo`001oooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00cooooo00?o0000ooooooooool00Oooool000_ooooo00?o0000ooooooooool0
0oooool3o`0001Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`2Kooooo`03ool0
0?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool02_ooool3o`0000?ooooo0008ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool0Voooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00cooooo
00?o0000ooooooooool00Oooool000Sooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo01Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`2Kooooo`03ool0
0?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`01ooooo`002Ooo
ool3o`0000Gooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oo
oooooooo09_ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0<ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooooooo`2Kooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool03?ooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Gooooo00?oo`00ooooooooool0Voooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool05Oooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`04ooooo`?oo`00V_ooool3ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool03?ooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Cooooo
0ooo002Jooooo`?oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo007ooooo
000Aooooo`;o00005Oooool3ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Cooooo0ooo002Jooooo`?oo`001oooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01?ooool3ool000gooooo0_l0
0003ooooo`004Oooool00ol0003oooooooooo`0Dooooo`?oo`001oooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0Zoooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01?ooool3ool000kooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool05?ooool3ool000Oooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo0:_ooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Cooooo0ooo000>oooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01kooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo0:_ooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01Gooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool0Zoooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`2[ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo01kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo0:_ooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo0_l0000Oooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`2[ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Dooooo`;o00000oooool0017o
oooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool0Zoooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`0Nooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`2[ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`0Eooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01kooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo0:_ooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01Gooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0Zoooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`2[ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo01kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo0:_ooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
7_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
Zoooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
5Oooool00ol0003oooooooooo`01ooooo`004Oooool2o`0001oooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo0:_ooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01Cooooo0_l00003ooooo`004Oooool0
0ol0003oooooooooo`0Nooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`2[ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
01kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
0:_ooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
01Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool07_ooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Cooooo0ooo002/ooooo`?oo`001oooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo
00?o0000ooooooooool07_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Cooooo
0ooo002/ooooo`?oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01Gooooo
00?o0000ooooooooool00Oooool000[ooooo0ol00004ooooo`03o`000?oooooooooo01kooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`04ooooo`?oo`00[?ooool3ool000Oooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo000;
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo0;gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0E
ooooo`03o`000?oooooooooo007ooooo0008ooooo`Go00001?ooool00ol0003oooooooooo`0Noooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0_Oooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool000Sooooo00Co0000oooooooo
oooo00001Oooool3o`0001kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`2moooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool04oooool3o`0000?ooooo0009ooooo`03
o`000?oooooo000000Gooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo0;gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Eooooo`03
o`000?oooooooooo007ooooo000:ooooo`;o00001Oooool00ol0003oooooooooo`0Nooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool0_Oooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo01Gooooo00?o0000ooooooooool00Oooool000_ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0_Ooo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo0;gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Eooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool01_ooool00ooo
003oooooooooo`2mooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool05Oooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool0_Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01Go
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool07_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo0;gooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`0Eooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00007oooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo0;gooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`0Dooooo`;o00000oooool0017ooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo0;gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0E
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01kooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`2mooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool05Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Nooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool0_Oooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
7_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo0;gooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo01kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`2mooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`01ooooo`004Oooool0
0ol0003oooooooooo`0Nooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0_Oooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0
017ooooo0_l0000Oooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0_Oooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo01Cooooo0_l00003ooooo`004Oooool00ol0003o
ooooooooo`0Nooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0_Oooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo
00?o0000ooooooooool07_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo0;gooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`2mooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool05Oooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool0_Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01Gooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo0;gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Eoooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01kooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`2mooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool05Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Nooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool0_Oooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo0_l0000Oooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool0_Oooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo01Cooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`0Nooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool0_Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool07_ooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo0;gooooo00?oo`00ooooooooool01_ooool00ooo
003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01ko
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`2mooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`0Nooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0_Oooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool07_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo0;gooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo0009
ooooo`?o00001Oooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool0_Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01Gooooo00?o0000
ooooooooool00Oooool000Sooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo01kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`2mooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`01ooooo`002?ooool01Ol0
003ooooooooooooooooo000000Cooooo0ol0000Nooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool0_Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01?ooooo0ol00003
ooooo`002?ooool4o`0000Gooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo0;gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Eoooo
o`03o`000?oooooooooo007ooooo0008ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool07_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo0;gooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo0009ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo0;gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Eooooo`03o`00
0?oooooooooo007ooooo000:ooooo`;o00001Oooool00ol0003oooooooooo`0Nooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool0_Oooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool07_ooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo0;gooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
01kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`2mooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`0Nooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0_Oooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo
0_l0000Oooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0_Oooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo01Cooooo0_l00003ooooo`004Oooool00ol0003ooooooooo
o`0Nooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0_Oooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool07_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo0;gooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo01kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`2moooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool0_Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01Gooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo0;gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Eooooo`03o`00
0?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`2mooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool05Ooo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Nooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool0_Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo0_l0000Oooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool0_Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
01Cooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool0_Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01Go
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool07_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo0;gooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`0Eooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01kooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`2mooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool05Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0N
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0_Oooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool07_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo0;gooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo01kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`2mooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`01ooooo`00
4Oooool2o`0001oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`2mooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool05?ooool2o`0000?ooooo000Aooooo`03o`000?oo
oooooooo01kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`2mooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`01ooooo`004Oooool0
0ol0003oooooooooo`0Nooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0_Oooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
0;gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`2mooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool05Oooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool0_Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01Gooooo
00?o0000ooooooooool00Oooool000Wooooo0ol00005ooooo`03o`000?oooooooooo01kooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`2mooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool05Oooool00ol0003oooooooooo`01ooooo`002?ooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo0;gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Eooooo`03o`000?oo
oooooooo007ooooo0008ooooo`05o`000?ooooooooooooooool000001?ooool3o`0001kooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`2mooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool04oooool3o`0000?ooooo0009ooooo`?o00001Oooool00ol0003oooooooooo`0N
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0_Oooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool000Sooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`2mooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool05Oooool0
0ol0003oooooooooo`01ooooo`002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool07_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo0;gooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo0009oooo
o`?o00001Oooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool0_Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01Gooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo0;gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Eooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`2mooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
5Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Nooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool0_Oooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo0_l0000Oooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool0_Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo01Cooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool0_Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
01Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool07_ooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo0;gooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`0Eooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01kooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`2mooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool05Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`0Nooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0_Oooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool07_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo0;gooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo01kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`2moooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`0Mooooo`?oo`001oooool00ooo003oooooooooo`2mooooo`03
ool00?oooooooooo00Gooooo0ooo000Fooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000
7_ooool3ool000Oooooo00?oo`00ooooooooool0_Oooool00ooo003oooooooooo`05ooooo`?oo`00
5Oooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo01gooooo0ooo0007ooooo`03ool00?oo
oooooooo0;gooooo00?oo`00ooooooooool01Oooool3ool001Kooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool09oooool00ooo003oooooooooo`2mooooo`03ool00?oooooo
oooo01kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool09oooool00ooo
003oooooooooo`2mooooo`03ool00?oooooooooo01kooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool09oooool00ooo003oooooooooo`2mooooo`03ool00?oooooooooo01ko
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool09oooool00ooo003ooooo
ooooo`2mooooo`03ool00?oooooooooo01kooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool09oooool00ooo003oooooooooo`2mooooo`03ool00?oooooooooo01kooooo00?o
0000ooooooooool00Oooool0017ooooo0_l0000Xooooo`03ool00?oooooooooo0;gooooo00?oo`00
ooooooooool07Oooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo02Oooooo00?oo`00oooo
ooooool0_Oooool00ooo003oooooooooo`0Nooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo02Oooooo00?oo`00ooooooooool0_Oooool00ooo003oooooooooo`0Nooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo02Oooooo00?oo`00ooooooooool0
_Oooool00ooo003oooooooooo`0Nooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo02Oooooo00?oo`00ooooooooool0_Oooool00ooo003oooooooooo`0Nooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo02Oooooo00?oo`00ooooooooool0_Oooool0
0ooo003oooooooooo`0Nooooo`03o`000?oooooooooo007ooooo0003ooooo`?o00001?ooool2o`00
00Gooooo00?o0000ooooooooool09oooool00ooo003oooooooooo`2mooooo`03ool00?oooooooooo
01kooooo00?o0000ooooooooool00Oooool000Cooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo02Oooooo00?oo`00ooooooooool0_Oooool00ooo
003oooooooooo`0Nooooo`03o`000?oooooooooo007ooooo0004ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001?ooool3o`0002Oooooo00?oo`00ooooooooool0_Oooool00ooo
003oooooooooo`0Looooo`?o00000oooool000Cooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo02Gooooo0ooo002nooooo`?oo`007oooool00ol0
003oooooooooo`01ooooo`001?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool09Oooool3ool00;kooooo0ooo000Oooooo`03o`000?oooooooooo
007ooooo0003ooooo`;o00001?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
02Gooooo0ooo002nooooo`?oo`007oooool00ol0003oooooooooo`01ooooo`001?ooool00ol0003o
ooooooooo`03ooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo007o
oooo000Aoooooooo00003Ol00003ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.77509, -1.04587, \
0.114327, 0.0643637}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Phase plot of DFT as a function of index k", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fft\  = \ DFT[xd];\)\), "\n", 
    \(\(g4 = 
        DiscreteListPlot[\({#[\([1]\)], \ 
                Arg[#[\([2]\)] + 0.0000001]} &\)\  /@ \ fft, Red, \ 
          PlotRange \[Rule] {\(-\[Pi]\), \ \[Pi]}, \ Frame \[Rule] True, \ 
          Axes \[Rule] False];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0328407 0.309017 0.0983632 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18801 -0.0125 -3 -9 ]
[.18801 -0.0125 3 0 ]
[.35222 -0.0125 -6 -9 ]
[.35222 -0.0125 6 0 ]
[.51642 -0.0125 -6 -9 ]
[.51642 -0.0125 6 0 ]
[.68062 -0.0125 -6 -9 ]
[.68062 -0.0125 6 0 ]
[.84483 -0.0125 -6 -9 ]
[.84483 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01393 -12 -4.5 ]
[-0.0125 .01393 0 4.5 ]
[-0.0125 .11229 -12 -4.5 ]
[-0.0125 .11229 0 4.5 ]
[-0.0125 .21065 -12 -4.5 ]
[-0.0125 .21065 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40738 -6 -4.5 ]
[-0.0125 .40738 0 4.5 ]
[-0.0125 .50574 -6 -4.5 ]
[-0.0125 .50574 0 4.5 ]
[-0.0125 .60411 -6 -4.5 ]
[-0.0125 .60411 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18801 0 m
.18801 .00625 L
s
[(5)] .18801 -0.0125 0 1 Mshowa
.35222 0 m
.35222 .00625 L
s
[(10)] .35222 -0.0125 0 1 Mshowa
.51642 0 m
.51642 .00625 L
s
[(15)] .51642 -0.0125 0 1 Mshowa
.68062 0 m
.68062 .00625 L
s
[(20)] .68062 -0.0125 0 1 Mshowa
.84483 0 m
.84483 .00625 L
s
[(25)] .84483 -0.0125 0 1 Mshowa
.125 Mabswid
.05665 0 m
.05665 .00375 L
s
.08949 0 m
.08949 .00375 L
s
.12233 0 m
.12233 .00375 L
s
.15517 0 m
.15517 .00375 L
s
.22085 0 m
.22085 .00375 L
s
.25369 0 m
.25369 .00375 L
s
.28654 0 m
.28654 .00375 L
s
.31938 0 m
.31938 .00375 L
s
.38506 0 m
.38506 .00375 L
s
.4179 0 m
.4179 .00375 L
s
.45074 0 m
.45074 .00375 L
s
.48358 0 m
.48358 .00375 L
s
.54926 0 m
.54926 .00375 L
s
.5821 0 m
.5821 .00375 L
s
.61494 0 m
.61494 .00375 L
s
.64778 0 m
.64778 .00375 L
s
.71346 0 m
.71346 .00375 L
s
.74631 0 m
.74631 .00375 L
s
.77915 0 m
.77915 .00375 L
s
.81199 0 m
.81199 .00375 L
s
.87767 0 m
.87767 .00375 L
s
.91051 0 m
.91051 .00375 L
s
.94335 0 m
.94335 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01393 m
.00625 .01393 L
s
[(-3)] -0.0125 .01393 1 0 Mshowa
0 .11229 m
.00625 .11229 L
s
[(-2)] -0.0125 .11229 1 0 Mshowa
0 .21065 m
.00625 .21065 L
s
[(-1)] -0.0125 .21065 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .40738 m
.00625 .40738 L
s
[(1)] -0.0125 .40738 1 0 Mshowa
0 .50574 m
.00625 .50574 L
s
[(2)] -0.0125 .50574 1 0 Mshowa
0 .60411 m
.00625 .60411 L
s
[(3)] -0.0125 .60411 1 0 Mshowa
.125 Mabswid
0 .0336 m
.00375 .0336 L
s
0 .05327 m
.00375 .05327 L
s
0 .07295 m
.00375 .07295 L
s
0 .09262 m
.00375 .09262 L
s
0 .13196 m
.00375 .13196 L
s
0 .15164 m
.00375 .15164 L
s
0 .17131 m
.00375 .17131 L
s
0 .19098 m
.00375 .19098 L
s
0 .23033 m
.00375 .23033 L
s
0 .25 m
.00375 .25 L
s
0 .26967 m
.00375 .26967 L
s
0 .28934 m
.00375 .28934 L
s
0 .32869 m
.00375 .32869 L
s
0 .34836 m
.00375 .34836 L
s
0 .36803 m
.00375 .36803 L
s
0 .38771 m
.00375 .38771 L
s
0 .42705 m
.00375 .42705 L
s
0 .44673 m
.00375 .44673 L
s
0 .4664 m
.00375 .4664 L
s
0 .48607 m
.00375 .48607 L
s
0 .52542 m
.00375 .52542 L
s
0 .54509 m
.00375 .54509 L
s
0 .56476 m
.00375 .56476 L
s
0 .58443 m
.00375 .58443 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18801 .61178 m
.18801 .61803 L
s
.35222 .61178 m
.35222 .61803 L
s
.51642 .61178 m
.51642 .61803 L
s
.68062 .61178 m
.68062 .61803 L
s
.84483 .61178 m
.84483 .61803 L
s
.125 Mabswid
.05665 .61428 m
.05665 .61803 L
s
.08949 .61428 m
.08949 .61803 L
s
.12233 .61428 m
.12233 .61803 L
s
.15517 .61428 m
.15517 .61803 L
s
.22085 .61428 m
.22085 .61803 L
s
.25369 .61428 m
.25369 .61803 L
s
.28654 .61428 m
.28654 .61803 L
s
.31938 .61428 m
.31938 .61803 L
s
.38506 .61428 m
.38506 .61803 L
s
.4179 .61428 m
.4179 .61803 L
s
.45074 .61428 m
.45074 .61803 L
s
.48358 .61428 m
.48358 .61803 L
s
.54926 .61428 m
.54926 .61803 L
s
.5821 .61428 m
.5821 .61803 L
s
.61494 .61428 m
.61494 .61803 L
s
.64778 .61428 m
.64778 .61803 L
s
.71346 .61428 m
.71346 .61803 L
s
.74631 .61428 m
.74631 .61803 L
s
.77915 .61428 m
.77915 .61803 L
s
.81199 .61428 m
.81199 .61803 L
s
.87767 .61428 m
.87767 .61803 L
s
.91051 .61428 m
.91051 .61803 L
s
.94335 .61428 m
.94335 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01393 m
1 .01393 L
s
.99375 .11229 m
1 .11229 L
s
.99375 .21065 m
1 .21065 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .40738 m
1 .40738 L
s
.99375 .50574 m
1 .50574 L
s
.99375 .60411 m
1 .60411 L
s
.125 Mabswid
.99625 .0336 m
1 .0336 L
s
.99625 .05327 m
1 .05327 L
s
.99625 .07295 m
1 .07295 L
s
.99625 .09262 m
1 .09262 L
s
.99625 .13196 m
1 .13196 L
s
.99625 .15164 m
1 .15164 L
s
.99625 .17131 m
1 .17131 L
s
.99625 .19098 m
1 .19098 L
s
.99625 .23033 m
1 .23033 L
s
.99625 .25 m
1 .25 L
s
.99625 .26967 m
1 .26967 L
s
.99625 .28934 m
1 .28934 L
s
.99625 .32869 m
1 .32869 L
s
.99625 .34836 m
1 .34836 L
s
.99625 .36803 m
1 .36803 L
s
.99625 .38771 m
1 .38771 L
s
.99625 .42705 m
1 .42705 L
s
.99625 .44673 m
1 .44673 L
s
.99625 .4664 m
1 .4664 L
s
.99625 .48607 m
1 .48607 L
s
.99625 .52542 m
1 .52542 L
s
.99625 .54509 m
1 .54509 L
s
.99625 .56476 m
1 .56476 L
s
.99625 .58443 m
1 .58443 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .30902 m
.02381 .30902 L
s
.05665 .30902 m
.05665 .38026 L
s
.08949 .30902 m
.08949 .4245 L
s
.12233 .30902 m
.12233 .45255 L
s
.15517 .30902 m
.15517 .16427 L
s
.18801 .30902 m
.18801 .18143 L
s
.22085 .30902 m
.22085 .19663 L
s
.25369 .30902 m
.25369 .21066 L
s
.28654 .30902 m
.28654 .22394 L
s
.31938 .30902 m
.31938 .23672 L
s
.35222 .30902 m
.35222 .24917 L
s
.38506 .30902 m
.38506 .26137 L
s
.4179 .30902 m
.4179 .27341 L
s
.45074 .30902 m
.45074 .28534 L
s
.48358 .30902 m
.48358 .29719 L
s
.51642 .30902 m
.51642 .30902 L
s
.54926 .30902 m
.54926 .32084 L
s
.5821 .30902 m
.5821 .3327 L
s
.61494 .30902 m
.61494 .34462 L
s
.64778 .30902 m
.64778 .35666 L
s
.68062 .30902 m
.68062 .36887 L
s
.71346 .30902 m
.71346 .38131 L
s
.74631 .30902 m
.74631 .3941 L
s
.77915 .30902 m
.77915 .40738 L
s
.81199 .30902 m
.81199 .4214 L
s
.84483 .30902 m
.84483 .4366 L
s
.87767 .30902 m
.87767 .45376 L
s
.91051 .30902 m
.91051 .16549 L
s
.94335 .30902 m
.94335 .19353 L
s
.97619 .30902 m
.97619 .23777 L
s
.015 w
.02381 .30902 Mdot
.05665 .38026 Mdot
.08949 .4245 Mdot
.12233 .45255 Mdot
.15517 .16427 Mdot
.18801 .18143 Mdot
.22085 .19663 Mdot
.25369 .21066 Mdot
.28654 .22394 Mdot
.31938 .23672 Mdot
.35222 .24917 Mdot
.38506 .26137 Mdot
.4179 .27341 Mdot
.45074 .28534 Mdot
.48358 .29719 Mdot
.51642 .30902 Mdot
.54926 .32084 Mdot
.5821 .3327 Mdot
.61494 .34462 Mdot
.64778 .35666 Mdot
.68062 .36887 Mdot
.71346 .38131 Mdot
.74631 .3941 Mdot
.77915 .40738 Mdot
.81199 .4214 Mdot
.84483 .4366 Mdot
.87767 .45376 Mdot
.91051 .16549 Mdot
.94335 .19353 Mdot
.97619 .23777 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005oooool2o`0002Wooooo0ol0000Uooooo`?o00001?ooool2o`0002?ooooo0ol00003oooo
o`?o00008Oooool5o`0000?ooooo0_l0000Rooooo`Go00000_ooool3o`0002[ooooo000Fooooo`04
o`000?ooooooooooo`0002Oooooo00Go0000ooooooooooooooooo`00000Uooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00008oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool07oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
02;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo02Oooooo000F
ooooo`04o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02Oooooo000Fooooo`04o`000?ooooooooooo`0002_o
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
02?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Qooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool09oooool001Kooooo00Co0000oooooooooooo00009oooool4o`0002Kooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co0000
8Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00008Oooool01_l0
003ooooooooooooooooo0000ooooo`Co0000:_ooool001Kooooo00Co0000oooooooooooo00009ooo
ool00ol0003oooooooooo`0Vooooo`;o00001?ooool01?l0003oooooooooool0000Rooooo`;o0000
0oooool00ol0003oooooooooo`0Rooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool0000Qooooo`07o`000?ooooooooooooooool0003oooooo`00000]ooooo`005oooool2
o`0002Sooooo1Ol0000Uooooo`03o`000?oooooooooo00?ooooo0_l0000Tooooo`04o`000?oooooo
ooooooooo`Go00008Oooool3o`0000Cooooo0_l0000Sooooo`?o00000_ooool5o`0002Wooooo003o
ooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Boooooooo00002ol0
0004ooooo`002_ooool3o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`002Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`02ooooo`000oooool5o`0000Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool000_ooooo0_l00005ooooo`?o
0000ooooool5ooooo`?o00001?ooool000gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool000Wooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`002_oo
ool3o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000B
ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool2o`00
0?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003o
ooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool0
0_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000B
ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool2o`00
0?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003o
ooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool0
0_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000B
ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool2o`00
0?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003o
ooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool0
0_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000B
ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool2o`00
0?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003o
ooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool0
0_ooool000Wooooo1Ol00004ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooooooo
o`02ooooo`002_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo0?oooooo1ooo
ool00ol0003oooooooooo`02ooooo`000oooool5o`0000?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool000cooooo00?o0000oooo
ooooool00oooool3o`000?oooooo1Oooool3o`0000Cooooo0009ooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool000Wo
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0
003oooooooooo`02ooooo`002_ooool3o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`03
o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooo
ooooo`02ooooo`004_ooool2o`000?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooo
oooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3ooooo
o`Oooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03
o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooo
ooooo`02ooooo`004_ooool2o`000?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooo
oooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3ooooo
o`Oooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool09Oooool3ool00<Go
oooo0ooo000Fooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo02Gooooo
0ooo0035ooooo`?oo`005_ooool00ol0003oooooooooo`02ooooo`004_ooool2o`0002Kooooo0ooo
0035ooooo`?oo`005Oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo02Kooooo00?oo`00
ooooooooool0aOooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo00;ooooo000Boooo
o`03o`000?oooooooooo02Kooooo00?oo`00ooooooooool01?ooool3ool00;kooooo00?oo`00oooo
ooooool05Oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`0Vooooo`03
ool00?oooooooooo00Cooooo0ooo002nooooo`03ool00?oooooooooo01Gooooo00?o0000oooooooo
ool00_ooool001;ooooo00?o0000ooooooooool09_ooool00ooo003oooooooooo`04ooooo`?oo`00
__ooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo00;ooooo000Booooo`;o00009ooo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo0;cooooo00?oo`00ooooooooool05?oo
ool2o`0000Cooooo000Booooo`03o`000?oooooooooo02Kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`04ooooo`?oo`00]Oooool00ooo003oooooooooo`05ooooo`?oo`003Oooool0
0ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`0Vooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01?ooool3ool00;Gooooo00?oo`00ooooooooool01Oooool3ool0
00gooooo00?o0000ooooooooool00_ooool000[ooooo0ol00005ooooo`03o`000?oooooooooo02Ko
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`04ooooo`?oo`00]Oooool00ooo003o
ooooooooo`05ooooo`?oo`003Oooool00ol0003oooooooooo`02ooooo`002oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo02Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo0;?ooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00;ooooo0003ooooo`Go00000oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo02Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Cooooo0ooo002/ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool03?ooool00ol0003oooooooooo`02ooooo`002oooool00ol0003oooooooooo`04
ooooo`?o00009_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01?ooool3ool00:cooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0:
ooooo`?o00001?ooool000_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Voooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`04oooo
o`?oo`00[?ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00cooooo00?o0000oooo
ooooool00_ooool000[ooooo0_l00006ooooo`03o`000?oooooooooo02Kooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo
ool0Zoooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00cooooo00?o0000oooooooo
ool00_ooool000_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Vooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool0
0?oooooooooo00Gooooo0ooo002Sooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
3?ooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`0Vooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oo
oooooooo00Gooooo0ooo002Sooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool03?oo
ool00ol0003oooooooooo`02ooooo`004_ooool2o`0002Oooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Oooool3
ool00:?ooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0;ooooo`;o00001?ooool0
01;ooooo00?o0000ooooooooool09_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Cooooo0ooo002Kooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01?ooool3ool0
00Gooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool09_ooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Cooooo0ooo002Kooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01?ooool3ool000Gooooo00?o0000ooooooooool00_ooool001;ooooo
00?o0000ooooooooool09_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Cooooo
0ooo002Kooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01?ooool3ool000Gooooo
00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool09_ooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01?ooool3ool009;ooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool001;ooooo0_l0000Wooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`04ooooo`?oo`00T_ooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool00_ooool2o`0000Cooooo000Boooo
o`03o`000?oooooooooo02Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Cooooo0ooo002Booooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo000Booooo`03
o`000?oooooooooo02Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Gooooo00?oo`00ooooooooool0TOooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`02ooooo`00
4_ooool00ol0003oooooooooo`0Vooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Gooooo0ooo0029ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo02Kooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Ooo
ool3ool008Wooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool001;ooooo0_l0000Wooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00Gooooo0ooo0029ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`02ooooo`;o00001?ooool001;ooooo00?o0000ooooooooool09_ooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00Cooooo0ooo0021ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo000Booooo`03o`000?oooooooooo02Kooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`04ooooo`?oo`00POooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01?ooool3ool0087ooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool09_ooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01?ooool3ool007Sooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool09_ooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01?ooool3ool007Sooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool001;ooooo0_l0000Wooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`04ooooo`?oo`00N?ooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool00_ooool2o`0000Cooooo000Booooo`03
o`000?oooooooooo02Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01?ooool3ool006oooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool000_ooooo0_l00005ooooo`03o`000?oooooooooo02Kooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1?ooool3ool006oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool000[ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0Vooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Cooooo0ooo001_ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo000:ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
0_ooool3ool0027ooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`05ooooo`?oo`00
I_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`002_ooool01?l0003oooooooooool00004ooooo`?o0000
0_ooool3ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`05ooooo`?oo`00
1oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`06ooooo`04ool00?ooooooooooooooo`?o00001?ooool000[ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`?oo`001oooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0IOooool3ool000Oo
oooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Mooooo`03o`000?oooooooooo00;o
oooo000:ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool03?ooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0KOooool3ool000Oo
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Go
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool07Oooool00ol0003oooooooooo`02ooooo`002oooool2o`0000Gooooo
00?o0000ooooooooool03?ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool0KOooool3ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool07Oooool00ol0003ooooo
ooooo`02ooooo`004_ooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01Oooool00ooo003oooooooooo`1]ooooo`?oo`001oooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`0Mooooo`03o`000?oooooooooo00;ooooo000Booooo`;o00003Oooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0M_ooool3ool000Oooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01cooooo0_l00004
ooooo`004_ooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool01Oooool00ooo003oooooooooo`1fooooo`?oo`001oooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool07Oooool00ol0003oooooooooo`02oooo
o`004_ooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool01Oooool00ooo003oooooooooo`1fooooo`?oo`001oooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool07Oooool00ol0003oooooooooo`02ooooo`00
4_ooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`20ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`000?oo
oooooooo00cooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oo
oooooooo07oooooo0ooo0007ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Ooo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool07Ooo
ool00ol0003oooooooooo`02ooooo`004_ooool2o`0000gooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo07oooooo0ooo0007ooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool07?ooool2o`0000Cooooo000Booooo`03o`000?oooooooooo
00cooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo
07oooooo0ooo0007ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool07Oooool00ol0
003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`27ooooo`?oo`001oooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo00cooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo08Oooooo
0ooo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo01gooooo00?o0000ooooooooool00_ooool001;ooooo00?o
0000ooooooooool03?ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?o
o`00ooooooooool0Qoooool3ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool07Oooool00ol0003ooooooooo
o`02ooooo`004_ooool2o`0000gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05
ooooo`03ool00?oooooooooo093ooooo0ooo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`0Looooo`;o00001?ooool001;ooooo00?o0000oooo
ooooool03?ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooo
ooooool0T?ooool3ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo01gooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000oooooooo
ool03?ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo
ool0T?ooool3ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo01gooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0
2oooool3ool000Oooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`2Iooooo`?oo`00
1oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01gooooo00?o0000ooooooooool0
0_ooool001;ooooo00?o0000ooooooooool02oooool3ool000Oooooo00?oo`00ooooooooool01Ooo
ool00ooo003oooooooooo`2Iooooo`?oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo01gooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool02oooool3
ool000Oooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`2Iooooo`?oo`001oooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo01gooooo00?o0000ooooooooool00_ooool0
01;ooooo0_l0000Fooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0Xoooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo01cooooo0_l00004ooooo`004_ooool00ol0003o
ooooooooo`0Eooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0XOooool3ool000So
oooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool07Oooool00ol0003oooooooooo`02ooooo`002_ooool3o`0000Gooooo
00?o0000ooooooooool05Oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo0:7ooooo
0ooo0008ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo01gooooo00?o0000ooooooooool00_ooool000_ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo00Gooooo00?o
o`00ooooooooool0XOooool3ool000Sooooo00?oo`00ooooooooool01Oooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool07Oooool00ol0003ooooooooo
o`02ooooo`002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`2Zooooo`?oo`001oooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool07Oooool00ol0003oooooooooo`02
ooooo`002oooool00ol0003oooooooooo`04ooooo`?o00005Oooool00ooo003oooooooooo`05oooo
o`03ool00?oooooooooo0:[ooooo0ooo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`0Kooooo`?o00001?ooool000_ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo
ool0Z_ooool3ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo01gooooo00?o0000ooooooooool00_ooool000[ooooo0_l00006ooooo`03o`00
0?oooooooooo01Gooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`2dooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Mooooo`03o`00
0?oooooooooo00;ooooo000;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05Ooo
ool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo0;?ooooo0ooo0007ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool07Oooool00ol0003oooooooooo`02ooooo`004_ooool0
0ol0003oooooooooo`0Cooooo`?oo`001oooool00ooo003oooooooooo`2cooooo`?oo`001oooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo01gooooo00?o0000ooooooooool00_ooool0
01;ooooo0_l0000Dooooo`?oo`001oooool00ooo003oooooooooo`2cooooo`?oo`001oooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo01cooooo0_l00004ooooo`004_ooool00ol0003o
ooooooooo`0Cooooo`?oo`001oooool00ooo003oooooooooo`2mooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool07Oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003ooooo
ooooo`0Mooooo`03ool00?oooooooooo0;cooooo0ooo0007ooooo`03ool00?oooooooooo01gooooo
00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool07Oooool00ooo003ooooooooo
o`2looooo`?oo`001oooool00ooo003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo000B
ooooo`03o`000?oooooooooo01gooooo00?oo`00ooooooooool0_?ooool3ool000Oooooo00?oo`00
ooooooooool07Oooool00ol0003oooooooooo`02ooooo`004_ooool2o`0001kooooo00?oo`00oooo
ooooool0a_ooool00ooo003oooooooooo`0Looooo`;o00001?ooool001;ooooo00?o0000oooooooo
ool07?ooool3ool00<Oooooo00?oo`00ooooooooool07Oooool00ol0003oooooooooo`02ooooo`00
4_ooool00ol0003oooooooooo`0Looooo`?oo`00aOooool3ool001oooooo00?o0000ooooooooool0
0_ooool001;ooooo00?o0000ooooooooool07?ooool3ool00<Gooooo0ooo000Oooooo`03o`000?oo
oooooooo00;ooooo000Booooo`03o`000?oooooooooo0>Cooooo0ooo000Oooooo`03o`000?oooooo
oooo00;ooooo000Booooo`;o0000ooooool7ooooo`;o00001?ooool001;ooooo00?o0000oooooooo
ool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo
1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o
0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooo
oooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02oooo
o`004_ooool2o`000?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo0?oooooo
1oooool00ol0003oooooooooo`02ooooo`002Oooool5o`0000Cooooo00?o0000ooooooooool0oooo
ool7ooooo`03o`000?oooooooooo00;ooooo000:ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000;ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000<oooo
o`03o`000?oooooooooo00?ooooo0ol0003oooooo`Gooooo0ol00004ooooo`002Oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo
00;ooooo0009ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`3ooooo
o`Oooooo00?o0000ooooooooool00_ooool000[ooooo0ol00005ooooo`03o`000?oooooooooo0?oo
oooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool00_ooool001;ooooo0_l0003oooooo`Oooooo0_l00004ooooo`004_ooool0
0ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000oooo
ooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oo
oooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool00_ooool001;ooooo0_l0003oooooo`Oooooo0_l00004ooooo`004_ooool0
0ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000oooo
ooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oo
oooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00;ooooo000Booooo`;o0000ooooool7ooooo`;o00001?ooool001;ooooo00?o0000oooo
ooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oo
oooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00;ooooo000Booooo`;o0000ooooool7ooooo`;o00001?ooool001;ooooo00?o0000oooo
ooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000:ooooo`?o00001Oooool00ol0003o
ooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool000Wooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`00
3Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooo
ooooo`02ooooo`002oooool2o`0000Gooooo0ol0003oooooo`Gooooo0ol00004ooooo`003Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02
ooooo`002Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`02ooooo`002_ooool3o`0000Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`004_ooooooo`0000_o00001?ooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.85793, -3.6139, 0.114882, \
0.0383558}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Rearrange and scale DFT result", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g5 = 
        DiscreteListPlot[FourierRearrange[Abs[Last\  /@ \ fft], fs], Red, 
          PlotRange \[Rule] All, ImageSize \[Rule] 504, \ 
          Frame \[Rule] True, \ Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g6\  = \ Show[g1, g5];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.0147151 0.0391604 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09304 -6 -4.5 ]
[-0.0125 .09304 0 4.5 ]
[-0.0125 .17136 -6 -4.5 ]
[-0.0125 .17136 0 4.5 ]
[-0.0125 .24968 -6 -4.5 ]
[-0.0125 .24968 0 4.5 ]
[-0.0125 .328 -6 -4.5 ]
[-0.0125 .328 0 4.5 ]
[-0.0125 .40632 -12 -4.5 ]
[-0.0125 .40632 0 4.5 ]
[-0.0125 .48464 -12 -4.5 ]
[-0.0125 .48464 0 4.5 ]
[-0.0125 .56296 -12 -4.5 ]
[-0.0125 .56296 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09304 m
.00625 .09304 L
s
[(2)] -0.0125 .09304 1 0 Mshowa
0 .17136 m
.00625 .17136 L
s
[(4)] -0.0125 .17136 1 0 Mshowa
0 .24968 m
.00625 .24968 L
s
[(6)] -0.0125 .24968 1 0 Mshowa
0 .328 m
.00625 .328 L
s
[(8)] -0.0125 .328 1 0 Mshowa
0 .40632 m
.00625 .40632 L
s
[(10)] -0.0125 .40632 1 0 Mshowa
0 .48464 m
.00625 .48464 L
s
[(12)] -0.0125 .48464 1 0 Mshowa
0 .56296 m
.00625 .56296 L
s
[(14)] -0.0125 .56296 1 0 Mshowa
.125 Mabswid
0 .0343 m
.00375 .0343 L
s
0 .05388 m
.00375 .05388 L
s
0 .07346 m
.00375 .07346 L
s
0 .11262 m
.00375 .11262 L
s
0 .1322 m
.00375 .1322 L
s
0 .15178 m
.00375 .15178 L
s
0 .19094 m
.00375 .19094 L
s
0 .21052 m
.00375 .21052 L
s
0 .2301 m
.00375 .2301 L
s
0 .26926 m
.00375 .26926 L
s
0 .28884 m
.00375 .28884 L
s
0 .30842 m
.00375 .30842 L
s
0 .34758 m
.00375 .34758 L
s
0 .36716 m
.00375 .36716 L
s
0 .38674 m
.00375 .38674 L
s
0 .4259 m
.00375 .4259 L
s
0 .44548 m
.00375 .44548 L
s
0 .46506 m
.00375 .46506 L
s
0 .50422 m
.00375 .50422 L
s
0 .5238 m
.00375 .5238 L
s
0 .54338 m
.00375 .54338 L
s
0 .58254 m
.00375 .58254 L
s
0 .60212 m
.00375 .60212 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09304 m
1 .09304 L
s
.99375 .17136 m
1 .17136 L
s
.99375 .24968 m
1 .24968 L
s
.99375 .328 m
1 .328 L
s
.99375 .40632 m
1 .40632 L
s
.99375 .48464 m
1 .48464 L
s
.99375 .56296 m
1 .56296 L
s
.125 Mabswid
.99625 .0343 m
1 .0343 L
s
.99625 .05388 m
1 .05388 L
s
.99625 .07346 m
1 .07346 L
s
.99625 .11262 m
1 .11262 L
s
.99625 .1322 m
1 .1322 L
s
.99625 .15178 m
1 .15178 L
s
.99625 .19094 m
1 .19094 L
s
.99625 .21052 m
1 .21052 L
s
.99625 .2301 m
1 .2301 L
s
.99625 .26926 m
1 .26926 L
s
.99625 .28884 m
1 .28884 L
s
.99625 .30842 m
1 .30842 L
s
.99625 .34758 m
1 .34758 L
s
.99625 .36716 m
1 .36716 L
s
.99625 .38674 m
1 .38674 L
s
.99625 .4259 m
1 .4259 L
s
.99625 .44548 m
1 .44548 L
s
.99625 .46506 m
1 .46506 L
s
.99625 .50422 m
1 .50422 L
s
.99625 .5238 m
1 .5238 L
s
.99625 .54338 m
1 .54338 L
s
.99625 .58254 m
1 .58254 L
s
.99625 .60212 m
1 .60212 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .05388 m
.02395 .05387 L
.02408 .05386 L
.02423 .05384 L
.02437 .05382 L
.02462 .05375 L
.02489 .05365 L
.02519 .05351 L
.02551 .05332 L
.02608 .05289 L
.02722 .05167 L
.02847 .04979 L
.02973 .04735 L
.03109 .04415 L
.03355 .03706 L
.03593 .02895 L
.03718 .02431 L
.03852 .01921 L
.03884 .01796 L
.03919 .01661 L
.03935 .01599 L
.03952 .01534 L
.03967 .01478 L
.03982 .01527 L
.04101 .01984 L
.04331 .02852 L
.04586 .03727 L
.04819 .04404 L
.04934 .04685 L
.0506 .04943 L
.05177 .05137 L
.05288 .05274 L
.05342 .05325 L
.05401 .05367 L
.05433 .05385 L
.05467 .05399 L
.05495 .05408 L
.05511 .05411 L
.05526 .05414 L
.05542 .05415 L
.05551 .05416 L
.05559 .05416 L
.05575 .05416 L
.05582 .05415 L
.05591 .05414 L
.05605 .05412 L
.05621 .05409 L
.05649 .05401 L
.05666 .05395 L
.05684 .05387 L
Mistroke
.05717 .05369 L
.0578 .05323 L
.05844 .05262 L
.05905 .05189 L
.06017 .05019 L
.06271 .0448 L
.06513 .03785 L
.06736 .03027 L
.06855 .02587 L
.06983 .02098 L
.07045 .01857 L
.07075 .01738 L
.07103 .01627 L
.07129 .01527 L
.07142 .01476 L
.07156 .01523 L
.07213 .01748 L
.07672 .03468 L
.07925 .0427 L
.08036 .0457 L
.08157 .04855 L
.08267 .05073 L
.08385 .05259 L
.0845 .0534 L
.08509 .054 L
.08568 .05446 L
.08624 .05478 L
.08653 .05489 L
.0868 .05497 L
.08696 .055 L
.0871 .05502 L
.08718 .05503 L
.08726 .05504 L
.08742 .05504 L
.08757 .05503 L
.08765 .05503 L
.08773 .05502 L
.08789 .05499 L
.08806 .05495 L
.08838 .05485 L
.08866 .05473 L
.08918 .05442 L
.08975 .05396 L
.09089 .05266 L
.09213 .0507 L
.09325 .04845 L
.09578 .0419 L
.09828 .0337 L
.10059 .02504 L
.10176 .02044 L
Mistroke
.10233 .01815 L
.10284 .01605 L
.10298 .01551 L
.10313 .01491 L
.10326 .01508 L
.10339 .0156 L
.10398 .01798 L
.10523 .02302 L
.10995 .04042 L
.11254 .04789 L
.11372 .05063 L
.11497 .053 L
.11612 .05468 L
.11678 .05541 L
.11739 .05593 L
.11768 .05613 L
.11795 .05628 L
.1182 .05639 L
.11847 .05649 L
.1186 .05652 L
.11875 .05655 L
.11889 .05657 L
.11902 .05659 L
.11917 .05659 L
.11931 .05659 L
.11946 .05658 L
.11954 .05657 L
.11962 .05656 L
.11978 .05652 L
.11993 .05648 L
.12026 .05636 L
.12055 .05622 L
.12086 .05603 L
.1214 .0556 L
.12199 .055 L
.12329 .05319 L
.12451 .0509 L
.12696 .04475 L
.1292 .03753 L
.13169 .02814 L
.1329 .02321 L
.134 .01863 L
.13455 .01629 L
.1347 .01564 L
.13479 .01529 L
.13486 .01496 L
.135 .01505 L
.13515 .01569 L
.13623 .02029 L
.13861 .03016 L
Mistroke
.14331 .04691 L
.14454 .05033 L
.14588 .05346 L
.14714 .05581 L
.14771 .05665 L
.14831 .05742 L
.14892 .05804 L
.14948 .05847 L
.14974 .05863 L
.15003 .05877 L
.15017 .05883 L
.15031 .05887 L
.15044 .05891 L
.15057 .05893 L
.15065 .05895 L
.15074 .05896 L
.15089 .05897 L
.15098 .05898 L
.15107 .05897 L
.15116 .05897 L
.15124 .05896 L
.15139 .05894 L
.15148 .05893 L
.15156 .05891 L
.15187 .05881 L
.15214 .05869 L
.15244 .05853 L
.15305 .05807 L
.15365 .05747 L
.15427 .05667 L
.15539 .05486 L
.15659 .05235 L
.1579 .04897 L
.16279 .03171 L
.16505 .02199 L
.16567 .01922 L
.16601 .0177 L
.16632 .01627 L
.16646 .01564 L
.16659 .01505 L
.16675 .01507 L
.16688 .0157 L
.1675 .01849 L
.17007 .02999 L
.1725 .04009 L
.17492 .04881 L
.17711 .05513 L
.17834 .05788 L
.17949 .05991 L
.18008 .06073 L
Mistroke
.18071 .06142 L
.18103 .06172 L
.18139 .06198 L
.18172 .06218 L
.18202 .06231 L
.18217 .06236 L
.18233 .0624 L
.18247 .06243 L
.18263 .06245 L
.18271 .06246 L
.18279 .06246 L
.18287 .06246 L
.18296 .06245 L
.18312 .06244 L
.1832 .06243 L
.18328 .06241 L
.18344 .06237 L
.18359 .06232 L
.18386 .06221 L
.18416 .06204 L
.18448 .06182 L
.18504 .06131 L
.18564 .0606 L
.18672 .05893 L
.18786 .0566 L
.18908 .05349 L
.19129 .04642 L
.19368 .03698 L
.19627 .02515 L
.19748 .0193 L
.19809 .0163 L
.19826 .01547 L
.19835 .01501 L
.19844 .01485 L
.1986 .01564 L
.19877 .01647 L
.20107 .02785 L
.20567 .0484 L
.20803 .05675 L
.20934 .06049 L
.21055 .06328 L
.21178 .06543 L
.21243 .06627 L
.21277 .06662 L
.21312 .06693 L
.21343 .06715 L
.21372 .06731 L
.21386 .06737 L
.21401 .06743 L
.21415 .06747 L
Mistroke
.21428 .0675 L
.21436 .06752 L
.21445 .06753 L
.2146 .06754 L
.21468 .06754 L
.21477 .06753 L
.21485 .06753 L
.21494 .06752 L
.21509 .06749 L
.21518 .06747 L
.21526 .06745 L
.21555 .06733 L
.21583 .06719 L
.21613 .06698 L
.21675 .06641 L
.21732 .06571 L
.21785 .06491 L
.21906 .06257 L
.22036 .05926 L
.22277 .0511 L
.22532 .04009 L
.22773 .02796 L
.22878 .02232 L
.22933 .01929 L
.22963 .01763 L
.22992 .01606 L
.23006 .01525 L
.23022 .01505 L
.23031 .01554 L
.23039 .01601 L
.23055 .01689 L
.23113 .02015 L
.23228 .02654 L
.23481 .04017 L
.23942 .06115 L
.2418 .06876 L
.24249 .07045 L
.24313 .07181 L
.2437 .07283 L
.24433 .07374 L
.24463 .0741 L
.24494 .07442 L
.24522 .07465 L
.24551 .07485 L
.24569 .07495 L
.24585 .07502 L
.246 .07508 L
.24608 .0751 L
.24617 .07512 L
.24631 .07514 L
Mistroke
.24645 .07516 L
.24653 .07516 L
.24661 .07516 L
.24676 .07514 L
.2469 .07512 L
.24703 .07509 L
.24717 .07504 L
.24731 .07498 L
.24756 .07485 L
.24782 .07466 L
.24843 .07409 L
.24899 .07337 L
.25016 .07127 L
.25126 .06858 L
.25375 .06006 L
.2562 .04875 L
.25844 .03638 L
.26074 .02224 L
.26137 .0182 L
.26169 .01614 L
.26177 .01557 L
.26187 .01496 L
.26196 .01504 L
.26204 .01557 L
.26324 .02343 L
.26802 .05341 L
.27042 .06629 L
.27261 .0758 L
.27374 .07972 L
.27497 .08312 L
.27565 .08458 L
.27627 .08566 L
.27687 .08645 L
.27717 .08676 L
.2775 .08703 L
.2778 .0872 L
.27797 .08727 L
.27813 .08732 L
.27828 .08735 L
.27841 .08736 L
.27857 .08736 L
.27872 .08734 L
.27886 .08731 L
.279 .08726 L
.27912 .08721 L
.27926 .08714 L
.27956 .08694 L
.27984 .0867 L
.28048 .08593 L
.28106 .08498 L
Mistroke
.28236 .08198 L
.28356 .07818 L
.28466 .07381 L
.28717 .0611 L
.28961 .04544 L
.29081 .03683 L
.29191 .02852 L
.29298 .02013 L
.29324 .01805 L
.29351 .01582 L
.29367 .01489 L
.29382 .01607 L
.2941 .01836 L
.29646 .03766 L
.30129 .07448 L
.3035 .0883 L
.30476 .09487 L
.30593 .10003 L
.30709 .10409 L
.30768 .10576 L
.30833 .10724 L
.30868 .1079 L
.30901 .10841 L
.30935 .10884 L
.30966 .10914 L
.3098 .10925 L
.30996 .10935 L
.31011 .10943 L
.31024 .10948 L
.31039 .10951 L
.31055 .10953 L
.31063 .10953 L
.31071 .10952 L
.31087 .10949 L
.31102 .10944 L
.3111 .1094 L
.31118 .10936 L
.31151 .10912 L
.31179 .10884 L
.3121 .10844 L
.3128 .10722 L
.31344 .10569 L
.31468 .10161 L
.31587 .0964 L
.31826 .08206 L
.32047 .06457 L
.32274 .04318 L
.32393 .03078 L
.32458 .02373 L
.3249 .02023 L
Mistroke
.32519 .01701 L
.32535 .01523 L
.3255 .01588 L
.32566 .01767 L
.32583 .01963 L
.32654 .02766 L
.32777 .04198 L
.33021 .0702 L
.33254 .09616 L
.33512 .12179 L
.33757 .14148 L
.33866 .14846 L
.33986 .15459 L
.34043 .15692 L
.34104 .15896 L
.34138 .15988 L
.34169 .16058 L
.342 .16117 L
.34229 .1616 L
.34256 .16189 L
.34269 .16199 L
.34284 .16208 L
.34299 .16214 L
.34308 .16216 L
.34315 .16217 L
.3433 .16217 L
.34344 .16213 L
.34357 .16207 L
.34371 .16199 L
.34384 .16188 L
.34396 .16176 L
.34425 .16137 L
.34452 .1609 L
.34509 .15957 L
.3457 .15756 L
.34635 .15483 L
.34695 .15171 L
.34803 .14471 L
.34918 .13519 L
.35175 .10652 L
.35417 .0702 L
.35534 .04977 L
.35598 .03781 L
.35658 .02612 L
.35683 .02115 L
.35696 .01841 L
.35709 .01584 L
.35722 .0164 L
.35737 .0195 L
.35764 .02499 L
Mistroke
.3588 .05034 L
.36352 .16499 L
.36853 .29692 L
.37335 .41779 L
.378 .51366 L
.3804 .55141 L
.38163 .56698 L
.38294 .58073 L
.38418 .59076 L
.38531 .59739 L
.38585 .59971 L
.38613 .6007 L
.38644 .60158 L
.3867 .6022 L
.38685 .60248 L
.387 .60273 L
.38714 .60292 L
.38726 .60307 L
.38739 .60317 L
.38752 .60325 L
.38766 .60331 L
.38775 .60332 L
.38782 .60332 L
.38797 .60328 L
.38812 .60321 L
.38825 .6031 L
.38838 .60297 L
.38866 .60256 L
.38897 .60193 L
.38926 .6012 L
.38989 .599 L
.39044 .59651 L
.39103 .59316 L
.39211 .5854 L
.39335 .57384 L
.39448 .56106 L
.39701 .52502 L
.40184 .43261 L
.4065 .32483 L
.41144 .20463 L
.41621 .09726 L
.4186 .05004 L
.41965 .03127 L
.41994 .02633 L
.42024 .0212 L
.4205 .0169 L
.42065 .01495 L
.42079 .01719 L
.422 .03573 L
.42314 .05163 L
Mistroke
.42567 .08078 L
.42685 .09163 L
.4281 .10109 L
.42927 .10813 L
.43033 .11304 L
.43089 .11505 L
.43148 .11681 L
.43181 .1176 L
.43212 .11821 L
.43243 .11873 L
.43272 .11911 L
.43296 .11937 L
.43309 .11947 L
.43323 .11957 L
.43338 .11965 L
.43352 .1197 L
.43366 .11973 L
.43379 .11974 L
.43394 .11973 L
.43408 .1197 L
.43421 .11965 L
.43434 .11958 L
.43449 .11949 L
.43465 .11936 L
.43493 .11908 L
.43524 .11867 L
.43553 .1182 L
.43608 .11711 L
.43731 .11369 L
.43837 .10972 L
.43952 .10447 L
.44444 .07372 L
.44689 .05551 L
.44919 .03803 L
.45031 .02959 L
.45139 .02176 L
.45198 .01755 L
.45214 .01642 L
.45223 .0158 L
.45231 .01521 L
.45239 .01476 L
.45247 .01535 L
.45262 .01636 L
.45375 .02392 L
.45611 .03816 L
.45869 .05091 L
.45988 .05562 L
.46115 .05982 L
.46236 .06298 L
.46345 .06515 L
Mistroke
.46403 .06603 L
.46465 .06676 L
.46517 .06722 L
.46547 .06742 L
.46575 .06756 L
.4659 .06761 L
.46606 .06766 L
.46614 .06768 L
.46623 .0677 L
.46638 .06772 L
.46654 .06773 L
.46668 .06772 L
.46681 .06771 L
.46696 .06769 L
.46711 .06765 L
.46729 .06759 L
.46763 .06743 L
.46796 .06723 L
.46826 .067 L
.46886 .06641 L
.46951 .06557 L
.4707 .06355 L
.47294 .05823 L
.47531 .05074 L
.47784 .04122 L
.48025 .03124 L
.48152 .02582 L
.48286 .02008 L
.48344 .01761 L
.48376 .01625 L
.48392 .01559 L
.48406 .01498 L
.48415 .0148 L
.48423 .01517 L
.48442 .01594 L
.48475 .0173 L
.48538 .01991 L
.4877 .02894 L
.49008 .03717 L
.49226 .04348 L
.49459 .04872 L
.49582 .05078 L
.49649 .05169 L
.49711 .05239 L
.49766 .0529 L
.49826 .05334 L
.49859 .05352 L
.49889 .05366 L
.49919 .05376 L
.49933 .0538 L
Mistroke
.49949 .05383 L
.49964 .05385 L
.49978 .05387 L
.49991 .05387 L
.50004 .05388 L
.50019 .05387 L
.50035 .05385 L
.50049 .05383 L
.50064 .0538 L
.5009 .05373 L
.50119 .05362 L
.50171 .05335 L
.5023 .05293 L
.50286 .05242 L
.50412 .05087 L
.50535 .04883 L
.50666 .04612 L
.50923 .0393 L
.51166 .03127 L
.51387 .02292 L
.51447 .0205 L
.51512 .01784 L
.51544 .01654 L
.51559 .01589 L
.51574 .01529 L
.51586 .01475 L
.516 .01526 L
.5163 .0165 L
.51869 .02673 L
.52123 .03744 L
.52363 .04694 L
.52624 .05583 L
.52746 .05932 L
.52876 .06244 L
.52986 .06458 L
.53107 .06632 L
.53171 .06697 L
.53202 .06721 L
.5323 .0674 L
.53256 .06753 L
.53284 .06763 L
.53298 .06767 L
.53312 .0677 L
.53327 .06772 L
.53343 .06773 L
.53358 .06772 L
.53373 .0677 L
.53382 .06769 L
.53389 .06767 L
.53407 .06762 L
Mistroke
.53423 .06756 L
.53441 .06748 L
.53474 .06728 L
.53505 .06704 L
.53537 .06674 L
.53595 .06605 L
.53709 .06416 L
.53831 .06133 L
.54052 .05412 L
.54307 .04256 L
.5455 .02872 L
.54666 .02126 L
.54699 .01902 L
.5473 .01689 L
.54744 .01595 L
.54759 .01495 L
.54774 .01559 L
.54789 .01661 L
.55011 .03275 L
.5547 .06744 L
.55725 .0855 L
.55958 .09973 L
.56074 .1057 L
.56199 .11116 L
.56318 .11519 L
.56375 .11672 L
.56428 .11785 L
.56484 .11878 L
.56513 .11915 L
.56528 .1193 L
.56544 .11944 L
.56558 .11954 L
.56571 .11961 L
.56584 .11967 L
.56596 .11971 L
.56611 .11974 L
.56624 .11974 L
.56638 .11972 L
.56653 .11968 L
.56669 .11962 L
.56683 .11953 L
.56699 .11941 L
.56715 .11927 L
.56742 .11894 L
.56772 .1185 L
.56839 .11711 L
.56902 .11535 L
.57018 .11085 L
.57127 .10511 L
.57246 .09708 L
Mistroke
.57375 .08635 L
.57617 .06044 L
.57739 .04438 L
.57807 .03474 L
.57871 .02511 L
.579 .02058 L
.57916 .01805 L
.57931 .01566 L
.57938 .01502 L
.57947 .01638 L
.57964 .01928 L
.57995 .02449 L
.58109 .04437 L
.5833 .08713 L
.58828 .19793 L
.59307 .31423 L
.59768 .42215 L
.60025 .4759 L
.60258 .51832 L
.60504 .55501 L
.6073 .58027 L
.60843 .58955 L
.60963 .59682 L
.61025 .59954 L
.61082 .60142 L
.61116 .60222 L
.61146 .60275 L
.61163 .60297 L
.61171 .60307 L
.61181 .60315 L
.61189 .60321 L
.61198 .60326 L
.61214 .60331 L
.61229 .60332 L
.61242 .60328 L
.61257 .6032 L
.61266 .60314 L
.61273 .60307 L
.61289 .60289 L
.61305 .60265 L
.61336 .60207 L
.61364 .60137 L
.61394 .60046 L
.61447 .5984 L
.61509 .59533 L
.61567 .59179 L
.61699 .58138 L
.61825 .56846 L
.61944 .5536 L
.62167 .51931 L
Mistroke
.62629 .426 L
.6312 .30406 L
.63593 .17937 L
.63834 .11782 L
.63961 .08695 L
.64095 .05585 L
.64216 .02937 L
.64249 .02239 L
.64267 .0186 L
.64276 .01676 L
.64284 .01506 L
.64292 .01596 L
.643 .01764 L
.64317 .02116 L
.64348 .02722 L
.64579 .06966 L
.64818 .10548 L
.65036 .13076 L
.65156 .1415 L
.6527 .14961 L
.6539 .15596 L
.65458 .15856 L
.65491 .15956 L
.65521 .16034 L
.65551 .16095 L
.65583 .16148 L
.65598 .16169 L
.65615 .16187 L
.65624 .16195 L
.65632 .16201 L
.6564 .16206 L
.65649 .1621 L
.65664 .16216 L
.65678 .16217 L
.65694 .16216 L
.65702 .16214 L
.6571 .16211 L
.65725 .16203 L
.65739 .16193 L
.65769 .16162 L
.65796 .16123 L
.65821 .16078 L
.65878 .15945 L
.65934 .15774 L
.65993 .15549 L
.66117 .14944 L
.66251 .14098 L
.66494 .12124 L
.66987 .06933 L
.67232 .04085 L
Mistroke
.67352 .02697 L
.67409 .02048 L
.67437 .01734 L
.67449 .01598 L
.67462 .01491 L
.67476 .01642 L
.67488 .01783 L
.67516 .02092 L
.67575 .02736 L
.67682 .0387 L
.67919 .06159 L
.68155 .08068 L
.6828 .08901 L
.68414 .09643 L
.68543 .10205 L
.68661 .10581 L
.68717 .10716 L
.68747 .10775 L
.68779 .10828 L
.68806 .10867 L
.68837 .10901 L
.68865 .10925 L
.68878 .10934 L
.68891 .1094 L
.68905 .10946 L
.6892 .10951 L
.68934 .10952 L
.68947 .10953 L
.68963 .10951 L
.68977 .10947 L
.68993 .10941 L
.69009 .10932 L
.6904 .10909 L
.69069 .10879 L
.69134 .10785 L
.69191 .10674 L
.69242 .10549 L
.69358 .10188 L
.69588 .09169 L
.69838 .07673 L
.70071 .06002 L
.70329 .03966 L
.70446 .03008 L
.70508 .02504 L
.70573 .01974 L
.70601 .0175 L
.70616 .01627 L
.7063 .01511 L
.70638 .01498 L
.70647 .01569 L
Mistroke
.70662 .01693 L
.70692 .01934 L
.70802 .02798 L
.71037 .04531 L
.71295 .06179 L
.71413 .06817 L
.7154 .07409 L
.71659 .07871 L
.7177 .08214 L
.71892 .08494 L
.71956 .08599 L
.71989 .08641 L
.72025 .08678 L
.72041 .08692 L
.72059 .08705 L
.72075 .08715 L
.7209 .08722 L
.72105 .08728 L
.7212 .08732 L
.72128 .08734 L
.72137 .08735 L
.72152 .08736 L
.72166 .08736 L
.72181 .08733 L
.72193 .0873 L
.72207 .08726 L
.72222 .08719 L
.72238 .0871 L
.72267 .0869 L
.72296 .08664 L
.72327 .08629 L
.72383 .08551 L
.72449 .08431 L
.72509 .08297 L
.7264 .07927 L
.72763 .07486 L
.73228 .05172 L
.73463 .03727 L
.73587 .02923 L
.73656 .02474 L
.73721 .02048 L
.73751 .01854 L
.73783 .01647 L
.73792 .01586 L
.73801 .01528 L
.73809 .01477 L
.73817 .01522 L
.73849 .01731 L
.73967 .0248 L
.74196 .03872 L
Mistroke
.74433 .0514 L
.74692 .06265 L
.74811 .06673 L
.74939 .07024 L
.75001 .07161 L
.75059 .07271 L
.75116 .07358 L
.75169 .07422 L
.75224 .07471 L
.75254 .0749 L
.7527 .07498 L
.75286 .07505 L
.75301 .0751 L
.7531 .07512 L
.75319 .07513 L
.75327 .07515 L
.75335 .07515 L
.7535 .07516 L
.75365 .07515 L
.75379 .07513 L
.75394 .07509 L
.75409 .07504 L
.75436 .07492 L
.75464 .07475 L
.75515 .07432 L
.75576 .07362 L
.75632 .0728 L
.75751 .07045 L
.75862 .06762 L
.76112 .05906 L
.76585 .03669 L
.76701 .03044 L
.76823 .02372 L
.76927 .01792 L
.76955 .01633 L
.76971 .01546 L
.76986 .01479 L
.76999 .01556 L
.77014 .01639 L
.7704 .01783 L
.77273 .03039 L
.77525 .04274 L
.7776 .05251 L
.77884 .05684 L
.78018 .06073 L
.78146 .06367 L
.78263 .06565 L
.7832 .06635 L
.7835 .06666 L
.78381 .06693 L
Mistroke
.78412 .06715 L
.78439 .06731 L
.78453 .06737 L
.78467 .06742 L
.7848 .06746 L
.78493 .0675 L
.78508 .06752 L
.78522 .06753 L
.78537 .06754 L
.78545 .06754 L
.78553 .06753 L
.78565 .06751 L
.78579 .06749 L
.78594 .06745 L
.78608 .0674 L
.7864 .06725 L
.78669 .06707 L
.78734 .06652 L
.78793 .06583 L
.78858 .06488 L
.78988 .06236 L
.79225 .05588 L
.79478 .04664 L
.79718 .03615 L
.79845 .03017 L
.79978 .02364 L
.80098 .01772 L
.80131 .0161 L
.8014 .01563 L
.80149 .01519 L
.80157 .01479 L
.80166 .01508 L
.80174 .01549 L
.80182 .01587 L
.80199 .01671 L
.8023 .01821 L
.80461 .02931 L
.80713 .04037 L
.80945 .04899 L
.81172 .0556 L
.81286 .05814 L
.8135 .05932 L
.81411 .06027 L
.8147 .06103 L
.81535 .06168 L
.81563 .0619 L
.81593 .0621 L
.81619 .06223 L
.81647 .06234 L
.81664 .06239 L
Mistroke
.81672 .06241 L
.8168 .06243 L
.81694 .06245 L
.8171 .06246 L
.81719 .06246 L
.81727 .06246 L
.81743 .06245 L
.81751 .06243 L
.81759 .06242 L
.81777 .06238 L
.81792 .06233 L
.81806 .06228 L
.81837 .06213 L
.81867 .06194 L
.819 .06169 L
.81963 .06107 L
.82022 .06033 L
.82156 .05809 L
.82273 .05551 L
.82398 .05218 L
.82854 .0359 L
.83107 .02497 L
.83217 .01998 L
.83276 .01732 L
.83291 .01662 L
.83308 .01586 L
.83324 .01514 L
.83339 .01495 L
.83353 .0156 L
.83368 .01631 L
.834 .01774 L
.83456 .02026 L
.83566 .02511 L
.83805 .03512 L
.84059 .04438 L
.84292 .05114 L
.84406 .05378 L
.84532 .05606 L
.84589 .05689 L
.8465 .05763 L
.84708 .05818 L
.8476 .05855 L
.84788 .0587 L
.84819 .05883 L
.84834 .05888 L
.84851 .05892 L
.84867 .05895 L
.84881 .05897 L
.84895 .05898 L
.84908 .05897 L
Mistroke
.84923 .05896 L
.84938 .05894 L
.84952 .05892 L
.84964 .05889 L
.84992 .05879 L
.85023 .05865 L
.85056 .05845 L
.85113 .05799 L
.85176 .05735 L
.85244 .05645 L
.85368 .05435 L
.85481 .05193 L
.85733 .04492 L
.85985 .03617 L
.86216 .02701 L
.86333 .02214 L
.86442 .01752 L
.8647 .01632 L
.86484 .01573 L
.86497 .01519 L
.86512 .01487 L
.86519 .0152 L
.86528 .01555 L
.86556 .01674 L
.86681 .022 L
.87136 .03945 L
.87369 .04657 L
.87489 .04959 L
.8762 .05231 L
.87745 .0543 L
.87805 .05505 L
.87861 .05561 L
.87892 .05587 L
.87926 .0561 L
.87954 .05627 L
.87984 .05641 L
.88 .05646 L
.88018 .05651 L
.88027 .05654 L
.88036 .05655 L
.88045 .05657 L
.88053 .05658 L
.88068 .05659 L
.88076 .05659 L
.88085 .05659 L
.88093 .05659 L
.88101 .05658 L
.88116 .05657 L
.8813 .05654 L
.88145 .05651 L
Mistroke
.88172 .05642 L
.88204 .05628 L
.88234 .05611 L
.88298 .05563 L
.88358 .05503 L
.88465 .05361 L
.88581 .05159 L
.8882 .04597 L
.89073 .03815 L
.89311 .02953 L
.89529 .02095 L
.89587 .01857 L
.89642 .01635 L
.89657 .01577 L
.8967 .01523 L
.89685 .01483 L
.89699 .0154 L
.89762 .01793 L
.90014 .02786 L
.90478 .0435 L
.90718 .04935 L
.90839 .05157 L
.90907 .0526 L
.90971 .0534 L
.9103 .054 L
.91061 .05426 L
.91094 .0545 L
.91125 .05468 L
.91152 .05481 L
.9118 .05491 L
.91194 .05495 L
.91206 .05498 L
.91221 .05501 L
.91229 .05502 L
.91237 .05503 L
.91246 .05504 L
.91254 .05504 L
.91269 .05504 L
.91284 .05503 L
.91297 .05501 L
.91312 .05499 L
.91327 .05495 L
.91359 .05485 L
.9139 .05471 L
.91423 .05452 L
.91458 .05427 L
.91521 .05371 L
.9158 .05305 L
.91713 .05108 L
.9183 .04883 L
Mistroke
.91955 .04593 L
.92457 .03013 L
.92579 .02556 L
.92708 .02057 L
.92761 .01849 L
.92818 .01624 L
.92835 .01558 L
.92851 .01495 L
.92865 .01504 L
.92881 .01566 L
.9294 .01796 L
.93404 .03516 L
.93638 .04237 L
.93762 .04561 L
.93896 .04858 L
.94023 .05086 L
.94079 .05168 L
.9414 .05244 L
.94194 .053 L
.94252 .05348 L
.94284 .05369 L
.94313 .05385 L
.94342 .05398 L
.94369 .05407 L
.94383 .0541 L
.94398 .05413 L
.94412 .05415 L
.94425 .05416 L
.9444 .05416 L
.94449 .05416 L
.94457 .05416 L
.94471 .05414 L
.94487 .05412 L
.94503 .05408 L
.9452 .05404 L
.94552 .05392 L
.94582 .05377 L
.94611 .0536 L
.94662 .05321 L
.94719 .05267 L
.94833 .05122 L
.94956 .04913 L
.95069 .04679 L
.95321 .04014 L
.95571 .03201 L
.95802 .02356 L
.95918 .01912 L
.95975 .01693 L
.95999 .01597 L
.96014 .01542 L
Mistroke
.96027 .01492 L
.96039 .01501 L
.96053 .01555 L
.96081 .01663 L
.9614 .0189 L
.96265 .02368 L
.96505 .03242 L
.96766 .04074 L
.96888 .04407 L
.97017 .04714 L
.97129 .04936 L
.97248 .05127 L
.97349 .05248 L
.97396 .05293 L
.9744 .05326 L
.97484 .05353 L
.97507 .05363 L
.97532 .05373 L
.97554 .05379 L
.97574 .05384 L
.97585 .05385 L
.97596 .05387 L
.97607 .05387 L
.97619 .05388 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.05556 .01472 m
.05556 .05416 L
s
.0873 .01472 m
.0873 .05504 L
s
.11905 .01472 m
.11905 .05659 L
s
.15079 .01472 m
.15079 .05897 L
s
.18254 .01472 m
.18254 .06244 L
s
.21429 .01472 m
.21429 .0675 L
s
.24603 .01472 m
.24603 .07508 L
s
.27778 .01472 m
.27778 .08719 L
s
.30952 .01472 m
.30952 .10902 L
s
.34127 .01472 m
.34127 .15959 L
s
.37302 .01472 m
.37302 .40985 L
s
.40476 .01472 m
.40476 .36634 L
s
.43651 .01472 m
.43651 .11606 L
s
.46825 .01472 m
.46825 .067 L
s
.5 .01472 m
.5 .05388 L
s
.53175 .01472 m
.53175 .067 L
s
.56349 .01472 m
.56349 .11606 L
s
.59524 .01472 m
.59524 .36634 L
s
.62698 .01472 m
.62698 .40985 L
s
.65873 .01472 m
.65873 .15959 L
s
.69048 .01472 m
.69048 .10902 L
s
.72222 .01472 m
.72222 .08719 L
s
.75397 .01472 m
.75397 .07508 L
s
.78571 .01472 m
.78571 .0675 L
s
.81746 .01472 m
.81746 .06244 L
s
.84921 .01472 m
.84921 .05897 L
s
.88095 .01472 m
.88095 .05659 L
s
.9127 .01472 m
.9127 .05504 L
s
.94444 .01472 m
.94444 .05416 L
s
.97619 .01472 m
.97619 .05388 L
s
.015 w
.05556 .05416 Mdot
.0873 .05504 Mdot
.11905 .05659 Mdot
.15079 .05897 Mdot
.18254 .06244 Mdot
.21429 .0675 Mdot
.24603 .07508 Mdot
.27778 .08719 Mdot
.30952 .10902 Mdot
.34127 .15959 Mdot
.37302 .40985 Mdot
.40476 .36634 Mdot
.43651 .11606 Mdot
.46825 .067 Mdot
.5 .05388 Mdot
.53175 .067 Mdot
.56349 .11606 Mdot
.59524 .36634 Mdot
.62698 .40985 Mdot
.65873 .15959 Mdot
.69048 .10902 Mdot
.72222 .08719 Mdot
.75397 .07508 Mdot
.78571 .0675 Mdot
.81746 .06244 Mdot
.84921 .05897 Mdot
.88095 .05659 Mdot
.9127 .05504 Mdot
.94444 .05416 Mdot
.97619 .05388 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<oooool3o`0002kooooo1Ol0000]ooooo`;o0000;_ooool5o`00033ooooo0ol0000Roooo
o`00=?ooool00ol0003oooooooooo`0^ooooo`04o`000?ooooooooooo`0002cooooo00Co0000oooo
oooooooo0000;_ooool01?l0003oooooooooool0000aooooo`03o`000?oooooooooo027ooooo000[
ooooo`Go000000?oooooo`000?l000000ol0000Xooooo`Go00000oooool00ol0003oooooooooo`0/
ooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool0;_ooool5o`0002;ooooo000a
ooooo`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool0:oooool01?l0003ooooooooo
ool0000`ooooo`03o`000?oooooooooo02gooooo00Co0000oooooooooooo00008oooool003;ooooo
00?o0000ooooool00000;oooool01Ol0003ooooooooooooooooo000002cooooo00Co0000oooooooo
oooo0000;Oooool01Ol0003ooooooooooooooooo000002oooooo00?o0000ooooool000008oooool0
03?ooooo0_l0000_ooooo`05o`000?ooooooooooooooool00000;?ooool01?l0003oooooooooool0
000]ooooo`05o`000?ooooooooooooooool00000<?ooool2o`0002?ooooo000dooooo`03o`000?oo
oooooooo02kooooo0ol0000^ooooo`;o0000;oooool3o`0003;ooooo00?o0000ooooooooool08Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0017oooooool0
000=o`0000?ooooo000:ooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo007ooooo0009ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00Oooool0
00Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`23ooooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool3
o`0000Sooooo00Go003oooooooooooooooooool00008ooooo`03ool00?oooooooooo00Gooooo00Go
o`00ooooooooooooooooo`00o`04ooooo`03ool00?oooooooooo00Gooooo00Goo`00oooooooooooo
ooooo`00o`04ooooo`05ool00?ooooooooooooooool00?l00oooool01Ooo003ooooooooooooooooo
003o00?ooooo00?oo`00ooooooooool00_ooool01Ol00?ooooooooooooooooooo`0000?ooooo00Go
003oooooooooooooooooool00004ooooo`05o`00oooooooooooooooooooo00001oooool01?oo003o
ooooooooooooool2o`00o`?ooooo00?oo`00ooooooooool01Oooool01?oo003oooooooooooooool2
o`00o`?ooooo00Goo`00ooooooooooooooooo`00o`03ooooo`05ool00?ooooooooooooooool00?l0
1?ooool01Ooo003ooooooooooooooooo003o00?ooooo00?oo`00ooooooooool01Oooool00ooo003o
ooooooooo`02ooooo`05o`00oooooooooooooooooooo00000oooool01Ol00?oooooooooooooooooo
o`0000Cooooo00Go003oooooooooooooooooool00003ooooo`05o`00oooooooooooooooooooo0000
1?ooool01Ol00?ooooooooooooooooooo`0000?ooooo00Go003oooooooooooooooooool00008oooo
o`05ool00?ooooooooooooooool00?l00oooool01Ooo003ooooooooooooooooo003o00Cooooo00Go
o`00ooooooooooooooooo`00o`03ooooo`05ool00?ooooooooooooooool00?l00oooool00ooo003o
ooooooooo`02ooooo`?o00000oooool000Wooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`08ooooo`05o`00oooooooooooooooooooo00000oooool2o`00o`?ooooo00Goo`00oooo
ooooooooooooo`00o`03ooooo`04ool00?ooooooooooooooo`;o003o0oooool00ooo003ooooooooo
o`02o`00o`?ooooo00Goo`00ooooooooooooooooo`00o`04ooooo`05ool00?ooooooooooooooool0
0?l00oooool01Ooo003ooooooooooooooooo003o00?ooooo00?oo`00ooooooooool00_ooool01Ol0
0?ooooooooooooooooooo`0000?ooooo00Go003oooooooooooooooooool00004ooooo`05o`00oooo
oooooooooooooooo00001oooool00ooo003oooooooooo`02ooooo`05o`00oooooooooooooooooooo
00000oooool01Ol00?ooooooooooooooooooo`0000Cooooo00Go003oooooooooooooooooool00002
ooooo`;o003o0oooool01Ooo003ooooooooooooooooo003o00Cooooo00Goo`00oooooooooooooooo
o`00o`03ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool00_ooool01Ol00?oooooo
ooooooooooooo`0000?ooooo00Go003oooooooooooooooooool00003ooooo`;o003o0oooool01Ooo
003ooooooooooooooooo003o00?ooooo00?oo`00ooooooooool00_ooool01Ol00?oooooooooooooo
ooooo`0000?ooooo00Go003oooooooooooooooooool00003ooooo`;o003o0oooool01Ooo003ooooo
oooooooooooo003o00?ooooo00Coo`00oooooooooooooooo0_l00?l3ooooo`05ool00?oooooooooo
ooooool00?l00oooool01Ooo003ooooooooooooooooo003o00?ooooo00?oo`00ooooooooool01?oo
ool00ol0003oooooooooo`01ooooo`002Oooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00Oooooo00?o003oooooool00?l00_ooool01?oo003oooooooooooooool2o`00o`?ooooo
00Goo`00ooooooooooooooooo`00o`03ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool00_l00?l3ooooo`03ool00?oooooooooo00;ooooo00Go003oooooooooooooooooool00003oooo
o`05o`00oooooooooooooooooooo00000oooool2o`00o`;ooooo00?oo`00ooooooooool00_ooool0
1Ol00?ooooooooooooooooooo`0000?ooooo00Go003oooooooooooooooooool00004ooooo`05o`00
oooooooooooooooooooo00001oooool01?oo003oooooooooooooool2o`00o`?ooooo00Goo`00oooo
ooooooooooooo`00o`03ooooo`03ool00?oooooooooo00;ooooo00Go003oooooooooooooooooool0
0007ooooo`03ool00?oooooooooo00Kooooo00Goo`00ooooooooooooooooo`00o`03ooooo`03ool0
0?oooooooooo00Gooooo00Coo`00oooooooooooooooo0_l00?l3ooooo`05ool00?oooooooooooooo
ool00?l00oooool00ooo003oooooooooo`02ooooo`05o`00oooooooooooooooooooo00000oooool0
1Ol00?ooooooooooooooooooo`0000?ooooo0_l00?l3ooooo`05ool00?ooooooooooooooool00?l0
0oooool01?oo003oooooooooooooool2o`00o`?ooooo00Coo`00oooooooooooo003o1?ooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00;o003o0oooool00ooo003oooooooooo`02oooo
o`04o`00ooooooooooooool000Kooooo00?o0000ooooooooool00Oooool000[ooooo0_l00005oooo
o`03o`000?oooooooooo00Oooooo00?o003oooooool00?l00_ooool01?oo003oooooooooooooool2
o`00o`?ooooo00Goo`00ooooooooooooooooo`00o`03ooooo`03ool00?oooooooooo00Kooooo00Ko
o`00oooooooooooo003oooooool00?l2ooooo`05ool00?ooooooooooooooool00?l01?ooool01?oo
003oooooooooool00?l4ooooo`04ool00?ooooooooooooooo`;o003o0_ooool01Ooo003ooooooooo
oooooooo003o00Cooooo00Goo`00ooooooooooooooooo`00o`03ooooo`04ool00?oooooooooooooo
o`;o003o0oooool00ooo003oooooooooo`05ooooo`04ool00?ooooooooooooooo`;o003o0oooool0
1Ooo003ooooooooooooooooo003o00?ooooo00Goo`00ooooooooooooooooo`00o`04ooooo`03ool0
0?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool01Ooo003ooooooooooooooooo003o00?o
oooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`02ooooo`05o`00oooooooooooooooo
oooo00000oooool01Ol00?ooooooooooooooooooo`0000Cooooo00Go003oooooooooooooooooool0
0003ooooo`05o`00oooooooooooooooooooo00000oooool2o`00o`?ooooo00Coo`00oooooooooooo
003o1?ooool01?oo003oooooooooooooool2o`00o`?ooooo00?oo`00ooooooooool00_ooool01?l0
0?oooooooooooooo0002ooooo`03o`00oooooooooooo00?ooooo00Koo`00oooooooooooo003ooooo
ool00?l2ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`09ooooo`04o`00ooooooooooooool000;ooooo
00?o003oooooool00?l00oooool01_oo003oooooooooool00?ooooooo`00o`;ooooo00Koo`00oooo
oooooooo003oooooool00?l3ooooo`06ool00?ooooooooooo`00oooooooo003o0_ooool01Ooo003o
oooooooooooooooo003o00Cooooo00Koo`00oooooooooooo003oooooool00?l2ooooo`03ool00?oo
oooooooo00;ooooo00Co003oooooooooooooo`000oooool00ol00?ooooooooooo`02ooooo`05ool0
0?ooooooooooooooool00?l00oooool01Ooo003ooooooooooooooooo003o00Cooooo00?oo`00oooo
ooooool01Oooool01Ooo003ooooooooooooooooo003o00Cooooo00Koo`00oooooooooooo003ooooo
ool00?l2ooooo`04ool00?ooooooooooo`00o`Gooooo00Koo`00oooooooooooo003oooooool00?l2
ooooo`04ool00?ooooooooooooooo`;o003o0oooool01Ooo003ooooooooooooooooo003o00?ooooo
00?oo`00ooooooooool01Oooool00ooo003oooooooooo`02ooooo`05o`00oooooooooooooooooooo
00000oooool01Ol00?ooooooooooooooooooo`0000?ooooo00?o003oooooooooool00_ooool01Ooo
003ooooooooooooooooo003o00?ooooo00Goo`00ooooooooooooooooo`00o`04ooooo`06ool00?oo
ooooooooo`00oooooooo003o0_ooool01?oo003oooooooooool00?l5ooooo`03ool00?oooooooooo
00;ooooo00Co003oooooooooooooo`000_ooool00ol00?ooooooo`00o`03ooooo`04ool00?oooooo
ooooo`00o`Cooooo00Coo`00oooooooooooo003o0_ooool00ol00?ooooooool00006ooooo`03o`00
0?oooooooooo007ooooo000Aooooo`;o00001oooool01?l00?ooooooooooool00?l2ooooo`03ool0
0?oooooooooo00Kooooo00Coo`00oooooooooooo003o1?ooool01?oo003oooooooooool00?l2oooo
o`04o`00ooooooooooooool000Oooooo00Koo`00oooooooooooo003oooooool00?l3ooooo`06ool0
0?ooooooooooo`00oooooooo003o0_ooool00ooo003oooooooooo`02ooooo`04o`00oooooooooooo
ool000?ooooo0_l00?l3ooooo`05ool00?ooooooooooooooool00?l00oooool01Ooo003ooooooooo
oooooooo003o00Cooooo00?oo`00ooooooooool01Oooool01Ooo003ooooooooooooooooo003o00Co
oooo00?oo`00ooooooooool01Oooool01?oo003oooooooooool00?l2ooooo`04o`00oooooooooooo
ool000;ooooo00?o003oooooool00?l00_ooool01?oo003oooooooooooooool2o`00o`?ooooo00?o
o`00ooooooooool00_l00?l3ooooo`03ool00?oooooooooo00Gooooo00Coo`00oooooooooooooooo
0_l00?l3ooooo`04ool00?ooooooooooooooo`;o003o0_ooool01Ooo003ooooooooooooooooo003o
00Cooooo00Koo`00oooooooooooo003oooooool00?l2ooooo`04ool00?ooooooooooooooo`;o003o
0oooool01_oo003oooooooooool00?ooooooo`00o`;ooooo00?oo`00ooooooooool01_ooool01_oo
003oooooooooool00?ooooooo`00o`;ooooo00Koo`00oooooooooooo003oooooool00?l3ooooo`03
ool00?oooooooooo00Gooooo00Koo`00oooooooooooo003oooooool00?l2ooooo`03ool00?oooooo
oooo00?ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo
00?ooooo00?oo`00ooooooooool00oooool01_l00?oooooooooooooo003oooooo`00o`Gooooo00Co
o`00oooooooooooo003o0_ooool01?l00?oooooooooooooo0004ooooo`04o`00ooooooooooooool0
00Cooooo00Go003oooooooooooooooooool00002ooooo`03o`00oooooooo003o00;ooooo00Coo`00
oooooooooooo003o1?ooool00ooo003oooooooooo`02ooooo`05o`00oooooooooooooooooooo0000
0_ooool00ol00?ooooooo`00o`02ooooo`04ool00?ooooooooooooooo`;o003o0oooool00ooo003o
ooooooooo`05ooooo`03ool00?oooooooooo00;ooooo00Go003oooooooooooooooooool00002oooo
o`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool00oooool01_l00?oooooooooooooo003o
ooooo`00o`;ooooo00Co003oooooooooooooo`000_ooool00ol00?ooooooo`00o`03ooooo`03ool0
0?oooooooooo00;o003o0oooool00ooo003oooooooooo`05ooooo`04ool00?ooooooooooooooo`;o
003o0oooool01Ooo003ooooooooooooooooo003o00?ooooo00Coo`00oooooooooooooooo0_l00?l3
ooooo`04ool00?ooooooooooo`00o`Cooooo00?oo`00ooooooooool00_ooool01Ol00?oooooooooo
ooooooooo`0000;ooooo00?o003oooooool00?l00_ooool00ooo003oooooooooo`03ooooo`06o`00
ooooooooooooool00?oooooo003o1Oooool01?oo003oooooooooool00?l2ooooo`04o`00oooooooo
ooooool000Cooooo00Ko003oooooooooooooo`00ooooool00?l2ooooo`04o`00ooooooooooooool0
00Kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01_ooool01ol00?oo
oooooooooooooooo003ooooooooo00000_ooool01ol00?oooooooooooooooooo003ooooooooo0000
1Oooool00ol00?ooooooool00005ooooo`06o`00ooooooooooooool00?oooooo003o0_ooool01?l0
0?oooooooooooooo0005ooooo`04o`00ooooooooooooool000Cooooo00Co003oooooooooooooo`00
0_ooool00ol00?ooooooo`00o`02ooooo`03ool00?oooooooooo00;ooooo00Go003ooooooooooooo
ooooool00002ooooo`03o`00oooooooo003o00;ooooo00?oo`00ooooooooool00_ooool01Ol00?oo
ooooooooooooooooo`0000Oooooo00Coo`00oooooooooooooooo0_l00?l3ooooo`06ool00?oooooo
ooooo`00oooooooo003o0_ooool00ooo003oooooooooo`03ooooo`06o`00ooooooooooooool00?oo
oooo003o1Oooool00ooo003oooooooooo`02ooooo`05o`00oooooooooooooooooooo00000_ooool0
0ol00?ooooooooooo`02ooooo`03ool00?oooooooooo00Gooooo00Goo`00ooooooooooooooooo`00
o`04ooooo`04ool00?ooooooooooo`00o`Cooooo00?oo`00ooooooooool00_ooool01Ol00?oooooo
ooooooooooooo`0000;ooooo00?o003oooooool00?l00_ooool01?oo003oooooooooool00?l2oooo
o`04o`00ooooooooooooool000Cooooo00Co003oooooooooooooo`000_ooool01?l00?oooooooooo
ool00?l2ooooo`03ool00?oooooo003o00Gooooo00?oo`00ooooooooool00oooool01_l00?oooooo
oooooooo003oooooo`00o`?ooooo00?o003ooooooooo00001Oooool00ol00?ooooooool00006oooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Kooooo00Co003ooooooooo
oooooooo0_l00?l00ooo003oooooo`00o`04ooooo`03o`00ooooooooo`0000Gooooo00?o003ooooo
oooo00001Oooool01_l00?oooooooooooooo003oooooo`00o`;ooooo00Ko003oooooooooooooo`00
ooooool00?l6ooooo`03ool00?oooooo003o00Gooooo00Koo`00oooooooooooo003oooooool00?l2
ooooo`07ool00?ooooooooooooooool00?ooooooo`00o`02ooooo`04ool00?ooooooooooo`00o`Co
oooo00?oo`00ooooooooool00_ooool01Ol00?ooooooooooooooooooo`0000Oooooo00Coo`00oooo
oooooooooooo0_l00?l3ooooo`06ool00?ooooooooooo`00oooooooo003o0_ooool00ooo003ooooo
o`00o`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`02o`00o`?ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`02ooooo`05o`00
oooooooooooooooooooo00001?ooool01?l00?oooooooooooooo0005ooooo`04o`00oooooooooooo
ool000Cooooo00Co003oooooooooooooo`000_ooool01?l00?ooooooooooool00?l2ooooo`03ool0
0?oooooooooo00Gooooo00Coo`00oooooooooooo003o0_ooool2o`00o`03oooooooo003ooooo00Co
oooo00?o003ooooooooo00002?ooool00ooo003o003oooooo`03ooooo`03o`00ooooooooo`0000Oo
oooo00?oo`00ooooooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`0;ooooo`04o`00oooo003oooooo`00o`Cooooo00Co003ooooooooo003o003o1?ooool2o`00
o`03ool00?oooooo003o00Kooooo00?oo`00o`00ooooool00oooool01Ol00?ooooooool00?oooooo
003o00Kooooo00?oo`00ooooool00?l01Oooool00ooo003oooooooooo`03ooooo`03o`00oooooooo
o`0000?ooooo00?o003oooooooooool00_ooool01_oo003oooooooooool00?ooooooo`00o`;ooooo
00Coo`00oooooooooooooooo0_l00?l3ooooo`03ool00?oooooooooo00Gooooo00Goo`00oooooooo
ooooooooo`00o`04ooooo`04ool00?ooooooooooo`00o`;ooooo00Go003ooooooooo003oooooo`00
o`06ooooo`03ool00?l00?oooooo00?ooooo00?o003ooooooooo00000_ooool01?l00?oooooooooo
ool00?l2ooooo`05ool00?ooooooooooooooool00?l00oooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo00;ooooo00Go003oooooooooooooooooool00002ooooo`03o`00oooooooo003o
00;ooooo00Coo`00oooooooooooo003o1Oooool00ooo003oooooooooo`03ooooo`05o`00oooooooo
o`00ooooool00?l01_ooool00ooo003oooooo`00o`03ooooo`05o`00ooooooooo`00ooooool00?l0
1_ooool00ooo003oooooooooo`03ooooo`05o`00ooooooooo`00ooooool00?l01?ooool01?l00?oo
ooooool00?l00?l6ooooo`03ool00?l00?oo003o00Cooooo00?o003oool00?ooool01Oooool00ol0
003oooooooooo`01ooooo`004Oooool2o`0000Gooooo00?o003oooooooooool01?ooool3ool000Go
oooo0ooo00000ol00?ooooooooooo`03ooooo`?oo`001Oooool00ol00?ooooooool00007ooooo`03
ool00?oooooo003o00Cooooo00Go003ooooooooo003oooooo`00o`03ooooo`03o`00ooooooooo`00
00Gooooo00?o003ooooooooo00000_ooool01?l00?ooooooooooool00?l2ooooo`03ool00?oooooo
oooo00;ooooo00Co003oooooooooooooo`000oooool00ol00?ooooooooooo`02ooooo`03ool00?oo
oooooooo00Gooooo00Goo`00ooooooooooooooooo`00o`04ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooool00?l01?ooool3ool000Gooooo00Go003ooooooooo003oooooo`00o`03ooooo`04
o`00ooooooooooooool000;ooooo0_l00?l3ooooo`03ool00?oooooooooo00Gooooo00Coo`00oooo
oooooooooooo0_l00?l3ooooo`06ool00?ooooooooooo`00oooooooo003o0_ooool01?oo003ooooo
ooooool00?l5ooooo`03ool00?oooooo003o00?ooooo00Go003ooooooooo003oooooo`00o`06oooo
o`03ool00?oooooo003o00?ooooo00?o003ooooooooo00002?ooool00ooo003o003oooooo`04oooo
o`?oo`001Oooool3ool000Kooooo0ooo0005ooooo`?oo`001?ooool2o`0000?ooooo000Aooooo`03
o`000?oooooooooo00_ooooo0ooo0005ooooo`?oo`001_ooool3ool000Gooooo0ooo0006ooooo`03
o`00oooo003ooooo00Gooooo00Co003ooooooooo003o003o1?ooool01Ol00?ooooooool00?oooooo
003o00Gooooo00Coo`00oooooooooooo003o0_ooool01?l00?oooooooooooooo0004ooooo`04o`00
ooooooooooooool000?ooooo0_l00?l3ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo
ool00_ooool01ol00?ooooooooooooooooooo`00ooooool00?l01Oooool00ooo003oooooo`00o`04
ooooo`?oo`001_ooool01?l00?ooo`00ooooool00?l3ooooo`04o`00ooooooooooooool000;ooooo
0_l00?l3ooooo`03ool00?oooooooooo00Gooooo00Coo`00oooooooooooooooo0_l00?l3ooooo`04
ool00?ooooooooooo`00o`Cooooo00Coo`00oooooooooooo003o0_ooool01_l00?oooooooooooooo
003oooooo`00o`Gooooo00?oo`00ooooooooool01?ooool01?l00?ooooooool00?l00?l5ooooo`03
o`00oooo003ooooo00Gooooo0ooo0006ooooo`?oo`001Oooool3ool000Kooooo0ooo0005ooooo`?o
o`001Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0;ooooo`?oo`00
1Oooool3ool000Kooooo0ooo0005ooooo`?oo`001_ooool3ool000Gooooo00?o003ooooooooo0000
1Oooool01Ol00?ooooooool00?oooooo003o00?ooooo00?o003ooooooooo00001Oooool01?l00?oo
oooooooooooo0002ooooo`03o`00oooooooo003o00;ooooo00?oo`00ooooooooool00_ooool01Ol0
0?ooooooooooooooooooo`0000Oooooo00?oo`00ooooooooool00_ooool01ol00?oooooooooooooo
ooooo`00ooooool00?l00oooool00ol00?ooooooool00006ooooo`?oo`001oooool00ooo003ooooo
ooooo`03ooooo`04o`00ooooooooooooool000;ooooo00?o003oooooooooool00_ooool00ooo003o
ooooooooo`05ooooo`05ool00?ooooooooooooooool00?l01?ooool01?oo003oooooooooool00?l4
ooooo`04ool00?ooooooooooo`00o`;ooooo00Ko003oooooooooooooo`00ooooool00?l5ooooo`03
ool00?oooooooooo00Cooooo00?o003ooooooooo00001_ooool3ool000Gooooo0ooo0006ooooo`?o
o`001Oooool3ool000Kooooo0ooo0005ooooo`?oo`001Oooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`0Tooooo`?oo`001_ooool3ool000Gooooo0ooo0007ooooo`03ool0
0?oooooo003o00?ooooo00?o003ooooooooo00000_ooool01?l00?ooooooooooool00?l2ooooo`04
ool00?ooooooooooo`00o`Cooooo00?oo`00ooooooooool00_ooool01Ol00?oooooooooooooooooo
o`0000Oooooo00Coo`00oooooooooooooooo0_l00?l3ooooo`03ool00?oooooo003o00Cooooo0ooo
0007ooooo`03o`000?oooooooooo00Cooooo0ooo0007ooooo`04ool00?ooooooooooo`00o`Cooooo
00?oo`00ooooooooool01Oooool01Ooo003ooooooooooooooooo003o00Cooooo00?oo`00oooooooo
ool00_ooool01?l00?oooooooooooooo0005ooooo`06o`00ooooooooooooool00?oooooo003o0ooo
ool01Ol00?ooooooool00?oooooo003o00Cooooo0ooo0006ooooo`?oo`001Oooool3ool002Oooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0;Oooool3ool000Gooooo0ooo
0007ooooo`03ool00?oooooo003o00?ooooo00?o003ooooooooo00000_ooool00ol00?oooooooooo
o`03ooooo`04ool00?ooooooooooo`00o`Cooooo00Coo`00oooooooooooooooo0_l00?l3ooooo`03
ool00?oooooooooo00Gooooo00Goo`00ooooooooooooooooo`00o`04ooooo`03ool00?oooooo003o
00Cooooo0ooo0007ooooo`03o`000?oooooooooo00Cooooo0ooo0007ooooo`05ool00?oooooooooo
ooooool00?l00oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00;ooooo00Go003o
ooooooooooooooooool00004ooooo`04o`00ooooooooooooool000;ooooo00Oo003ooooooooooooo
ooooo`00ooooooooo`0000Kooooo00?o003oool00?l00?l01Oooool3ool000Kooooo0ooo000_oooo
o`03o`000?oooooooooo007ooooo000Aooooo`;o0000=_ooool3ool000Kooooo0ooo0005ooooo`04
o`00oooo003oooooo`00o`Kooooo00?oo`00ooooooooool00_ooool01?l00?oooooooooooooo0003
ooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool01Oooool01Ooo003ooooooooooooo
oooo003o00Cooooo00?oo`00ooooooooool01?ooool3ool000Oooooo00?o0000ooooooooool01?oo
ool3ool000Cooooo00Co003oooooooooooooo`000oooool01Ol00?ooooooooooooooooooo`0000Oo
oooo00Coo`00oooooooooooooooo0_l00?l3ooooo`04ool00?ooooooooooo`00o`;ooooo00?o003o
oooooooo00000_ooool00ol00?ooooooooooo`03ooooo`03ool00?l00?oooooo00Cooooo0ooo0005
ooooo`?oo`00=oooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo03kooooo0ooo0006oooo
o`03ool00?oooooo003o00Cooooo00?o003ooooooooo00001?ooool01?l00?oooooooooooooo0003
ooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`03
ooooo`04o`00ooooooooooooool0013ooooo00?o0000ooooooooool02oooool01?l00?oooooooooo
oooo0002ooooo`03o`00oooooooo003o00;ooooo00?oo`00ooooooooool01Oooool01ooo003ooooo
oooooooooooo003oooooool00?l00_ooool01?oo003oooooooooool00?l2ooooo`05o`00oooooooo
o`00ooooool00?l01?ooool01?l00?ooooooool00?l00?l5ooooo`?oo`00@?ooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`0nooooo`?oo`001_ooool00ooo003ooooooooo
o`04ooooo`05o`00ooooooooo`00ooooool00?l00oooool00ol00?ooooooool00003ooooo`;o003o
0oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00?ooooo00Ko003ooooooooooooo
o`00ooooool00?l>ooooo`03o`000?oooooooooo00cooooo00?o003ooooooooo00000_ooool00ol0
0?ooooooooooo`02ooooo`03ool00?oooooooooo00Gooooo00Goo`00ooooooooooooooooo`00o`04
ooooo`04ool00?ooooooooooo`00o`Cooooo00?oo`00ooooool00?l01?ooool01?l00?ooooooool0
0?l00?l5ooooo`?oo`00@?ooool00ol0003oooooooooo`01ooooo`002?ooool5o`0000Cooooo00?o
0000ooooooooool0A_ooool00ol00?ooo`00o`00o`05ooooo`05o`00ooooooooo`00ooooool00?l0
1Oooool00ooo003oooooooooo`02ooooo`05o`00oooooooooooooooooooo00001oooool01?oo003o
ooooooooool00?l2ooooo`06o`00ooooooooooooool00?oooooo003o3_ooool00ol0003ooooooooo
o`0>ooooo`03ool00?oooooo003o00Gooooo00?oo`00ooooooooool01Oooool01Ooo003ooooooooo
oooooooo003o00Cooooo00?oo`00ooooooooool00oooool00ol00?ooooooool00007ooooo`03o`00
oooo003o003o04Sooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`16ooooo`?oo`001oooool00ooo003oooooo`00o`05ooooo`06ool0
0?ooooooooooo`00oooooooo003o0oooool00ooo003oooooooooo`05ooooo`04ool00?oooooooooo
o`00o`;ooooo00Go003oooooooooooooo`00o`00o`0?ooooo`03o`000?oooooooooo00kooooo00?o
o`00ooooooooool00_ooool01?l00?oooooooooooooo0007ooooo`03ool00?oooooooooo00?ooooo
00Co003oooooooooooooo`001Oooool00ol00?ooooooool00006ooooo`?oo`00BOooool00ol0003o
ooooooooo`01ooooo`002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Kooooo
0ooo0007ooooo`03ool00?oooooo003o00?ooooo00?o003ooooooooo00000_ooool00ol00?oooooo
ooooo`03ooooo`03ool00?oooooooooo00Gooooo00Coo`00oooooooooooo003o1Oooool00ooo003o
ooooooooo`0>ooooo`03o`000?oooooooooo00cooooo00?o003ooooooooo00001?ooool01?l00?oo
oooooooooooo0007ooooo`03ool00?oooooooooo00?ooooo00Ko003oooooooooooooo`00ooooool0
0?l3ooooo`05o`00ooooooooo`00ooooool00?l01?ooool3ool004Wooooo00?o0000ooooooooool0
0Oooool000_ooooo00?o0000ooooooooool00oooool3o`0004Kooooo0ooo0006ooooo`03o`00oooo
003ooooo00Cooooo00?o003ooooooooo00000_ooool00ol00?ooooooooooo`03ooooo`03ool00?oo
oooooooo00Gooooo00Coo`00oooooooooooo003o0_ooool01?l00?oooooooooooooo000@ooooo`03
o`000?oooooooooo00cooooo00Go003ooooooooo003oooooo`00o`02ooooo`04o`00oooooooooooo
ool000Oooooo00Ooo`00ooooooooooooooooo`00oooooooo003o00;ooooo00?oo`00ooooool00?l0
0oooool01Ol00?ooooooool00?oooooo003o00Cooooo0ooo0017ooooo`?o00000oooool000Sooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo04oooooo00?o003oool00?l0
0?l01?ooool00ol00?ooooooool00002ooooo`03o`00oooooooo003o00?ooooo00?oo`00oooooooo
ool01Oooool00ooo003oooooooooo`03ooooo`05o`00ooooooooooooool00?l00?l03oooool00ol0
003oooooooooo`0<ooooo`05o`00ooooooooo`00ooooool00?l00_ooool01?l00?oooooooooooooo
0007ooooo`07ool00?ooooooooooooooool00?ooooooo`00o`02ooooo`03ool00?oooooo003o00Go
oooo00?oo`00o`00ooooool0D?ooool00ol0003oooooooooo`01ooooo`002?ooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool0Coooool00ol00?ooo`00o`00o`04ooooo`03
o`00ooooooooo`0000Cooooo00Go003oooooooooooooooooool00007ooooo`04ool00?oooooooooo
o`00o`;ooooo00Go003oooooooooooooo`00o`00o`0?ooooo`03o`000?oooooooooo00kooooo00?o
o`00ooooool00?l01Oooool00ooo003oooooooooo`05ooooo`05ool00?ooooooooooooooool00?l0
1?ooool00ooo003oooooo`00o`04ooooo`03o`00oooo003ooooo057ooooo00?o0000ooooooooool0
0Oooool000Wooooo0ol00005ooooo`03o`000?oooooooooo04kooooo0ooo00000ol00?oooooooooo
o`04ooooo`03ool00?oooooooooo00?ooooo00Co003oooooooooooooo`001oooool01?oo003ooooo
ooooool00?l3ooooo`03o`00ooooooooo`00013ooooo00?o0000ooooooooool03_ooool00ooo003o
ooooo`00o`02ooooo`04o`00ooooooooooooool000Oooooo00?oo`00ooooooooool00oooool01?l0
0?oooooooooooooo0006ooooo`?oo`00DOooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`1>ooooo`?oo`0000?o003oooooooooool00_ooool00ol00?ooooooool00002oooo
o`04o`00ooooooooooooo`00o`;ooooo00?oo`00ooooooooool01Oooool01?oo003oooooooooool0
0?l5ooooo`03ool00?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol00?ooo`00o`00
o`03ooooo`04o`00ooooooooooooool000Oooooo00?oo`00ooooooooool00oooool01_l00?oooooo
oooooooo003oooooo`00o`Cooooo0ooo001Aooooo`03o`000?oooooooooo007ooooo000Aooooo`;o
0000Coooool3ool000Gooooo00?o003ooooooooo00000_ooool00ol00?ooooooooooo`03ooooo`03
ool00?oooooooooo00Gooooo00Coo`00oooooooooooo003o0oooool3ool0013ooooo00?o0000oooo
ooooool03?ooool3ool00005o`00ooooooooooooooooool00?l00_ooool00ooo003oooooooooo`05
ooooo`04ool00?ooooooooooo`00o`;ooooo00Ko003oooooooooooooo`00ooooool00?l4ooooo`?o
o`00D?ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo05Oooooo00Go003oool00?oooooo
ooooo`00o`02ooooo`04o`00ooooooooooooool000Oooooo00?oo`00ooooooooool01?ooool3ool0
013ooooo00?o0000ooooooooool03?ooool3ool000Cooooo00Co003oooooooooooooo`001oooool0
1?oo003oooooooooool00?l2ooooo`06o`00ooooooooooooool00?oooooo003oF?ooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Gooooo`03o`00oooo003ooooo00Cooooo
00Co003oooooooooooooo`001oooool00ooo003oooooooooo`04ooooo`?oo`004?ooool00ol0003o
ooooooooo`0<ooooo`?oo`001oooool00ooo003oooooooooo`05ooooo`04ool00?ooooooooooo`00
o`Gooooo00?oo`00ooooool00?l0F?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`1Hooooo`03ool00?oooooooooo00?ooooo00Co003oooooooooooooo`001oooool01?oo
003oooooooooool00?lFooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool01Oooool0
1?oo003oooooooooool00?l5ooooo`03ool00?oooooooooo05Sooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0F?ooool01?oo003oooooooooool00?l2ooooo`04o`00oooo
ooooooooool000Oooooo00Coo`00oooooooooooo003o5_ooool00ol0003oooooooooo`0Cooooo`04
o`00ooooooooooooool000Oooooo00?oo`00ooooooooool01?ooool00ol00?ooooooool0001Joooo
o`03o`000?oooooooooo007ooooo000Aooooo`;o0000F?ooool01Ol00?ooo`00oooooooooooo003o
00Gooooo00?oo`00ooooooooool01Oooool01?oo003oooooooooool00?lFooooo`03o`000?oooooo
oooo01?ooooo00Co003oooooooooooooo`001oooool01?oo003oooooooooool00?l3ooooo`04o`00
ooooooooo`00o`00oeSooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1Gooooo`04o`00
oooo003oooooo`00o`Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Gooooo`03
o`000?oooooooooo01?ooooo00Co003oooooooooooooo`001oooool01?oo003oooooooooool00?l3
ooooo`04o`00ooooooooo`00o`00oeWooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool0Eoooool00ol00?ooo`00ooooo`04ooooo`04o`00ooooooooooooool000Oooooo00?o
o`00ooooooooool05oooool00ol0003oooooooooo`0Fooooo`03ool00?oooooooooo00Gooooo00Co
o`00oooooooooooo003o1Oooool00ooo003o003oooooo`1Hooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo05Sooooo00?oo`00ooooooooool00oooool01?l00?oooooooooo
oooo0007ooooo`04ool00?ooooooooooo`00oaKooooo00?o0000ooooooooool05_ooool00ooo003o
ooooooooo`05ooooo`04ool00?ooooooooooo`00o`Gooooo00?oo`00ooooooooool0F?ooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Hooooo`03ool00?oooooo003o00?o
oooo00Co003oooooooooooooo`001oooool01?oo003oooooooooool00?lFooooo`03o`000?oooooo
oooo01?ooooo00Co003oooooooooooooo`001oooool00ooo003oooooooooo`04ooooo`03o`00oooo
ooooo`0005[ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001Iooooo`03ool00?oooooo
003o00Kooooo00?oo`00ooooooooool01Oooool01?oo003oooooooooool00?lFooooo`03o`000?oo
oooooooo01?ooooo00Co003oooooooooooooo`001oooool00ooo003oooooooooo`04ooooo`03o`00
ooooooooo`0005Wooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1Hooooo`03ool00?oo
oooo003o00Kooooo00?oo`00ooooooooool01Oooool01?oo003oooooooooool00?lFooooo`03o`00
0?oooooooooo01Cooooo00?o003ooooooooo00001oooool01?oo003oooooooooool00?l4ooooo`03
o`00oooo003ooooo05Wooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
Eoooool3ool00005o`00ooooooooooooooooool00?l00_ooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo01Oooooo00?o0000ooooooooool05_ooool00ooo003oooooooooo`05ooooo`04
ool00?ooooooooooo`00o`?ooooo0ooo001Jooooo`03o`000?oooooooooo007ooooo000:ooooo`?o
00001?ooool00ol0003oooooooooo`1Gooooo`?oo`001?ooool01?l00?oooooooooooooo0007oooo
o`03ool00?oooooo003o01Oooooo00?o0000ooooooooool05_ooool00ooo003oooooooooo`05oooo
o`04ool00?ooooooooooo`00o`?ooooo0ooo001Jooooo`03o`000?oooooooooo007ooooo000;oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Eoooool3ool000Cooooo00Co003ooooo
ooooooooo`001oooool00ooo003oooooo`00o`0Gooooo`03o`000?oooooooooo01Cooooo00?o003o
oooooooo00001oooool00ooo003oooooooooo`04ooooo`?oo`00F_ooool00ol0003oooooooooo`01
ooooo`002?ooool5o`0000Cooooo00?o0000ooooooooool0G_ooool01?l00?oooooooooooooo0007
ooooo`03ool00?oooooo003o01Oooooo00?o0000ooooooooool05?ooool00ol00?ooooooool00007
ooooo`03ool00?oooooooooo067ooooo00?o0000ooooooooool00Oooool000Sooooo00Co0000oooo
oooooooo00001Oooool3o`00067ooooo00?oo`00ooooooooool01Oooool00ooo003oooooo`00o`0G
ooooo`03o`000?oooooooooo01Cooooo00?o003ooooooooo00001oooool01?oo003oooooooooool0
0?mNooooo`?o00000oooool000Wooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`1N
ooooo`04o`00ooooooooooooool000Oooooo00?oo`00ooooooooool05oooool00ol0003ooooooooo
o`0Dooooo`03o`00ooooooooo`0000Oooooo00Coo`00oooooooooooo003oH?ooool00ol0003ooooo
ooooo`01ooooo`002_ooool2o`0000Gooooo00?o0000ooooooooool0G_ooool01?l00?oooooooooo
oooo0007ooooo`03ool00?oooooooooo01Oooooo00?o0000ooooooooool05_ooool00ooo003ooooo
ooooo`05ooooo`04ool00?ooooooooooo`00of3ooooo00?o0000ooooooooool00Oooool000_ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1Nooooo`04o`00ooooooooooooool000Oo
oooo00?oo`00ooooool00?l05oooool00ol0003oooooooooo`0Dooooo`03o`00ooooooooo`0000Oo
oooo00Coo`00oooooooooooo003oH?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`1Nooooo`04o`00ooooooooooooool000Oooooo00?oo`00ooooool00?l05oooool00ol0
003oooooooooo`0Dooooo`03o`00ooooooooo`0000Oooooo00?oo`00ooooooooool0HOooool00ol0
003oooooooooo`01ooooo`004Oooool2o`0006;ooooo00?oo`00ooooooooool01Oooool00ooo003o
ooooo`00o`0Gooooo`03o`000?oooooooooo01Cooooo00?o003ooooooooo00001oooool01?oo003o
ooooooooool00?mOooooo`;o00000oooool0017ooooo00?o0000ooooooooool0Goooool00ol00?oo
ooooool00007ooooo`03ool00?oooooooooo01Oooooo00?o0000ooooooooool05?ooool00ol00?oo
ooooool00007ooooo`04ool00?ooooooooooo`00of3ooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool0Goooool00ol00?ooooooool00007ooooo`03ool00?oooooooooo01Oo
oooo00?o0000ooooooooool05_ooool00ooo003oooooooooo`05ooooo`04ool00?ooooooooooo`00
of3ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Goooool00ol00?oo
ooooool00007ooooo`03ool00?oooooo003o01Oooooo00?o0000ooooooooool05_ooool00ooo003o
ooooooooo`05ooooo`04ool00?ooooooooooo`00of3ooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool0Goooool00ol00?ooooooool00007ooooo`03ool00?oooooo003o01Oo
oooo00?o0000ooooooooool05?ooool00ol00?ooooooool00007ooooo`03ool00?oooooooooo067o
oooo00?o0000ooooooooool00Oooool0017ooooo0_l0001Rooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooool00?l05oooool00ol0003oooooooooo`0Dooooo`03o`00ooooooooo`0000Oooooo
00?oo`00ooooooooool0H?ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo067ooooo00?o
o`00ooooooooool01Oooool00ooo003oooooo`00o`0Gooooo`03o`000?oooooooooo01Cooooo00?o
003ooooooooo00001oooool00ooo003oooooo`00o`1Qooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo05oooooo00?o003ooooooooo00001oooool00ooo003oooooooooo`0G
ooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooo`00o`1Q
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo05oooooo00?o003ooooo
oooo00001oooool00ooo003oooooo`00o`0Gooooo`03o`000?oooooooooo01Kooooo00?oo`00oooo
ooooool01Oooool00ooo003oooooo`00o`1Qooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo05oooooo00?o003ooooooooo00001oooool00ooo003oooooo`00o`0Gooooo`03
o`000?oooooooooo01Cooooo00?o003ooooooooo00001oooool00ooo003oooooooooo`1Qooooo`03
o`000?oooooooooo007ooooo000Aooooo`;o0000H_ooool00ooo003oooooooooo`05ooooo`03ool0
0?oooooo003o01Oooooo00?o0000ooooooooool05?ooool00ol00?ooooooool00007ooooo`03ool0
0?oooooooooo063ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1Qooooo`03ool00?oo
oooooooo00Gooooo00?oo`00ooooool00?l05oooool00ol0003oooooooooo`0Dooooo`03o`00oooo
ooooo`0000Oooooo00?oo`00ooooool00?l0HOooool00ol0003oooooooooo`01ooooo`004Oooool0
0ol0003oooooooooo`1Oooooo`03o`00ooooooooo`0000Oooooo00?oo`00ooooooooool05oooool0
0ol0003oooooooooo`0Dooooo`03o`00ooooooooo`0000Oooooo00?oo`00ooooool00?l0HOooool0
0ol0003oooooooooo`01ooooo`002Oooool3o`0000Gooooo00?o0000ooooooooool0Goooool00ol0
0?ooooooool00007ooooo`03ool00?oooooooooo01Oooooo00?o0000ooooooooool05_ooool00ooo
003oooooooooo`05ooooo`03ool00?oooooo003o067ooooo00?o0000ooooooooool00Oooool000So
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo05oooooo00?o003ooooo
oooo00001oooool00ooo003oooooo`00o`0Gooooo`03o`000?oooooooooo01Gooooo00?o003oool0
0?ooool01_ooool00ooo003oooooo`00o`1Qooooo`03o`000?oooooooooo007ooooo0008ooooo`05
o`000?ooooooooooooooool000001?ooool3o`0005oooooo00?o003ooooooooo00001oooool00ooo
003oooooo`00o`0Gooooo`03o`000?oooooooooo01Gooooo00?o003oool00?ooool01_ooool00ooo
003oooooooooo`1Oooooo`?o00000oooool000Sooooo1?l00005ooooo`03o`000?oooooooooo067o
oooo00?oo`00ooooooooool01Oooool00ooo003o003oooooo`0Gooooo`03o`000?oooooooooo01Go
oooo00?o003oool00?ooool01_ooool00ooo003oooooo`00o`1Qooooo`03o`000?oooooooooo007o
oooo0008ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Goooool00ol00?oooooo
ool00007ooooo`03ool00?oooooooooo01Oooooo00?o0000ooooooooool05Oooool00ol00?ooo`00
ooooo`06ooooo`03ool00?oooooo003o067ooooo00?o0000ooooooooool00Oooool000Wooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`03o`00ooooooooo`0000Oooooo00?o
o`00ooooooooool05oooool00ol0003oooooooooo`0Fooooo`03ool00?oooooooooo00Gooooo00?o
o`00ooooool00?l0HOooool00ol0003oooooooooo`01ooooo`002_ooool2o`0000Gooooo00?o0000
ooooooooool0Goooool00ol00?ooooooool00007ooooo`03ool00?l00?oooooo01Oooooo00?o0000
ooooooooool05_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo003o067ooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Goooool00ol00?ooooooool00007oooo
o`03ool00?l00?oooooo01Oooooo00?o0000ooooooooool05Oooool00ol00?ooo`00ooooo`06oooo
o`03ool00?oooooooooo067ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001Rooooo`03
ool00?oooooooooo00Gooooo00?oo`00o`00ooooool05oooool00ol0003oooooooooo`0Eooooo`03
o`00oooo003ooooo00Kooooo00?oo`00ooooooooool0H?ooool2o`0000?ooooo000Aooooo`03o`00
0?oooooooooo067ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Gooooo`03o`00
0?oooooooooo01Gooooo00?o003oool00?ooool01_ooool00ooo003oooooo`00o`1Qooooo`03o`00
0?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo05oooooo00?o003ooooooooo00001ooo
ool00ooo003oooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool01Ooo
ool00ooo003oooooo`00o`1Qooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo05oooooo00?o003ooooooooo00001oooool00ooo003o003oooooo`0Gooooo`03o`000?oooooo
oooo01Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooo`00o`1Qooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo05oooooo00?o003ooooooooo00001oooool00ooo
003o003oooooo`0Gooooo`03o`000?oooooooooo01Gooooo00?o003oool00?ooool01_ooool00ooo
003oooooooooo`1Qooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000H_ooool00ooo003o
ooooooooo`05ooooo`03ool00?l00?oooooo01Oooooo00?o0000ooooooooool05Oooool00ol00?oo
o`00ooooo`06ooooo`03ool00?oooooooooo063ooooo0_l00003ooooo`004Oooool00ol0003ooooo
ooooo`1Qooooo`03ool00?oooooooooo00Gooooo00?oo`00o`00ooooool05oooool00ol0003ooooo
ooooo`0Eooooo`03o`00oooo003ooooo00Kooooo00?oo`00ooooool00?l0HOooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`1Pooooo`03o`00oooo003ooooo00Kooooo00?o
o`00ooooooooool05oooool00ol0003oooooooooo`0Eooooo`03o`00oooo003ooooo00Kooooo00?o
o`00ooooool00?l0HOooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1P
ooooo`03o`00oooo003ooooo00Kooooo00?oo`00o`00ooooool05oooool00ol0003oooooooooo`0F
ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooool00?l0HOooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`1Pooooo`03o`00oooo003ooooo00Kooooo00?oo`00o`00
ooooool05oooool00ol0003oooooooooo`0Eooooo`03o`00oooo003ooooo00Kooooo00?oo`00oooo
ool00?l0HOooool00ol0003oooooooooo`01ooooo`004Oooool2o`00067ooooo00?o003oool00?oo
ool01_ooool00ooo003o003oooooo`0Gooooo`03o`000?oooooooooo01Gooooo00?o003oool00?oo
ool01_ooool00ooo003oooooooooo`1Pooooo`;o00000oooool0017ooooo00?o0000ooooooooool0
HOooool00ooo003oooooooooo`05ooooo`03ool00?l00?oooooo01Oooooo00?o0000ooooooooool0
5Oooool00ol00?ooo`00ooooo`06ooooo`03ool00?l00?oooooo067ooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool0H?ooool00ol00?ooo`00ooooo`06ooooo`03ool00?oo
oooooooo01Oooooo00?o0000ooooooooool05Oooool00ol00?ooo`00ooooo`06ooooo`03ool00?l0
0?oooooo067ooooo00?o0000ooooooooool00Oooool000Wooooo0ol00005ooooo`03o`000?oooooo
oooo063ooooo00?o003oool00?ooool01_ooool00ooo003oooooooooo`0Gooooo`03o`000?oooooo
oooo01Kooooo00?oo`00ooooooooool01Oooool00ooo003o003oooooo`1Qooooo`03o`000?oooooo
oooo007ooooo0008ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1P
ooooo`03o`00oooo003ooooo00Kooooo00?oo`00o`00ooooool05oooool00ol0003oooooooooo`0F
ooooo`03ool00?oooooooooo00Gooooo00?oo`00o`00ooooool0HOooool00ol0003oooooooooo`01
ooooo`002?ooool01Ol0003ooooooooooooooooo000000Cooooo0ol0001Pooooo`03o`00oooo003o
oooo00Kooooo00?oo`00o`00ooooool05oooool00ol0003oooooooooo`0Fooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool0Goooool3o`0000?ooooo0009ooooo`?o00001Oooool00ol0
003oooooooooo`1Qooooo`03ool00?oooooooooo00Gooooo00?oo`00o`00ooooool05oooool00ol0
003oooooooooo`0Fooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0HOooool00ol0
003oooooooooo`01ooooo`002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool0HOooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo01Oooooo00?o0000oooo
ooooool05_ooool00ooo003oooooooooo`05ooooo`03ool00?l00?oooooo067ooooo00?o0000oooo
ooooool00Oooool000Sooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo
063ooooo00?o003oool00?ooool01_ooool00ooo003oooooooooo`0Gooooo`03o`000?oooooooooo
01Kooooo00?oo`00ooooooooool01Oooool00ooo003o003oooooo`1Qooooo`03o`000?oooooooooo
007ooooo0009ooooo`?o00001Oooool00ol0003oooooooooo`1Pooooo`03o`00oooo003ooooo00Ko
oooo00?oo`00ooooooooool05oooool00ol0003oooooooooo`0Fooooo`03ool00?oooooooooo00Go
oooo00?oo`00o`00ooooool0HOooool00ol0003oooooooooo`01ooooo`004Oooool2o`00067ooooo
00?o003oool00?ooool01_ooool00ooo003oooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo
00?oo`00ooooooooool01Oooool00ooo003oooooooooo`1Pooooo`;o00000oooool0017ooooo00?o
0000ooooooooool0HOooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo01Oooooo00?o
0000ooooooooool05_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo067ooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0HOooool00ooo003oooooooooo`05
ooooo`03ool00?oooooooooo01Oooooo00?o0000ooooooooool05_ooool00ooo003oooooooooo`05
ooooo`03ool00?l00?oooooo067ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool0H?ooool00ol00?ooo`00ooooo`06ooooo`03ool00?oooooooooo01Oooooo00?o0000oooo
ooooool05_ooool00ooo003oooooooooo`05ooooo`03ool00?l00?oooooo067ooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool0H?ooool00ol00?ooo`00ooooo`06ooooo`03
ool00?oooooooooo01Oooooo00?o0000ooooooooool05_ooool00ooo003oooooooooo`05ooooo`03
ool00?l00?oooooo067ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
H?ooool00ol00?ooo`00ooooo`05ooooo`?oo`006?ooool00ol0003oooooooooo`0Eooooo`?oo`00
1_ooool00ooo003o003oooooo`1Qooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000HOoo
ool00ol00?ooo`00ooooo`05ooooo`?oo`006?ooool00ol0003oooooooooo`0Eooooo`?oo`001_oo
ool00ooo003oooooooooo`1Pooooo`;o00000oooool0017ooooo00?o0000ooooooooool0HOooool0
0ooo003oooooooooo`04ooooo`?oo`006?ooool00ol0003oooooooooo`0Eooooo`?oo`001_ooool0
0ooo003o003oooooo`1Qooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
063ooooo00?o003oool00?ooool08?ooool00ol0003oooooooooo`0Fooooo`03o`00oooooooooooo
00Gooooo00?oo`00o`00ooooool0HOooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`1Pooooo`03o`00oooo003ooooo023ooooo00?o0000ooooooooool07_ooool00ooo003o
003oooooo`1Qooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo063ooooo
00?o003oool00?ooool01_ooool00ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo01kooooo
00?oo`00o`00ooooool0HOooool00ol0003oooooooooo`01ooooo`004Oooool2o`00067ooooo00?o
003oool00?ooool01_ooool00ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo00?o
003oooooooooool01Oooool00ooo003oooooooooo`1Pooooo`;o00000oooool0017ooooo00?o0000
ooooooooool0HOooool00ooo003oooooooooo`05ooooo`03o`00oooooooooooo01Oooooo00?o0000
ooooooooool05_ooool00ol00?ooooooooooo`05ooooo`03ool00?oooooooooo067ooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0HOooool00ooo003oooooooooo`0Ooooo
o`03o`000?oooooooooo01Kooooo00?o003oooooooooool01Oooool00ooo003o003oooooo`1Qoooo
o`03o`000?oooooooooo007ooooo0003ooooo`?o00001?ooool2o`0000Gooooo00?o0000oooooooo
ool0HOooool00ooo003oooooooooo`0Oooooo`03o`000?oooooooooo01kooooo00?oo`00o`00oooo
ool0HOooool00ol0003oooooooooo`01ooooo`001?ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0HOooool00ooo003oooooooooo`05ooooo`03
o`00oooooooooooo01Oooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`1Qooooo`03
o`000?oooooooooo007ooooo0004ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00001?ooool3o`0005oooooo0ooo0007ooooo`03o`00oooooooooooo01Oooooo00?o0000oooooooo
ool05_ooool00ol00?ooooooooooo`04ooooo`?oo`00H?ooool3o`0000?ooooo0004ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Oooooo`?o
o`001oooool00ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo00?o003ooooooooo
ool01?ooool3ool006;ooooo00?o0000ooooooooool00Oooool000Cooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo05oooooo0ooo0007ooooo`03
o`00oooooooooooo01Oooooo00?o0000ooooooooool05_ooool00ol00?ooooooooooo`04ooooo`?o
o`00H_ooool00ol0003oooooooooo`01ooooo`000oooool2o`0000Cooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`1Qooooo`03o`00oooooooooooo01oooooo00?o0000oooooooo
ool05_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo067ooooo00?o0000oooooooo
ool00Oooool000Cooooo00?o0000ooooooooool00oooool2o`0000Gooooo00?o0000ooooooooool0
HOooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Oooooo00?o0000ooooooooool0
7_ooool00ol00?ooooooooooo`1Qooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000H_oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Oooooo00?o0000ooooooooool05ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo063ooooo0_l00003ooooo`004Oooool0
0ol0003oooooooooo`1Qooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool06?ooool0
0ol0003oooooooooo`0Gooooo`03o`00oooooooooooo06Sooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool0J?ooool00ol00?ooooooooooo`0Hooooo`03o`000?oooooooooo
01Oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Qooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo067ooooo00?o003oooooooooool07oooool00ol0003o
ooooooooo`0Gooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0HOooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Qooooo`03o`00oooooooooooo01oooooo
00?o0000ooooooooool07_ooool00ol00?ooooooooooo`1Qooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo067ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0Hooooo`03o`000?oooooooooo01kooooo00?o003oooooooooool0HOooool00ol0003ooooooooo
o`01ooooo`004Oooool2o`0006;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0H
ooooo`03o`000?oooooooooo01Oooooo00?o003oooooooooool0Ioooool2o`0000?ooooo000Aoooo
o`03o`000?oooooooooo06Sooooo00?o003oooooooooool06?ooool00ol0003oooooooooo`0Goooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool0HOooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo01Oooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`1Qooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo067ooooo00?o003oooooooooool07oooool00ol0003oooooooooo`0Nooooo`03o`00
oooooooooooo067ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0HOoo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01Sooooo00?o0000ooooooooool07_oo
ool00ol00?ooooooooooo`1Qooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000H_ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01Sooooo00?o0000ooooooooool05oooool0
0ol00?ooooooooooo`1Wooooo`;o00000oooool0017ooooo00?o0000ooooooooool0J?ooool00ol0
0?ooooooooooo`0Hooooo`03o`000?oooooooooo01Oooooo00?o003oooooooooool0J?ooool00ol0
003oooooooooo`01ooooo`000oooool3o`0000;ooooo1Ol00004ooooo`03o`000?oooooooooo06So
oooo00?o003oooooooooool06?ooool00ol0003oooooooooo`0Gooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool0HOooool00ol0003oooooooooo`01ooooo`001?ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0H_ooool00ol00?oo
ooooooooo`0Nooooo`03o`000?oooooooooo01Oooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`1Qooooo`03o`000?oooooooooo007ooooo0004ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Rooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool06?ooool00ol0003oooooooooo`0Mooooo`03o`00oooooooooooo06;ooooo
00?o0000ooooooooool00Oooool000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`?o0000H_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01Sooooo00?o
0000ooooooooool05oooool00ol00?ooooooooooo`1Vooooo`?o00000oooool000Cooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H_oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01Sooooo00?o0000ooooooooool05ooo
ool00ol00?ooooooooooo`1Xooooo`03o`000?oooooooooo007ooooo0003ooooo`;o00000oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0J?ooool00ol00?oooooooooo
o`0Hooooo`03o`000?oooooooooo01Sooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`1Rooooo`03o`000?oooooooooo007ooooo0004ooooo`03o`000?oooooooooo00;ooooo0ol00005
ooooo`03o`000?oooooooooo06;ooooo00?o003oooooooooool07_ooool00ol0003oooooooooo`0H
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0H_ooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`1Rooooo`03o`00oooooooooooo01kooooo00?o0000oooo
ooooool07Oooool00ol00?ooooooooooo`1Rooooo`03o`000?oooooooooo007ooooo000Aooooo`;o
0000Hoooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Wooooo00?o0000oooooooo
ool07Oooool00ol00?ooooooooooo`1Qooooo`;o00000oooool0017ooooo00?o0000ooooooooool0
H_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Wooooo00?o0000ooooooooool0
6?ooool00ol00?ooooooooooo`1Wooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo06Oooooo00?o003oooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool0H_ooool00ol0003oooooooooo`01ooooo`004Oooool0
0ol0003oooooooooo`23ooooo`03o`000?oooooooooo01Sooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`1Rooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
06;ooooo00?o003oooooooooool07_ooool00ol0003oooooooooo`0Mooooo`03o`00oooooooooooo
06;ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001Sooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool06Oooool00ol0003oooooooooo`0Mooooo`03o`00oooooooooooo067o
oooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1Rooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`00oooooooooooo06Oooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Ioooool00ol00?oooooooooo
o`0Iooooo`03o`000?oooooooooo01Sooooo00?o003oooooooooool0Ioooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`1Wooooo`03o`00oooooooooooo01Wooooo00?o0000
ooooooooool06?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo06;ooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0H_ooool00ol00?ooooooooooo`0Noooo
o`03o`000?oooooooooo01Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Roooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0Iooooo`03o`000?oooooooooo01gooooo00?o003ooooooooo
ool0H_ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0006Cooooo00Go003ooooooooooooo
ooooo`00o`0Kooooo`03o`000?oooooooooo01Sooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`1Qooooo`;o00000oooool0017ooooo00?o0000ooooooooool0Hoooool01Ol00?oooooo
oooooooooooo003o01_ooooo00?o0000ooooooooool06?ooool00ol00?ooooooooooo`1Wooooo`03
o`000?oooooooooo007ooooo0003ooooo`?o00001?ooool3o`0000Cooooo00?o0000ooooooooool0
Ioooool00ol00?ooooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool0
0_l00?mTooooo`03o`000?oooooooooo007ooooo0004ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1Sooooo`03o`00oooooooooooo01gooooo00?o
0000ooooooooool06Oooool01?l00?ooooooooooool00?mUooooo`03o`000?oooooooooo007ooooo
0004ooooo`04o`000?ooooooooooooooo`Go00001?ooool00ol0003oooooooooo`1Sooooo`03o`00
oooooooooooo01gooooo00?o0000ooooooooool07?ooool00ol00?ooooooooooo`1Sooooo`03o`00
0?oooooooooo007ooooo0004ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`03ooooo`?o0000Hoooool01?l00?ooooooooooool00?lLooooo`03o`000?oooooooooo01co
oooo00?o003oooooooooool0HOooool3o`0000?ooooo0004ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooool000001Oooool00ol0003oooooooooo`1Sooooo`04o`00ooooooooooooo`00oaco
oooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`1Vooooo`03o`000?oooooooooo007o
oooo0003ooooo`;o00001Oooool2o`0000Gooooo00?o0000ooooooooool0I_ooool00ol00?oooooo
ooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool0I_ooool00ol0003ooooo
ooooo`01ooooo`001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0Poooool00ol0003oooooooooo`0Iooooo`04o`00ooooooooooooo`00ofGooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Hoooool00ol00?oooooooooo
o`0Mooooo`03o`000?oooooooooo01cooooo00?o003oooooooooool0Hoooool00ol0003ooooooooo
o`01ooooo`004Oooool2o`0006Cooooo00Co003ooooooooooooo003o7?ooool00ol0003ooooooooo
o`0Looooo`03o`00oooooooooooo06;ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1T
ooooo`03o`00oooooooo003o01cooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`1V
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06Kooooo00?o003ooooo
ooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo06Kooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool0I_ooool00ol00?ooooooooooo`0Jooooo`03
o`000?oooooooooo01Wooooo00?o003oooooool00?l0I_ooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`1Tooooo`03o`00oooooooooooo01cooooo00?o0000ooooooooool0
6_ooool2o`00ofKooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001Uooooo`;o003o7Ooo
ool00ol0003oooooooooo`0Kooooo`03o`00oooooooooooo06?ooooo0_l00003ooooo`004Oooool0
0ol0003oooooooooo`1Uooooo`03o`00oooooooooooo01_ooooo00?o0000ooooooooool0P_ooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo
08;ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`01ooooo`004Oooooooo`0000go00000oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.95693, -1.55794, \
0.0394232, 0.0958772}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g7 = 
        DiscreteListPlot[
          FourierRearrange[Arg[\(\((Last[#] +  .0000001)\) &\)\  /@ \ fft], 
            fs], Red, PlotRange \[Rule] All, ImageSize \[Rule] 504, \ 
          Frame \[Rule] True, \ Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g8 = \ Show[g2, g7];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309222 0.0998921 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00955 -12 -4.5 ]
[-0.0125 .00955 0 4.5 ]
[-0.0125 .10944 -12 -4.5 ]
[-0.0125 .10944 0 4.5 ]
[-0.0125 .20933 -12 -4.5 ]
[-0.0125 .20933 0 4.5 ]
[-0.0125 .30922 -6 -4.5 ]
[-0.0125 .30922 0 4.5 ]
[-0.0125 .40911 -6 -4.5 ]
[-0.0125 .40911 0 4.5 ]
[-0.0125 .50901 -6 -4.5 ]
[-0.0125 .50901 0 4.5 ]
[-0.0125 .6089 -6 -4.5 ]
[-0.0125 .6089 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00955 m
.00625 .00955 L
s
[(-3)] -0.0125 .00955 1 0 Mshowa
0 .10944 m
.00625 .10944 L
s
[(-2)] -0.0125 .10944 1 0 Mshowa
0 .20933 m
.00625 .20933 L
s
[(-1)] -0.0125 .20933 1 0 Mshowa
0 .30922 m
.00625 .30922 L
s
[(0)] -0.0125 .30922 1 0 Mshowa
0 .40911 m
.00625 .40911 L
s
[(1)] -0.0125 .40911 1 0 Mshowa
0 .50901 m
.00625 .50901 L
s
[(2)] -0.0125 .50901 1 0 Mshowa
0 .6089 m
.00625 .6089 L
s
[(3)] -0.0125 .6089 1 0 Mshowa
.125 Mabswid
0 .02952 m
.00375 .02952 L
s
0 .0495 m
.00375 .0495 L
s
0 .06948 m
.00375 .06948 L
s
0 .08946 m
.00375 .08946 L
s
0 .12942 m
.00375 .12942 L
s
0 .14939 m
.00375 .14939 L
s
0 .16937 m
.00375 .16937 L
s
0 .18935 m
.00375 .18935 L
s
0 .22931 m
.00375 .22931 L
s
0 .24929 m
.00375 .24929 L
s
0 .26927 m
.00375 .26927 L
s
0 .28924 m
.00375 .28924 L
s
0 .3292 m
.00375 .3292 L
s
0 .34918 m
.00375 .34918 L
s
0 .36916 m
.00375 .36916 L
s
0 .38914 m
.00375 .38914 L
s
0 .42909 m
.00375 .42909 L
s
0 .44907 m
.00375 .44907 L
s
0 .46905 m
.00375 .46905 L
s
0 .48903 m
.00375 .48903 L
s
0 .52899 m
.00375 .52899 L
s
0 .54896 m
.00375 .54896 L
s
0 .56894 m
.00375 .56894 L
s
0 .58892 m
.00375 .58892 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00955 m
1 .00955 L
s
.99375 .10944 m
1 .10944 L
s
.99375 .20933 m
1 .20933 L
s
.99375 .30922 m
1 .30922 L
s
.99375 .40911 m
1 .40911 L
s
.99375 .50901 m
1 .50901 L
s
.99375 .6089 m
1 .6089 L
s
.125 Mabswid
.99625 .02952 m
1 .02952 L
s
.99625 .0495 m
1 .0495 L
s
.99625 .06948 m
1 .06948 L
s
.99625 .08946 m
1 .08946 L
s
.99625 .12942 m
1 .12942 L
s
.99625 .14939 m
1 .14939 L
s
.99625 .16937 m
1 .16937 L
s
.99625 .18935 m
1 .18935 L
s
.99625 .22931 m
1 .22931 L
s
.99625 .24929 m
1 .24929 L
s
.99625 .26927 m
1 .26927 L
s
.99625 .28924 m
1 .28924 L
s
.99625 .3292 m
1 .3292 L
s
.99625 .34918 m
1 .34918 L
s
.99625 .36916 m
1 .36916 L
s
.99625 .38914 m
1 .38914 L
s
.99625 .42909 m
1 .42909 L
s
.99625 .44907 m
1 .44907 L
s
.99625 .46905 m
1 .46905 L
s
.99625 .48903 m
1 .48903 L
s
.99625 .52899 m
1 .52899 L
s
.99625 .54896 m
1 .54896 L
s
.99625 .56894 m
1 .56894 L
s
.99625 .58892 m
1 .58892 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30922 m
1 .30922 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .30922 m
.02847 .26492 L
.03355 .21661 L
.03602 .19312 L
.03723 .18166 L
.03832 .17124 L
.03887 .16604 L
.03916 .1633 L
.03932 .1618 L
.03946 .1604 L
.03959 .15918 L
.03973 .47169 L
.03988 .47023 L
.04002 .46889 L
.04054 .46398 L
.04291 .44142 L
.0477 .39589 L
.05231 .3521 L
.05721 .3055 L
.06193 .26064 L
.06434 .23774 L
.06694 .21296 L
.06817 .20133 L
.06946 .18904 L
.07056 .17855 L
.07087 .17567 L
.07103 .17409 L
.07119 .17259 L
.07134 .1712 L
.0715 .4835 L
.07164 .48212 L
.07178 .48085 L
.07651 .43583 L
.08106 .39256 L
.08591 .34647 L
.09058 .30212 L
.09554 .25496 L
.09802 .23143 L
.10032 .20954 L
.10146 .19868 L
.10254 .18842 L
.10283 .18567 L
.10299 .18416 L
.10314 .18275 L
.10322 .49584 L
.1033 .49505 L
.10348 .49337 L
.10379 .49042 L
.10492 .47968 L
.10989 .43237 L
Mistroke
.11469 .3868 L
.1193 .34297 L
.12421 .29633 L
.12894 .25144 L
.13135 .2285 L
.13262 .21645 L
.13331 .20987 L
.13396 .20373 L
.13454 .19821 L
.1347 .19662 L
.13486 .19512 L
.135 .50759 L
.13516 .50612 L
.13648 .4936 L
.13879 .47159 L
.14372 .4248 L
.14846 .37976 L
.15302 .33646 L
.15788 .29035 L
.16255 .24598 L
.16497 .22299 L
.16556 .2174 L
.16619 .21143 L
.16637 .20967 L
.16646 .2088 L
.16655 .208 L
.1667 .52033 L
.16679 .51954 L
.16688 .51871 L
.16752 .51263 L
.17209 .46919 L
.17696 .42294 L
.18165 .37844 L
.18664 .33113 L
.19144 .28556 L
.19363 .26474 L
.19488 .25288 L
.19606 .24174 L
.1972 .23087 L
.19752 .22789 L
.19785 .22475 L
.19813 .22207 L
.19821 .22134 L
.19829 .22055 L
.19844 .53296 L
.19852 .53217 L
.19861 .53134 L
.19876 .52985 L
.19912 .52649 L
.19976 .52037 L
Mistroke
.20097 .50893 L
.20554 .46562 L
.2104 .41952 L
.21508 .37515 L
.22005 .32799 L
.22484 .28257 L
.22726 .25965 L
.22831 .24968 L
.22945 .23889 L
.22976 .23595 L
.22993 .23435 L
.23009 .23285 L
.23022 .5454 L
.23037 .54403 L
.23067 .54112 L
.23182 .53021 L
.23435 .50624 L
.23934 .45896 L
.24415 .41342 L
.24878 .36962 L
.2537 .32304 L
.25614 .2999 L
.25844 .2782 L
.26063 .25745 L
.26123 .25177 L
.26156 .24867 L
.26172 .24716 L
.26186 .24579 L
.262 .55834 L
.26212 .55714 L
.2624 .5545 L
.26299 .54892 L
.26763 .50502 L
.27257 .45833 L
.27733 .41339 L
.2819 .37019 L
.28676 .32422 L
.28901 .30305 L
.29145 .27999 L
.29209 .27392 L
.29278 .26747 L
.29311 .26433 L
.29327 .26279 L
.29342 .26138 L
.29356 .26009 L
.2937 .57255 L
.29385 .57119 L
.294 .56969 L
.29643 .54681 L
.30131 .50074 L
Mistroke
.30601 .45642 L
.31101 .40934 L
.31583 .36401 L
.32046 .32043 L
.3228 .29838 L
.32405 .28668 L
.32473 .28023 L
.32507 .27705 L
.32523 .2755 L
.32538 .27409 L
.32554 .58648 L
.32568 .58513 L
.326 .58217 L
.32666 .57589 L
.32783 .5649 L
.33013 .54333 L
.33478 .49969 L
.33972 .45332 L
.34448 .4087 L
.34906 .36584 L
.35161 .342 L
.35393 .32026 L
.35509 .30948 L
.35569 .3038 L
.35634 .29776 L
.35661 .29522 L
.3569 .29249 L
.35699 .29173 L
.35707 .29093 L
.35723 .60332 L
.35737 .60198 L
.35753 .60051 L
.35862 .59026 L
.36351 .54465 L
.36822 .5008 L
.37322 .45428 L
.37805 .40953 L
.38268 .36657 L
.38762 .32097 L
.39237 .27716 L
.39693 .23515 L
.4018 .19056 L
.40648 .14778 L
.41146 .10248 L
.41394 .07992 L
.41625 .05903 L
.41848 .03887 L
.41913 .03307 L
.41973 .02762 L
.42027 .02273 L
Mistroke
.42042 .02139 L
.42058 .01997 L
.42071 .33259 L
.42086 .33126 L
.42574 .28749 L
.43044 .24561 L
.43543 .20142 L
.44024 .15921 L
.44487 .11898 L
.44721 .09877 L
.44979 .07662 L
.45097 .06657 L
.45159 .0613 L
.45193 .05844 L
.45209 .05704 L
.45224 .05577 L
.45238 .05456 L
.45252 .36724 L
.45266 .36604 L
.45281 .36474 L
.45344 .35944 L
.45453 .35017 L
.45947 .30878 L
.46423 .26955 L
.4688 .23245 L
.47367 .19367 L
.47836 .15706 L
.48075 .13869 L
.482 .12907 L
.48269 .12381 L
.48334 .11888 L
.48362 .11678 L
.48391 .11457 L
.48407 .11341 L
.48415 .42658 L
.48423 .42597 L
.48453 .42374 L
.48584 .41388 L
.48814 .39659 L
.49285 .36171 L
.49785 .32499 L
.50266 .28972 L
.5073 .25567 L
.50964 .23832 L
.51223 .21909 L
.51341 .21025 L
.51406 .20536 L
.51468 .2007 L
.51525 .19638 L
.51541 .19519 L
Mistroke
.51558 .19393 L
.51573 .19274 L
.51588 .50547 L
.51602 .5044 L
.51615 .50342 L
.51644 .5012 L
.51697 .49716 L
.52174 .46064 L
.52632 .42486 L
.53119 .38603 L
.53589 .34795 L
.54088 .30677 L
.54337 .28591 L
.54447 .27668 L
.54568 .26647 L
.54624 .26176 L
.54684 .25668 L
.54711 .25434 L
.54726 .25307 L
.5474 .25188 L
.54752 .25086 L
.54765 .5636 L
.54779 .56239 L
.54792 .56129 L
.55031 .54099 L
.55513 .49949 L
.55977 .45915 L
.5647 .41583 L
.56946 .37376 L
.57403 .33303 L
.57657 .31026 L
.57778 .29944 L
.57836 .29417 L
.57889 .28939 L
.57903 .28815 L
.57918 .28681 L
.57932 .28555 L
.57945 .5982 L
.57959 .59696 L
.57974 .59561 L
.58004 .59287 L
.5813 .58157 L
.58358 .56098 L
.58846 .51673 L
.59316 .47396 L
.59815 .42832 L
.60297 .38419 L
.6076 .34161 L
.61252 .29619 L
.61727 .25235 L
Mistroke
.62183 .21011 L
.62668 .16504 L
.63135 .12159 L
.63632 .07531 L
.6388 .05218 L
.64001 .04091 L
.64111 .03067 L
.64166 .02553 L
.64226 .01997 L
.64253 .01742 L
.64268 .01602 L
.64282 .01472 L
.64294 .32742 L
.64307 .32623 L
.64334 .3237 L
.64571 .3015 L
.6507 .25488 L
.6555 .20992 L
.66012 .16663 L
.66504 .12052 L
.66977 .07608 L
.67214 .05379 L
.67318 .04402 L
.67377 .03848 L
.67405 .03583 L
.67432 .03333 L
.67446 .03203 L
.67461 .34445 L
.67474 .34317 L
.67487 .34199 L
.67545 .33648 L
.67665 .32523 L
.67916 .30158 L
.68391 .2569 L
.68848 .2139 L
.69334 .16809 L
.69802 .12398 L
.7004 .10154 L
.703 .07706 L
.7042 .0657 L
.70486 .05947 L
.70548 .0536 L
.70576 .05093 L
.70606 .04812 L
.70622 .04664 L
.70631 .04581 L
.70639 .35885 L
.70654 .35748 L
.70669 .35601 L
.70779 .34566 L
Mistroke
.71278 .29853 L
.71759 .25312 L
.72221 .20941 L
.72714 .16289 L
.73188 .11808 L
.73425 .09559 L
.73643 .07499 L
.73702 .06941 L
.73757 .06422 L
.73785 .0616 L
.738 .06014 L
.73814 .37263 L
.7383 .37116 L
.73846 .36958 L
.73877 .36671 L
.74128 .3429 L
.74622 .29616 L
.75098 .25115 L
.75555 .20785 L
.76042 .16174 L
.7651 .11735 L
.76633 .10576 L
.76766 .09313 L
.76827 .08735 L
.76892 .0812 L
.76923 .07821 L
.76953 .0754 L
.76966 .07417 L
.7698 .07287 L
.76995 .38527 L
.77008 .38397 L
.77467 .34047 L
.77956 .29417 L
.78426 .24958 L
.78926 .20219 L
.79407 .15652 L
.79871 .11258 L
.79994 .10086 L
.80055 .09513 L
.8011 .08989 L
.80124 .08854 L
.8014 .08706 L
.80154 .08567 L
.80168 .39819 L
.80184 .39669 L
.80198 .39532 L
.80231 .39226 L
.80363 .37965 L
.80847 .3338 L
.81311 .28969 L
Mistroke
.81806 .24276 L
.82282 .19756 L
.8274 .15409 L
.82995 .12988 L
.83116 .11841 L
.83227 .10781 L
.83283 .10249 L
.83312 .09981 L
.83319 .09908 L
.83328 .09828 L
.83343 .41067 L
.83358 .40922 L
.83375 .40764 L
.83408 .40445 L
.83468 .39875 L
.83697 .37707 L
.84186 .33063 L
.84657 .28591 L
.85157 .23838 L
.85639 .19259 L
.86103 .14852 L
.86343 .12575 L
.86401 .12022 L
.86464 .11427 L
.86482 .11253 L
.86491 .11166 L
.86499 .11086 L
.86515 .42319 L
.86523 .42241 L
.86532 .42157 L
.86596 .41546 L
.87099 .36776 L
.87582 .3218 L
.88048 .27757 L
.88543 .23052 L
.8902 .18521 L
.8926 .1624 L
.89478 .14163 L
.89536 .13612 L
.89599 .13012 L
.89628 .12738 L
.89644 .12587 L
.89659 .12446 L
.89672 .12327 L
.89685 .4358 L
.897 .43436 L
.89714 .43305 L
.89966 .40907 L
.90445 .36359 L
.90905 .31985 L
Mistroke
.91395 .2733 L
.91866 .22849 L
.92367 .18086 L
.92619 .15697 L
.92729 .14649 L
.92787 .14093 L
.92819 .13787 L
.92835 .13636 L
.9285 .13497 L
.92864 .44744 L
.92879 .44601 L
.92911 .44299 L
.92967 .4377 L
.93076 .42733 L
.93314 .40463 L
.93769 .3614 L
.94254 .31534 L
.9472 .27103 L
.95216 .2239 L
.95463 .2004 L
.95693 .17851 L
.95807 .16767 L
.95915 .15742 L
.95975 .15175 L
.95991 .1502 L
.96008 .14856 L
.96023 .14715 L
.96031 .14635 L
.96039 .45942 L
.96054 .45804 L
.96068 .45672 L
.96094 .45425 L
.96152 .44868 L
.96613 .40487 L
.97103 .35825 L
.97575 .31337 L
.97619 .30922 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.05556 .30922 m
.05556 .32123 L
s
.0873 .30922 m
.0873 .33327 L
s
.11905 .30922 m
.11905 .34538 L
s
.15079 .30922 m
.15079 .35761 L
s
.18254 .30922 m
.18254 .37 L
s
.21429 .30922 m
.21429 .38264 L
s
.24603 .30922 m
.24603 .39562 L
s
.27778 .30922 m
.27778 .40911 L
s
.30952 .30922 m
.30952 .42336 L
s
.34127 .30922 m
.34127 .43879 L
s
.37302 .30922 m
.37302 .45622 L
s
.40476 .30922 m
.40476 .16346 L
s
.43651 .30922 m
.43651 .19194 L
s
.46825 .30922 m
.46825 .23687 L
s
.5 .30922 m
.5 .30922 L
s
.53175 .30922 m
.53175 .38158 L
s
.56349 .30922 m
.56349 .4265 L
s
.59524 .30922 m
.59524 .45498 L
s
.62698 .30922 m
.62698 .16223 L
s
.65873 .30922 m
.65873 .17965 L
s
.69048 .30922 m
.69048 .19509 L
s
.72222 .30922 m
.72222 .20933 L
s
.75397 .30922 m
.75397 .22282 L
s
.78571 .30922 m
.78571 .2358 L
s
.81746 .30922 m
.81746 .24844 L
s
.84921 .30922 m
.84921 .26084 L
s
.88095 .30922 m
.88095 .27306 L
s
.9127 .30922 m
.9127 .28517 L
s
.94444 .30922 m
.94444 .29721 L
s
.97619 .30922 m
.97619 .30922 L
s
.015 w
.05556 .32123 Mdot
.0873 .33327 Mdot
.11905 .34538 Mdot
.15079 .35761 Mdot
.18254 .37 Mdot
.21429 .38264 Mdot
.24603 .39562 Mdot
.27778 .40911 Mdot
.30952 .42336 Mdot
.34127 .43879 Mdot
.37302 .45622 Mdot
.40476 .16346 Mdot
.43651 .19194 Mdot
.46825 .23687 Mdot
.5 .30922 Mdot
.53175 .38158 Mdot
.56349 .4265 Mdot
.59524 .45498 Mdot
.62698 .16223 Mdot
.65873 .17965 Mdot
.69048 .19509 Mdot
.72222 .20933 Mdot
.75397 .22282 Mdot
.78571 .2358 Mdot
.81746 .24844 Mdot
.84921 .26084 Mdot
.88095 .27306 Mdot
.9127 .28517 Mdot
.94444 .29721 Mdot
.97619 .30922 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00=?ooool3o`0002gooooo1Ol0000]ooooo`;o0000;_ooool5o`0002oooooo0ol0000Soooo
o`00=Oooool00ol0003oooooooooo`0]ooooo`04o`000?ooooooooooo`0002cooooo00Co0000oooo
oooooooo0000;_ooool01?l0003oooooooooool0000`ooooo`03o`000?oooooooooo02;ooooo000/
ooooo`Go000000?oooooo`000?l000000ol0000Wooooo`Go00000oooool00ol0003oooooooooo`0/
ooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool0;Oooool5o`0002?ooooo000b
ooooo`04o`000?ooooooooooo`00037ooooo00?o0000ooooooooool0:oooool01?l0003ooooooooo
ool0000`ooooo`03o`000?oooooooooo02cooooo00Co0000oooooooooooo00009?ooool003?ooooo
00?o0000ooooool00000;_ooool01Ol0003ooooooooooooooooo000002cooooo00Co0000oooooooo
oooo0000;Oooool01Ol0003ooooooooooooooooo000002kooooo00?o0000ooooool000009?ooool0
03Cooooo0_l0000^ooooo`05o`000?ooooooooooooooool00000;?ooool01?l0003oooooooooool0
000]ooooo`05o`000?ooooooooooooooool00000;oooool2o`0002Cooooo000eooooo`03o`000?oo
oooooooo02gooooo0ol0000^ooooo`;o0000;oooool3o`00037ooooo00?o0000ooooooooool08_oo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool000_ooooo0ol0
0005oooooooo00002Ol00005ooooo`002_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`001?ooool5o`0000Gooooo00?o0000
ooooooooool00_ooool3o`00087ooooo00?o0000ooooooooool0O_ooool3o`0000Gooooo000<oooo
o`;o00001Oooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo083ooooo00?o0000oooo
ooooool00oooool000kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`21ooooo`03
o`000?oooooooooo02;ooooo00?o003oooooooooool0Foooool00ol0003oooooooooo`03ooooo`00
2_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0POooool00ol0003o
ooooooooo`0Rooooo`03o`00oooooooooooo05_ooooo00?o0000ooooooooool00oooool000_ooooo
0ol00005ooooo`03o`000?oooooooooo06cooooo00?o003oooooooooool04_ooool00ol0003ooooo
ooooo`20ooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo06cooooo00?o
003oooooooooool04_ooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo00?ooooo000C
ooooo`;o0000K?ooool2o`00oaCooooo00?o0000ooooooooool08_ooool00ol00?ooooooooooo`1J
ooooo`;o00001Oooool001?ooooo00?o0000ooooooooool0Joooool2o`00oaCooooo00?o0000oooo
ooooool08_ooool00ol00?ooooooooooo`1Kooooo`03o`000?oooooooooo00?ooooo000Cooooo`03
o`000?oooooooooo06_ooooo00?o003oooooooooool04oooool00ol0003oooooooooo`0Qooooo`;o
003o1oooool00ol00?ooooooooooo`1Cooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`00
0?oooooooooo06cooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`0Zooooo`03o`00
oooooooooooo05?ooooo00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool0K?oo
ool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo02[ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`1:ooooo`03o`000?oooooooooo00?ooooo000Cooooo`;o0000K?ooool2
o`00oaCooooo00?o0000ooooooooool08Oooool2o`00oa3ooooo00?o003oooooooooool0BOooool2
o`0000Gooooo000Cooooo`03o`000?oooooooooo06_ooooo0_l00?l7ooooo`03o`00oooooooooooo
00[ooooo00?o0000ooooooooool08Oooool2o`00oa3ooooo00?o003oooooooooool0B_ooool00ol0
003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`1[ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool02_ooool00ol0003oooooooooo`0Qooooo`;o003o1oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo04[ooooo00?o0000ooooooooool00oooool001?ooooo
00?o0000ooooooooool0M?ooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo027ooooo
0_l00?l7ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`12ooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo06cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo02Wooooo0_l0
0?l7ooooo`;o003o1oooool00ol00?ooooooooooo`12ooooo`03o`000?oooooooooo00?ooooo000C
ooooo`;o0000Joooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00[ooooo00?o0000
ooooooooool08Oooool2o`00o`Oooooo00?o003oooooooooool01Oooool2o`00o`Oooooo00?o003o
ooooooooool0@Oooool2o`0000Gooooo000Cooooo`03o`000?oooooooooo06[ooooo00?o003ooooo
ool00?l01_ooool2o`00o`cooooo00?o0000ooooooooool08Oooool2o`00o`oooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo03Wooooo00?o0000oooo
ooooool00oooool001?ooooo00?o0000ooooooooool0J_ooool00ol00?ooooooooooo`06ooooo`;o
003o3?ooool00ol0003oooooooooo`0Pooooo`03o`00oooooooo003o00Kooooo0_l00?l8ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool2o`00oc_ooooo00?o0000oooooooo
ool00oooool001?ooooo00?o0000ooooooooool0J_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00_ooooo00?o0000ooooooooool08?ooool00ol00?ooooooo`00o`06ooooo`;o003o
2?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
>Oooool00ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`1/ooooo`03o`00oooo
oooooooo00Cooooo0_l00?l<ooooo`03o`000?oooooooooo02Wooooo0_l00?l7ooooo`;o003o1ooo
ool00ol00?ooooooooooo`12ooooo`03o`000?oooooooooo00?ooooo000Cooooo`;o0000Joooool0
0ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool08?ooool0
0ol00?ooooooo`00o`06ooooo`;o003o1oooool2o`00o`Kooooo00?o003oooooooooool01_ooool2
o`00o`Oooooo00?o003oooooooooool0<?ooool2o`0000Gooooo000Cooooo`03o`000?oooooooooo
06[ooooo00?o003oooooool00?l01_ooool2o`00o`cooooo00?o0000ooooooooool08?ooool00ol0
0?ooooooo`00o`0>ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool2o`00
o`Oooooo00?o003oooooooooool0<Oooool00ol0003oooooooooo`03ooooo`004oooool00ol0003o
ooooooooo`1Yooooo`03o`00oooooooooooo00Oooooo0_l00?l<ooooo`03o`000?oooooooooo023o
oooo00?o003oooooool00?l01_ooool2o`00oa3ooooo00?o003oooooooooool01Oooool2o`00o`Oo
oooo00?o003oooooooooool0<Oooool00ol0003oooooooooo`03ooooo`002_ooool5o`0000Cooooo
00?o0000ooooooooool0JOooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo
00?o0000ooooooooool08?ooool00ol00?ooooooo`00o`06ooooo`;o003o2?ooool00ol00?oooooo
ooooo`04ooooo`;o003o2?ooool00ol00?ooooooooooo`04ooooo`;o003o1oooool00ol00?oooooo
ooooo`0Yooooo`03o`000?oooooooooo00?ooooo000;ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0K?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00_ooooo
00?o0000ooooooooool0:?ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Kooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02Wooooo
00?o0000ooooooooool00oooool000Cooooo1Ol00003ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0JOooool01?l00?ooooooooooool00?l7ooooo`03o`00oooooooooooo00[ooooo
00?o0000ooooooooool0:?ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Kooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0jooooo`03o`000?oooooooooo00?ooooo
000=ooooo`03o`000?oooooooooo00?ooooo0ol0001Yooooo`04o`00ooooooooooooo`00o`Oooooo
00?o003oooooooooool02_ooool00ol0003oooooooooo`0Oooooo`04o`00ooooooooooooo`00o`ko
oooo00?o003oooooooooool01_ooool2o`00o`Oooooo0_l00?l6ooooo`;o003o1oooool00ol00?oo
ooooooooo`0Wooooo`?o00001Oooool000[ooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo06Wooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`07oooo
o`03o`00oooooooooooo00;ooooo00?o0000ooooooooool07oooool01?l00?ooooooooooool00?l5
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooo003o00Kooooo0_l00?l7ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool08?ooool00ol0003oooooooooo`03ooooo`002_ooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool0JOooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`0Oooooo`04o`00oooooooo
ooooo`00o`Gooooo00?o003oooooool00?l02?ooool00ol00?ooooooooooo`04ooooo`;o003o2?oo
ool00ol00?ooooooooooo`04ooooo`;o003o1oooool00ol00?ooooooooooo`05ooooo`;o003o8_oo
ool00ol0003oooooooooo`03ooooo`002oooool3o`0000Gooooo00?o0000ooooooooool0K?ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool00_ooool0
0ol0003oooooooooo`0Xooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l01_ooool2
o`00o`oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`;o003o8_ooool0
0ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`1/ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo
02Sooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool06?ooool00ol0003oooooooooo`03ooooo`004oooool2o`0006Wo
oooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool00_ooool00ol0003oooooooooo`0Oooooo`04o`00ooooooooooooo`00o`gooooo00Co003o
oooooooooooo003o1Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Oooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01Oooooo0_l0
0005ooooo`004oooool00ol0003oooooooooo`1Xooooo`05o`00ooooooooooooooooool00?l01Ooo
ool00ol00?ooooooo`00o`0<ooooo`03o`000?oooooooooo01oooooo00Co003ooooooooooooo003o
3Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l0
1_ooool2o`00o`Kooooo0_l00?l8ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
6?ooool00ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`1Xooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooool00?l01oooool00ol00?ooooooooooo`02ooooo`03o`000?oo
oooooooo01oooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`08ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`06ooooo`;o003o
1_ooool2o`00o`Oooooo0_l00?l7ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
4?ooool00ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`1aooooo`03o`00oooo
oooooooo00Oooooo0_l00?l4ooooo`03o`000?oooooooooo02;ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l0
2?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Kooooo0_l00?l7ooooo`;o003o
1oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool0
0oooool001?ooooo00?o0000ooooooooool0K?ooool00ol00?ooooooooooo`02ooooo`04o`00oooo
ooooooooo`00o`Kooooo0_l00?l4ooooo`03o`000?oooooooooo02Oooooo00Co003ooooooooooooo
003o1Oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool04?ooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo013ooooo00?o0000ooooooooool00oooool001?ooooo0_l0001Yooooo`05
o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00?ooooo00?o0000ooooooooool07_ooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003o
ooooooooool00oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00Gooooo00Co
003ooooooooooooo003o1oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo
0_l00005ooooo`004oooool00ol0003oooooooooo`1Xooooo`05o`00ooooooooooooooooool00?l0
1?ooool01?l00?ooooooooooool00?l6ooooo`03o`00oooooooooooo00?ooooo00?o0000oooooooo
ool07_ooool01Ol00?oooooooooooooooooo003o00gooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01_ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Cooooo0_l00?l7ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01oooool00ol0003oooooooooo`03ooooo`004oooool00ol0
003oooooooooo`1Xooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooooooo003o1oooool0
0ol00?ooooooooooo`02ooooo`03o`000?oooooooooo01kooooo00Go003oooooooooooooooooo`00
o`04ooooo`04o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`03ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01_ooool2o`00o`Ko
oooo00?o003oooooool00?l01oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Go
oooo0_l00?l9ooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo00Oooooo
00?o003oooooooooool0G?ooool3ool000Sooooo00?o003oooooooooool01oooool2o`00o`Cooooo
00?o0000ooooooooool07Oooool3ool000;ooooo00?o003oooooooooool00_ooool01?l00?oooooo
ooooool00?l8ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o2?ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool00ol0
0?ooooooo`00o`07ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool2o`00
o`Wooooo00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool01oooool00ol00?oo
ooooooooo`1Looooo`?oo`000oooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00
o`Kooooo0_l00?l4ooooo`03o`000?oooooooooo01gooooo0ooo0007ooooo`04o`00oooooooooooo
o`00o`Gooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo013ooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`06ooooo`;o003o1ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool00ooo
ool001?ooooo0_l00008ooooo`03o`00oooooooooooo05cooooo0ooo0003ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooo
oooo01gooooo0ooo0007ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooooooooooooooo
o`00o`04ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool2o`00o`Oooooo
00?o003oooooooooool01oooool2o`0000Gooooo000Cooooo`03o`000?oooooooooo00Oooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`1Dooooo`03o`00oooo003ooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
1?ooool00ol0003oooooooooo`0Nooooo`05ool00?ooooooooooooooool00?l03?ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l5ooooo`03o`00oooooooooooo00kooooo00?o003oooooool00?l01_ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool00oooool0
01?ooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
05Cooooo00?o003oool00?ooool01_ooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003o
ooooooooool00_ooool00ol0003oooooooooo`0Mooooo`03o`00oooo003ooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool00ooo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool0
0?l02?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00oooooo0_l00?l9ooooo`03
o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`1Dooooo`03o`00oooo003ooooo00Kooooo00?o003oooooooooool0
1oooool00ol00?ooooooo`00o`04ooooo`03o`000?oooooooooo01gooooo00?o003oool00?ooool0
0_ooool00ol00?ooooooooooo`03ool000;ooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`02ooooo`04o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool00_ooool01?l00?oo
ooooooooool00?l5ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l01oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo0_l00?l9ooooo`03o`000?oooooooooo
00?ooooo000Cooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`1Fooooo`05ool00?ooooooooooooooool00?l00oooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooo003o00Cooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`04oooo
o`?oo`000_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool0
0ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Kooooo00?o003oooooool00?l01_ooool0
0ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?l8ooooo`03o`00oooooooo
oooo00Oooooo00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool01oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0C?ooool00ol0
0?ooo`00ooooo`02ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00oooool00ol0
0?ooooooo`00o`04ooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool01?ooool3ool0
00;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`;o003o1_ooool00ol00?ooooooooooo`09
ooooo`03o`000?oooooooooo00?ooooo000Cooooo`;o00002?ooool00ol00?ooooooooooo`05oooo
o`;o003o1oooool00ol00?ooooooooooo`1<ooooo`03o`00oooo003ooooo00;ooooo00?o003ooooo
oooo00000_oo0003ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol0
003oooooooooo`0Mooooo`03o`00oooo003ooooo00;ooooo00Go003oooooooooooooooooool00008
ooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooo003o00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`08ooooo`;o
00001Oooool001?ooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`05ooooo`;o003o
1oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04?ooooo00?o003oool00?ooool0
0_ooool00ol00?ooooooool00002ool000?ooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`02ooooo`05o`000?ooooooooooooooool00?l06oooool00ol00?ooo`00ooooo`02ooooo`05
o`00oooooooooooooooooooo00001_ooool3ool000_ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00
o`08ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00
o`09ooooo`03o`000?oooooooooo00?ooooo000;ooooo`?o00001Oooool00ol0003oooooooooo`06
ooooo`;o003o2?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo0_l00?m5
ooooo`03o`00oooo003ooooo00Cooooo0ooo000;ooooo`03o`00oooooooooooo00;ooooo00?o0000
ooooooooool00_l00?lKooooo`03o`00oooo003ooooo00;ooooo00Go003oooooooooooooooooool0
0003ooooo`03o`00oooooooooooo00?oo`000oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1Oooool01?l00?ooooooooooool00?l7ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`09ooooo`03o`000?oooooo
oooo00?ooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool2o`00
o`Oooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`15ooooo`05ool00?oooooooooo
ooooool00?l00oooool00ooo003oooooooooo`06ooooo`04o`00ooooooooooooo`00o`Cooooo00Go
0000ooooooooooooooooo`00o`0Looooo`03ool00?oooooooooo00Gooooo00Goo`00oooooooooooo
ooooo`00o`02ooooo`?oo`000oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`05ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003o
oooooooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Sooooo00?o
003oooooooooool01oooool00ol0003oooooooooo`03ooooo`001?ooool5o`0000?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04Cooooo00Goo`00
ooooooooooooooooo`00o`03ooooo`05ool00?ooooooooooooooool00?l01?ooool01?l00?oooooo
ooooool00?l4ooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool01Oooool01Ooo003o
oooooooooooooooo003o00?ooooo00?o003oool00?ooool00_ooool00ol00?ooooooooooo`03ool0
00Oooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`03ooooo`04o`00oooooooooooo
o`00o`Gooooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`08ooooo`03o`00oooooooo
oooo00Oooooo00?o0000ooooooooool00oooool000cooooo00?o0000ooooooooool01?ooool3o`00
00Oooooo00?o003oooooooooool01Oooool2o`00o`Kooooo0_l00?l8ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool0>_ooool00ol00?ooooooool00003ooooo`05o`00oooooooooooo
oooooooo00000oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00Co0000
oooooooooooo003o7?ooool00ol00?ooo`00ooooo`02ooooo`05o`00oooooooooooooooooooo0000
1oooool00ol00?ooo`00ooooo`02ooooo`03o`00oooooooooooo00?oo`000_ooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool01_ooool00ol00?ooooooo`00o`06ooooo`03
o`00oooooooooooo00Oooooo0ol00005ooooo`003?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Oooooo00?o003oooooooooool01Oooool2o`00o`Kooooo0_l00?l7ooooo`;o003o
1oooool00ol00?ooooooooooo`0jooooo`03o`00ooooooooo`0000?ooooo00Go003ooooooooooooo
003oool00003ooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool00_l00?lKooooo`03
o`00oooo003ooooo00;ooooo00Go003oooooooooooooooooool00007ooooo`03o`00oooo003ooooo
00Gooooo0ooo0002ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l8ooooo`03o`00
oooooooooooo00;ooooo00Co003ooooooooooooo003o3_ooool00ol00?ooooooo`00o`09ooooo`03
o`000?oooooooooo00?ooooo000;ooooo`;o00001_ooool00ol0003oooooooooo`06ooooo`;o003o
2?ooool00ol00?ooooooooooo`04ooooo`;o003o1oooool2o`00o`Oooooo00?o003oooooooooool0
>_ooool00ol00?ooooooool00006ooooo`03o`00oooo003ooooo00;ooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00;o003o6_ooool00ol00?oooooo
ool00003ooooo`05o`00ooooooooooooo`00oooo00000oooool00ol00?ooooooooooo`02ooooo`05
ool00?ooooooooooooooool00?l00oooool01Ooo003ooooooooooooooooo003o00Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?oooooo
ooooool00?l5ooooo`04o`00ooooooooooooo`00o`Oooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooo003o00Wooooo00?o0000ooooooooool00oooool000co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`;o003o3oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Gooooo0_l00?lnooooo`03ool00?oooooooooo00Co
oooo00?o003oool00?ooool01oooool01?l00?ooooooooooool00?l4ooooo`03o`000?oooooooooo
00;o003o7?ooool01Ooo003ooooooooooooooooo003o00;ooooo00?o003oool00?ooool00_ooool0
1_l00?oooooooooooooooooo003oool000?ooooo00Go003oooooooooooooooooool00003ooooo`03
o`00oooooooooooo00?oo`000oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Oooooo00?o
003oooooooooool00oooool00ol00?ooooooo`00o`08ooooo`03o`00oooooooooooo00Oooooo00?o
0000ooooooooool00oooool001?ooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03Oooool2o`00o`Oooooo00?o003o
ooooooooool0=?ooool01Ooo003ooooooooooooooooo003o00?ooooo00Goo`00oooooooooooooooo
o`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00?o0000ooooooooool07_ooool00ooo003o
ooooooooo`04ooooo`03o`00oooo003ooooo00;ooooo00Ko003oooooooooooooooooo`00oooo0003
ooooo`05o`00ooooooooooooo`00oooo00001_ooool3ool001?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool01_ooool00ol00?oooooo
o`00o`08ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool00oooool001?ooooo0_l0
0007ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l01_ooool2o`00o`Sooooo00?o
003oooooooooool01?ooool2o`00o`Oooooo00?o003oooooooooool0<_ooool00ol00?ooooooool0
0003ooooo`05o`00oooooooooooooooooooo00000oooool01Ol00?oooooooooooooooooo003o00So
oooo00?o0000ooooool00?l07?ooool00ol00?ooooooool00003ooooo`05o`00oooooooooooooooo
oooo00000oooool01_l00?oooooooooooooooooo003oool000?ooooo00Go003ooooooooooooo003o
ool00006ooooo`?oo`000oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo003o00Gooooo
00?o003oooooooooool02Oooool2o`0000Gooooo000Cooooo`03o`000?oooooooooo00Oooooo00?o
003oooooooooool01?ooool00ol00?ooooooo`00o`06ooooo`;o003o1_ooool00ol00?ooooooo`00
o`07ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0<_ooool00ol00?ooooooool0
0003ooooo`05o`00ooooooooooooo`00oooo00000oooool00ol00?ooooooooooo`0:ooooo`05o`00
0?oooooo003oooooool00?l06_ooool00ol00?ooooooool00003ooooo`05o`00oooooooooooooooo
oooo00001oooool00ol00?ooo`00ooooo`06ooooo`05ool00?ooooooooooooooool00?l00oooool0
0ooo003oooooooooo`02ooooo`03o`00ooooooooo`0000;oo`000oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool0
0?l5ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o2Oooool00ol0003ooooo
ooooo`03ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`00oooooooo003o00Sooooo00?o
003oooooooooool01?ooool2o`00o`Kooooo00?o003oooooool00?l01oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0:?ooool01?l00?oooooooooo
oooo0006ooooo`03o`00oooo003ooooo00;ooooo00?o003oooooooooool00ooo0002ooooo`03o`00
oooooooooooo00;ooooo00Go0000ooooool00?ooooooo`00o`0Jooooo`03o`00ooooooooo`0000?o
oooo00Go003ooooooooooooo003oool00003ooooo`03o`00oooooooooooo00;ooooo00?oo`00oooo
ooooool01Oooool01Ooo003ooooooooooooooooo003o00?ooooo00?oo`00ooooooooool00_ooool0
0ol00?ooooooool00002ool000?ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool0
0?l4ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00?ooooo00Co003ooooooooooooo003o2Oooool00ol0003oooooooooo`03ooooo`00
4oooool00ol0003oooooooooo`05ooooo`03o`00oooooooo003o00Sooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
3_ooool2o`00obgooooo00?oo`00ooooooooool00oooool00ol00?ooooooool00006ooooo`?oo`00
0_ooool00ol00?ooooooooooo`02ooooo`05o`000?oooooo003oooooool00?l06_ooool00ol00?oo
ooooool00003ooooo`05o`00ooooooooooooo`00oooo00000oooool00ol00?ooooooooooo`02oooo
o`05ool00?ooooooooooooooool00?l00_ooool00ol00?ooo`00ooooo`02ooooo`05o`00oooooooo
oooooooooooo00001?ooool00ol00?ooooooool00002ool000?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`07ooooo`03
o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o2?ooool00ol00?ooooooooooo`07oooo
o`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo00Gooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo0_l00?l]ooooo`09
ool00?ooooooooooooooool00?ooooooo`00ooooooooo`0000?ooooo00?o003oooooooooool00ooo
0002ooooo`03o`00oooooooooooo00;ooooo00Go0000ooooooooooooooooo`00o`0Looooo`03ool0
0?oooooooooo00?ooooo00?o003ooooooooo00000oooool01_l00?ooooooooooool00?ooooooool0
00?ooooo00Go003ooooooooooooo003oool00007ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool02Oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Sooooo00?o003ooooooooo
ool01oooool00ol0003oooooooooo`03ooooo`004oooool2o`0000Kooooo00?o003oooooooooool0
1_ooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
1?ooool2o`00o`Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo023ooooo00Co003oooooooooooooo`000oooool01Ol00?ooooooooooooooooooo`00
00?ooooo00Go003oooooooooooooooooool00008ooooo`03o`000?oooooo003o01_ooooo00Co003o
ooooooooooooo`001oooool01Ooo003ooooooooooooooooo003o00;ooooo00?o003ooooooooo0000
0oooool01Ol00?ooooooooooool00?ooo`0000Oooooo00?oo`00ooooooooool01_ooool01Ooo003o
oooooooooooooooo003o00;ooooo0ooo0007ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool01Oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00Wooooo0_l00005
ooooo`004oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Oooooo00?o003ooooo
ooooool01?ooool2o`00o`Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Poooo
o`04o`00ooooooooooooool000?ooooo00Go003oooooool00?ooooooool00003ooooo`05o`00oooo
oooooooooooooooo00002?ooool01Ol0003oooooo`00oooooooo003o00Oooooo00?o003ooooooooo
ool03oooool01?l00?oooooooooooooo0003ooooo`05o`00oooooooooooooooooooo00001_ooool0
0ol00?ooooooool00007ooooo`05ool00?ooooooooooooooool00?l00oooool00ooo003ooooooooo
o`02ooooo`05o`00ooooooooooooo`00oooo00000oooool00ol00?ooooooooooo`03ool000oooooo
00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool02_ooool00ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`00
oooooooo003o00Sooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`06ooooo`03o`00
oooooooo003o00Oooooo00?o003oooooooooool01?ooool2o`00o`Sooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`0Pooooo`04o`00ooooooooooooool000?ooooo00Go003oooooool0
0?ooooooool00003ooooo`05o`00oooooooooooooooooooo00000oooool00ol00?ooooooooooo`02
ooooo`05o`000?oooooo003oooooool00?l01oooool00ol00?ooooooooooo`0?ooooo`04o`00oooo
ooooooooool000?ooooo00Go003oooooool00?ooooooool00008ooooo`03ool00?oooooooooo00Go
oooo00Goo`00ooooooooooooooooo`00o`02ooooo`03o`00oooo003ooooo00?ooooo00Go003ooooo
oooooooo003oool00003ooooo`03o`00oooooooooooo00?oo`000_ooool00ol00?ooooooooooo`06
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0;ooooo`04o`00oooo
ooooooooo`00o`Wooooo00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool01Ooo
ool00ol00?ooooooo`00o`08ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00oooooo0_l00?l7ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool06?ooool01?l00?oooooooooooooo0005ooooo`03o`00
ooooooooo`0000Kooooo00?o003oool00?ooool00_ooool00ol00?ooooooooooo`02ooooo`05o`00
0?l00?ooooooooooool00?l01oooool00ol00?ooooooooooo`0Booooo`09ool00?oooooooooooooo
ool00?ooooooo`00ooooooooo`0000?ooooo00?o003oooooooooool00_ooool01Ooo003ooooooooo
oooooooo003o00;ooooo00?o003oool00?ooool00_ooool01Ol00?ooooooooooooooooooo`0000Co
oooo00Go003ooooooooooooo003oool00003ooooo`05o`00oooooooooooooooooooo00000oooool0
0ol00?ooooooooooo`03ool000?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o2Oooool00ol0003ooooooooo
o`03ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00oooooo0_l00?l7
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool06oooool02Ooo003ooooooooooooo
oooo003oooooool00?ooooooool00006ooooo`03o`00oooo003ooooo00;ooooo00?o003ooooooooo
ool00_ooool01Ol0003ooooooooooooooooo003o00Oooooo00?o003oooooooooool04_ooool00ooo
003oooooooooo`03ooooo`03o`00ooooooooo`0000?ooooo00Ko003ooooooooooooo003ooooooooo
0003ooooo`05o`00ooooooooooooo`00oooo00001oooool00ooo003oooooooooo`05ooooo`03o`00
oooo003ooooo00Kooooo00Goo`00ooooooooooooooooo`00o`02ooooo`?oo`000oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l8
ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool00oooool001?ooooo00?o0000oooo
ooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Kooooo0_l00?l7oooo
o`;o003o1_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Sooooo00Co003ooooo
ooooooooo`000oooool01Ol00?ooooooooooooooooooo`0000?ooooo00Go003ooooooooooooo003o
ool00003ooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol00?oooooo
ooooo`0?ooooo`04o`00ooooooooooooool000Gooooo00?o003ooooooooo00000oooool01_l00?oo
ooooooooool00?ooooooool000?ooooo00Go003oooooool00?ooooooool00006ooooo`03o`00oooo
003ooooo00Oooooo00?oo`00ooooooooool01Oooool01Ooo003ooooooooooooooooo003o00;ooooo
0ooo0007ooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooooooo003o1?ooool00ol00?oo
ooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo000Cooooo`;o00002?ooool00ol00?oooooo
ooooo`03ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01Oooool01?l00?oo
ooooooooool00?l5ooooo`03o`00oooooooo003o00Kooooo0_l00?l7ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool08Oooool01?l00?oooooooooooooo0003ooooo`;o003o0_ooool0
1Ooo003ooooooooooooooooo003o00;ooooo00?o003oool00?ooool01oooool01Ol0003o003ooooo
oooooooo003o00Kooooo0_l00?lAooooo`04o`00ooooooooooooool000?ooooo00Go003ooooooooo
ooooooooool00006ooooo`03o`00ooooooooo`0000Oooooo00Goo`00ooooooooooooooooo`00o`02
ooooo`03o`00oooo003ooooo00?ooooo00Go003ooooooooooooo003oool00003ooooo`05o`00oooo
ooooooooo`00oooo00001oooool00ooo003oooooooooo`04ooooo`?oo`001oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00[ooooo0_l00005ooooo`004oooool00ol0003ooooooooo
o`07ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o1Oooool00ol00?oooooo
o`00o`05ooooo`04o`00ooooooooooooo`00o`Oooooo00?o003oooooooooool01?ooool2o`00o`So
oooo00?o003oooooooooool01?ooool2o`00o`Oooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0>ooooo`05o`00oooooooooooooooooooo00000oooool2o`00o`;ooooo00Goo`00oooo
ooooooooooooo`00o`03ooooo`05ool00?ooooooooooooooool00?l01?ooool01Ol0003o003ooooo
oooooooo003o00Kooooo00?o003oooooooooool04?ooool01?l00?oooooooooooooo0003ooooo`05
o`00oooooooo003ooooooooo00002?ooool00ooo003oooooooooo`05ooooo`05ool00?oooooooooo
ooooool00?l00_ooool00ol00?ooo`00ooooo`03ooooo`05o`00ooooooooooooo`00oooo00000ooo
ool01Ol00?ooooooooooool00?ooo`0000?ooooo00Go003oooooooooooooooooool00004ooooo`03
o`00ooooooooo`0000;oo`000oooool00ol00?ooooooooooo`0:ooooo`05o`00oooooooooooooooo
ool00?l02Oooool00ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`04ooooo`04
o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`05oooo
o`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l04?ooool00ol00?ooooooooooo`04
ooooo`;o003o1oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00kooooo00Go003o
ooooooooooooooooool00004ooooo`04o`00ooooooooooooool000Kooooo00?o003oool00?ooool0
0_ooool00ol00?ooooooooooo`02ooooo`05o`000?l00?ooooooooooool00?l01_ooool00ol00?oo
ooooooooo`0Cooooo`09ool00?ooooooooooooooool00?ooooooo`00ooooooooo`0000?ooooo00?o
003oooooooooool00_ooool02Ooo003ooooooooooooooooo003oooooool00?ooooooool00003oooo
o`05o`00oooooooooooooooooooo00001?ooool01Ol00?ooooooo`00ooooooooo`0000?ooooo00Go
003ooooooooooooo003oool00003ooooo`05o`00oooooooooooooooooooo00001?ooool00ol00?oo
ooooool00002ool000?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l02Oooool00ol0003oooooooooo`03ooooo`004oooool00ol0003o
ooooooooo`04ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00kooooo00?o003oooooool00?l01oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool04oooool01?oo
003oooooooooooooool2o`00o`;ooooo00?oo`00ooooooooool01?ooool00ol00?ooo`00ooooo`02
ooooo`03o`00oooooooooooo00;ooooo00Go0000ooooooooooooooooo`00o`06ooooo`;o003o5?oo
ool00ooo003oooooooooo`02ooooo`04o`00ooooooooooooool000?ooooo00?o003oooooool00?l0
0_ooool02Ooo003ooooooooooooooooo003oooooool00?ooooooool00003ooooo`05o`00oooooooo
oooooooooooo00001_ooool00ol00?ooooooool00006ooooo`03o`00oooo003ooooo00;ooooo00Go
003oooooooooooooooooool00004ooooo`05o`00ooooooooooooo`00oooo00000oooool00ol00?oo
ooooooooo`03ool000;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03
o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
0oooool00ol00?ooooooo`00o`05ooooo`?o003o1_ooool00ol00?ooooooo`00o`06ooooo`;o003o
1oooool00ol00?ooooooooooo`05ooooo`;o003o5?ooool01Ooo003ooooooooooooooooo003o00?o
oooo00Woo`00ooooooooooooooooo`00oooooooo003ooooooooo00000oooool00ol00?oooooooooo
o`02ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`06ooooo`05o`00oooooooooooooooooooo00001?ooool01?l00?oooooooooooooo0003ooooo`03
o`00oooooooo003o00;ooooo00Woo`00ooooooooooooooooo`00oooooooo003ooooooooo00001_oo
ool00ol00?ooo`00ooooo`07ooooo`03ool00?oooooooooo00Gooooo00Goo`00oooooooooooooooo
o`00o`03ooooo`03ool00?oooooooooo00;ooooo00Go003ooooooooooooo003oool00006ooooo`?o
o`000_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o0000oooooooo
ool00oooool001?ooooo0_l00008ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool00oooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool01Ol0
0?ooooooooooooooooooo`0000?ooooo00Go003oooooooooooooooooool00003ooooo`05o`00oooo
oooo003ooooooooo00002?ooool00ol00?ooooooooooo`08ooooo`;o003o1oooool00ol00?oooooo
ooooo`06ooooo`05o`00oooooooooooooooooooo00000oooool01Ol00?ooooooooooooooooooo`00
00Gooooo00Co003oooooooooooooo`000oooool01Ol00?ooooooo`00ooooooooo`0000?ooooo00Go
003ooooooooooooo003oool00004ooooo`05o`00oooooooo003ooooooooo00000oooool01Ol00?oo
ooooooooooooooooo`0000Oooooo00?oo`00ooooooooool01Oooool00ol00?ooo`00ooooo`05oooo
o`?oo`000_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00[ooooo0_l00005oooo
o`004oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o1ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Sooooo00?o003oooooooooool01?oo
ool2o`00o`Kooooo00?o003oooooooooool01_ooool2o`00o`Oooooo00?o003oooooooooool01_oo
ool01Ol00?ooooooooooooooooooo`0000?ooooo0_l00?l2ooooo`05ool00?ooooooooooooooool0
0?l00oooool00ooo003oooooooooo`06ooooo`05o`00ooooooooooooooooool00?l01_ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00Go003oooooooooooooooooool00003
ooooo`05o`00oooooooooooooooooooo00001Oooool01?l00?oooooooooooooo0007ooooo`09ool0
0?ooooooooooooooool00?ooooooo`00ooooooooo`0000Cooooo00Go003oooooool00?ooooooool0
0003ooooo`05o`00oooooooooooooooooooo00000oooool01Ol00?ooooooooooooooooooo`0000Co
oooo00Go003ooooooooooooo003oool00003ooooo`05o`00oooooooooooooooooooo00001_ooool3
ool000?ooooo00?o003oooooooooool01oooool00ol0003oooooooooo`03ooooo`004oooool00ol0
003oooooooooo`04ooooo`04o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool00_ooool0
1?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o1Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo0_l00?l6ooooo`;o
003o1oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00Go003ooooooooo
ooooooooool00004ooooo`04o`00ooooooooooooool000?ooooo00Go003oooooooooooooooooool0
0003ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`06ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool02_ooool01?oo003oooooooooooooool2o`00o`;o
oooo00Goo`00ooooooooooooooooo`00o`04ooooo`09ool00?ooooooooooooooool00?ooooooo`00
ooooooooo`0000?ooooo00Go003oooooooooooooooooool00004ooooo`05o`00oooooooo003ooooo
oooo00000oooool01Ol00?ooooooooooool00?ooo`0000?ooooo00Go003ooooooooooooo003oool0
0004ooooo`05o`00oooooooooooooooooooo00000oooool01Ol00?ooooooooooooooooooo`0000?o
oooo00?o003oooooooooool00ooo0003ooooo`03o`00oooooooooooo00Oooooo00?o0000oooooooo
ool00oooool000cooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo00Co003ooooooooooooo
003o3Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool03oooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00Cooooo0_l00?l7ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool02_ooool00ooo003oooooooooo`02ooooo`04
o`00ooooooooooooool000Gooooo00?o003ooooooooo00000oooool00ol00?ooooooooooo`02oooo
o`05o`000?ooooooooooooooool00?l01_ooool2o`00o`Oooooo00?o003oooooooooool02_ooool0
1?oo003oooooooooooooool2o`00o`;ooooo00Ooo`00ooooooooooooooooo`00oooooooo003o00;o
oooo00Woo`00ooooooooooooooooo`00oooooooo003ooooooooo00000oooool01Ol00?oooooooooo
ooooooooo`0000Cooooo00Go003oooooool00?ooooooool00003ooooo`05o`00ooooooooooooo`00
oooo00000oooool01Ol00?ooooooooooool00?ooo`0000Cooooo00Go003oooooooooooooooooool0
0003ooooo`05o`00oooooooooooooooooooo00000oooool00ol00?ooooooooooo`03ool000?ooooo
00?o003oooooooooool01oooool00ol0003oooooooooo`03ooooo`002oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00_ooooo00Co003ooooooooooooo003o1Oooool00ol00?oo
ooooo`00o`06ooooo`03o`00oooooooo003o00Oooooo00?o003oooooooooool01?ooool2o`00o`Oo
oooo0_l00?l7ooooo`03o`00oooooooooooo00[ooooo00Goo`00ooooooooooooooooo`00o`03oooo
o`09ool00?ooooooooooooooool00?ooooooo`00ooooooooo`0000?ooooo00?o003oooooooooool0
0_ooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1_ooool01Ol00?ooooooooooooooooooo`0000Cooooo00Co003oooooooooooooo`000oooool00ol0
0?ooooooo`00o`02ooooo`04ool00?ooooooooooooooo`;o003o0_ooool00ooo003oooooooooo`03
ooooo`03o`00ooooooooo`0000Sooooo00?oo`00ooooooooool00oooool00ol00?ooooooool00003
ooooo`05o`00ooooooooooooo`00oooo00001?ooool01Ol00?ooooooooooool00?ooo`0000Oooooo
00Goo`00ooooooooooooooooo`00o`03ooooo`03ool00?oooooooooo00;ooooo00?o003ooooooooo
ool01oooool00ol0003oooooooooo`03ooooo`002oooool01?l0003oooooooooool00004ooooo`oo
000000Goo`00o`000?l0003o0000o`00o`03o`000005ool00?l00?oo0000o`000?l00?l00ol00000
0ooo003o0000o`000002o`000006o`00ool0003o0000o`000?oo003o003o0_l000002Ol00?oo0000
o`000?l0003oo`00o`000?l00?oo0000o`00o`03o`000003ool00?l0003o003o00Ko000000?oo`00
o`000?l00?l01Ol000000ooo003o0000o`000005o`000003ool00?l0003o000000;o000000Go003o
o`000?l0003o0000ool00002o`000003o`00ool0003o000000;o000000Goo`00o`000?l0003o0000
o`00o`04o`000005ool00?l0003o0000o`000?l00?l00ol000002Ooo003o0000o`000?l0003o003o
o`000?l00?oo0000ool00006o`0000?oo`001ol000001Ooo003o0000o`00ool0003o003o00?o0000
00Goo`00o`000?l0003o0000o`00o`04o`000005ool00?l0003o0000o`000?l00?l00ol000001Ooo
003o0000o`000?l0003o003o00?o000000Coo`00o`000?l0003o00000_l00?l3o`000004ool00?l0
003o0000o`0000;o003o0_l000000ooo003o0000o`000003o`000003o`00ool0003oo`0000Co0000
00Go003oo`000?l0003o0000ool00003o`000005o`00ool0003o003oo`000?oo00001_l000000ol0
0?ooo`00o`000006o`000003o`00oooo003o000000Go000000?o003oool00?l000000_l000001Ol0
0?oo0000o`000?l0003oo`0000Ko00000ooo0006o`0000Gooooo000;ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`02ooooo`05ool00?oooooo
ooooooooool00?l00oooool01Ooo003o003ooooooooooooo003o00?ooooo00?oo`00o`00ooooool0
0_ooool01Ol00?ooooooooooooooooooo`0000?ooooo00Wo003oooooooooooooooooool00?oooooo
003oooooool00?l00oooool00ooo003oooooo`00o`06ooooo`05ool00?oooooo003oooooool00?l0
0oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00;ooooo00Go003ooooooooooooo
ooooool00002ooooo`;o003o0oooool01Ooo003ooooooooooooooooo003o00Sooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`08ooooo`?oo`000oooool02Ol00?oooooooooooooooooo
o`00ooooool00?ooooooo`00o`03ooooo`05ool00?ooooooooooooooool00?l01?ooool01Ooo003o
oooooooooooooooo003o00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=oooo
o`03o`00oooooooo003o00Kooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`0>oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o2?ooool00ol00?oooooooooo
o`04ooooo`?oo`001Oooool00ol0003oooooooooo`03ooooo`002oooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool00_ooool01Ooo003ooooooooo
oooooooo003o00?ooooo00Goo`00ooooooooooooooooo`00o`03ooooo`03ool00?l00?oooooo00;o
oooo00Go003oooooooooooooooooool00003ooooo`09o`00oooooooooooooooooooo003oooooo`00
oooooooo003o00?ooooo00?oo`00ooooooooool00_ooool02Ol00?ooooooooooooooooooo`00oooo
ool00?ooooooo`00o`03ooooo`03ool00?oooooooooo00;o003o0oooool01?oo003oooooooooool0
0?l5ooooo`05ool00?ooooooooooooooool00?l00oooool01Ooo003ooooooooooooooooo003o00So
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00?o
o`000oooool01ol00?ooooooooooooooooooo`00ooooool00?l01Oooool01?oo003oooooooooool0
0?l5ooooo`05ool00?ooooooooooooooool00?l01oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00kooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`05ooooo`03o`00
oooooooo003o00Gooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool00_ooool00ol00?ooooooool00002ool000Go
oooo00?o0000ooooooooool00oooool000_ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`07ooooo`03o`00oooooooooooo00?oo`000oooool01Ol00?ooooooooooooooooooo`00
00Oooooo00?oo`00o`00ooooool01_ooool00ooo003o003oooooo`05ooooo`03ool00?oooooooooo
00Gooooo00?oo`00ooooool00?l00_ooool01Ol00?ooooooooooooooooooo`0000?ooooo00Go003o
ooooooooooooooooool00002ooooo`;o003o0oooool01?oo003oooooooooool00?l5ooooo`03ool0
0?oooooooooo00;o003o0oooool00ooo003oooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool00oooool01_l00?oooooooooooooooooo003oo`0000?ooooo00Wo003ooooo
ooooooooooooool00?oooooo003oooooool00?l00oooool01?oo003oooooooooool00?l5ooooo`03
ool00?oooooooooo00Wooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`;o
003o1_ooool00ol00?ooooooooooo`06ooooo`;o003o1_ooool00ol00?ooooooo`00o`05ooooo`04
o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Kooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`000?oooooo
oooo00?ooooo000<ooooo`;o00001Oooool00ol0003oooooooooo`0:ooooo`?oo`001oooool01Ooo
003ooooooooooooooooo003o00?ooooo00?oo`00o`00ooooool01_ooool00ooo003o003oooooo`05
ooooo`05ool00?l00?ooooooooooool00?l00oooool00ooo003oooooo`00o`02ooooo`05o`00oooo
oooooooooooooooo00000oooool02Ol00?ooooooooooooooooooo`00ooooool00?ooooooo`00o`03
ooooo`06ool00?ooooooooooo`00oooooooo003o0oooool01?oo003oooooooooool00?l4ooooo`03
ool00?oooooooooo00[ooooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`05ooooo`03
o`00oooooooooooo00;ooooo00Go0000ooooooooooooooooo`00o`03ooooo`05ool00?oooooooooo
ooooool00?l00oooool00ooo003oooooooooo`02o`00o`Cooooo00Coo`00oooooooooooo003o2?oo
ool00ol00?ooooooooooo`05ooooo`;o003o1oooool2o`00o`Sooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l0
1Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooooooo
003o1_ooool00ol0003oooooooooo`03ooooo`004oooool2o`0000_ooooo0ooo0003ooooo`05o`00
oooooooooooooooooooo00000oooool01Ol00?ooooooooooooooooooo`0000Cooooo00Ko003ooooo
ooooooooooooool00?l00?l2ooooo`06o`00oooooooooooooooooooo003o003o0_ooool01ol00?oo
ooooooooooooooooo`00ooooool00?l01_ooool00ooo003oooooo`00o`05ooooo`05ool00?oooooo
ooooooooool00?l00oooool00ooo003oooooooooo`02ooooo`05o`00oooooooooooooooooooo0000
0_ooool00ol00?ooooooooooo`02ooooo`05ool00?ooooooooooooooool00?l02?ooool00ol00?oo
ooooooooo`05ooooo`;o003o2_ooool00ol00?oo0000ooooo`06ooooo`05ool00?oooooooooooooo
ool00?l00oooool00ooo003oooooooooo`02o`00o`Cooooo00Coo`00oooooooooooo003o4?ooool2
o`00o`Oooooo0_l00?l8ooooo`03o`00oooooooooooo00cooooo00?o003oooooool00?l02?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00_ooooo00Go003oooooooooooooooooo`00
o`0=ooooo`;o00001Oooool001?ooooo00?o0000ooooooooool01oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00?o003oooooooooool00ooo0002ooooo`06o`00oooooooooooooooooooo003o
003o0oooool01Ol00?ooooooooooooooooooo`0000?ooooo00Ko003oooooooooooooooooool00?l0
0?l2ooooo`07o`00oooooooooooooooooooo003oooooo`00o`06ooooo`03ool00?oooooo003o00Go
oooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`02ooooo`05o`00oooooooooooooooo
oooo00000_ooool2o`00o`?ooooo00Goo`00ooooooooooooooooo`00o`08ooooo`03o`00oooooooo
oooo00Gooooo0_l00?l:ooooo`03o`00ool0003ooooo00;ooooo00Wo003oooooooooooooooooool0
0?oooooo003oooooool00?l00oooool01Ooo003ooooooooooooooooo003o00Cooooo00Coo`00oooo
oooooooo003o4Oooool00ol00?ooooooooooo`0=ooooo`;o003o1oooool2o`00o`Kooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`Sooooo00?o
003oooooooooool03?ooool00ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`07
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00ooo0002ooooo`06o`00oooooooo
oooooooooooo003o003o0oooool01Ol00?ooooooooooooooooooo`0000?ooooo00Ko003ooooooooo
ooooooooool00?l00?l2ooooo`05o`00oooooooooooooooooooo00001?ooool01_l00?oooooooooo
ooooooooo`00o`00o`;ooooo00Wo003oooooooooooooooooool00?oooooo003oooooool00?l00ooo
ool01_oo003oooooooooool00?ooooooo`00o`?ooooo00Goo`00ooooooooooooooooo`00o`03oooo
o`05ool00?ooooooooooooooool00?l04?ooool00ol00?ooooooooooo`05ooooo`06o`00oooooooo
ooooooooool00?oo00000oooool01ol00?ooooooooooooooooooo`00ooooool00?l01Oooool01Ooo
003ooooooooooooooooo003o00Cooooo00Coo`00oooooooooooo003o8Oooool2o`00o`Oooooo0_l0
0?l6ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l01_ooool00ol00?oooooooooo
o`05ooooo`04o`00ooooooooooooo`00o`Oooooo00?o003oooooooooool00oooool01?l00?oooooo
ooooool00?l6ooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo00Oooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`03ool000Kooooo00?oo`00ooooooooool0
0_ooool01Ol00?ooooooooooooooooooo`0000Oooooo00?oo`00ooooooooool01Oooool00ooo003o
ooooo`00o`02ooooo`06o`00oooooooooooooooooooo003o003o0_ooool02Ol00?oooooooooooooo
ooooo`00ooooool00?ooooooo`00o`03ooooo`04ool00?ooooooooooo`00o`Gooooo00?oo`00oooo
ooooool00_l00?l3ooooo`05ool00?ooooooooooooooool00?l04Oooool00ol00?ooooooooooo`04
ooooo`06o`00ooooooooooooooooool00?oo00000oooool01_l00?ooooooooooooooooooo`00o`00
o`Kooooo00Coo`00oooooooooooo003o1Oooool00ooo003oooooooooo`0Booooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`;o003o1_ooool0
0ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo00?o003oooooooooool01Oooool0
1?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo
003o1_ooool00ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`07ooooo`05o`00
ooooooooooooooooool00?l03oooool3ool000Oooooo00?oo`00ooooooooool01Oooool00ooo003o
ooooooooo`05ooooo`03ool00?oooooo003o00;ooooo00Go003oooooooooooooooooool00003oooo
o`09o`00oooooooooooooooooooo003oooooo`00oooooooo003o00?ooooo00Koo`00oooooooooooo
003oooooool00?l3ooooo`03ool00?oooooooooo00;o003o0oooool00ooo003oooooooooo`0Coooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool01Ol0003ooooooooooooooooo
003o00?ooooo00Goo`00ooooooooooooooooo`00o`03ooooo`03ool00?oooooooooo00;o003o1?oo
ool01?oo003oooooooooool00?lAooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
3oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l0
1_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1_ooool01?l00?ooooooooooool00?l6ooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`00
0?oooooooooo00_ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`03ool000?ooooo
00Go003oooooooooooooooooool00003ooooo`06o`00oooooooooooooooooooo003o003o0_ooool0
1_l00?ooooooooooooooooooo`00o`00o`?ooooo00Ko003oooooooooooooooooool00?l00?l6oooo
o`05ool00?ooooooooooooooool00?l00oooool00ooo003oooooooooo`02ooooo`05o`00oooooooo
oooooooooooo00000_ooool00ol00?ooooooooooo`02ooooo`04ool00?ooooooooooo`00oa7ooooo
0_l00?l6ooooo`06o`00ooooooooooooo`00oooooooo00001oooool01Ooo003ooooooooooooooooo
003o00?ooooo00?oo`00ooooooooool00_l00?l4ooooo`04ool00?ooooooooooo`00oaWooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooool00?l02?ooool00ol00?ooooooooooo`0;ooooo`04o`00ooooooooooooo`00o`Sooooo
00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`004oooool2o`0000Sooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`03ool000?ooooo00Go003oooooooooooooooooool00003ooooo`06o`00oooooooooooo
oooooooo003o003o0_ooool01_l00?ooooooooooooooooooo`00o`00o`Oooooo00?oo`00o`00oooo
ool01Oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00;ooooo00Wo003ooooooooo
ooooooooool00?oooooo003oooooool00?l00oooool01?oo003oooooooooool00?lAooooo`;o003o
2Oooool00ol00?ooooooo`000003ooooo`06o`00oooooooooooooooooooo003o003o0_ooool01Ol0
0?ooooooooooooooooooo`0000?ooooo00?o003oooooooooool00_ooool01?oo003oooooooooool0
0?lIooooo`03o`00oooooooooooo00Gooooo0_l00?l7ooooo`;o003o1_ooool00ol00?oooooooooo
o`0@ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0<ooooo`;o00001Oooool001?ooooo00?o0000ooooooooool01oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l01?ooool00ol00?ooooooool00002ool000?ooooo00Go003oooooooooooooooooool00003oooo
o`05o`00oooooooooooooooooooo00001?ooool01_l00?ooooooooooooooooooo`00o`00o`;ooooo
00Wo003oooooooooooooooooool00?oooooo003oooooool00?l00oooool00ooo003oooooo`00o`02
ooooo`05o`00oooooooooooooooooooo00000oooool01Ol00?ooooooooooooooooooo`0000;ooooo
00?o003oooooooooool03oooool00ol00?ooooooooooo`05ooooo`06o`00ooooooooooooo`00oooo
oooo00000oooool01_l00?ooooooooooooooooooo`00o`00o`Kooooo00Goo`00oooooooooooooooo
o`00o`04ooooo`04ool00?ooooooooooo`00oaWooooo00?o003oooooooooool01Oooool2o`00o`Oo
oooo0_l00?l6ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00Sooooo00?o003oooooooooool00oooool01?l00?oo
ooooooooool00?l6ooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo00Oo
oooo00?o003oooooooooool01_ooool01?l00?ooooooooooool00?l8ooooo`03o`00oooooooooooo
00;ooooo00?o003ooooooooo00000_oo0003ooooo`05o`00oooooooooooooooooooo00001oooool0
0ooo003oooooooooo`02ooooo`06o`00oooooooooooooooooooo003o003o0_ooool02Ol00?oooooo
ooooooooooooo`00ooooool00?ooooooo`00o`03ooooo`03ool00?oooooo003o00Kooooo00Goo`00
ooooooooooooooooo`00o`03ooooo`04ool00?ooooooooooo`00oa7ooooo00?o003oooooooooool0
1Oooool01_l00?ooooooooooool00?ooooooo`0000?ooooo00Ko003oooooooooooooooooool00?l0
0?l6ooooo`03ool00?oooooo003o00Kooooo00?oo`00ooooooooool06_ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool2o`00o`Kooooo00?o
003oooooool00?l01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo003o00Gooooo00Co
003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`07ooooo`03o`000?oooooooooo00?ooooo
000Cooooo`03o`000?oooooooooo00Oooooo00Go003oooooooooooooooooo`00o`0@ooooo`03o`00
oooooooooooo00Cooooo0ooo0007ooooo`03ool00?oooooooooo00Gooooo00?oo`00o`00ooooool0
0_ooool01Ol00?ooooooooooooooooooo`0000?ooooo00Ko003oooooooooooooooooool00?l00?l2
ooooo`07o`00oooooooooooooooooooo003oooooo`00o`06ooooo`05ool00?oooooo003oooooool0
0?l00oooool00ooo003oooooooooo`0Booooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool00_ooool01Ol0003ooooooooooooooooo003o00?ooooo00Goo`00o`00ooooooooooooo`00o`03
ooooo`05ool00?oooooo003oooooool00?l01?ooool00ooo003oooooooooo`0Rooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooo003o00Kooooo0_l00?l6ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_oo
ool00ol00?ooooooo`00o`07ooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooo
oooo00_ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooool00003ooooo`06o`00oooooooooooooooooooo003o
003o0oooool01_l00?ooooooooooooooooooo`00o`00o`;ooooo00Ko003oooooooooooooooooool0
0?l00?l2ooooo`07o`00oooooooooooooooooooo003oooooo`00o`02ooooo`07o`00oooooooooooo
oooooooo003oooooo`00o`05ooooo`04ool00?ooooooooooo`00oa7ooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Goo`00oooooooooooo
ooooo`00o`03ooooo`05ool00?oooooo003oooooool00?l01?ooool00ooo003oooooo`00o`0Roooo
o`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool2o`00o`Oooooo0_l00?l>oooo
o`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01oooool00ol0003oooooooooo`03
ooooo`004oooool2o`0000_ooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l4
ooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooooooo003o1?ooool00ol00?oooooooooo
o`03ool000;ooooo00Ko003oooooooooooooooooool00?l00?l7ooooo`03ool00?l00?oooooo00Go
oooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`02ooooo`09o`00oooooooooooooooo
oooo003oooooo`00oooooooo003o00?ooooo00Coo`00oooooooooooo003o6oooool01?l00?oooooo
ooooool00007ooooo`05ool00?ooooooooooooooool00?l00oooool01Ooo003oooooo`00oooooooo
003o00Cooooo00?oo`00ooooool00?l08_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Gooooo0_l00?l@ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00oooool0
1?l00?ooooooooooool00?l>ooooo`;o00001Oooool001?ooooo00?o0000ooooooooool01oooool0
1?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00ooo0002ooooo`05
o`00oooooooooooooooooooo00001?ooool01_l00?ooooooooooooooooooo`00o`00o`;ooooo00Ko
003oooooooooooooooooool00?l00?l6ooooo`03ool00?oooooo003o00;ooooo00Go003ooooooooo
ooooooooool00003ooooo`07o`00oooooooooooooooooooo003oooooo`00o`0Looooo`04o`00oooo
ooooooooo`0000?ooooo00Go003oooooooooooooooooool00007ooooo`05ool00?oooooooooooooo
ool00?l01?ooool00ooo003oooooo`00o`0Rooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo0_l00?l6oooo
o`03o`00oooooooo003o00Oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`07oooo
o`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo00Oooooo00?o003ooooooooo
ool01_ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l01?ooool0
1?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00?oo`000_ooool01Ol00?oooooooooo
ooooooooo`0000Cooooo00Go003oooooooooooooooooool00003ooooo`06o`00oooooooooooooooo
oooo003o003o0_ooool01ol00?ooooooooooooooooooo`00ooooool00?l01_ooool01Ooo003ooooo
oooooooooooo003o00?ooooo00?oo`00ooooool00?l06_ooool00ol00?ooooooo`00o`02ooooo`05
o`000?ooooooooooooooool00?l00oooool00ooo003oooooooooo`05ooooo`03ool00?oooooo003o
00Kooooo00?oo`00ooooooooool0:oooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool2o`00
o`Oooooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o
00Kooooo00?o003oooooool00?l01oooool00ol0003oooooooooo`03ooooo`004oooool00ol0003o
ooooooooo`07ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o1oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo0ooo0003ooooo`05o`00oooooooo
oooooooooooo00000oooool01_l00?ooooooooooooooooooo`00o`00o`;ooooo00Oo003ooooooooo
ooooooooool00?oooooo003o00Kooooo00Goo`00o`00ooooooooooooo`00o`03ooooo`03ool00?oo
oooooooo01[ooooo00?o003oooooooooool00_ooool01_l0003ooooooooooooooooo003oooooo`?o
o`000oooool01ol00?ooooooooooooooooooo`00ooooool00?l01_ooool00ooo003oooooooooo`0[
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool2o`00o`Oooooo00?o003o
ooooooooool01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooool00?l01oooool00ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`0:oooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`06oooo
o`05o`00ooooooooooooooooool00?l00_ooool3ool000?ooooo00Go003oooooooooooooooooool0
0003ooooo`06o`00oooooooooooooooooooo003o003o0_ooool01ol00?ooooooooooooooooooo`00
ooooool00?l00_ooool01_l00?ooooooooooooooooooo`00o`00o`Kooooo00?oo`00ooooooooool0
6_ooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0ooo0003ooooo`06o`00
oooooooooooooooooooo003o003o0_ooool00ol00?ooooooooooo`02ooooo`03ool00?oooooo003o
03?ooooo00?o003oooooooooool01Oooool2o`00o`Oooooo0_l00?l>ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooool00?l01oooool00ol0003oooooooooo`03ooooo`004oooool2o`0000_o
oooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Ko
oooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00ooo0007ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooooooo`02ooooo`06o`00oooooooooooooooooooo003o003o1_ooool00ooo003ooooo
o`00o`0Looooo`04o`00ooooooooooooo`0000Gooooo0ooo0003ooooo`06o`00oooooooooooooooo
oooo003o003o0_ooool00ol00?ooooooooooo`02ooooo`03ool00?oooooo003o03?ooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooo`00o`0?ooooo`;o00001Oooool001?ooooo00?o0000oooo
ooooool01oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Gooooo00Co003o
oooooooooooo003o1Oooool00ol00?ooooooooooo`05ooooo`04o`00ooooooooooooo`00o`Cooooo
00?o003oooooooooool02?ooool3ool000?ooooo00Ko003oooooooooooooooooool00?l00?l6oooo
o`03ool00?l00?oooooo00;ooooo00Ko003oooooooooooooooooool00?l00?l2ooooo`07o`00oooo
oooooooooooooooo003oooooo`00o`0Looooo`04o`00ooooooooooooo`0000?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00oooooooooooooooooooo00000oooool00ol00?oooooooooo
o`02ooooo`03ool00?l00?oooooo03?ooooo00?o003oooooooooool03_ooool00ol00?oooooooooo
o`05ooooo`;o003o2?ooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo000C
ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooo`00o`05
ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool01Oooool01?l00?oooooooooo
ool00?l4ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo00000_oo0003ooooo`06o`00
oooooooooooooooooooo003o003o0_ooool01_l00?ooooooooooooooooooo`00o`00o`Oooooo00Go
o`00ooooooooooooooooo`00o`03ooooo`03ool00?oooooo003o01[ooooo0_l00?l3ooooo`05o`00
0?ooooooooooooooool00?l00_ooool00ol00?ooooooooooo`06ooooo`03ool00?l00?oooooo00Ko
oooo00?oo`00o`00ooooool0<oooool00ol00?ooooooooooo`05ooooo`;o003o1oooool00ol00?oo
ooooooooo`05ooooo`;o003o2?ooool00ol00?ooooooooooo`04ooooo`;o003o2?ooool00ol0003o
ooooooooo`03ooooo`002oooool3o`0000Gooooo00?o0000ooooooooool01oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooo003o00Sooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo00000_oo0003ooooo`05o`00
oooooooooooooooooooo00000oooool01_l00?ooooooooooooooooooo`00o`00o`Oooooo00Goo`00
o`00ooooooooooooo`00o`03ooooo`03ool00?oooooooooo01[ooooo0_l00?l3ooooo`05o`000?oo
ooooooooooooool00?l00_ooool00ol00?ooooooooooo`02ooooo`06o`00oooooooooooooooooooo
003o003o1oooool00ooo003oooooooooo`0cooooo`03o`00oooooooooooo00Gooooo0_l00?l7oooo
o`03o`00oooooooooooo00Gooooo0_l00?l6ooooo`03o`00oooooooooooo00Kooooo0_l00?l8oooo
o`03o`000?oooooooooo00?ooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02Oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool01Oooool01Ol0
0?ooooooooooooooooooo`0000?ooooo00Ko003oooooooooooooooooool00?l00?l3ooooo`06o`00
oooooooooooooooooooo003o003o1_ooool00ooo003oooooooooo`0Jooooo`03o`00oooooooooooo
00;ooooo00Go0000ooooooooooooooooo`00o`07ooooo`06o`00oooooooooooooooooooo003o003o
0_ooool00ol00?ooooooooooo`02ooooo`03ool00?l00?oooooo03_ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1_ooool2o`00o`Sooooo00?o0000ooooooooool00oooool000cooooo00?o0000ooooooooool01?oo
ool3o`0000Wooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`05ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`05o`00
ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`05ooooo`?oo`000_ooool01Ol00?oo
ooooooooooooooooo`0000Cooooo00Ko003oooooooooooooooooool00?l00?l6ooooo`03ool00?oo
oooo003o01[ooooo0_l00?l3ooooo`03o`000?oooooooooo00Wooooo00Ko003ooooooooooooooooo
ool00?l00?l2ooooo`03o`00oooooooooooo00;ooooo00?oo`00o`00ooooool0>oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00gooooo0_l00?l?ooooo`?o00001Oooool000cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`00oooooooo003o00Kooooo
00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00Go
oooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003o
ooooooooool01Oooool3ool000Kooooo00?oo`00ooooooooool00_ooool01_l00?oooooooooooooo
ooooo`00o`00o`;ooooo00Oo003oooooooooooooooooool00?oooooo003o01_ooooo00Go003ooooo
ooooooooooooo`000003ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooooooooooooooo
ool00003ooooo`03o`00oooooooooooo00;ooooo00?oo`00o`00ooooool0A?ooool00ol00?oooooo
ooooo`05ooooo`;o003o1oooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo
000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1Oooool00ol00?oooooo
ooooo`05ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool01_ooool01?l00?oo
ooooooooool00?l4ooooo`03o`00oooooooooooo00?oo`000_ooool01_l00?oooooooooooooooooo
o`00o`00o`?ooooo00Go003oooooooooooooooooool00003ooooo`07o`00oooooooooooooooooooo
003oooooo`00o`0Jooooo`;o003o0oooool01Ol0003ooooooooooooooooo003o00;ooooo00?o003o
ooooooooool01_ooool01Ooo003ooooooooooooooooo003o00Cooooo00?oo`00o`00ooooool0A?oo
ool00ol00?ooooooooooo`05ooooo`;o003o1oooool00ol00?ooooooooooo`05ooooo`;o003o2?oo
ool00ol0003oooooooooo`03ooooo`002oooool2o`0000Kooooo00?o0000ooooooooool01oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooo003o00Oooooo00?o003oooooooooool01?ooool0
0ol00?ooooooo`00o`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01Oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Ko003oooooooooooooooooool00?l00?l7ooooo`05
ool00?ooooooooooooooool00?l00oooool00ooo003o003oooooo`0Jooooo`;o003o0oooool01Ol0
003ooooooooooooooooo003o00;ooooo00?o003oooooooooool01_ooool00ooo003o003oooooo`06
ooooo`03ool00?oooooooooo04Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05
ooooo`;o003o1oooool2o`00o`Sooooo00?o0000ooooooooool00oooool000cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`07ooooo`03o`00oooooooo003o013ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00ooo0003
ooooo`05o`00oooooooooooooooooooo00000oooool01Ol00?ooooooooooooooooooo`0001cooooo
00?o003oooooooooool00_ooool01Ol0003ooooooooooooooooo003o00Oooooo00?o003ooooooooo
ool00ooo0002ooooo`03o`00oooooooooooo00;ooooo00?oo`00o`00ooooool0A?ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool2o`00o`So
oooo00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool02Oooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooool00?l01Oooool01?l00?oooooo
ooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o3?ooool0
0ol00?ooooooooooo`03ool000?ooooo00Go003oooooooooooooooooool00007ooooo`03ool00?l0
0?oooooo01[ooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`00oooo
oooooooo00?oo`000_ooool00ol00?ooooooooooo`02ooooo`03ool00?l00?oooooo05Cooooo0_l0
0?l8ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool00oooool001?ooooo0_l00008
ooooo`03o`00oooooooo003o00Kooooo0_l00?l6ooooo`03o`00oooooooo003o00Kooooo00?o003o
ooooooooool01Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Sooooo
00?o003oooooooooool03Oooool3ool000?ooooo00Go003oooooooooooooooooool00003ooooo`06
o`00oooooooooooooooooooo003o003o8?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool00ooo0002ooooo`03o`00oooooooooooo00;ooooo00?oo`00
ooooooooool0C?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00kooooo0_l00005
ooooo`004oooool00ol0003oooooooooo`07ooooo`03o`00oooooooo003o00Kooooo0_l00?l6oooo
o`03o`00oooooooo003o00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`05oooo
o`03o`00oooooooooooo00Kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l4ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?ooooooooooooooooooo`0000?o
oooo00Ko003oooooooooooooooooool00?l00?lPooooo`07o`000?ooooooooooooooool00?oooooo
o`00o`0=ooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool0C?ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01oooool00ol0003ooooo
ooooo`03ooooo`004oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00Kooooo0_l0
0?l8ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01Oooool00ol00?oooooooooo
o`0>ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oo
oooooooooooooooo003o00Kooooo0ooo0003ooooo`06o`00oooooooooooooooooooo003o003o8?oo
ool01ol0003ooooooooooooooooo003oooooool00?l02Oooool00ol00?ooooooooooo`06ooooo`03
ool00?oooooooooo05Cooooo0_l00?l7ooooo`03o`00oooooooooooo00Oooooo00?o0000oooooooo
ool00oooool001?ooooo00?o0000ooooooooool01oooool2o`00oa7ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
1Oooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l01_ooool3ool0
00?ooooo00Go003oooooooooooooooooool0000Qooooo`05o`000?ooooooooooooooool00?l01ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ooo003ooooo
ooooo`1Dooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol0003ooooo
ooooo`03ooooo`004oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00gooooo00?o
003oooooool00?l01oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Gooooo00Co
003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Co
oooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00ooooooooo`0000;oo`001oooool00ooo
003oooooooooo`0Oooooo`03o`000?oooooooooo00Wooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool0E?ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool00oooool001?ooooo0_l00009oooo
o`03o`00oooooooooooo00Gooooo0_l00?l6ooooo`03o`00oooooooooooo00Kooooo0_l00?l6oooo
o`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1oooool00ol00?ooooooooooo`0D
ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooool0000Qooooo`03o`00
0?oooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00;ooooo00?oo`00ooooooooool0E?ooool00ol00?ooooooooooo`0?ooooo`;o0000
1Oooool001?ooooo00?o0000ooooooooool01oooool2o`00o`Oooooo0_l00?l6ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l8ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`03ool0023ooooo
00Oo0000ooooooooooooooooo`00oooooooo003o00Gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`03ool005oooooo00?o003oooooooooool01oooool00ol0003oooooooooo`03oooo
o`004oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00Kooooo0_l00?l6ooooo`;o
003o1oooool2o`00o`Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo
003o00cooooo00?o003oooooooooool00ooo000Pooooo`04o`000?ooooooooooooooo`;o003o2Ooo
ool00ol00?ooooooooooo`05ooooo`?oo`00Goooool00ol00?ooooooooooo`07ooooo`03o`000?oo
oooooooo00?ooooo000Cooooo`03o`000?oooooooooo00Oooooo0_l00?l7ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01Oooool01?l00?ooooooooooool00?l4ooooo`05o`00oooo
ooooooooooooool00?l01oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?oo`00
8?ooool01?l0003oooooooooooooool2o`00o`Kooooo00Co003ooooooooooooo003o1oooool3ool0
05oooooo00?o003oooooooooool01oooool00ol0003oooooooooo`03ooooo`004oooool00ol0003o
ooooooooo`08ooooo`03o`00oooooooooooo00gooooo0_l00?l8ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00Go
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`04o`00oooooooo
ooooo`00ob[ooooo00?o0000ooooooooool02Oooool01?l00?ooooooooooool00?l4ooooo`05o`00
ooooooooooooooooool00?l0J_ooool00ol0003oooooooooo`03ooooo`004oooool2o`0000Wooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`;o003o1oooool2o`00o`Kooooo
0_l00?l6ooooo`03o`00oooooooo003o00Sooooo00?o003oooooooooool05?ooool01?l00?oooooo
ooooool00?l8ooooo`03o`00oooooooooooo01oooooo00?o0000ooooooooool00_ooool00ol00?oo
ooooooooo`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`1Y
ooooo`;o00001Oooool001?ooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05oooo
o`;o003o1_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ool00?l02?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00Go003ooooo
ooooooooooooo`00o`0Qooooo`04o`000?ooooooooooooooo`;o003o1_ooool00ol00?oooooooooo
o`05ooooo`05o`00ooooooooooooooooool00?l0J_ooool00ol0003oooooooooo`03ooooo`004ooo
ool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00Gooooo0_l00?l7ooooo`03o`00oooo
oooooooo00Gooooo0_l00?l6ooooo`03o`00oooooooooooo00Kooooo00?o003oooooool00?l01Ooo
ool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`gooooo00Go003ooooooooooooo
ooooo`00o`0Qooooo`04o`000?ooooooooooooooo`;o003o2Oooool00ol00?ooooooooooo`1aoooo
o`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo013ooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00oooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooo
oooo003o2?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02?ooooo00Co0000oooo
oooooooooooo0_l00?l6ooooo`04o`00ooooooooooooo`00og?ooooo00?o0000ooooooooool00ooo
ool001?ooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l5ooooo`04o`00oooo
ooooooooo`00ob[ooooo00Go0000ooooooooooooooooo`00o`07ooooo`03o`00oooooooo003o00Go
oooo00Go003oooooooooooooooooo`00o`1Zooooo`03o`000?oooooooooo00?ooooo000Cooooo`;o
00006Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo0_l00?l6ooooo`;o
003o2?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooool0
0?l02?ooool00ol00?ooooooooooo`0Pooooo`05o`000?ooooooooooooooool00?l01oooool00ol0
0?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l0JOooool2o`0000Gooooo000Coooo
o`03o`000?oooooooooo01Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05oooo
o`;o003o1_ooool2o`00o`Sooooo00?o003oooooooooool05Oooool00ol00?ooooooo`00o`05oooo
o`04o`00ooooooooooooo`00ob;ooooo00Go0000ooooooooooooooooo`00o`07ooooo`03o`00oooo
oooooooo00Gooooo00Co003ooooooooooooo003oJoooool00ol0003oooooooooo`03ooooo`004ooo
ool00ol0003oooooooooo`0Hooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Ooo
ool2o`00o`Kooooo00?o003oooooooooool01_ooool2o`00o`Kooooo00?o003oooooool00?l01Ooo
ool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo
003o8_ooool01Ol0003ooooooooooooooooo003o00oooooo00Co003ooooooooooooo003oJoooool0
0ol0003oooooooooo`03ooooo`002_ooool5o`0000Cooooo00?o0000ooooooooool08Oooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Oooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0Sooooo`05o`000?ooooooooooooooool00?l02Oooool00ol00?oooooooooo
o`1booooo`03o`000?oooooooooo00?ooooo000;ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool08Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01Oooool2o`00o`Kooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooooooo02?ooooo00Go0000ooooooooooooooooo`00o`07ooooo`03o`00
oooooooo003o00Gooooo00Co003ooooooooooooo003oJoooool00ol0003oooooooooo`03ooooo`00
3?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo027ooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`05ooooo`;o003o1oooool2o`00o`kooooo00?o003oooooool00?l0
1_ooool00ol00?ooooooo`00o`08ooooo`03o`00oooooooooooo023ooooo00?o0000ooooooooool0
2Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00of_ooooo00?o0000oooooooo
ool00oooool000gooooo00?o0000ooooooooool00oooool3o`0002Wooooo00?o003oooooooooool0
1Oooool2o`00o`Sooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooo003o00Gooooo00Co003ooooooooooooo003o8_ooool00ol0003oooooooooo`09ooooo`03
o`00oooooooooooo00Gooooo00Co003ooooooooooooo003oJOooool3o`0000Gooooo000:ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Yooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`;o003o3oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooo003o02?ooooo00?o0000ooooooooool04Oooool01?l0
0?ooooooooooool00?m[ooooo`03o`000?oooooooooo00?ooooo000:ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`0Yooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooo003o02?ooooo00?o0000ooooooooool02oooool00ol00?ooooooooooo`1b
ooooo`03o`000?oooooooooo00?ooooo000;ooooo`?o00001Oooool00ol0003oooooooooo`0boooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool2o`00o`Kooooo00?o003ooooo
ool00?l02?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo02?ooooo00?o0000oooo
ooooool02Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo06cooooo00?o0000oooo
ooooool00oooool001?ooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`06ooooo`03
o`00oooooooo003o00Oooooo00?o003oooooooooool08Oooool00ol0003oooooooooo`09ooooo`;o
003o1_ooool01?l00?ooooooooooool00?m[ooooo`03o`000?oooooooooo00?ooooo000Cooooo`;o
0000<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool01Oooool2o`00o`Sooooo00?o003oooooooooool08Oooool00ol0003oooooooooo`09ooooo`03
o`00oooooooooooo00Gooooo00Co003ooooooooooooo003oJ_ooool2o`0000Gooooo000Cooooo`03
o`000?oooooooooo037ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`;o
003o3oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo003o02?ooooo00?o0000oooooooo
ool02Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo003o06cooooo00?o0000oooooooo
ool00oooool001?ooooo00?o0000ooooooooool0>_ooool00ol00?ooooooooooo`05ooooo`;o003o
1_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooo003o02?ooooo00?o0000ooooooooool0
2_ooool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oo
oooooooo03[ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`;o003o2?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02?ooooo00?o0000ooooooooool02Ooo
ool2o`00ogGooooo00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool0>_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo0_l00?l7ooooo`;o003o;?ooool0
0ol0003oooooooooo`09ooooo`;o003o1_ooool00ol00?ooooooo`00o`1/ooooo`03o`000?oooooo
oooo00?ooooo000Cooooo`;o0000C?ooool00ol00?ooooooooooo`05ooooo`;o003o2?ooool00ol0
0?ooooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo0_l00?l6ooooo`03o`00oooooooo003o
06_ooooo0_l00005ooooo`004oooool00ol0003oooooooooo`12ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`0Sooooo`03o`000?oooooooooo00Wo
oooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`1/ooooo`03o`000?oooooooooo00?o
oooo000Cooooo`03o`000?oooooooooo04;ooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Gooooo0_l00?lTooooo`03o`000?oooooooooo00Wooooo
00?o003oooooooooool0M?ooool00ol0003oooooooooo`03ooooo`004oooool00ol0003ooooooooo
o`12ooooo`03o`00oooooooooooo00Gooooo0_l00?l7ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool08oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo07Cooooo00?o
0000ooooooooool00oooool001?ooooo00?o0000ooooooooool0B_ooool2o`00o`Oooooo00?o003o
ooooooooool0:oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo00Gooooo0_l00?m]
ooooo`03o`000?oooooooooo00?ooooo000Cooooo`;o0000Boooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool08_ooool00ol0003oooooooooo`0Aoooo
o`;o003oK?ooool2o`0000Gooooo000Cooooo`03o`000?oooooooooo04[ooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`05ooooo`;o003o9?ooool00ol0003oooooooooo`0Aooooo`;o
003oKOooool00ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`1Cooooo`03o`00
oooooooooooo00Gooooo0_l00?lTooooo`03o`000?oooooooooo017ooooo0_l00?m]ooooo`03o`00
0?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo05?ooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0Sooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool00ooo
ool001?ooooo00?o0000ooooooooool0Doooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo02?ooooo00?o0000ooooooooool04Oooool2o`00ofgooooo00?o0000ooooooooool00oooool0
01?ooooo00?o0000ooooooooool0Doooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
02?ooooo00?o0000ooooooooool04Oooool2o`00ofgooooo00?o0000ooooooooool00oooool001?o
oooo0_l0001Looooo`03o`00oooooooooooo02?ooooo00?o0000ooooooooool04Oooool2o`00ofco
oooo0_l00005ooooo`004oooool00ol0003oooooooooo`1Kooooo`03o`00oooooooooooo02?ooooo
00?o0000ooooooooool04Oooool2o`00ofgooooo00?o0000ooooooooool00oooool000_ooooo0ol0
0005ooooo`03o`000?oooooooooo05_ooooo00?o003oooooooooool08oooool00ol0003ooooooooo
o`20ooooo`03o`000?oooooooooo00?ooooo000:ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`1Kooooo`03o`00oooooooooooo02?ooooo00?o0000ooooooooool0P?oo
ool00ol0003oooooooooo`03ooooo`003_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo087ooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`03ooooo`003?ooool2o`00
00Gooooo0ol00021ooooo`03o`000?oooooooooo07kooooo0ol00005ooooo`003_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool000[ooooo
00Go0000ooooooooooooooooo`000004oooooooo00002Ol00005ooooo`002oooool3o`000?oooooo
4oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-6.03148, -3.56329, \
0.0399221, 0.0380621}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Show all", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{{g3, g4}, {g6, g8}}], \ 
        ImageSize \[Rule] 504];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 504 311.489 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.0147151 0.0391604 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09304 -6 -4.5 ]
[-0.0125 .09304 0 4.5 ]
[-0.0125 .17136 -6 -4.5 ]
[-0.0125 .17136 0 4.5 ]
[-0.0125 .24968 -6 -4.5 ]
[-0.0125 .24968 0 4.5 ]
[-0.0125 .328 -6 -4.5 ]
[-0.0125 .328 0 4.5 ]
[-0.0125 .40632 -12 -4.5 ]
[-0.0125 .40632 0 4.5 ]
[-0.0125 .48464 -12 -4.5 ]
[-0.0125 .48464 0 4.5 ]
[-0.0125 .56296 -12 -4.5 ]
[-0.0125 .56296 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09304 m
.00625 .09304 L
s
[(2)] -0.0125 .09304 1 0 Mshowa
0 .17136 m
.00625 .17136 L
s
[(4)] -0.0125 .17136 1 0 Mshowa
0 .24968 m
.00625 .24968 L
s
[(6)] -0.0125 .24968 1 0 Mshowa
0 .328 m
.00625 .328 L
s
[(8)] -0.0125 .328 1 0 Mshowa
0 .40632 m
.00625 .40632 L
s
[(10)] -0.0125 .40632 1 0 Mshowa
0 .48464 m
.00625 .48464 L
s
[(12)] -0.0125 .48464 1 0 Mshowa
0 .56296 m
.00625 .56296 L
s
[(14)] -0.0125 .56296 1 0 Mshowa
.125 Mabswid
0 .0343 m
.00375 .0343 L
s
0 .05388 m
.00375 .05388 L
s
0 .07346 m
.00375 .07346 L
s
0 .11262 m
.00375 .11262 L
s
0 .1322 m
.00375 .1322 L
s
0 .15178 m
.00375 .15178 L
s
0 .19094 m
.00375 .19094 L
s
0 .21052 m
.00375 .21052 L
s
0 .2301 m
.00375 .2301 L
s
0 .26926 m
.00375 .26926 L
s
0 .28884 m
.00375 .28884 L
s
0 .30842 m
.00375 .30842 L
s
0 .34758 m
.00375 .34758 L
s
0 .36716 m
.00375 .36716 L
s
0 .38674 m
.00375 .38674 L
s
0 .4259 m
.00375 .4259 L
s
0 .44548 m
.00375 .44548 L
s
0 .46506 m
.00375 .46506 L
s
0 .50422 m
.00375 .50422 L
s
0 .5238 m
.00375 .5238 L
s
0 .54338 m
.00375 .54338 L
s
0 .58254 m
.00375 .58254 L
s
0 .60212 m
.00375 .60212 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09304 m
1 .09304 L
s
.99375 .17136 m
1 .17136 L
s
.99375 .24968 m
1 .24968 L
s
.99375 .328 m
1 .328 L
s
.99375 .40632 m
1 .40632 L
s
.99375 .48464 m
1 .48464 L
s
.99375 .56296 m
1 .56296 L
s
.125 Mabswid
.99625 .0343 m
1 .0343 L
s
.99625 .05388 m
1 .05388 L
s
.99625 .07346 m
1 .07346 L
s
.99625 .11262 m
1 .11262 L
s
.99625 .1322 m
1 .1322 L
s
.99625 .15178 m
1 .15178 L
s
.99625 .19094 m
1 .19094 L
s
.99625 .21052 m
1 .21052 L
s
.99625 .2301 m
1 .2301 L
s
.99625 .26926 m
1 .26926 L
s
.99625 .28884 m
1 .28884 L
s
.99625 .30842 m
1 .30842 L
s
.99625 .34758 m
1 .34758 L
s
.99625 .36716 m
1 .36716 L
s
.99625 .38674 m
1 .38674 L
s
.99625 .4259 m
1 .4259 L
s
.99625 .44548 m
1 .44548 L
s
.99625 .46506 m
1 .46506 L
s
.99625 .50422 m
1 .50422 L
s
.99625 .5238 m
1 .5238 L
s
.99625 .54338 m
1 .54338 L
s
.99625 .58254 m
1 .58254 L
s
.99625 .60212 m
1 .60212 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .05388 m
.02395 .05387 L
.02408 .05386 L
.02423 .05384 L
.02437 .05382 L
.02462 .05375 L
.02489 .05365 L
.02519 .05351 L
.02551 .05332 L
.02608 .05289 L
.02722 .05167 L
.02847 .04979 L
.02973 .04735 L
.03109 .04415 L
.03355 .03706 L
.03593 .02895 L
.03718 .02431 L
.03852 .01921 L
.03884 .01796 L
.03919 .01661 L
.03935 .01599 L
.03952 .01534 L
.03967 .01478 L
.03982 .01527 L
.04101 .01984 L
.04331 .02852 L
.04586 .03727 L
.04819 .04404 L
.04934 .04685 L
.0506 .04943 L
.05177 .05137 L
.05288 .05274 L
.05342 .05325 L
.05401 .05367 L
.05433 .05385 L
.05467 .05399 L
.05495 .05408 L
.05511 .05411 L
.05526 .05414 L
.05542 .05415 L
.05551 .05416 L
.05559 .05416 L
.05575 .05416 L
.05582 .05415 L
.05591 .05414 L
.05605 .05412 L
.05621 .05409 L
.05649 .05401 L
.05666 .05395 L
.05684 .05387 L
Mistroke
.05717 .05369 L
.0578 .05323 L
.05844 .05262 L
.05905 .05189 L
.06017 .05019 L
.06271 .0448 L
.06513 .03785 L
.06736 .03027 L
.06855 .02587 L
.06983 .02098 L
.07045 .01857 L
.07075 .01738 L
.07103 .01627 L
.07129 .01527 L
.07142 .01476 L
.07156 .01523 L
.07213 .01748 L
.07672 .03468 L
.07925 .0427 L
.08036 .0457 L
.08157 .04855 L
.08267 .05073 L
.08385 .05259 L
.0845 .0534 L
.08509 .054 L
.08568 .05446 L
.08624 .05478 L
.08653 .05489 L
.0868 .05497 L
.08696 .055 L
.0871 .05502 L
.08718 .05503 L
.08726 .05504 L
.08742 .05504 L
.08757 .05503 L
.08765 .05503 L
.08773 .05502 L
.08789 .05499 L
.08806 .05495 L
.08838 .05485 L
.08866 .05473 L
.08918 .05442 L
.08975 .05396 L
.09089 .05266 L
.09213 .0507 L
.09325 .04845 L
.09578 .0419 L
.09828 .0337 L
.10059 .02504 L
.10176 .02044 L
Mistroke
.10233 .01815 L
.10284 .01605 L
.10298 .01551 L
.10313 .01491 L
.10326 .01508 L
.10339 .0156 L
.10398 .01798 L
.10523 .02302 L
.10995 .04042 L
.11254 .04789 L
.11372 .05063 L
.11497 .053 L
.11612 .05468 L
.11678 .05541 L
.11739 .05593 L
.11768 .05613 L
.11795 .05628 L
.1182 .05639 L
.11847 .05649 L
.1186 .05652 L
.11875 .05655 L
.11889 .05657 L
.11902 .05659 L
.11917 .05659 L
.11931 .05659 L
.11946 .05658 L
.11954 .05657 L
.11962 .05656 L
.11978 .05652 L
.11993 .05648 L
.12026 .05636 L
.12055 .05622 L
.12086 .05603 L
.1214 .0556 L
.12199 .055 L
.12329 .05319 L
.12451 .0509 L
.12696 .04475 L
.1292 .03753 L
.13169 .02814 L
.1329 .02321 L
.134 .01863 L
.13455 .01629 L
.1347 .01564 L
.13479 .01529 L
.13486 .01496 L
.135 .01505 L
.13515 .01569 L
.13623 .02029 L
.13861 .03016 L
Mistroke
.14331 .04691 L
.14454 .05033 L
.14588 .05346 L
.14714 .05581 L
.14771 .05665 L
.14831 .05742 L
.14892 .05804 L
.14948 .05847 L
.14974 .05863 L
.15003 .05877 L
.15017 .05883 L
.15031 .05887 L
.15044 .05891 L
.15057 .05893 L
.15065 .05895 L
.15074 .05896 L
.15089 .05897 L
.15098 .05898 L
.15107 .05897 L
.15116 .05897 L
.15124 .05896 L
.15139 .05894 L
.15148 .05893 L
.15156 .05891 L
.15187 .05881 L
.15214 .05869 L
.15244 .05853 L
.15305 .05807 L
.15365 .05747 L
.15427 .05667 L
.15539 .05486 L
.15659 .05235 L
.1579 .04897 L
.16279 .03171 L
.16505 .02199 L
.16567 .01922 L
.16601 .0177 L
.16632 .01627 L
.16646 .01564 L
.16659 .01505 L
.16675 .01507 L
.16688 .0157 L
.1675 .01849 L
.17007 .02999 L
.1725 .04009 L
.17492 .04881 L
.17711 .05513 L
.17834 .05788 L
.17949 .05991 L
.18008 .06073 L
Mistroke
.18071 .06142 L
.18103 .06172 L
.18139 .06198 L
.18172 .06218 L
.18202 .06231 L
.18217 .06236 L
.18233 .0624 L
.18247 .06243 L
.18263 .06245 L
.18271 .06246 L
.18279 .06246 L
.18287 .06246 L
.18296 .06245 L
.18312 .06244 L
.1832 .06243 L
.18328 .06241 L
.18344 .06237 L
.18359 .06232 L
.18386 .06221 L
.18416 .06204 L
.18448 .06182 L
.18504 .06131 L
.18564 .0606 L
.18672 .05893 L
.18786 .0566 L
.18908 .05349 L
.19129 .04642 L
.19368 .03698 L
.19627 .02515 L
.19748 .0193 L
.19809 .0163 L
.19826 .01547 L
.19835 .01501 L
.19844 .01485 L
.1986 .01564 L
.19877 .01647 L
.20107 .02785 L
.20567 .0484 L
.20803 .05675 L
.20934 .06049 L
.21055 .06328 L
.21178 .06543 L
.21243 .06627 L
.21277 .06662 L
.21312 .06693 L
.21343 .06715 L
.21372 .06731 L
.21386 .06737 L
.21401 .06743 L
.21415 .06747 L
Mistroke
.21428 .0675 L
.21436 .06752 L
.21445 .06753 L
.2146 .06754 L
.21468 .06754 L
.21477 .06753 L
.21485 .06753 L
.21494 .06752 L
.21509 .06749 L
.21518 .06747 L
.21526 .06745 L
.21555 .06733 L
.21583 .06719 L
.21613 .06698 L
.21675 .06641 L
.21732 .06571 L
.21785 .06491 L
.21906 .06257 L
.22036 .05926 L
.22277 .0511 L
.22532 .04009 L
.22773 .02796 L
.22878 .02232 L
.22933 .01929 L
.22963 .01763 L
.22992 .01606 L
.23006 .01525 L
.23022 .01505 L
.23031 .01554 L
.23039 .01601 L
.23055 .01689 L
.23113 .02015 L
.23228 .02654 L
.23481 .04017 L
.23942 .06115 L
.2418 .06876 L
.24249 .07045 L
.24313 .07181 L
.2437 .07283 L
.24433 .07374 L
.24463 .0741 L
.24494 .07442 L
.24522 .07465 L
.24551 .07485 L
.24569 .07495 L
.24585 .07502 L
.246 .07508 L
.24608 .0751 L
.24617 .07512 L
.24631 .07514 L
Mistroke
.24645 .07516 L
.24653 .07516 L
.24661 .07516 L
.24676 .07514 L
.2469 .07512 L
.24703 .07509 L
.24717 .07504 L
.24731 .07498 L
.24756 .07485 L
.24782 .07466 L
.24843 .07409 L
.24899 .07337 L
.25016 .07127 L
.25126 .06858 L
.25375 .06006 L
.2562 .04875 L
.25844 .03638 L
.26074 .02224 L
.26137 .0182 L
.26169 .01614 L
.26177 .01557 L
.26187 .01496 L
.26196 .01504 L
.26204 .01557 L
.26324 .02343 L
.26802 .05341 L
.27042 .06629 L
.27261 .0758 L
.27374 .07972 L
.27497 .08312 L
.27565 .08458 L
.27627 .08566 L
.27687 .08645 L
.27717 .08676 L
.2775 .08703 L
.2778 .0872 L
.27797 .08727 L
.27813 .08732 L
.27828 .08735 L
.27841 .08736 L
.27857 .08736 L
.27872 .08734 L
.27886 .08731 L
.279 .08726 L
.27912 .08721 L
.27926 .08714 L
.27956 .08694 L
.27984 .0867 L
.28048 .08593 L
.28106 .08498 L
Mistroke
.28236 .08198 L
.28356 .07818 L
.28466 .07381 L
.28717 .0611 L
.28961 .04544 L
.29081 .03683 L
.29191 .02852 L
.29298 .02013 L
.29324 .01805 L
.29351 .01582 L
.29367 .01489 L
.29382 .01607 L
.2941 .01836 L
.29646 .03766 L
.30129 .07448 L
.3035 .0883 L
.30476 .09487 L
.30593 .10003 L
.30709 .10409 L
.30768 .10576 L
.30833 .10724 L
.30868 .1079 L
.30901 .10841 L
.30935 .10884 L
.30966 .10914 L
.3098 .10925 L
.30996 .10935 L
.31011 .10943 L
.31024 .10948 L
.31039 .10951 L
.31055 .10953 L
.31063 .10953 L
.31071 .10952 L
.31087 .10949 L
.31102 .10944 L
.3111 .1094 L
.31118 .10936 L
.31151 .10912 L
.31179 .10884 L
.3121 .10844 L
.3128 .10722 L
.31344 .10569 L
.31468 .10161 L
.31587 .0964 L
.31826 .08206 L
.32047 .06457 L
.32274 .04318 L
.32393 .03078 L
.32458 .02373 L
.3249 .02023 L
Mistroke
.32519 .01701 L
.32535 .01523 L
.3255 .01588 L
.32566 .01767 L
.32583 .01963 L
.32654 .02766 L
.32777 .04198 L
.33021 .0702 L
.33254 .09616 L
.33512 .12179 L
.33757 .14148 L
.33866 .14846 L
.33986 .15459 L
.34043 .15692 L
.34104 .15896 L
.34138 .15988 L
.34169 .16058 L
.342 .16117 L
.34229 .1616 L
.34256 .16189 L
.34269 .16199 L
.34284 .16208 L
.34299 .16214 L
.34308 .16216 L
.34315 .16217 L
.3433 .16217 L
.34344 .16213 L
.34357 .16207 L
.34371 .16199 L
.34384 .16188 L
.34396 .16176 L
.34425 .16137 L
.34452 .1609 L
.34509 .15957 L
.3457 .15756 L
.34635 .15483 L
.34695 .15171 L
.34803 .14471 L
.34918 .13519 L
.35175 .10652 L
.35417 .0702 L
.35534 .04977 L
.35598 .03781 L
.35658 .02612 L
.35683 .02115 L
.35696 .01841 L
.35709 .01584 L
.35722 .0164 L
.35737 .0195 L
.35764 .02499 L
Mistroke
.3588 .05034 L
.36352 .16499 L
.36853 .29692 L
.37335 .41779 L
.378 .51366 L
.3804 .55141 L
.38163 .56698 L
.38294 .58073 L
.38418 .59076 L
.38531 .59739 L
.38585 .59971 L
.38613 .6007 L
.38644 .60158 L
.3867 .6022 L
.38685 .60248 L
.387 .60273 L
.38714 .60292 L
.38726 .60307 L
.38739 .60317 L
.38752 .60325 L
.38766 .60331 L
.38775 .60332 L
.38782 .60332 L
.38797 .60328 L
.38812 .60321 L
.38825 .6031 L
.38838 .60297 L
.38866 .60256 L
.38897 .60193 L
.38926 .6012 L
.38989 .599 L
.39044 .59651 L
.39103 .59316 L
.39211 .5854 L
.39335 .57384 L
.39448 .56106 L
.39701 .52502 L
.40184 .43261 L
.4065 .32483 L
.41144 .20463 L
.41621 .09726 L
.4186 .05004 L
.41965 .03127 L
.41994 .02633 L
.42024 .0212 L
.4205 .0169 L
.42065 .01495 L
.42079 .01719 L
.422 .03573 L
.42314 .05163 L
Mistroke
.42567 .08078 L
.42685 .09163 L
.4281 .10109 L
.42927 .10813 L
.43033 .11304 L
.43089 .11505 L
.43148 .11681 L
.43181 .1176 L
.43212 .11821 L
.43243 .11873 L
.43272 .11911 L
.43296 .11937 L
.43309 .11947 L
.43323 .11957 L
.43338 .11965 L
.43352 .1197 L
.43366 .11973 L
.43379 .11974 L
.43394 .11973 L
.43408 .1197 L
.43421 .11965 L
.43434 .11958 L
.43449 .11949 L
.43465 .11936 L
.43493 .11908 L
.43524 .11867 L
.43553 .1182 L
.43608 .11711 L
.43731 .11369 L
.43837 .10972 L
.43952 .10447 L
.44444 .07372 L
.44689 .05551 L
.44919 .03803 L
.45031 .02959 L
.45139 .02176 L
.45198 .01755 L
.45214 .01642 L
.45223 .0158 L
.45231 .01521 L
.45239 .01476 L
.45247 .01535 L
.45262 .01636 L
.45375 .02392 L
.45611 .03816 L
.45869 .05091 L
.45988 .05562 L
.46115 .05982 L
.46236 .06298 L
.46345 .06515 L
Mistroke
.46403 .06603 L
.46465 .06676 L
.46517 .06722 L
.46547 .06742 L
.46575 .06756 L
.4659 .06761 L
.46606 .06766 L
.46614 .06768 L
.46623 .0677 L
.46638 .06772 L
.46654 .06773 L
.46668 .06772 L
.46681 .06771 L
.46696 .06769 L
.46711 .06765 L
.46729 .06759 L
.46763 .06743 L
.46796 .06723 L
.46826 .067 L
.46886 .06641 L
.46951 .06557 L
.4707 .06355 L
.47294 .05823 L
.47531 .05074 L
.47784 .04122 L
.48025 .03124 L
.48152 .02582 L
.48286 .02008 L
.48344 .01761 L
.48376 .01625 L
.48392 .01559 L
.48406 .01498 L
.48415 .0148 L
.48423 .01517 L
.48442 .01594 L
.48475 .0173 L
.48538 .01991 L
.4877 .02894 L
.49008 .03717 L
.49226 .04348 L
.49459 .04872 L
.49582 .05078 L
.49649 .05169 L
.49711 .05239 L
.49766 .0529 L
.49826 .05334 L
.49859 .05352 L
.49889 .05366 L
.49919 .05376 L
.49933 .0538 L
Mistroke
.49949 .05383 L
.49964 .05385 L
.49978 .05387 L
.49991 .05387 L
.50004 .05388 L
.50019 .05387 L
.50035 .05385 L
.50049 .05383 L
.50064 .0538 L
.5009 .05373 L
.50119 .05362 L
.50171 .05335 L
.5023 .05293 L
.50286 .05242 L
.50412 .05087 L
.50535 .04883 L
.50666 .04612 L
.50923 .0393 L
.51166 .03127 L
.51387 .02292 L
.51447 .0205 L
.51512 .01784 L
.51544 .01654 L
.51559 .01589 L
.51574 .01529 L
.51586 .01475 L
.516 .01526 L
.5163 .0165 L
.51869 .02673 L
.52123 .03744 L
.52363 .04694 L
.52624 .05583 L
.52746 .05932 L
.52876 .06244 L
.52986 .06458 L
.53107 .06632 L
.53171 .06697 L
.53202 .06721 L
.5323 .0674 L
.53256 .06753 L
.53284 .06763 L
.53298 .06767 L
.53312 .0677 L
.53327 .06772 L
.53343 .06773 L
.53358 .06772 L
.53373 .0677 L
.53382 .06769 L
.53389 .06767 L
.53407 .06762 L
Mistroke
.53423 .06756 L
.53441 .06748 L
.53474 .06728 L
.53505 .06704 L
.53537 .06674 L
.53595 .06605 L
.53709 .06416 L
.53831 .06133 L
.54052 .05412 L
.54307 .04256 L
.5455 .02872 L
.54666 .02126 L
.54699 .01902 L
.5473 .01689 L
.54744 .01595 L
.54759 .01495 L
.54774 .01559 L
.54789 .01661 L
.55011 .03275 L
.5547 .06744 L
.55725 .0855 L
.55958 .09973 L
.56074 .1057 L
.56199 .11116 L
.56318 .11519 L
.56375 .11672 L
.56428 .11785 L
.56484 .11878 L
.56513 .11915 L
.56528 .1193 L
.56544 .11944 L
.56558 .11954 L
.56571 .11961 L
.56584 .11967 L
.56596 .11971 L
.56611 .11974 L
.56624 .11974 L
.56638 .11972 L
.56653 .11968 L
.56669 .11962 L
.56683 .11953 L
.56699 .11941 L
.56715 .11927 L
.56742 .11894 L
.56772 .1185 L
.56839 .11711 L
.56902 .11535 L
.57018 .11085 L
.57127 .10511 L
.57246 .09708 L
Mistroke
.57375 .08635 L
.57617 .06044 L
.57739 .04438 L
.57807 .03474 L
.57871 .02511 L
.579 .02058 L
.57916 .01805 L
.57931 .01566 L
.57938 .01502 L
.57947 .01638 L
.57964 .01928 L
.57995 .02449 L
.58109 .04437 L
.5833 .08713 L
.58828 .19793 L
.59307 .31423 L
.59768 .42215 L
.60025 .4759 L
.60258 .51832 L
.60504 .55501 L
.6073 .58027 L
.60843 .58955 L
.60963 .59682 L
.61025 .59954 L
.61082 .60142 L
.61116 .60222 L
.61146 .60275 L
.61163 .60297 L
.61171 .60307 L
.61181 .60315 L
.61189 .60321 L
.61198 .60326 L
.61214 .60331 L
.61229 .60332 L
.61242 .60328 L
.61257 .6032 L
.61266 .60314 L
.61273 .60307 L
.61289 .60289 L
.61305 .60265 L
.61336 .60207 L
.61364 .60137 L
.61394 .60046 L
.61447 .5984 L
.61509 .59533 L
.61567 .59179 L
.61699 .58138 L
.61825 .56846 L
.61944 .5536 L
.62167 .51931 L
Mistroke
.62629 .426 L
.6312 .30406 L
.63593 .17937 L
.63834 .11782 L
.63961 .08695 L
.64095 .05585 L
.64216 .02937 L
.64249 .02239 L
.64267 .0186 L
.64276 .01676 L
.64284 .01506 L
.64292 .01596 L
.643 .01764 L
.64317 .02116 L
.64348 .02722 L
.64579 .06966 L
.64818 .10548 L
.65036 .13076 L
.65156 .1415 L
.6527 .14961 L
.6539 .15596 L
.65458 .15856 L
.65491 .15956 L
.65521 .16034 L
.65551 .16095 L
.65583 .16148 L
.65598 .16169 L
.65615 .16187 L
.65624 .16195 L
.65632 .16201 L
.6564 .16206 L
.65649 .1621 L
.65664 .16216 L
.65678 .16217 L
.65694 .16216 L
.65702 .16214 L
.6571 .16211 L
.65725 .16203 L
.65739 .16193 L
.65769 .16162 L
.65796 .16123 L
.65821 .16078 L
.65878 .15945 L
.65934 .15774 L
.65993 .15549 L
.66117 .14944 L
.66251 .14098 L
.66494 .12124 L
.66987 .06933 L
.67232 .04085 L
Mistroke
.67352 .02697 L
.67409 .02048 L
.67437 .01734 L
.67449 .01598 L
.67462 .01491 L
.67476 .01642 L
.67488 .01783 L
.67516 .02092 L
.67575 .02736 L
.67682 .0387 L
.67919 .06159 L
.68155 .08068 L
.6828 .08901 L
.68414 .09643 L
.68543 .10205 L
.68661 .10581 L
.68717 .10716 L
.68747 .10775 L
.68779 .10828 L
.68806 .10867 L
.68837 .10901 L
.68865 .10925 L
.68878 .10934 L
.68891 .1094 L
.68905 .10946 L
.6892 .10951 L
.68934 .10952 L
.68947 .10953 L
.68963 .10951 L
.68977 .10947 L
.68993 .10941 L
.69009 .10932 L
.6904 .10909 L
.69069 .10879 L
.69134 .10785 L
.69191 .10674 L
.69242 .10549 L
.69358 .10188 L
.69588 .09169 L
.69838 .07673 L
.70071 .06002 L
.70329 .03966 L
.70446 .03008 L
.70508 .02504 L
.70573 .01974 L
.70601 .0175 L
.70616 .01627 L
.7063 .01511 L
.70638 .01498 L
.70647 .01569 L
Mistroke
.70662 .01693 L
.70692 .01934 L
.70802 .02798 L
.71037 .04531 L
.71295 .06179 L
.71413 .06817 L
.7154 .07409 L
.71659 .07871 L
.7177 .08214 L
.71892 .08494 L
.71956 .08599 L
.71989 .08641 L
.72025 .08678 L
.72041 .08692 L
.72059 .08705 L
.72075 .08715 L
.7209 .08722 L
.72105 .08728 L
.7212 .08732 L
.72128 .08734 L
.72137 .08735 L
.72152 .08736 L
.72166 .08736 L
.72181 .08733 L
.72193 .0873 L
.72207 .08726 L
.72222 .08719 L
.72238 .0871 L
.72267 .0869 L
.72296 .08664 L
.72327 .08629 L
.72383 .08551 L
.72449 .08431 L
.72509 .08297 L
.7264 .07927 L
.72763 .07486 L
.73228 .05172 L
.73463 .03727 L
.73587 .02923 L
.73656 .02474 L
.73721 .02048 L
.73751 .01854 L
.73783 .01647 L
.73792 .01586 L
.73801 .01528 L
.73809 .01477 L
.73817 .01522 L
.73849 .01731 L
.73967 .0248 L
.74196 .03872 L
Mistroke
.74433 .0514 L
.74692 .06265 L
.74811 .06673 L
.74939 .07024 L
.75001 .07161 L
.75059 .07271 L
.75116 .07358 L
.75169 .07422 L
.75224 .07471 L
.75254 .0749 L
.7527 .07498 L
.75286 .07505 L
.75301 .0751 L
.7531 .07512 L
.75319 .07513 L
.75327 .07515 L
.75335 .07515 L
.7535 .07516 L
.75365 .07515 L
.75379 .07513 L
.75394 .07509 L
.75409 .07504 L
.75436 .07492 L
.75464 .07475 L
.75515 .07432 L
.75576 .07362 L
.75632 .0728 L
.75751 .07045 L
.75862 .06762 L
.76112 .05906 L
.76585 .03669 L
.76701 .03044 L
.76823 .02372 L
.76927 .01792 L
.76955 .01633 L
.76971 .01546 L
.76986 .01479 L
.76999 .01556 L
.77014 .01639 L
.7704 .01783 L
.77273 .03039 L
.77525 .04274 L
.7776 .05251 L
.77884 .05684 L
.78018 .06073 L
.78146 .06367 L
.78263 .06565 L
.7832 .06635 L
.7835 .06666 L
.78381 .06693 L
Mistroke
.78412 .06715 L
.78439 .06731 L
.78453 .06737 L
.78467 .06742 L
.7848 .06746 L
.78493 .0675 L
.78508 .06752 L
.78522 .06753 L
.78537 .06754 L
.78545 .06754 L
.78553 .06753 L
.78565 .06751 L
.78579 .06749 L
.78594 .06745 L
.78608 .0674 L
.7864 .06725 L
.78669 .06707 L
.78734 .06652 L
.78793 .06583 L
.78858 .06488 L
.78988 .06236 L
.79225 .05588 L
.79478 .04664 L
.79718 .03615 L
.79845 .03017 L
.79978 .02364 L
.80098 .01772 L
.80131 .0161 L
.8014 .01563 L
.80149 .01519 L
.80157 .01479 L
.80166 .01508 L
.80174 .01549 L
.80182 .01587 L
.80199 .01671 L
.8023 .01821 L
.80461 .02931 L
.80713 .04037 L
.80945 .04899 L
.81172 .0556 L
.81286 .05814 L
.8135 .05932 L
.81411 .06027 L
.8147 .06103 L
.81535 .06168 L
.81563 .0619 L
.81593 .0621 L
.81619 .06223 L
.81647 .06234 L
.81664 .06239 L
Mistroke
.81672 .06241 L
.8168 .06243 L
.81694 .06245 L
.8171 .06246 L
.81719 .06246 L
.81727 .06246 L
.81743 .06245 L
.81751 .06243 L
.81759 .06242 L
.81777 .06238 L
.81792 .06233 L
.81806 .06228 L
.81837 .06213 L
.81867 .06194 L
.819 .06169 L
.81963 .06107 L
.82022 .06033 L
.82156 .05809 L
.82273 .05551 L
.82398 .05218 L
.82854 .0359 L
.83107 .02497 L
.83217 .01998 L
.83276 .01732 L
.83291 .01662 L
.83308 .01586 L
.83324 .01514 L
.83339 .01495 L
.83353 .0156 L
.83368 .01631 L
.834 .01774 L
.83456 .02026 L
.83566 .02511 L
.83805 .03512 L
.84059 .04438 L
.84292 .05114 L
.84406 .05378 L
.84532 .05606 L
.84589 .05689 L
.8465 .05763 L
.84708 .05818 L
.8476 .05855 L
.84788 .0587 L
.84819 .05883 L
.84834 .05888 L
.84851 .05892 L
.84867 .05895 L
.84881 .05897 L
.84895 .05898 L
.84908 .05897 L
Mistroke
.84923 .05896 L
.84938 .05894 L
.84952 .05892 L
.84964 .05889 L
.84992 .05879 L
.85023 .05865 L
.85056 .05845 L
.85113 .05799 L
.85176 .05735 L
.85244 .05645 L
.85368 .05435 L
.85481 .05193 L
.85733 .04492 L
.85985 .03617 L
.86216 .02701 L
.86333 .02214 L
.86442 .01752 L
.8647 .01632 L
.86484 .01573 L
.86497 .01519 L
.86512 .01487 L
.86519 .0152 L
.86528 .01555 L
.86556 .01674 L
.86681 .022 L
.87136 .03945 L
.87369 .04657 L
.87489 .04959 L
.8762 .05231 L
.87745 .0543 L
.87805 .05505 L
.87861 .05561 L
.87892 .05587 L
.87926 .0561 L
.87954 .05627 L
.87984 .05641 L
.88 .05646 L
.88018 .05651 L
.88027 .05654 L
.88036 .05655 L
.88045 .05657 L
.88053 .05658 L
.88068 .05659 L
.88076 .05659 L
.88085 .05659 L
.88093 .05659 L
.88101 .05658 L
.88116 .05657 L
.8813 .05654 L
.88145 .05651 L
Mistroke
.88172 .05642 L
.88204 .05628 L
.88234 .05611 L
.88298 .05563 L
.88358 .05503 L
.88465 .05361 L
.88581 .05159 L
.8882 .04597 L
.89073 .03815 L
.89311 .02953 L
.89529 .02095 L
.89587 .01857 L
.89642 .01635 L
.89657 .01577 L
.8967 .01523 L
.89685 .01483 L
.89699 .0154 L
.89762 .01793 L
.90014 .02786 L
.90478 .0435 L
.90718 .04935 L
.90839 .05157 L
.90907 .0526 L
.90971 .0534 L
.9103 .054 L
.91061 .05426 L
.91094 .0545 L
.91125 .05468 L
.91152 .05481 L
.9118 .05491 L
.91194 .05495 L
.91206 .05498 L
.91221 .05501 L
.91229 .05502 L
.91237 .05503 L
.91246 .05504 L
.91254 .05504 L
.91269 .05504 L
.91284 .05503 L
.91297 .05501 L
.91312 .05499 L
.91327 .05495 L
.91359 .05485 L
.9139 .05471 L
.91423 .05452 L
.91458 .05427 L
.91521 .05371 L
.9158 .05305 L
.91713 .05108 L
.9183 .04883 L
Mistroke
.91955 .04593 L
.92457 .03013 L
.92579 .02556 L
.92708 .02057 L
.92761 .01849 L
.92818 .01624 L
.92835 .01558 L
.92851 .01495 L
.92865 .01504 L
.92881 .01566 L
.9294 .01796 L
.93404 .03516 L
.93638 .04237 L
.93762 .04561 L
.93896 .04858 L
.94023 .05086 L
.94079 .05168 L
.9414 .05244 L
.94194 .053 L
.94252 .05348 L
.94284 .05369 L
.94313 .05385 L
.94342 .05398 L
.94369 .05407 L
.94383 .0541 L
.94398 .05413 L
.94412 .05415 L
.94425 .05416 L
.9444 .05416 L
.94449 .05416 L
.94457 .05416 L
.94471 .05414 L
.94487 .05412 L
.94503 .05408 L
.9452 .05404 L
.94552 .05392 L
.94582 .05377 L
.94611 .0536 L
.94662 .05321 L
.94719 .05267 L
.94833 .05122 L
.94956 .04913 L
.95069 .04679 L
.95321 .04014 L
.95571 .03201 L
.95802 .02356 L
.95918 .01912 L
.95975 .01693 L
.95999 .01597 L
.96014 .01542 L
Mistroke
.96027 .01492 L
.96039 .01501 L
.96053 .01555 L
.96081 .01663 L
.9614 .0189 L
.96265 .02368 L
.96505 .03242 L
.96766 .04074 L
.96888 .04407 L
.97017 .04714 L
.97129 .04936 L
.97248 .05127 L
.97349 .05248 L
.97396 .05293 L
.9744 .05326 L
.97484 .05353 L
.97507 .05363 L
.97532 .05373 L
.97554 .05379 L
.97574 .05384 L
.97585 .05385 L
.97596 .05387 L
.97607 .05387 L
.97619 .05388 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.05556 .01472 m
.05556 .05416 L
s
.0873 .01472 m
.0873 .05504 L
s
.11905 .01472 m
.11905 .05659 L
s
.15079 .01472 m
.15079 .05897 L
s
.18254 .01472 m
.18254 .06244 L
s
.21429 .01472 m
.21429 .0675 L
s
.24603 .01472 m
.24603 .07508 L
s
.27778 .01472 m
.27778 .08719 L
s
.30952 .01472 m
.30952 .10902 L
s
.34127 .01472 m
.34127 .15959 L
s
.37302 .01472 m
.37302 .40985 L
s
.40476 .01472 m
.40476 .36634 L
s
.43651 .01472 m
.43651 .11606 L
s
.46825 .01472 m
.46825 .067 L
s
.5 .01472 m
.5 .05388 L
s
.53175 .01472 m
.53175 .067 L
s
.56349 .01472 m
.56349 .11606 L
s
.59524 .01472 m
.59524 .36634 L
s
.62698 .01472 m
.62698 .40985 L
s
.65873 .01472 m
.65873 .15959 L
s
.69048 .01472 m
.69048 .10902 L
s
.72222 .01472 m
.72222 .08719 L
s
.75397 .01472 m
.75397 .07508 L
s
.78571 .01472 m
.78571 .0675 L
s
.81746 .01472 m
.81746 .06244 L
s
.84921 .01472 m
.84921 .05897 L
s
.88095 .01472 m
.88095 .05659 L
s
.9127 .01472 m
.9127 .05504 L
s
.94444 .01472 m
.94444 .05416 L
s
.97619 .01472 m
.97619 .05388 L
s
.015 w
.05556 .05416 Mdot
.0873 .05504 Mdot
.11905 .05659 Mdot
.15079 .05897 Mdot
.18254 .06244 Mdot
.21429 .0675 Mdot
.24603 .07508 Mdot
.27778 .08719 Mdot
.30952 .10902 Mdot
.34127 .15959 Mdot
.37302 .40985 Mdot
.40476 .36634 Mdot
.43651 .11606 Mdot
.46825 .067 Mdot
.5 .05388 Mdot
.53175 .067 Mdot
.56349 .11606 Mdot
.59524 .36634 Mdot
.62698 .40985 Mdot
.65873 .15959 Mdot
.69048 .10902 Mdot
.72222 .08719 Mdot
.75397 .07508 Mdot
.78571 .0675 Mdot
.81746 .06244 Mdot
.84921 .05897 Mdot
.88095 .05659 Mdot
.9127 .05504 Mdot
.94444 .05416 Mdot
.97619 .05388 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309222 0.0998921 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00955 -12 -4.5 ]
[-0.0125 .00955 0 4.5 ]
[-0.0125 .10944 -12 -4.5 ]
[-0.0125 .10944 0 4.5 ]
[-0.0125 .20933 -12 -4.5 ]
[-0.0125 .20933 0 4.5 ]
[-0.0125 .30922 -6 -4.5 ]
[-0.0125 .30922 0 4.5 ]
[-0.0125 .40911 -6 -4.5 ]
[-0.0125 .40911 0 4.5 ]
[-0.0125 .50901 -6 -4.5 ]
[-0.0125 .50901 0 4.5 ]
[-0.0125 .6089 -6 -4.5 ]
[-0.0125 .6089 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00955 m
.00625 .00955 L
s
[(-3)] -0.0125 .00955 1 0 Mshowa
0 .10944 m
.00625 .10944 L
s
[(-2)] -0.0125 .10944 1 0 Mshowa
0 .20933 m
.00625 .20933 L
s
[(-1)] -0.0125 .20933 1 0 Mshowa
0 .30922 m
.00625 .30922 L
s
[(0)] -0.0125 .30922 1 0 Mshowa
0 .40911 m
.00625 .40911 L
s
[(1)] -0.0125 .40911 1 0 Mshowa
0 .50901 m
.00625 .50901 L
s
[(2)] -0.0125 .50901 1 0 Mshowa
0 .6089 m
.00625 .6089 L
s
[(3)] -0.0125 .6089 1 0 Mshowa
.125 Mabswid
0 .02952 m
.00375 .02952 L
s
0 .0495 m
.00375 .0495 L
s
0 .06948 m
.00375 .06948 L
s
0 .08946 m
.00375 .08946 L
s
0 .12942 m
.00375 .12942 L
s
0 .14939 m
.00375 .14939 L
s
0 .16937 m
.00375 .16937 L
s
0 .18935 m
.00375 .18935 L
s
0 .22931 m
.00375 .22931 L
s
0 .24929 m
.00375 .24929 L
s
0 .26927 m
.00375 .26927 L
s
0 .28924 m
.00375 .28924 L
s
0 .3292 m
.00375 .3292 L
s
0 .34918 m
.00375 .34918 L
s
0 .36916 m
.00375 .36916 L
s
0 .38914 m
.00375 .38914 L
s
0 .42909 m
.00375 .42909 L
s
0 .44907 m
.00375 .44907 L
s
0 .46905 m
.00375 .46905 L
s
0 .48903 m
.00375 .48903 L
s
0 .52899 m
.00375 .52899 L
s
0 .54896 m
.00375 .54896 L
s
0 .56894 m
.00375 .56894 L
s
0 .58892 m
.00375 .58892 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00955 m
1 .00955 L
s
.99375 .10944 m
1 .10944 L
s
.99375 .20933 m
1 .20933 L
s
.99375 .30922 m
1 .30922 L
s
.99375 .40911 m
1 .40911 L
s
.99375 .50901 m
1 .50901 L
s
.99375 .6089 m
1 .6089 L
s
.125 Mabswid
.99625 .02952 m
1 .02952 L
s
.99625 .0495 m
1 .0495 L
s
.99625 .06948 m
1 .06948 L
s
.99625 .08946 m
1 .08946 L
s
.99625 .12942 m
1 .12942 L
s
.99625 .14939 m
1 .14939 L
s
.99625 .16937 m
1 .16937 L
s
.99625 .18935 m
1 .18935 L
s
.99625 .22931 m
1 .22931 L
s
.99625 .24929 m
1 .24929 L
s
.99625 .26927 m
1 .26927 L
s
.99625 .28924 m
1 .28924 L
s
.99625 .3292 m
1 .3292 L
s
.99625 .34918 m
1 .34918 L
s
.99625 .36916 m
1 .36916 L
s
.99625 .38914 m
1 .38914 L
s
.99625 .42909 m
1 .42909 L
s
.99625 .44907 m
1 .44907 L
s
.99625 .46905 m
1 .46905 L
s
.99625 .48903 m
1 .48903 L
s
.99625 .52899 m
1 .52899 L
s
.99625 .54896 m
1 .54896 L
s
.99625 .56894 m
1 .56894 L
s
.99625 .58892 m
1 .58892 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30922 m
1 .30922 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .30922 m
.02847 .26492 L
.03355 .21661 L
.03602 .19312 L
.03723 .18166 L
.03832 .17124 L
.03887 .16604 L
.03916 .1633 L
.03932 .1618 L
.03946 .1604 L
.03959 .15918 L
.03973 .47169 L
.03988 .47023 L
.04002 .46889 L
.04054 .46398 L
.04291 .44142 L
.0477 .39589 L
.05231 .3521 L
.05721 .3055 L
.06193 .26064 L
.06434 .23774 L
.06694 .21296 L
.06817 .20133 L
.06946 .18904 L
.07056 .17855 L
.07087 .17567 L
.07103 .17409 L
.07119 .17259 L
.07134 .1712 L
.0715 .4835 L
.07164 .48212 L
.07178 .48085 L
.07651 .43583 L
.08106 .39256 L
.08591 .34647 L
.09058 .30212 L
.09554 .25496 L
.09802 .23143 L
.10032 .20954 L
.10146 .19868 L
.10254 .18842 L
.10283 .18567 L
.10299 .18416 L
.10314 .18275 L
.10322 .49584 L
.1033 .49505 L
.10348 .49337 L
.10379 .49042 L
.10492 .47968 L
.10989 .43237 L
Mistroke
.11469 .3868 L
.1193 .34297 L
.12421 .29633 L
.12894 .25144 L
.13135 .2285 L
.13262 .21645 L
.13331 .20987 L
.13396 .20373 L
.13454 .19821 L
.1347 .19662 L
.13486 .19512 L
.135 .50759 L
.13516 .50612 L
.13648 .4936 L
.13879 .47159 L
.14372 .4248 L
.14846 .37976 L
.15302 .33646 L
.15788 .29035 L
.16255 .24598 L
.16497 .22299 L
.16556 .2174 L
.16619 .21143 L
.16637 .20967 L
.16646 .2088 L
.16655 .208 L
.1667 .52033 L
.16679 .51954 L
.16688 .51871 L
.16752 .51263 L
.17209 .46919 L
.17696 .42294 L
.18165 .37844 L
.18664 .33113 L
.19144 .28556 L
.19363 .26474 L
.19488 .25288 L
.19606 .24174 L
.1972 .23087 L
.19752 .22789 L
.19785 .22475 L
.19813 .22207 L
.19821 .22134 L
.19829 .22055 L
.19844 .53296 L
.19852 .53217 L
.19861 .53134 L
.19876 .52985 L
.19912 .52649 L
.19976 .52037 L
Mistroke
.20097 .50893 L
.20554 .46562 L
.2104 .41952 L
.21508 .37515 L
.22005 .32799 L
.22484 .28257 L
.22726 .25965 L
.22831 .24968 L
.22945 .23889 L
.22976 .23595 L
.22993 .23435 L
.23009 .23285 L
.23022 .5454 L
.23037 .54403 L
.23067 .54112 L
.23182 .53021 L
.23435 .50624 L
.23934 .45896 L
.24415 .41342 L
.24878 .36962 L
.2537 .32304 L
.25614 .2999 L
.25844 .2782 L
.26063 .25745 L
.26123 .25177 L
.26156 .24867 L
.26172 .24716 L
.26186 .24579 L
.262 .55834 L
.26212 .55714 L
.2624 .5545 L
.26299 .54892 L
.26763 .50502 L
.27257 .45833 L
.27733 .41339 L
.2819 .37019 L
.28676 .32422 L
.28901 .30305 L
.29145 .27999 L
.29209 .27392 L
.29278 .26747 L
.29311 .26433 L
.29327 .26279 L
.29342 .26138 L
.29356 .26009 L
.2937 .57255 L
.29385 .57119 L
.294 .56969 L
.29643 .54681 L
.30131 .50074 L
Mistroke
.30601 .45642 L
.31101 .40934 L
.31583 .36401 L
.32046 .32043 L
.3228 .29838 L
.32405 .28668 L
.32473 .28023 L
.32507 .27705 L
.32523 .2755 L
.32538 .27409 L
.32554 .58648 L
.32568 .58513 L
.326 .58217 L
.32666 .57589 L
.32783 .5649 L
.33013 .54333 L
.33478 .49969 L
.33972 .45332 L
.34448 .4087 L
.34906 .36584 L
.35161 .342 L
.35393 .32026 L
.35509 .30948 L
.35569 .3038 L
.35634 .29776 L
.35661 .29522 L
.3569 .29249 L
.35699 .29173 L
.35707 .29093 L
.35723 .60332 L
.35737 .60198 L
.35753 .60051 L
.35862 .59026 L
.36351 .54465 L
.36822 .5008 L
.37322 .45428 L
.37805 .40953 L
.38268 .36657 L
.38762 .32097 L
.39237 .27716 L
.39693 .23515 L
.4018 .19056 L
.40648 .14778 L
.41146 .10248 L
.41394 .07992 L
.41625 .05903 L
.41848 .03887 L
.41913 .03307 L
.41973 .02762 L
.42027 .02273 L
Mistroke
.42042 .02139 L
.42058 .01997 L
.42071 .33259 L
.42086 .33126 L
.42574 .28749 L
.43044 .24561 L
.43543 .20142 L
.44024 .15921 L
.44487 .11898 L
.44721 .09877 L
.44979 .07662 L
.45097 .06657 L
.45159 .0613 L
.45193 .05844 L
.45209 .05704 L
.45224 .05577 L
.45238 .05456 L
.45252 .36724 L
.45266 .36604 L
.45281 .36474 L
.45344 .35944 L
.45453 .35017 L
.45947 .30878 L
.46423 .26955 L
.4688 .23245 L
.47367 .19367 L
.47836 .15706 L
.48075 .13869 L
.482 .12907 L
.48269 .12381 L
.48334 .11888 L
.48362 .11678 L
.48391 .11457 L
.48407 .11341 L
.48415 .42658 L
.48423 .42597 L
.48453 .42374 L
.48584 .41388 L
.48814 .39659 L
.49285 .36171 L
.49785 .32499 L
.50266 .28972 L
.5073 .25567 L
.50964 .23832 L
.51223 .21909 L
.51341 .21025 L
.51406 .20536 L
.51468 .2007 L
.51525 .19638 L
.51541 .19519 L
Mistroke
.51558 .19393 L
.51573 .19274 L
.51588 .50547 L
.51602 .5044 L
.51615 .50342 L
.51644 .5012 L
.51697 .49716 L
.52174 .46064 L
.52632 .42486 L
.53119 .38603 L
.53589 .34795 L
.54088 .30677 L
.54337 .28591 L
.54447 .27668 L
.54568 .26647 L
.54624 .26176 L
.54684 .25668 L
.54711 .25434 L
.54726 .25307 L
.5474 .25188 L
.54752 .25086 L
.54765 .5636 L
.54779 .56239 L
.54792 .56129 L
.55031 .54099 L
.55513 .49949 L
.55977 .45915 L
.5647 .41583 L
.56946 .37376 L
.57403 .33303 L
.57657 .31026 L
.57778 .29944 L
.57836 .29417 L
.57889 .28939 L
.57903 .28815 L
.57918 .28681 L
.57932 .28555 L
.57945 .5982 L
.57959 .59696 L
.57974 .59561 L
.58004 .59287 L
.5813 .58157 L
.58358 .56098 L
.58846 .51673 L
.59316 .47396 L
.59815 .42832 L
.60297 .38419 L
.6076 .34161 L
.61252 .29619 L
.61727 .25235 L
Mistroke
.62183 .21011 L
.62668 .16504 L
.63135 .12159 L
.63632 .07531 L
.6388 .05218 L
.64001 .04091 L
.64111 .03067 L
.64166 .02553 L
.64226 .01997 L
.64253 .01742 L
.64268 .01602 L
.64282 .01472 L
.64294 .32742 L
.64307 .32623 L
.64334 .3237 L
.64571 .3015 L
.6507 .25488 L
.6555 .20992 L
.66012 .16663 L
.66504 .12052 L
.66977 .07608 L
.67214 .05379 L
.67318 .04402 L
.67377 .03848 L
.67405 .03583 L
.67432 .03333 L
.67446 .03203 L
.67461 .34445 L
.67474 .34317 L
.67487 .34199 L
.67545 .33648 L
.67665 .32523 L
.67916 .30158 L
.68391 .2569 L
.68848 .2139 L
.69334 .16809 L
.69802 .12398 L
.7004 .10154 L
.703 .07706 L
.7042 .0657 L
.70486 .05947 L
.70548 .0536 L
.70576 .05093 L
.70606 .04812 L
.70622 .04664 L
.70631 .04581 L
.70639 .35885 L
.70654 .35748 L
.70669 .35601 L
.70779 .34566 L
Mistroke
.71278 .29853 L
.71759 .25312 L
.72221 .20941 L
.72714 .16289 L
.73188 .11808 L
.73425 .09559 L
.73643 .07499 L
.73702 .06941 L
.73757 .06422 L
.73785 .0616 L
.738 .06014 L
.73814 .37263 L
.7383 .37116 L
.73846 .36958 L
.73877 .36671 L
.74128 .3429 L
.74622 .29616 L
.75098 .25115 L
.75555 .20785 L
.76042 .16174 L
.7651 .11735 L
.76633 .10576 L
.76766 .09313 L
.76827 .08735 L
.76892 .0812 L
.76923 .07821 L
.76953 .0754 L
.76966 .07417 L
.7698 .07287 L
.76995 .38527 L
.77008 .38397 L
.77467 .34047 L
.77956 .29417 L
.78426 .24958 L
.78926 .20219 L
.79407 .15652 L
.79871 .11258 L
.79994 .10086 L
.80055 .09513 L
.8011 .08989 L
.80124 .08854 L
.8014 .08706 L
.80154 .08567 L
.80168 .39819 L
.80184 .39669 L
.80198 .39532 L
.80231 .39226 L
.80363 .37965 L
.80847 .3338 L
.81311 .28969 L
Mistroke
.81806 .24276 L
.82282 .19756 L
.8274 .15409 L
.82995 .12988 L
.83116 .11841 L
.83227 .10781 L
.83283 .10249 L
.83312 .09981 L
.83319 .09908 L
.83328 .09828 L
.83343 .41067 L
.83358 .40922 L
.83375 .40764 L
.83408 .40445 L
.83468 .39875 L
.83697 .37707 L
.84186 .33063 L
.84657 .28591 L
.85157 .23838 L
.85639 .19259 L
.86103 .14852 L
.86343 .12575 L
.86401 .12022 L
.86464 .11427 L
.86482 .11253 L
.86491 .11166 L
.86499 .11086 L
.86515 .42319 L
.86523 .42241 L
.86532 .42157 L
.86596 .41546 L
.87099 .36776 L
.87582 .3218 L
.88048 .27757 L
.88543 .23052 L
.8902 .18521 L
.8926 .1624 L
.89478 .14163 L
.89536 .13612 L
.89599 .13012 L
.89628 .12738 L
.89644 .12587 L
.89659 .12446 L
.89672 .12327 L
.89685 .4358 L
.897 .43436 L
.89714 .43305 L
.89966 .40907 L
.90445 .36359 L
.90905 .31985 L
Mistroke
.91395 .2733 L
.91866 .22849 L
.92367 .18086 L
.92619 .15697 L
.92729 .14649 L
.92787 .14093 L
.92819 .13787 L
.92835 .13636 L
.9285 .13497 L
.92864 .44744 L
.92879 .44601 L
.92911 .44299 L
.92967 .4377 L
.93076 .42733 L
.93314 .40463 L
.93769 .3614 L
.94254 .31534 L
.9472 .27103 L
.95216 .2239 L
.95463 .2004 L
.95693 .17851 L
.95807 .16767 L
.95915 .15742 L
.95975 .15175 L
.95991 .1502 L
.96008 .14856 L
.96023 .14715 L
.96031 .14635 L
.96039 .45942 L
.96054 .45804 L
.96068 .45672 L
.96094 .45425 L
.96152 .44868 L
.96613 .40487 L
.97103 .35825 L
.97575 .31337 L
.97619 .30922 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.05556 .30922 m
.05556 .32123 L
s
.0873 .30922 m
.0873 .33327 L
s
.11905 .30922 m
.11905 .34538 L
s
.15079 .30922 m
.15079 .35761 L
s
.18254 .30922 m
.18254 .37 L
s
.21429 .30922 m
.21429 .38264 L
s
.24603 .30922 m
.24603 .39562 L
s
.27778 .30922 m
.27778 .40911 L
s
.30952 .30922 m
.30952 .42336 L
s
.34127 .30922 m
.34127 .43879 L
s
.37302 .30922 m
.37302 .45622 L
s
.40476 .30922 m
.40476 .16346 L
s
.43651 .30922 m
.43651 .19194 L
s
.46825 .30922 m
.46825 .23687 L
s
.5 .30922 m
.5 .30922 L
s
.53175 .30922 m
.53175 .38158 L
s
.56349 .30922 m
.56349 .4265 L
s
.59524 .30922 m
.59524 .45498 L
s
.62698 .30922 m
.62698 .16223 L
s
.65873 .30922 m
.65873 .17965 L
s
.69048 .30922 m
.69048 .19509 L
s
.72222 .30922 m
.72222 .20933 L
s
.75397 .30922 m
.75397 .22282 L
s
.78571 .30922 m
.78571 .2358 L
s
.81746 .30922 m
.81746 .24844 L
s
.84921 .30922 m
.84921 .26084 L
s
.88095 .30922 m
.88095 .27306 L
s
.9127 .30922 m
.9127 .28517 L
s
.94444 .30922 m
.94444 .29721 L
s
.97619 .30922 m
.97619 .30922 L
s
.015 w
.05556 .32123 Mdot
.0873 .33327 Mdot
.11905 .34538 Mdot
.15079 .35761 Mdot
.18254 .37 Mdot
.21429 .38264 Mdot
.24603 .39562 Mdot
.27778 .40911 Mdot
.30952 .42336 Mdot
.34127 .43879 Mdot
.37302 .45622 Mdot
.40476 .16346 Mdot
.43651 .19194 Mdot
.46825 .23687 Mdot
.5 .30922 Mdot
.53175 .38158 Mdot
.56349 .4265 Mdot
.59524 .45498 Mdot
.62698 .16223 Mdot
.65873 .17965 Mdot
.69048 .19509 Mdot
.72222 .20933 Mdot
.75397 .22282 Mdot
.78571 .2358 Mdot
.81746 .24844 Mdot
.84921 .26084 Mdot
.88095 .27306 Mdot
.9127 .28517 Mdot
.94444 .29721 Mdot
.97619 .30922 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0328407 0.0147151 0.058334 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18801 -0.0125 -3 -9 ]
[.18801 -0.0125 3 0 ]
[.35222 -0.0125 -6 -9 ]
[.35222 -0.0125 6 0 ]
[.51642 -0.0125 -6 -9 ]
[.51642 -0.0125 6 0 ]
[.68062 -0.0125 -6 -9 ]
[.68062 -0.0125 6 0 ]
[.84483 -0.0125 -6 -9 ]
[.84483 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13138 -6 -4.5 ]
[-0.0125 .13138 0 4.5 ]
[-0.0125 .24805 -6 -4.5 ]
[-0.0125 .24805 0 4.5 ]
[-0.0125 .36472 -6 -4.5 ]
[-0.0125 .36472 0 4.5 ]
[-0.0125 .48139 -6 -4.5 ]
[-0.0125 .48139 0 4.5 ]
[-0.0125 .59805 -12 -4.5 ]
[-0.0125 .59805 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18801 0 m
.18801 .00625 L
s
[(5)] .18801 -0.0125 0 1 Mshowa
.35222 0 m
.35222 .00625 L
s
[(10)] .35222 -0.0125 0 1 Mshowa
.51642 0 m
.51642 .00625 L
s
[(15)] .51642 -0.0125 0 1 Mshowa
.68062 0 m
.68062 .00625 L
s
[(20)] .68062 -0.0125 0 1 Mshowa
.84483 0 m
.84483 .00625 L
s
[(25)] .84483 -0.0125 0 1 Mshowa
.125 Mabswid
.05665 0 m
.05665 .00375 L
s
.08949 0 m
.08949 .00375 L
s
.12233 0 m
.12233 .00375 L
s
.15517 0 m
.15517 .00375 L
s
.22085 0 m
.22085 .00375 L
s
.25369 0 m
.25369 .00375 L
s
.28654 0 m
.28654 .00375 L
s
.31938 0 m
.31938 .00375 L
s
.38506 0 m
.38506 .00375 L
s
.4179 0 m
.4179 .00375 L
s
.45074 0 m
.45074 .00375 L
s
.48358 0 m
.48358 .00375 L
s
.54926 0 m
.54926 .00375 L
s
.5821 0 m
.5821 .00375 L
s
.61494 0 m
.61494 .00375 L
s
.64778 0 m
.64778 .00375 L
s
.71346 0 m
.71346 .00375 L
s
.74631 0 m
.74631 .00375 L
s
.77915 0 m
.77915 .00375 L
s
.81199 0 m
.81199 .00375 L
s
.87767 0 m
.87767 .00375 L
s
.91051 0 m
.91051 .00375 L
s
.94335 0 m
.94335 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13138 m
.00625 .13138 L
s
[(2)] -0.0125 .13138 1 0 Mshowa
0 .24805 m
.00625 .24805 L
s
[(4)] -0.0125 .24805 1 0 Mshowa
0 .36472 m
.00625 .36472 L
s
[(6)] -0.0125 .36472 1 0 Mshowa
0 .48139 m
.00625 .48139 L
s
[(8)] -0.0125 .48139 1 0 Mshowa
0 .59805 m
.00625 .59805 L
s
[(10)] -0.0125 .59805 1 0 Mshowa
.125 Mabswid
0 .04388 m
.00375 .04388 L
s
0 .07305 m
.00375 .07305 L
s
0 .10222 m
.00375 .10222 L
s
0 .16055 m
.00375 .16055 L
s
0 .18972 m
.00375 .18972 L
s
0 .21888 m
.00375 .21888 L
s
0 .27722 m
.00375 .27722 L
s
0 .30638 m
.00375 .30638 L
s
0 .33555 m
.00375 .33555 L
s
0 .39389 m
.00375 .39389 L
s
0 .42305 m
.00375 .42305 L
s
0 .45222 m
.00375 .45222 L
s
0 .51055 m
.00375 .51055 L
s
0 .53972 m
.00375 .53972 L
s
0 .56889 m
.00375 .56889 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18801 .61178 m
.18801 .61803 L
s
.35222 .61178 m
.35222 .61803 L
s
.51642 .61178 m
.51642 .61803 L
s
.68062 .61178 m
.68062 .61803 L
s
.84483 .61178 m
.84483 .61803 L
s
.125 Mabswid
.05665 .61428 m
.05665 .61803 L
s
.08949 .61428 m
.08949 .61803 L
s
.12233 .61428 m
.12233 .61803 L
s
.15517 .61428 m
.15517 .61803 L
s
.22085 .61428 m
.22085 .61803 L
s
.25369 .61428 m
.25369 .61803 L
s
.28654 .61428 m
.28654 .61803 L
s
.31938 .61428 m
.31938 .61803 L
s
.38506 .61428 m
.38506 .61803 L
s
.4179 .61428 m
.4179 .61803 L
s
.45074 .61428 m
.45074 .61803 L
s
.48358 .61428 m
.48358 .61803 L
s
.54926 .61428 m
.54926 .61803 L
s
.5821 .61428 m
.5821 .61803 L
s
.61494 .61428 m
.61494 .61803 L
s
.64778 .61428 m
.64778 .61803 L
s
.71346 .61428 m
.71346 .61803 L
s
.74631 .61428 m
.74631 .61803 L
s
.77915 .61428 m
.77915 .61803 L
s
.81199 .61428 m
.81199 .61803 L
s
.87767 .61428 m
.87767 .61803 L
s
.91051 .61428 m
.91051 .61803 L
s
.94335 .61428 m
.94335 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13138 m
1 .13138 L
s
.99375 .24805 m
1 .24805 L
s
.99375 .36472 m
1 .36472 L
s
.99375 .48139 m
1 .48139 L
s
.99375 .59805 m
1 .59805 L
s
.125 Mabswid
.99625 .04388 m
1 .04388 L
s
.99625 .07305 m
1 .07305 L
s
.99625 .10222 m
1 .10222 L
s
.99625 .16055 m
1 .16055 L
s
.99625 .18972 m
1 .18972 L
s
.99625 .21888 m
1 .21888 L
s
.99625 .27722 m
1 .27722 L
s
.99625 .30638 m
1 .30638 L
s
.99625 .33555 m
1 .33555 L
s
.99625 .39389 m
1 .39389 L
s
.99625 .42305 m
1 .42305 L
s
.99625 .45222 m
1 .45222 L
s
.99625 .51055 m
1 .51055 L
s
.99625 .53972 m
1 .53972 L
s
.99625 .56889 m
1 .56889 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .07305 L
s
.05665 .01472 m
.05665 .0926 L
s
.08949 .01472 m
.08949 .16568 L
s
.12233 .01472 m
.12233 .53849 L
s
.15517 .01472 m
.15517 .60332 L
s
.18801 .01472 m
.18801 .23052 L
s
.22085 .01472 m
.22085 .15519 L
s
.25369 .01472 m
.25369 .12268 L
s
.28654 .01472 m
.28654 .10464 L
s
.31938 .01472 m
.31938 .09335 L
s
.35222 .01472 m
.35222 .08581 L
s
.38506 .01472 m
.38506 .08063 L
s
.4179 .01472 m
.4179 .07709 L
s
.45074 .01472 m
.45074 .07478 L
s
.48358 .01472 m
.48358 .07347 L
s
.51642 .01472 m
.51642 .07305 L
s
.54926 .01472 m
.54926 .07347 L
s
.5821 .01472 m
.5821 .07478 L
s
.61494 .01472 m
.61494 .07709 L
s
.64778 .01472 m
.64778 .08063 L
s
.68062 .01472 m
.68062 .08581 L
s
.71346 .01472 m
.71346 .09335 L
s
.74631 .01472 m
.74631 .10464 L
s
.77915 .01472 m
.77915 .12268 L
s
.81199 .01472 m
.81199 .15519 L
s
.84483 .01472 m
.84483 .23052 L
s
.87767 .01472 m
.87767 .60332 L
s
.91051 .01472 m
.91051 .53849 L
s
.94335 .01472 m
.94335 .16568 L
s
.97619 .01472 m
.97619 .0926 L
s
.015 w
.02381 .07305 Mdot
.05665 .0926 Mdot
.08949 .16568 Mdot
.12233 .53849 Mdot
.15517 .60332 Mdot
.18801 .23052 Mdot
.22085 .15519 Mdot
.25369 .12268 Mdot
.28654 .10464 Mdot
.31938 .09335 Mdot
.35222 .08581 Mdot
.38506 .08063 Mdot
.4179 .07709 Mdot
.45074 .07478 Mdot
.48358 .07347 Mdot
.51642 .07305 Mdot
.54926 .07347 Mdot
.5821 .07478 Mdot
.61494 .07709 Mdot
.64778 .08063 Mdot
.68062 .08581 Mdot
.71346 .09335 Mdot
.74631 .10464 Mdot
.77915 .12268 Mdot
.81199 .15519 Mdot
.84483 .23052 Mdot
.87767 .60332 Mdot
.91051 .53849 Mdot
.94335 .16568 Mdot
.97619 .0926 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0328407 0.309017 0.0983632 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18801 -0.0125 -3 -9 ]
[.18801 -0.0125 3 0 ]
[.35222 -0.0125 -6 -9 ]
[.35222 -0.0125 6 0 ]
[.51642 -0.0125 -6 -9 ]
[.51642 -0.0125 6 0 ]
[.68062 -0.0125 -6 -9 ]
[.68062 -0.0125 6 0 ]
[.84483 -0.0125 -6 -9 ]
[.84483 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01393 -12 -4.5 ]
[-0.0125 .01393 0 4.5 ]
[-0.0125 .11229 -12 -4.5 ]
[-0.0125 .11229 0 4.5 ]
[-0.0125 .21065 -12 -4.5 ]
[-0.0125 .21065 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40738 -6 -4.5 ]
[-0.0125 .40738 0 4.5 ]
[-0.0125 .50574 -6 -4.5 ]
[-0.0125 .50574 0 4.5 ]
[-0.0125 .60411 -6 -4.5 ]
[-0.0125 .60411 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18801 0 m
.18801 .00625 L
s
[(5)] .18801 -0.0125 0 1 Mshowa
.35222 0 m
.35222 .00625 L
s
[(10)] .35222 -0.0125 0 1 Mshowa
.51642 0 m
.51642 .00625 L
s
[(15)] .51642 -0.0125 0 1 Mshowa
.68062 0 m
.68062 .00625 L
s
[(20)] .68062 -0.0125 0 1 Mshowa
.84483 0 m
.84483 .00625 L
s
[(25)] .84483 -0.0125 0 1 Mshowa
.125 Mabswid
.05665 0 m
.05665 .00375 L
s
.08949 0 m
.08949 .00375 L
s
.12233 0 m
.12233 .00375 L
s
.15517 0 m
.15517 .00375 L
s
.22085 0 m
.22085 .00375 L
s
.25369 0 m
.25369 .00375 L
s
.28654 0 m
.28654 .00375 L
s
.31938 0 m
.31938 .00375 L
s
.38506 0 m
.38506 .00375 L
s
.4179 0 m
.4179 .00375 L
s
.45074 0 m
.45074 .00375 L
s
.48358 0 m
.48358 .00375 L
s
.54926 0 m
.54926 .00375 L
s
.5821 0 m
.5821 .00375 L
s
.61494 0 m
.61494 .00375 L
s
.64778 0 m
.64778 .00375 L
s
.71346 0 m
.71346 .00375 L
s
.74631 0 m
.74631 .00375 L
s
.77915 0 m
.77915 .00375 L
s
.81199 0 m
.81199 .00375 L
s
.87767 0 m
.87767 .00375 L
s
.91051 0 m
.91051 .00375 L
s
.94335 0 m
.94335 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01393 m
.00625 .01393 L
s
[(-3)] -0.0125 .01393 1 0 Mshowa
0 .11229 m
.00625 .11229 L
s
[(-2)] -0.0125 .11229 1 0 Mshowa
0 .21065 m
.00625 .21065 L
s
[(-1)] -0.0125 .21065 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .40738 m
.00625 .40738 L
s
[(1)] -0.0125 .40738 1 0 Mshowa
0 .50574 m
.00625 .50574 L
s
[(2)] -0.0125 .50574 1 0 Mshowa
0 .60411 m
.00625 .60411 L
s
[(3)] -0.0125 .60411 1 0 Mshowa
.125 Mabswid
0 .0336 m
.00375 .0336 L
s
0 .05327 m
.00375 .05327 L
s
0 .07295 m
.00375 .07295 L
s
0 .09262 m
.00375 .09262 L
s
0 .13196 m
.00375 .13196 L
s
0 .15164 m
.00375 .15164 L
s
0 .17131 m
.00375 .17131 L
s
0 .19098 m
.00375 .19098 L
s
0 .23033 m
.00375 .23033 L
s
0 .25 m
.00375 .25 L
s
0 .26967 m
.00375 .26967 L
s
0 .28934 m
.00375 .28934 L
s
0 .32869 m
.00375 .32869 L
s
0 .34836 m
.00375 .34836 L
s
0 .36803 m
.00375 .36803 L
s
0 .38771 m
.00375 .38771 L
s
0 .42705 m
.00375 .42705 L
s
0 .44673 m
.00375 .44673 L
s
0 .4664 m
.00375 .4664 L
s
0 .48607 m
.00375 .48607 L
s
0 .52542 m
.00375 .52542 L
s
0 .54509 m
.00375 .54509 L
s
0 .56476 m
.00375 .56476 L
s
0 .58443 m
.00375 .58443 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18801 .61178 m
.18801 .61803 L
s
.35222 .61178 m
.35222 .61803 L
s
.51642 .61178 m
.51642 .61803 L
s
.68062 .61178 m
.68062 .61803 L
s
.84483 .61178 m
.84483 .61803 L
s
.125 Mabswid
.05665 .61428 m
.05665 .61803 L
s
.08949 .61428 m
.08949 .61803 L
s
.12233 .61428 m
.12233 .61803 L
s
.15517 .61428 m
.15517 .61803 L
s
.22085 .61428 m
.22085 .61803 L
s
.25369 .61428 m
.25369 .61803 L
s
.28654 .61428 m
.28654 .61803 L
s
.31938 .61428 m
.31938 .61803 L
s
.38506 .61428 m
.38506 .61803 L
s
.4179 .61428 m
.4179 .61803 L
s
.45074 .61428 m
.45074 .61803 L
s
.48358 .61428 m
.48358 .61803 L
s
.54926 .61428 m
.54926 .61803 L
s
.5821 .61428 m
.5821 .61803 L
s
.61494 .61428 m
.61494 .61803 L
s
.64778 .61428 m
.64778 .61803 L
s
.71346 .61428 m
.71346 .61803 L
s
.74631 .61428 m
.74631 .61803 L
s
.77915 .61428 m
.77915 .61803 L
s
.81199 .61428 m
.81199 .61803 L
s
.87767 .61428 m
.87767 .61803 L
s
.91051 .61428 m
.91051 .61803 L
s
.94335 .61428 m
.94335 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01393 m
1 .01393 L
s
.99375 .11229 m
1 .11229 L
s
.99375 .21065 m
1 .21065 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .40738 m
1 .40738 L
s
.99375 .50574 m
1 .50574 L
s
.99375 .60411 m
1 .60411 L
s
.125 Mabswid
.99625 .0336 m
1 .0336 L
s
.99625 .05327 m
1 .05327 L
s
.99625 .07295 m
1 .07295 L
s
.99625 .09262 m
1 .09262 L
s
.99625 .13196 m
1 .13196 L
s
.99625 .15164 m
1 .15164 L
s
.99625 .17131 m
1 .17131 L
s
.99625 .19098 m
1 .19098 L
s
.99625 .23033 m
1 .23033 L
s
.99625 .25 m
1 .25 L
s
.99625 .26967 m
1 .26967 L
s
.99625 .28934 m
1 .28934 L
s
.99625 .32869 m
1 .32869 L
s
.99625 .34836 m
1 .34836 L
s
.99625 .36803 m
1 .36803 L
s
.99625 .38771 m
1 .38771 L
s
.99625 .42705 m
1 .42705 L
s
.99625 .44673 m
1 .44673 L
s
.99625 .4664 m
1 .4664 L
s
.99625 .48607 m
1 .48607 L
s
.99625 .52542 m
1 .52542 L
s
.99625 .54509 m
1 .54509 L
s
.99625 .56476 m
1 .56476 L
s
.99625 .58443 m
1 .58443 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .30902 m
.02381 .30902 L
s
.05665 .30902 m
.05665 .38026 L
s
.08949 .30902 m
.08949 .4245 L
s
.12233 .30902 m
.12233 .45255 L
s
.15517 .30902 m
.15517 .16427 L
s
.18801 .30902 m
.18801 .18143 L
s
.22085 .30902 m
.22085 .19663 L
s
.25369 .30902 m
.25369 .21066 L
s
.28654 .30902 m
.28654 .22394 L
s
.31938 .30902 m
.31938 .23672 L
s
.35222 .30902 m
.35222 .24917 L
s
.38506 .30902 m
.38506 .26137 L
s
.4179 .30902 m
.4179 .27341 L
s
.45074 .30902 m
.45074 .28534 L
s
.48358 .30902 m
.48358 .29719 L
s
.51642 .30902 m
.51642 .30902 L
s
.54926 .30902 m
.54926 .32084 L
s
.5821 .30902 m
.5821 .3327 L
s
.61494 .30902 m
.61494 .34462 L
s
.64778 .30902 m
.64778 .35666 L
s
.68062 .30902 m
.68062 .36887 L
s
.71346 .30902 m
.71346 .38131 L
s
.74631 .30902 m
.74631 .3941 L
s
.77915 .30902 m
.77915 .40738 L
s
.81199 .30902 m
.81199 .4214 L
s
.84483 .30902 m
.84483 .4366 L
s
.87767 .30902 m
.87767 .45376 L
s
.91051 .30902 m
.91051 .16549 L
s
.94335 .30902 m
.94335 .19353 L
s
.97619 .30902 m
.97619 .23777 L
s
.015 w
.02381 .30902 Mdot
.05665 .38026 Mdot
.08949 .4245 Mdot
.12233 .45255 Mdot
.15517 .16427 Mdot
.18801 .18143 Mdot
.22085 .19663 Mdot
.25369 .21066 Mdot
.28654 .22394 Mdot
.31938 .23672 Mdot
.35222 .24917 Mdot
.38506 .26137 Mdot
.4179 .27341 Mdot
.45074 .28534 Mdot
.48358 .29719 Mdot
.51642 .30902 Mdot
.54926 .32084 Mdot
.5821 .3327 Mdot
.61494 .34462 Mdot
.64778 .35666 Mdot
.68062 .36887 Mdot
.71346 .38131 Mdot
.74631 .3941 Mdot
.77915 .40738 Mdot
.81199 .4214 Mdot
.84483 .4366 Mdot
.87767 .45376 Mdot
.91051 .16549 Mdot
.94335 .19353 Mdot
.97619 .23777 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 311.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0001=b000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00=oooool3o`0002?ooooo1Ol0000Rooooo`;o0000
9?ooool5o`0002Gooooo0ol0001Looooo`?o00008_ooool5o`0002;ooooo0_l0000Sooooo`Go0000
9?ooool3o`0002Sooooo000hooooo`03o`000?oooooooooo02?ooooo00Co0000oooooooooooo0000
8Oooool01?l0003oooooooooool0000Tooooo`04o`000?ooooooooooo`0002Kooooo00?o0000oooo
ooooool0G?ooool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`00027ooooo00Co0000
oooooooooooo00008oooool01?l0003oooooooooool0000Uooooo`03o`000?oooooooooo02Oooooo
000_ooooo`Go000000?oooooo`000?l000000ol0000Mooooo`Go00000oooool00ol0003ooooooooo
o`0Qooooo`04o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool08oooool5o`0005Cooooo
1Ol000000ooooooo0000o`000003o`0001cooooo1Ol00003ooooo`03o`000?oooooooooo027ooooo
00Co0000oooooooooooo00009?ooool00ol0003oooooooooo`0Rooooo`Go0000:?ooool003Gooooo
00Co0000oooooooooooo00009oooool00ol0003oooooooooo`0Pooooo`04o`000?ooooooooooo`00
02Kooooo00?o0000ooooooooool08_ooool01?l0003oooooooooool0001Kooooo`04o`000?oooooo
ooooo`0002Kooooo00?o0000ooooooooool08?ooool01?l0003oooooooooool0000Uooooo`03o`00
0?oooooooooo027ooooo00Co0000oooooooooooo0000:Oooool003Kooooo00?o0000ooooool00000
9?ooool01Ol0003ooooooooooooooooo0000027ooooo00Co0000oooooooooooo00008oooool01Ol0
003ooooooooooooooooo000002Cooooo00?o0000ooooool00000G?ooool00ol0003oooooo`00000S
ooooo`05o`000?ooooooooooooooool000008Oooool01?l0003oooooooooool0000Rooooo`05o`00
0?ooooooooooooooool000008oooool00ol0003oooooo`00000Yooooo`00=oooool2o`0002Cooooo
00Go0000ooooooooooooooooo`00000Qooooo`04o`000?ooooooooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000Uooooo`;o0000GOooool2o`0002?ooooo00Go0000ooooooooooooooooo`00
000Qooooo`04o`000?ooooooooooo`0002;ooooo00Go0000ooooooooooooooooo`00000Tooooo`;o
0000:Oooool003Sooooo00?o0000ooooooooool08oooool3o`0002?ooooo0_l0000Uooooo`?o0000
9oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo02;ooooo0ol0000Sooooo`;o0000
9?ooool3o`0002Kooooo00?o0000ooooooooool09oooool00?oooooonOooool00?oooooonOooool0
0?oooooonOooool00?oooooonOooool001coooood_l0000Tooooo`?o00001?ooooo>o`00017ooooo
000Fooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo027ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
3oooool001Gooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1Vooooo`03o`00
0?oooooooooo06Gooooo00?o0000ooooooooool06oooool5o`0000Gooooo00Co0000oooooooooooo
oooo0_l0001Uooooo`03o`000?oooooooooo06;ooooo0_l0000Aooooo`005Oooool01?l0003ooooo
ooooool00003ooooo`?o00002Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?o
oooo00Goo`00ooooooooooooooooo`00o`02ooooo`03ool00?oooooooooo00Cooooo00Coo`00oooo
oooooooo003o0_ooool00ooo003oooooooooo`02o`00o`;ooooo00?oo`00ooooooooool01?ooool0
1?oo003oooooooooool00?l2ooooo`04ool00?ooooooooooo`00o`?ooooo00Coo`00oooooooooooo
003o0_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool00oooool01Ooo003ooooooooooooooooo003o00;ooooo00Coo`00oooooooooooo003o0oooool0
1?oo003oooooooooool00?l2ooooo`05ool00?ooooooooooooooool00?l00_ooool00ooo003ooooo
ooooo`03ooooo`05ool00?ooooooooooooooool00?l00_ooool01?oo003oooooooooool00?l3oooo
o`04ool00?ooooooooooo`00o`;ooooo00Goo`00ooooooooooooooooo`00o`02ooooo`04ool00?oo
ooooooooo`00o`?ooooo00Coo`00oooooooooooo003o0_ooool00ooo003oooooooooo`04ooooo`04
ool00?ooooooooooo`00o`?ooooo00Coo`00oooooooooooo003o0_ooool00ooo003oooooooooo`04
ooooo`04ool00?ooooooooooo`00o`;ooooo00Coo`00oooooooooooooooo0_l0000Uooooo`;o0000
1?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01[ooooo00?o003oooooooooool0
A_ooool00ol0003oooooooooo`0?ooooo`005Oooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00Kooooo00Co003oooooooooooooo`000_ooool2o`00o`;ooooo00Coo`00oooooooo
oooo003o0_ooool00ooo003oooooooooo`02o`00o`;ooooo00Coo`00oooooooooooo003o0oooool0
1?oo003oooooooooool00?l2ooooo`03ool00?oooooooooo00;o003o0_ooool01?oo003ooooooooo
ool00?l3ooooo`04ool00?ooooooooooo`00o`;ooooo00?oo`00ooooooooool00_l00?l2ooooo`04
ool00?ooooooooooo`00o`;ooooo00?oo`00ooooooooool01?ooool01?oo003oooooooooool00?l3
ooooo`04ool00?ooooooooooo`00o`;ooooo00Goo`00ooooooooooooooooo`00o`02ooooo`04ool0
0?ooooooooooo`00o`?ooooo00Coo`00oooooooooooo003o0_ooool01?oo003oooooooooool00?l3
ooooo`03ool00?oooooooooo00?ooooo00Goo`00ooooooooooooooooo`00o`02ooooo`04ool00?oo
ooooooooo`00o`?ooooo00Coo`00oooooooooooo003o0_ooool00ooo003oooooooooo`02o`00o`;o
oooo00Coo`00oooooooooooo003o0oooool01?oo003oooooooooool00?l2ooooo`05ool00?oooooo
ooooooooool00?l00_ooool01?oo003oooooooooool00?l3ooooo`04ool00?ooooooooooo`00o`;o
oooo00Goo`00ooooooooooooooooo`00o`02ooooo`04ool00?ooooooooooo`00o`;ooooo00?oo`00
ooooooooool00_ooool00ol0003oooooooooo`0Uooooo`05o`000?ooooooooooooooool00000I_oo
ool00ol0003oooooooooo`0Jooooo`03o`00oooooooooooo04Kooooo00?o0000ooooooooool03ooo
ool001Gooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`;o003o0_oo
ool00ooo003oooooooooo`02o`00o`;ooooo00Coo`00oooooooooooo003o0_ooool00ooo003ooooo
ooooo`04ooooo`04ool00?ooooooooooo`00o`?ooooo00Coo`00ooooool00?oo003o0_ooool01Ooo
003ooooooooooooooooo003o00;ooooo00Coo`00oooooooooooo003o0oooool01?oo003ooooooooo
ool00?l2ooooo`04ool00?ooooooooooo`00o`?ooooo00Coo`00oooooooooooo003o0_ooool00ooo
003oooooooooo`04ooooo`04ool00?ooooooooooo`00o`?ooooo00Coo`00oooooooooooo003o0_oo
ool01Ooo003ooooooooooooooooo003o00;ooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00;o003o0_ooool00ooo003oooooooooo`03ooooo`05ool0
0?ooooooooooooooool00?l00_ooool00ooo003oooooooooo`02o`00o`;ooooo00Coo`00oooooooo
oooo003o0_ooool00ooo003oooooooooo`02o`00o`;ooooo00?oo`00ooooooooool00_l00?l2oooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_l00?l2ooooo`04ool00?oooooooooo
o`00o`?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02o`00o`;ooooo00Ooo`00
ooooooooooooooooo`00ooooooooo`0000Cooooo00?o0000ooooooooool08Oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool0Doooool00ol00?ooooooooooo`0>ooooo`03
o`000?oooooooooo06?ooooo00?o0000ooooooooool03oooool001Gooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`05ooooo`05o`00oooooooo003ooooooooo00000_ooool2o`00
o`;ooooo00Coo`00ooooool00?oo003o0_ooool00ooo003oooooooooo`02o`00o`;ooooo00?oo`00
ooooooooool00_l00?l2ooooo`03ool00?oooooo003o00?ooooo00Coo`00oooooooooooo003o0ooo
ool01?oo003oooooooooool00?l3ooooo`03ool00?oooooo003o00?ooooo00Coo`00oooooooooooo
003o0oooool01?oo003oooooooooool00?l2ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool00_l00?l2ooooo`04ool00?ooooooooooo`00o`;ooooo00Coo`00oooooooooooo003o0ooo
ool01Ooo003oooooo`00oooooooo003o00;ooooo00Coo`00ooooool00?oo003o0_ooool01Ooo003o
oooooooooooooooo003o00;ooooo00?oo`00ooooooooool00oooool01Ooo003ooooooooooooooooo
003o00;ooooo00Goo`00ooooooooooooooooo`00o`02ooooo`04ool00?ooooooooooo`00o`;ooooo
00Goo`00ooooooooooooooooo`00o`02ooooo`04ool00?ooooooooooo`00o`?ooooo00?oo`00oooo
ool00?l00oooool00ooo003oooooooooo`02o`00o`;ooooo00Goo`00ooooooooooooooooo`00o`02
ooooo`07ool00?oooooo003oooooool00?ooooooool00002ooooo`;o003o0_ooool00ooo003ooooo
o`00o`03ooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool08_ooool3o`0000Cooooo
0_l0001Dooooo`03o`00oooooooooooo00kooooo00?o0000ooooooooool06Oooool2o`00odOooooo
0_l0000Aooooo`005_ooool2o`0000Cooooo0_l00008ooooo`03o`00ooooooooo`0000Kooooo00Oo
o`00ooooool00?ooooooo`00ooooooooo`0000;ooooo00Go003oooooool00?ooooooool00006oooo
o`07ool00?oooooo003oooooool00?ooooooool00002ooooo`;o003o0_ooool01Ooo003ooooooooo
oooooooo003o00;ooooo00Coo`00ooooool00?oo003o0_ooool01Ooo003ooooooooooooooooo003o
00;ooooo00Coo`00oooooooooooo003o0_ooool00ooo003oooooooooo`04ooooo`04ool00?oooooo
ooooo`00o`?ooooo00Ooo`00ooooooooooooooooo`00ooooooooo`0000;ooooo00Wo003oooooool0
0?ooooooool00?oooooo003oooooool00?l00_ooool01?oo003oooooo`00ool00?l2ooooo`03ool0
0?oooooooooo00;o003o0_ooool00ooo003oooooooooo`03ooooo`05ool00?ooooooooooooooool0
0?l00_ooool01Ooo003ooooooooooooooooo003o00;ooooo00Coo`00oooooooooooo003o0_ooool0
0ooo003oooooooooo`02o`00o`;ooooo00?oo`00ooooooooool00_l00?l2ooooo`07ool00?oooooo
003oooooool00?ooooooool00002ooooo`09o`00oooooooooooooooooooo003oooooo`00oooooooo
003o00;ooooo00Ooo`00ooooool00?ooooooo`00ooooooooo`0000;ooooo00_o003ooooooooooooo
ooooool00?oooooo003oooooool00?ooooooool00004ooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool0Doooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo01Wooooo0_l0
0?m8ooooo`03o`000?oooooooooo00oooooo000Looooo`03o`000?oooooooooo00Cooooo00?o003o
ooooooooool00_ooool00ooo003oooooo`00o`02ooooo`05o`00ooooooooo`00ooooool00?l00ooo
ool00ooo003oooooo`00o`02ooooo`06o`00ooooooooo`00ooooool00?oooooo0_l00?l00ooooooo
o`00ooooo`02ooooo`03o`00ooooooooo`0000;ooooo0_l00?l2ooooo`03ool00?oooooo003o00Co
oooo00Coo`00oooooooooooo003o0_ooool00ooo003oooooooooo`02o`00o`;ooooo00Coo`00oooo
oooooooo003o0_ooool00ooo003oooooooooo`04ooooo`05ool00?ooooooooooooooool00?l00_oo
ool01?oo003oooooo`00ool00?l2ooooo`0<ool00?ooooooooooo`00oooooooo003ooooooooo003o
ooooo`00oooooooo003o0_ooool01ooo003oooooo`00oooooooo003ooooooooo00000_ooool01Ol0
0?ooooooooooooooooooo`0000Gooooo00Goo`00ooooooooooooooooo`00o`02ooooo`04ool00?oo
ooooooooo`00o`?ooooo00Ooo`00ooooool00?ooooooo`00ooooooooo`0000;ooooo0_l00?l2oooo
o`05ool00?ooooooooooooooool00?l00_ooool01ooo003oooooo`00oooooooo003ooooooooo0000
1?ooool01ol00?ooooooool00?oooooo003oooooool00?l00_ooool01ooo003oooooo`00oooooooo
003ooooooooo00001?ooool02Ol00?ooooooool00?oooooo003oooooool00?ooooooool00004oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Doooool00ol00?ooooooooooo`0>oooo
o`03o`000?oooooooooo01Wooooo0_l00?l5ooooo`03o`00oooooooooooo043ooooo00?o0000oooo
ooooool03oooool001cooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`02o`00o`03
ool00?oooooo003o00;ooooo00?o003ooooooooo00000oooool00ol00?ooooooool00004ooooo`05
o`00ooooooooo`00ooooool00?l00_ooool00ol00?ooooooool00003ooooo`03o`00ooooooooo`00
00Cooooo00Oo003ooooooooo003oooooo`00oooooooo003o00;ooooo00Coo`00ooooool00?oo003o
0_ooool00ooo003oooooooooo`02o`00o`;ooooo00Coo`00oooooooooooo003o0_ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00;o003o0_ooool01ooo003oooooo`00oooooooo003o
oooooooo00001?ooool00ol00?ooooooool00006ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool00_l00?l2ooooo`03ool00?oooooooooo00?ooooo00Coo`00oooooooooooo003o0ooo
ool00ooo003oooooooooo`02o`00o`;ooooo00Ooo`00ooooooooooooooooo`00ooooooooo`0000;o
oooo00Wo003oooooool00?ooooooool00?oooooo003oooooool00?l00_ooool02Ooo003ooooooooo
oooooooo003ooooooooo003oooooo`00o`02ooooo`05o`00ooooooooo`00ooooool00?l01?ooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooo003o00;ooooo00?o003ooooooooo00001?ooool0
0ol00?ooo`00ooooo`03ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Doooool0
0ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo023ooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0iooooo`03o`000?oooooooooo00oooooo000Looooo`03o`000?oooooooooo
00Cooooo00Co003ooooooooooooooooo0ooo0003ooooo`04o`00ooooooooo`00o`00o`?ooooo00Co
003oool00?oooooo003o1?ooool00ooo003o003oooooo`02ooooo`04o`00ooooooooo`00o`00o`Co
oooo00?oo`00ooooool00?l01?ooool01Ooo003oooooo`00oooooooo003o00;ooooo00Ooo`00oooo
ool00?ooooooo`00ooooooooo`0000;ooooo00Go003oooooooooooooooooool00002ooooo`04o`00
ooooooooooooool000Kooooo00?oo`00ooooooooool00_l00?l2ooooo`09ool00?oooooo003ooooo
ool00?ooooooool00?oooooo003o00?ooooo0ooo0003ooooo`05o`00ooooooooo`00ooooool00?l0
0oooool00ooo003oooooooooo`02o`00o`;ooooo00?oo`00ooooooooool00oooool01Ooo003ooooo
oooooooooooo003o00;ooooo00Goo`00ooooooooooooooooo`00o`02ooooo`07ool00?oooooo003o
ooooool00?ooooooool00004ooooo`05o`00ooooooooo`00ooooool00?l00_ooool01?l00?oooooo
ool00?l00?l4ooooo`03ool00?oooooo003o00;ooooo00?o003ooooooooo00001?ooool01?l00?oo
ooooool00?l00?l3ooooo`04o`00oooo003o003oo`00o`;ooooo00Co003oool00?oo003oo`000ooo
ool3ool000?ooooo00?o0000ooooooooool0:Oooool2o`0005Cooooo00?o003oooooooooool03_oo
ool00ol0003oooooooooo`0Iooooo`;o003o1Oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo03Sooooo0_l0000Aooooo`007?ooool2o`0000?ooooo0_l00?l4ooooo`?oo`001?ooool3
ool000?ooooo0ooo0004ooooo`?oo`001Oooool00ooo003o003oooooo`02ooooo`04o`00oooo003o
ooooo`00o`;ooooo00?o003ooooooooo00000oooool01_l00?oooooooooooooo003oooooo`00o`?o
oooo00Goo`00ooooooooooooooooo`00o`02ooooo`04ool00?ooooooooooo`00o`;ooooo00?oo`00
ooooooooool01?ooool01?oo003oooooooooool00?l3ooooo`09ool00?ooooooooooooooool00?oo
ooooool00?oooooo003o00?ooooo0ooo0003ooooo`04o`00ooooooooo`00o`00o`;ooooo00?o003o
oooooooo00000oooool01?l00?oooooooooooooo0005ooooo`03ool00?oooooooooo00;o003o0_oo
ool00ooo003oooooooooo`02o`00o`;ooooo00?oo`00ooooool00?l00oooool00ooo003oooooo`00
o`02ooooo`05o`00ooooooooo`00ooooool00?l01?ooool00ooo003o003oooooo`02ooooo`04o`00
oooo003oooooo`00o`?ooooo0ooo0003ooooo`?oo`0000Co003ooooooooooooooooo0ooo0004oooo
o`?oo`000oooool3ool000?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Coooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01oooool00ol0003oooooooooo`0Ioooo
o`;o003o3?ooool00ol00?ooooooooooo`0iooooo`03o`000?oooooooooo00oooooo000Looooo`03
o`000?oooooooooo00Sooooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo0004ooooo`?o
o`000oooool01?l00?ooo`00ooooool00?l2ooooo`05o`00ooooooooo`00ooooool00?l01?ooool0
1ooo003ooooooooooooooooo003ooooooooo00000_ooool2o`00o`;ooooo00Coo`00oooooooooooo
003o0_ooool00ooo003oooooooooo`04ooooo`05ool00?ooooooooooooooool00?l00_ooool00ooo
003oooooo`00o`03ooooo`03ool00?l00?oooooo00?ooooo0ooo0003ooooo`04o`00ooooooooo`00
o`00o`;ooooo00?o003ooooooooo00000_ooool2o`00o`;ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`02o`00o`;ooooo00Coo`00oooooooooooo003o0oooool02Ooo003oooooo`00
oooooooo003ooooooooo003oooooo`00o`04ooooo`03ool00?oooooooooo00;ooooo00Co003ooooo
oooo003o003o0oooool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000Cooooo0ooo0003
ooooo`?oo`000oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05;ooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo01Wooooo0_l00?l5
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0c
ooooo`03o`000?oooooooooo00oooooo000Looooo`03o`000?oooooooooo00oooooo0ooo0003oooo
o`?oo`001?ooool3ool000Cooooo0ooo0003ooooo`?oo`000oooool2o`00o`03ool00?l00?oooooo
00;ooooo00Co003ooooooooo003o003o0_ooool00ol00?ooooooool00002ooooo`;o003o0_ooool0
1?oo003oooooooooool00?l2ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_l0
0?l2ooooo`03ool00?oooooo003o00;ooooo0ooo0005ooooo`03o`000?oooooooooo00?ooooo0ooo
0002ooooo`03o`00ooooooooo`0000;ooooo00Go003oooooooooooooooooool00005ooooo`04ool0
0?ooooooooooo`00o`?ooooo00?oo`00ooooooooool00_l00?l2ooooo`09ool00?oooooo003ooooo
ool00?ooooooool00?oooooo003o00;ooooo0_l00?l00ooo003o003oooooo`02ooooo`04o`00oooo
003oo`00ool000?ooooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo000@ooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool0Doooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Oooooo00?o0000ooooooooool08?ooool00ol00?ooooooooooo`03ooooo`;o003o
1Oooool00ol00?ooooooooooo`0cooooo`03o`000?oooooooooo00oooooo000Looooo`03o`000?oo
oooooooo02?ooooo0ooo0003ooooo`?oo`001Oooool00ooo003o003oooooo`02ooooo`04o`00oooo
ooooo`00o`00o`;ooooo00Go003ooooooooo003oooooo`00o`04ooooo`07ool00?oooooo003ooooo
ool00?ooooooool00006ooooo`03ool00?oooooooooo00;o003o0_ooool00ooo003o003oooooo`02
ooooo`?oo`001Oooool00ol0003oooooooooo`03ooooo`?oo`001?ooool00ooo003oooooooooo`02
o`00o`;ooooo00?oo`00ooooooooool00oooool01Ooo003ooooooooooooooooo003o00;ooooo00Go
o`00ooooooooooooooooo`00o`02ooooo`03ool00?oooooooooo00;ooooo00?o003oool00?ooool0
1?ooool00ol00?ooo`00o`00o`04ooooo`?oo`000oooool3ool002Cooooo00?o0000ooooooooool0
:Oooool2o`0005?ooooo0_l00?l6ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool0
6Oooool2o`00o`Cooooo0_l00?l5ooooo`;o003o1Oooool00ol00?ooooooooooo`0booooo`;o0000
4Oooool001cooooo0_l0000Zooooo`?oo`001?ooool3ool000?ooooo00Co003ooooooooo003o003o
1?ooool01Ooo003ooooooooooooooooo003o00;ooooo00?oo`00ooooool00?l00oooool00ooo003o
ooooooooo`04ooooo`04ool00?ooooooooooo`00o`?ooooo00?oo`00ooooooooool00_ooool3ool0
00Gooooo00?o0000ooooooooool00oooool3ool000;ooooo00?o003ooooooooo00000oooool01?l0
0?oooooooooooooo0005ooooo`03ool00?oooooooooo00;o003o0_ooool00ooo003oooooo`00o`02
ooooo`05o`00ooooooooo`00ooooool00?l00oooool00ooo003oooooo`00o`03ooooo`?oo`001?oo
ool3ool002[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Booooo`;o003o1Ooo
ool2o`00o`Wooooo00?o0000ooooooooool06?ooool00ol00?ooooooo`00o`0;ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0/ooooo`03o`000?oo
oooooooo00oooooo000Looooo`03o`000?oooooooooo033ooooo0ooo0005ooooo`0;ool00?l00?oo
ooooooooool00?ooooooool00?oooooo003oooooool00?l00_ooool00ooo003oooooo`00o`03oooo
o`03ool00?oooooooooo00Cooooo00Goo`00ooooooooooooooooo`00o`02ooooo`03ool00?l00?oo
oooo00[ooooo00?o0000ooooooooool02?ooool00ol00?ooooooool00002ooooo`;o003o0_ooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;o003o0_ooool00ooo003oooooo`00o`02
ooooo`04o`00ooooooooo`00o`00o`?ooooo00?o003oool00?l00?l01?ooool3ool0037ooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`1Booooo`03o`00oooooooooooo00Cooooo0_l0
0?l9ooooo`03o`000?oooooooooo01Sooooo00?o003oooooool00?l01?ooool2o`00o`Kooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02cooooo00?o
0000ooooooooool03oooool001Cooooo1Ol00003ooooo`03o`000?oooooooooo033ooooo0ooo0003
ooooo`?oo`000oooool01Ol00?ooooooool00?oooooo003o00;ooooo00?o003ooooooooo00000ooo
ool00ol00?ooooooool00006ooooo`03ool00?oooooooooo00;o003o0_ooool00ooo003o003ooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00Go003oool00?ooooooooooo`00o`03ooooo`03ool0
0?oooooooooo00?ooooo00Coo`00oooooooooooo003o0oooool00ooo003oooooo`00o`04ooooo`03
ool00?l00?oooooo00;ooooo0ooo0004ooooo`?oo`00<Oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo05?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`08ooooo`03
o`000?oooooooooo01oooooo0_l00?l5ooooo`;o003o1Oooool00ol00?ooooooooooo`0cooooo`03
o`000?oooooooooo00oooooo000Eooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool0=_ooool3ool000Cooooo00Co003oool00?oooooo003o1?ooool01ooo003oooooo`00oooooooo
003ooooooooo00001_ooool00ooo003oooooooooo`02o`00o`;ooooo00?oo`00o`00ooooool02_oo
ool00ol0003oooooooooo`0:ooooo`05ool00?oooooo003oooooool00?l00_ooool00ooo003ooooo
ooooo`03ooooo`08ool00?ooooooooooo`00oooooooo003ooooooooo0004ooooo`03o`00oooooooo
o`0000Cooooo0ooo000hooooo`03o`000?oooooooooo02Wooooo0_l0001Cooooo`;o003o1_ooool0
0ol00?ooooooooooo`07ooooo`03o`000?oooooooooo01Sooooo00?o003oooooool00?l01?ooool2
o`00o`Gooooo0_l00?l5ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`03o`00oooooooo
oooo02Gooooo0_l0000Aooooo`005_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
03Kooooo0ooo0005ooooo`03ool00?oooooooooo00;ooooo00Wo003ooooooooo003oooooo`00oooo
oooo003ooooooooo00001_ooool00ooo003oooooo`00o`04ooooo`03ool00?oooooooooo00[ooooo
00?o0000ooooooooool02Oooool00ol00?ooo`00ooooo`02ooooo`04o`00ooooooooooooool000Go
oooo00?oo`00ooooooooool00_ooool01Ol00?ooooooool00?oooooo003o00;ooooo00Co003ooooo
oooo003o003o0oooool3ool003Sooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1B
ooooo`;o003o1Oooool2o`00o`Wooooo00?o0000ooooooooool06?ooool00ol00?ooooooo`00o`0;
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool2o`00o`Gooooo00?o003o
ooooooooool09_ooool00ol0003oooooooooo`0?ooooo`005oooool00ol0003oooooooooo`02oooo
o`?o0000?Oooool00ol00?ooo`00ooooo`03ooooo`05o`00ooooooooo`00ooooool00?l00oooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00Co003ooooooooo003o003o2ooo
ool00ol0003oooooooooo`09ooooo`06o`00oooo003oooooo`00oooooooo003o0_ooool00ooo003o
ooooooooo`03ooooo`0:ool00?ooooooooooo`00oooooooo003ooooooooo003oooooo`00o`;ooooo
00Co003ooooooooo003o003o?Oooool2o`0002?ooooo1Ol00003ooooo`03o`000?oooooooooo057o
oooo00?o003oooooooooool01Oooool2o`00o`Wooooo00?o0000ooooooooool06?ooool00ol00?oo
ooooo`00o`04ooooo`;o003o1_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?o
oooo0_l00?l5ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool07oooool00ol0003o
ooooooooo`0?ooooo`005?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool0?Oooool00ol00?ooo`00o`00o`03ooooo`03o`00ooooooooo`0000?ooooo00?o003ooooooooo
00001_ooool00ooo003oooooo`00o`02ooooo`04o`00ooooooooo`00o`00o`_ooooo00?o0000oooo
ooooool02Oooool00ol00?ooo`00ooooo`05ooooo`03ool00?oooooooooo00?ooooo00Coo`00oooo
oooooooo003o0oooool00ooo003oooooo`00o`04ooooo`03ool00?l00?oooooo03gooooo00?o0000
ooooooooool08_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo05?ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo01[ooooo00?o
003oooooooooool00_ooool2o`00o`Cooooo00?o003oooooool00?l01?ooool2o`00o`cooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0Oooooo`03o`000?oooooooooo00oooooo000D
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0mooooo`?oo`001Ooo
ool01ooo003ooooooooooooooooo003ooooooooo00001_ooool00ooo003oooooo`00o`02ooooo`03
o`00ooooooooo`0000cooooo00?o0000ooooooooool02_ooool01Ooo003oooooo`00oooooooo003o
00;ooooo00?oo`00ooooooooool00oooool02?oo003oooooooooool00?ooooooo`00ooooooooo`00
1Oooool3ool003kooooo00?o0000ooooooooool06oooool5o`0000?ooooo00?o0000ooooooooool0
0oooool2o`0005;ooooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`07ooooo`03o`00
0?oooooooooo01Sooooo00?o003oooooooooool01?ooool2o`00o`Cooooo00?o003oooooool00?l0
1?ooool00ol00?ooooooooooo`04ooooo`;o003o1Oooool00ol00?ooooooooooo`0Uooooo`;o0000
4Oooool001Gooooo0ol00004ooooo`03o`000?oooooooooo03gooooo0ooo0003ooooo`09o`00oooo
ooooo`00ooooool00?ooooooo`00ooooooooo`0000Kooooo00?oo`00ooooool00?l00oooool3ool0
00_ooooo00?o0000ooooooooool02Oooool3ool00003o`00oooooooo003o00;ooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`02ooooo`05o`00ooooooooo`00ooooool00?l00oooool3
ool003kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo057ooooo00?o003oooooool00?l01?ooool00ol00?ooooooo`00o`09ooooo`03o`000?oooooo
oooo01Sooooo00?o003oooooool00?l02_ooool00ol00?ooooooooooo`04ooooo`;o003o1Oooool2
o`00o`Gooooo00?o003oooooooooool00oooool2o`00o`Gooooo00?o003oooooooooool06Oooool0
0ol0003oooooooooo`0?ooooo`007?ooool2o`0003kooooo0ooo0003ooooo`05o`00ooooooooo`00
ooooool00?l00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00Co003o
ool00?oo003oo`002oooool00ol0003oooooooooo`09ooooo`?oo`000oooool00ol00?ooooooool0
0005ooooo`0:ool00?ooooooooooo`00oooooooo003ooooooooo003oooooo`00o`?ooooo0ooo000n
ooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo057ooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`05ooooo`05o`00oooo
ooooooooooooool000006Oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooo003o00Ko
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`;o003o1Oooool00ol00?oo
ooooooooo`03ooooo`;o003o1Oooool00ol00?ooooooooooo`0Iooooo`03o`000?oooooooooo00oo
oooo000Looooo`03o`000?oooooooooo04?ooooo00Wo003ooooooooo003oooooo`00oooooooo003o
oooooooo00001_ooool00ooo003oooooooooo`03ooooo`?oo`002oooool00ol0003oooooooooo`09
ooooo`?oo`001Oooool00ooo003oooooooooo`03ooooo`09ool00?ooooooooooo`00oooooooo003o
oooooooo003o003o04Gooooo00?o0000ooooooooool08Oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool0Doooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00Gooooo00Go003oooooooooooooooooo`00000Looooo`07o`00ooooooooooooooooool00?oooooo
o`00o`04ooooo`03o`00oooooooo003o00Cooooo0_l00?l;ooooo`03o`00oooooooooooo00Cooooo
0_l00?l5ooooo`03o`00oooooooooooo01Wooooo00?o0000ooooooooool03oooool001cooooo00?o
0000ooooooooool0AOooool01ooo003ooooooooooooooooo003ooooooooo00001_ooool00ooo003o
ooooo`00o`0Aooooo`03o`000?oooooooooo00oooooo00?o003ooooooooo00001Oooool01?oo003o
ooooooooool00?l3ooooo`03ool00?oooooooooo04Cooooo00?o0000ooooooooool08_ooool3o`00
00Cooooo00?o0000ooooooooool0Doooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00?ooooo00Go003oooooooooooooooooo`00000Pooooo`03o`00oooooooo003o00Cooooo00?o003o
ooooool00?l01?ooool00ol00?ooooooooooo`04ooooo`;o003o1Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`0?
ooooo`007?ooool00ol0003oooooooooo`14ooooo`08o`00oooo003oooooo`00oooooooo003ooooo
oooo0006ooooo`03ool00?oooooo003o017ooooo00?o0000ooooooooool03oooool00ol00?oooooo
ool00005ooooo`03ool00?oooooooooo00;ooooo00Co003ooooooooo003o003oAOooool00ol0003o
ooooooooo`0Yooooo`;o0000D_ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooo003o00Go
oooo00Go003oooooooooooooooooo`00000Iooooo`04o`00ooooooooooooo`00o`[ooooo00?o003o
ooooooooool01?ooool2o`00o`Gooooo0_l00?l4ooooo`;o003o1Oooool2o`00o`Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0Aooooo`;o00004Oooool001cooooo0_l00015oooo
o`03o`00oooo003o003o00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooo`00o`0Aoooo
o`03o`000?oooooooooo00oooooo00?o003ooooooooo00001Oooool02Ooo003oooooooooool00?oo
ooooo`00ooooooooo`00o`00o`15ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
DOooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Gooooo00Go003ooooooooooooo
ooooo`00000Iooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooool00?l01_ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01?ooool2o`00
o`Gooooo0_l00?l5ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`03o`00oooooooooooo
00cooooo00?o0000ooooooooool03oooool001cooooo00?o0000ooooooooool0A?ooool00ol00?oo
o`00o`00o`02ooooo`03o`00ooooooooo`0000Kooooo00?oo`00ooooooooool04Oooool00ol0003o
ooooooooo`0Aooooo`03ool00?oooooooooo00?ooooo00Woo`00oooooooooooo003oooooool00?oo
ooooool00?l00?l0AOooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo057ooooo00?o
003oooooool00?l01?ooool00ol00?ooooooooooo`04ooooo`;o003o0oooool00ol0003ooooooooo
o`0Gooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooool00?l01?ooool00ol00?oooooo
o`00o`03ooooo`03o`00oooooooo003o00Kooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`04ooooo`;o003o1Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool03?ooool00ol0003oooooooooo`0?ooooo`007?ooool00ol0003ooooooooo
o`15ooooo`07ool00?ooooooooooooooool00?ooooooool00006ooooo`03ool00?oooooo003o017o
oooo00?o0000ooooooooool03oooool00ol00?ooooooool00005ooooo`04ool00?ooooooooooo`00
o`?ooooo00?oo`00ooooooooool0A?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
05?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`;o003o0oooool00ol0
003oooooooooo`0Nooooo`03o`00oooooooo003o00Cooooo00?o003oooooool00?l00oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03?ooool00ol0
003oooooooooo`0?ooooo`007?ooool00ol0003oooooooooo`14ooooo`03o`00oooo003o003o00;o
oooo00?o003ooooooooo00001_ooool00ooo003oooooo`00o`0Aooooo`03o`000?oooooooooo00oo
oooo00?o003ooooooooo00001Oooool00ooo003oooooooooo`03ooooo`03o`00oooo003o003o04Go
oooo00?o0000ooooooooool0:Oooool2o`00057ooooo00Co003ooooooooooooo003o0oooool01?l0
0?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool05oooool0
1?l00?ooooooooooool00?l9ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooool00?l0
1?ooool00ol00?ooooooo`00o`04ooooo`;o003o1Oooool2o`00o`Cooooo0_l00?l5ooooo`;o003o
1Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo0_l0000Aooooo`007?oo
ool2o`0004Gooooo00?o003oool00?l00?l01?ooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooo003o017ooooo00?o0000ooooooooool03oooool00ol00?ooooooool00005ooooo`04ool00?oo
ooooooooo`00o`;ooooo00?o003oool00?l00?l0AOooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo053ooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool00?l5oooo
o`05o`00ooooooooooooooooool000006?ooool3ool00005ooooool00?ooooooooooool00?l00_oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01?oo
ool2o`00o`Gooooo0_l00?l5ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`0?ooooo`005_ooool3
o`0000?ooooo00?o0000ooooooooool0A?ooool3ool000;ooooo00?o003ooooooooo00001_ooool0
0ooo003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?oo`00ooooooooool00oooool0
1?oo003oooooooooool00?l2ooooo`?oo`00AOooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo00Gooooo00?o003oooooooooool0Aoooool3ool000Gooooo00?o003oooooooooool01Ooo
ool2o`00o`?ooooo00?o0000ooooooooool05_ooool3ool00005ooooool00?ooooooooooool00?l0
0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Oo003oooooooooooooooooo`00oooooooo
003o00Kooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
003o00Cooooo0_l00?l6ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool2
o`00o`Oooooo00?o0000ooooooooool03oooool001Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`14ooooo`?oo`000_ooool00ol00?ooooooool00006ooooo`03ool00?oooooo003o
017ooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooo003o
00?ooooo0ooo0015ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01Oooool00ol0
0?ooooooooooo`17ooooo`?oo`0000?oooooo`00ooooool01Oooool00ol00?ooooooooooo`02oooo
o`;o003o0oooool00ol0003oooooooooo`0Fooooo`?oo`001?ooool01?l00?ooooooooooool00?l3
ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol0003ooooooooo
o`0?ooooo`005?ooool5o`0000?ooooo00?o0000ooooooooool0A?ooool3ool000;ooooo00?o003o
oooooooo00001_ooool00ooo003oooooo`00o`0Aooooo`03o`000?oooooooooo00oooooo00?o003o
oooooooo00001Oooool00ooo003oooooooooo`03ooooo`?oo`00AOooool00ol0003oooooooooo`0Y
ooooo`;o00001_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo043ooooo0ooo0000
0ooooooo003oooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_oo
ool00ol0003oooooooooo`0Fooooo`05o`00oooo003oooooooooool00?l02Oooool01?l00?oooooo
ooooool00?l3ooooo`03o`00oooooooo003o00Cooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00;ooooo0_l00?l5ooooo`;o003o1?ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Gooooo0_l0000Aooooo`005?ooool01?l0003ooooo
ooooool00004ooooo`?o0000Boooool00ooo003oooooooooo`04ooooo`03ool00?oooooo003o017o
oooo00?o0000ooooooooool03oooool00ol00?ooooooool00005ooooo`03ool00?oooooo003o04[o
oooo0_l0000[ooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`11ooooo`04ool00?ooooooooooo`00o`?ooooo00Co003ooooooooooooo003o1Oooool0
1Ol00?oooooooooooooooooo000001Sooooo00Ko003oool00?ooooooooooo`00ooooool3ool00003
ooooool00?oooooo00_ooooo00Go003oooooooooooooooooo`00o`02ooooo`07o`00oooooooooooo
ooooool00?ooooooo`00o`04ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool00ooo
ool2o`00o`Cooooo0_l00?l5ooooo`;o003o1oooool00ol0003oooooooooo`0?ooooo`005Oooool0
0ol0003oooooo`000004ooooo`03o`000?oooooooooo04Wooooo00?o003ooooooooo00001_ooool0
0ooo003oooooooooo`0Aooooo`03o`000?oooooooooo00oooooo00?o003ooooooooo00001Oooool0
0ooo003oooooo`00o`1;ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01Oooool0
0ol00?ooooooooooo`18ooooo`03ool00?oooooooooo00Cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooo`00o`03ooooo`03o`000?oooooooooo01Kooooo00Ko003oool00?ooooooooooo`00
ooooool3ool00003ooooool00?oooooo00;ooooo00Co003ooooooooooooo003o0oooool00ol00?oo
ooooo`00o`06ooooo`05o`00ooooooooooooooooool00?l01_ooool00ol00?ooooooo`00o`04oooo
o`;o003o1_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo0_l00?l7oooo
o`03o`000?oooooooooo00oooooo000Fooooo`;o00001?ooool00ol0003oooooooooo`19ooooo`03
o`00ooooooooo`0000Kooooo00?oo`00ooooool00?l04Oooool00ol0003oooooooooo`0Aooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooool00?l0Boooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo00Gooooo00?o003oooooooooool00oooool2o`00o`Gooooo00?o003ooooooooo
ool0>oooool01Ooo003oooooooooool00?oooooo00?oo`000_ooool01ol00?oooooooooooooooooo
003oooooool00?l00oooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo00;ooooo0ooo
00000ooooooo003oooooo`02ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l0
1?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo0_l00?l6ooooo`03o`00
oooooooooooo00Gooooo00?o0000ooooooooool03oooool001Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1:ooooo`03o`00oooo003ooooo00Gooooo00?oo`00ooooool00?l04Ooo
ool00ol0003oooooooooo`0?ooooo`03o`00ooooooooo`0000Gooooo00?oo`00ooooooooool0Booo
ool00ol0003oooooooooo`0Yooooo`;o00001_ooool00ol00?ooooooooooo`03ooooo`;o003o1Ooo
ool00ol00?ooooooooooo`0jooooo`06o`00oooo003oooooooooool00?oooooo0ooo0002ooooo`05
o`00ooooooooooooooooool00?l01Oooool00ol0003oooooooooo`0Fooooo`05o`00oooo003ooooo
ooooool00?l00_ooool00ooo003oooooooooo`03ooooo`?oo`0000Goooooo`00ooooooooooooo`00
o`02ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooool00?l01?ooool00ol00?ooooooo`00o`04ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool01Oooool2o`00017ooooo000Looooo`;o0000Booo
ool00ol00?ooo`00ooooo`05ooooo`03ool00?l00?oooooo017ooooo00?o0000ooooooooool03ooo
ool00ol00?ooooooool00005ooooo`03ool00?oooooo003o04_ooooo00?o0000ooooooooool08_oo
ool3o`0000Cooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`03ooooo`;o003o1Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo03?ooooo00Ko003oool00?oooooooooo
o`00ooooool3ool000;ooooo00?o003oooooooooool00oooool01Ol00?oooooooooooooooooo0000
00;ooooo00?o003oooooooooool04oooool01Ol00?ooo`00oooooooooooo003o00;ooooo00Coo`00
oooooooooooo003o0_ooool3ool000Oooooo00Go003oooooooooooooooooo`00o`02ooooo`07o`00
ooooooooooooooooool00?ooooooo`00o`04ooooo`03o`00oooooooo003o00Gooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooo`00o`04ooooo`;o003o1Oooool2o`00o`Oooooo00?o0000oooo
ooooool03oooool001cooooo00?o0000ooooooooool0Boooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo017ooooo00?o0000ooooooooool03oooool00ol00?ooooooool00005ooooo`03
ool00?oooooo003o04_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo0_l00?l<ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool0<oooool00ol00?ooo`00ooooo`04ooooo`03ool00?oooooooooo00Gooooo00?o003oooooool0
0?l00oooool01?l0003oooooooooool00?lEooooo`05o`00oooo003oooooooooool00?l00_ooool0
1?oo003oooooooooool00?l2ooooo`?oo`0000Goooooo`00ooooooooooooo`00o`02ooooo`03o`00
oooooooooooo00Cooooo00Oo003oooooooooooooooooo`00oooooooo003o00Cooooo00?o003ooooo
ool00?l00oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool00oooool2o`00o`Oooooo00?o0000ooooooooool03oooool001cooooo00?o0000oooooooo
ool0B_ooool00ol00?ooo`00ooooo`05ooooo`03ool00?l00?oooooo017ooooo00?o0000oooooooo
ool04Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooo003o04_ooooo00?o0000oooooooo
ool06oooool5o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo03Cooooo00Coo`00oooooooooooo003o0_ooool01Ooo003ooooooooooooooooo
003o00?ooooo00?o003oooooool00?l00oooool00ol0003oooooooooo`0Gooooo`03ool00?oooooo
oooo00;ooooo00Go003oool00?ooooooooooo`00o`02ooooo`06o`00oooo003oooooooooool00?oo
oooo0ooo0005ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool01?l00?oo
ooooooooool00?l3ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool2o`00
o`Kooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`0?ooooo`007?ooool00ol0003o
ooooooooo`1:ooooo`03o`00oooo003ooooo00Gooooo00?oo`00o`00ooooool04Oooool00ol0003o
ooooooooo`0?ooooo`03o`00ooooooooo`0000Gooooo00?oo`00ooooool00?l0Boooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`;o003o1Oooool2o`00o`Go
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo02go
oooo00Go003oool00?ooooooooooo`00o`02ooooo`05ool00?ooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`03ooooo`04o`000?oooooo003oo`00oaCooooo00?o003ooooooooo00000_oo
ool01?l00?oooooooooooooo0002ooooo`05o`00ooooooooooooo`00oooo00000_ooool00ol00?oo
ooooool00002ool00003ooooool00?oooooo00;ooooo00Co003ooooooooooooo003o1Oooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooo003o00Cooooo00?o003oooooool00?l01?ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00Kooooo0_l0000Aooooo`007?ooool2o`0004_o
oooo00?o003oool00?ooool01Oooool00ooo003o003oooooo`0Aooooo`03o`000?oooooooooo00oo
oooo00?o003ooooooooo00001Oooool00ooo003oooooooooo`1;ooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00?o
oooo0_l00?l5ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`03o`00oooooooooooo02go
oooo00Go003oool00?ooooooooooo`00o`02ooooo`05ool00?ooooooooooooooool00?l01Oooool0
1_l00?oooooooooooooooooo0000ooooo`;o003o5?ooool00ol00?ooooooool00002ooooo`04o`00
oooooooo003oool000Gooooo00?o003oool00?ooool00oooool3ool00003ooooool00?oooooo00;o
oooo00Co003ooooooooooooo003o0_ooool01?l00?ooooooooooool00?l3ooooo`04o`00oooooooo
ooooo`00o`Gooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`04ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooool00?l01oooool00ol0003oooooooooo`0?ooooo`007?ooool0
0ol0003oooooooooo`1;ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool04Oooool0
0ol0003oooooooooo`0@ooooo`03o`00oooo003ooooo00Cooooo00?oo`00ooooool00?l0Boooool0
0ol0003oooooooooo`0Rooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`;o003o1_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo0_l00?l5ooooo`03o`00oooooooo
oooo02gooooo00?o003oool00?ooool01?ooool00ooo003oooooooooo`04ooooo`04o`00oooooooo
ooooo`00o`?ooooo00Co0000ooooool00?oo003o5?ooool00ol00?ooooooool00002ooooo`04o`00
oooooooo003oool000;ooooo00Go003oooooooooooooooooool00002ooooo`04o`00oooooooooooo
ool000;ooooo00?o003oooooooooool00ooo00001Ooooooo003ooooooooooooo003o00;ooooo00Go
003oooooooooooooooooo`00o`02ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`06oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`07oooo
o`03o`000?oooooooooo00oooooo000Looooo`03o`000?oooooooooo04[ooooo00?o003oool00?oo
ool01Oooool00ooo003o003oooooo`0Aooooo`03o`000?oooooooooo017ooooo00?oo`00oooooooo
ool00oooool00ooo003oooooo`00o`1;ooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`0Wooooo`04ool00?ooooooooooo`00o`;ooooo00Goo`00oooo
ooooooooooooo`00o`02ooooo`04o`00ooooooooooooo`00o`?ooooo00?o0000ooooooooool05ooo
ool00ooo003oooooooooo`02ooooo`05o`00oooo003oooooooooool00?l00_ooool01Ol00?ooo`00
oooooooooooo003o00;ooooo00?oo`00ooooooooool00oooool3ool000Cooooo00?o003ooooooooo
ool01?ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooo003o00?ooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00Gooooo00?o0000oooo
ooooool03oooool001cooooo00?o0000ooooooooool0B_ooool00ol00?ooo`00ooooo`05ooooo`03
ool00?l00?oooooo017ooooo00?o0000ooooooooool04?ooool00ol00?ooo`00ooooo`04ooooo`03
ool00?oooooo003o04_ooooo00?o0000ooooooooool0:Oooool2o`0000Gooooo0_l00?l5ooooo`;o
003o1?ooool2o`00o`Kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`;o
003o:?ooool01Ol00?ooo`00oooooooooooo003o00;ooooo00Goo`00ooooooooooooooooo`00o`02
ooooo`03o`00oooooooooooo00Cooooo00Co0000ooooool00?oo003o5?ooool00ol00?ooooooool0
0002ooooo`04o`00ooooooooooooool000;ooooo00Go003ooooooooooooo003oool00002ooooo`04
o`00ooooooooooooool000;ooooo00?o003oooooooooool00ooo00000ooooooo003oooooo`03ool0
0003ooooool00?oooooo00Wooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l3
ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool01_ooool2o`00017ooooo000Loooo
o`;o0000Boooool00ol00?ooo`00ooooo`05ooooo`03ool00?l00?oooooo017ooooo00?o0000oooo
ooooool04?ooool00ol00?ooo`00ooooo`04ooooo`03ool00?oooooooooo04_ooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ool00?l01?ooool2o`00o`Gooooo0_l00?l5ooooo`03o`00oooooooooooo00?ooooo0_l00?l5oooo
o`03o`00oooooooooooo01oooooo00?o003ooooooooo00000_ooool01?l00?oooooooooooooo0003
ooooo`03o`00ooooooooo`0000;oo`0000?oooooo`00ooooool00_ooool01?l0003oooooo`00ool0
0?lDooooo`03o`00ooooooooo`0000;ooooo00Co003oooooool00?ooo`001Oooool00ol00?ooo`00
ooooo`04ooooo`04ool00?ooooooooooo`00o`;ooooo00Ko003oool00?ooooooooooo`00ooooool3
ool00003ooooool00?oooooo00;ooooo00Co003ooooooooooooo003o1Oooool01Ol00?oooooooooo
oooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`06ooooo`03o`00oooooooo003o00Oo
oooo00?o0000ooooooooool03oooool001cooooo00?o0000ooooooooool0Boooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol00?ooo`00
ooooo`04ooooo`03ool00?oooooo003o04_ooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`03ooooo`03o`00oooooooo003o00Kooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`04ooooo`;o003o1Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01oooooo
00?o003ooooooooo00001Oooool00ooo003oooooooooo`03ooooo`?oo`0000?oooooo`00ooooool0
0_ooool01?l0003o003oooooool00?lDooooo`03o`00ooooooooo`0000;ooooo00Co003oooooool0
0?ooo`000_ooool01Ol00?ooooooooooooooooooo`0000;ooooo00Co003oooooool00?ooo`000_oo
ool01Ol00?ooooooooooooooooooo`0000;ooooo00?o003ooooooooo00000_oo00000ooooooo003o
ooooo`02ooooo`04o`00ooooooooooooo`00o`;ooooo00Co003ooooooooooooo003o1_ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01oooool00ol0
003oooooooooo`0?ooooo`005Oooool3o`0000Cooooo00?o0000ooooooooool0B_ooool00ol00?oo
o`00ooooo`05ooooo`03ool00?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooo003o04_ooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool2o`00o`Go
oooo00?o003oooooooooool00oooool2o`00o`Kooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0Qooooo`07ool00?ooooooooooo`00oooooooo003oool00003ooooo`03o`00oooooooo
o`0000;oo`0000?oooooo`00ooooool00_ooool01?l0003oooooooooool00?lFooooo`03ool00?oo
oooooooo00;ooooo00Wo003oool00?ooooooooooo`00oooooooo003ooooooooo00000_ooool01?l0
0?ooooooo`00oooo0005ooooo`03o`00oooo003ooooo00Cooooo00?oo`00ooooooooool00oooool3
ool00005ooooool00?ooooooooooool00?l00_ooool01Ol00?oooooooooooooooooo003o00Kooooo
00?o003oooooool00?l01_ooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo00oooooo
000Dooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`1:ooooo`03o`00
oooo003ooooo00Gooooo00?oo`00o`00ooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`00
oooo003ooooo00Cooooo00?oo`00ooooool00?l0Boooool00ol0003oooooooooo`0Yooooo`;o0000
1?ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`02ooooo`;o003o1Oooool2o`00o`Gooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`0Hooooo`03o`00ooooooooo`0000;ooooo00Co003ooooooooooooo
o`000oooool01?l00?oooooooooooooo0006ooooo`03o`000?l00?oooooo00Kooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooool00002ooooo`04o`00ooooooooooooool000;ooooo00Go003o
ooooool00?ooooooool00002ooooo`04o`00oooooooo003oool000;ooooo00Go003ooooooooooooo
003oool00002ooooo`04o`00ooooooooooooool000;ooooo00?o003oooooooooool00ooo0004oooo
o`03o`00oooooooooooo00Cooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooo`00o`04
ooooo`03o`00oooooooooooo00Kooooo0_l0000Aooooo`005?ooool01Ol0003ooooooooooooooooo
000000?ooooo0ol0001:ooooo`03o`00oooo003ooooo00Gooooo00?oo`00o`00ooooool04Oooool0
0ol0003oooooooooo`0@ooooo`03o`00oooo003ooooo00Cooooo00?oo`00ooooooooool0B_ooool2
o`0002_ooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
003o00Cooooo0_l00?l4ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool00oooool2
o`00o`Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooo
o`0000;ooooo00Co003oooooool00?ooo`000oooool01?l00?oooooooooooooo0002ooooo`08o`00
ooooooooooooooooool0003o003oooooool00?l5ooooo`03o`00oooooooooooo00cooooo00?o003o
oooooooo00000_ooool2o`00o`03oooooooo003ooooo00?ooooo00?o003ooooooooo00001Oooool0
1?oo003oooooooooool00?l2ooooo`05o`00oooo003oooooooooool00?l00_ooool01?oo003ooooo
ooooool00?l2ooooo`?oo`0000?oooooo`00ooooool00ooo00000ooooooo003oooooo`02ooooo`04
o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`07oooo
o`03o`000?oooooooooo00oooooo000Dooooo`Co00001?ooool00ol0003oooooooooo`1;ooooo`03
ool00?oooooooooo00Cooooo00?oo`00o`00ooooool04Oooool00ol0003oooooooooo`0@ooooo`03
o`00oooo003ooooo00Cooooo00?oo`00ooooool00?l0Boooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo00?ooooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool2o`00o`Gooooo00?o003ooooooooo
ool04_ooool00ol00?ooooooool00004ooooo`03o`00oooo003ooooo00Cooooo00Go003oool00?oo
ooooooooo`00o`03ooooo`04o`000?l00?ooooooo`00o`Gooooo00?o003oooooooooool02oooool0
1?l00?oooooooooooooo0002ooooo`;o003o00Goooooool00?ooooooooooo`00o`03ooooo`07ool0
0?ooooooooooo`00oooooooo003oool00002ooooo`05o`00oooooooooooooooooooo00000_ooool0
1?l00?oooooooooooooo0002ooooo`05o`00ooooooooooooo`00oooo00000_ooool00ol00?oooooo
ool00002ool00003ooooool00?oooooo00Gooooo00?o003oooooooooool00oooool01Ol00?oooooo
oooooooooooo003o00;ooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`0?ooooo`00
5?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04[ooooo00?o003oool00?ooool0
1Oooool00ooo003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?oo`00ooooooooool0
0oooool00ooo003oooooo`00o`1;ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
0oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l0
1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
5?ooool01ooo003oooooooooool00?ooooooo`00oooo00000oooool01?l00?ooooooo`00oooo0002
ooooo`05o`00ooooooooooooooooool000000_ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00kooooo00Ooo`00ooooooooooooooooo`00ooooooooo`0000;ooooo00Go003oooooool0
0?ooooooool00002ooooo`04o`00oooooooo003oool000Gooooo00?o003oool00?ooool00oooool0
0ol00?ooo`00ooooo`04ooooo`06o`00oooo003oooooooooool00?oooooo0ooo00000ooooooo003o
ooooo`02ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o1_ooool00ol00?oo
ooooooooo`05ooooo`03o`000?oooooooooo00oooooo000Eooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0B_ooool00ol00?ooo`00ooooo`05ooooo`03ool00?l00?oooooo017ooooo
00?o0000ooooooooool04?ooool00ol00?ooo`00ooooo`04ooooo`03ool00?oooooo003o04_ooooo
00?o0000ooooooooool0:Oooool2o`0000Cooooo00?o003oooooool00?l01?ooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool2o`00o`Gooooo
0_l00?l5ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0Booooo`03o`00ooooooooo`0000;ooooo00Co003oooooooooooooo`000oooool01?l00?oo
ooooo`00oooo0002ooooo`06o`00ooooooooooooooooool0003o003o1oooool00ol00?oooooooooo
o`0;ooooo`04o`00ooooooooooooool000;ooooo00Co003oooooooooooooo`000_ooool01Ol00?oo
ooooo`00ooooooooo`0000;ooooo00Co003oooooool00?ooo`000_ooool01Ol00?ooooooooooool0
0?ooo`0000;ooooo00Co003oooooooooooooo`000_ooool01Ol00?ooooooooooooooooooo`0000Go
oooo00?oo`00ooooooooool00oooool3ool00005ooooool00?ooooooooooool00?l00_ooool01Ol0
0?oooooooooooooooooo003o00Wooooo0_l0000Aooooo`005_ooool2o`0000Cooooo0_l0001;oooo
o`03o`00oooo003ooooo00Gooooo00?oo`00o`00ooooool04Oooool00ol0003oooooooooo`0@oooo
o`03o`00oooo003ooooo00Cooooo00?oo`00ooooooooool0Boooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo00Gooooo00Go003oooooooooooooooooo`00o`02ooooo`07o`00oooooooo
ooooooooool00?ooooooo`00o`04ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool0
0oooool2o`00o`Cooooo0_l00?l5ooooo`;o003o1Oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00_ooooo00?o003ooooooooo00000_ooool01?l00?ooooooo`00oooo0003ooooo`04
o`00ooooooooooooool000Kooooo00Co0000o`00oooooooo003o1Oooool00ol00?ooooooooooo`0;
ooooo`04o`00ooooooooooooool000;ooooo0_l00?l00oooooooo`00ooooo`03ooooo`03o`00oooo
ooooo`0000Gooooo00Soo`00oooooooooooo003oooooool00?ooooooool000;ooooo00Co003ooooo
ool00?ooo`000_ooool01Ol00?ooooooooooool00?ooo`0000;ooooo00Co003oooooooooooooo`00
0_ooool00ol00?ooooooooooo`03ool00005ooooool00?ooooooooooool00?l01_ooool01?l00?oo
ooooooooool00?l7ooooo`03o`000?oooooooooo00oooooo000Looooo`03o`000?oooooooooo04_o
oooo00?oo`00ooooooooool01?ooool00ooo003o003oooooo`0Aooooo`03o`000?oooooooooo013o
oooo00?o003oool00?ooool01?ooool00ooo003oooooo`00o`1;ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool00oooool00ol00?ooooooo`00o`06ooooo`05o`00oooooooooooooooo
ool00?l01_ooool00ol00?ooooooo`00o`04ooooo`;o003o1Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool02_ooool01?l00?oooooooooooooo0004ooooo`03o`00oooo003ooooo00;ooooo00Co003o
ooooool00?ooo`000_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0;ooooo`04o`00ooooooooooooool000;ooooo0_l00?l01Ooooooo
o`00oooooooooooo003o00?ooooo00?oo`00ooooooooool00_l00?l02Oooooooo`00oooooooooooo
003oooooool00?ooooooool00002ooooo`04o`00oooooooo003oool000;ooooo00Go003ooooooooo
oooo003oool00002ooooo`04o`00ooooooooooooool000;ooooo00?o003oooooooooool00ooo0000
0ooooooo003oooooo`03ool00003ooooool00?oooooo00;ooooo00Co003ooooooooooooo003o1ooo
ool00ol0003oooooooooo`0?ooooo`007?ooool00ol0003oooooooooo`1:ooooo`03o`00oooo003o
oooo00Gooooo00?oo`00ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooool00?l0Boooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
003o00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00;ooooo0_l00?l6ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool2
o`00o`oooooo00?oo`00ooooooooool00_l00?l00oooooooo`00ooooo`04ooooo`05o`00oooo003o
ooooooooool00?l00oooool01?l0003oooooooooool00?l4ooooo`;o003o4?ooool01ooo003ooooo
oooooooooooo003ooooooooo00000_ooool01Ol00?ooooooo`00ooooooooo`0000;ooooo0_l00?l0
0oooooooo`00ooooo`05ooooo`03ool00?oooooooooo00;ooooo00?o003oool00?ooool01?ooool0
1Ol00?ooo`00oooooooooooo003o00;ooooo00Coo`00oooooooooooo003o0oooool00ooo003ooooo
ooooo`02ooooo`?oo`0000?oooooo`00ooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00
0?oooooooooo00oooooo000Looooo`03o`000?oooooooooo04[ooooo00?o003oool00?ooool01Ooo
ool00ooo003o003oooooo`0Aooooo`03o`000?oooooooooo017ooooo00?oo`00ooooooooool00ooo
ool00ooo003o003oooooo`1;ooooo`03o`000?oooooooooo02Wooooo0_l00003ooooo`04o`00oooo
ooooooooo`00o`?ooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooooooo`04ooooo`07
o`00ooooooooooooooooool00?ooooooo`00o`04ooooo`03o`00oooooooo003o00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool02_ooool01?l00?oooooooooooooo0002ooooo`04o`00ooooooooooooool000?ooooo
00Co003oooooool00?ooo`000_ooool01Ol00?oooooooooooooooooo003o00Sooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`04ooooo`04o`00ooooooooooooool000;ooooo00Co003o
ooooooooooooo`000_ooool01Ol00?ooooooo`00ooooooooo`0000;ooooo0_l00?l02Oooooooo`00
oooooooooooo003oooooool00?ooooooool00002ooooo`04o`00ooooooooooooool000;ooooo00Go
003oooooooooooooooooool00004ooooo`03o`00oooo003ooooo00Cooooo00Ko003oool00?oooooo
ooooo`00ooooool3ool00003ooooool00?oooooo00;ooooo00?o003oooooooooool01oooool2o`00
017ooooo000Looooo`;o0000Boooool00ol00?ooo`00ooooo`05ooooo`03ool00?l00?oooooo017o
oooo00?o0000ooooooooool04?ooool00ol00?ooo`00ooooo`04ooooo`03ool00?oooooooooo04_o
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`05ooooo`05o`00oooooooooooooooo
ool00?l00_ooool01ol00?oooooooooooooooooo003oooooool00?l01?ooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01?ooool2o`00o`Gooooo0_l0
0?l4ooooo`03o`00oooooooooooo00Cooooo0_l00?l5ooooo`03o`00oooooooooooo00Cooooo00Co
003oooooooooooooo`000_ooool2o`00o`03oooooooo003ooooo00;ooooo00Co003ooooooooooooo
o`001_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01?ooool01?l00?oooooooooooooo0002ooooo`04o`00ooooooooooooool000?ooooo00Co
003oooooooooooooo`001Oooool02?oo003oooooooooool00?ooooooo`00ooooooooo`000_ooool0
1?l00?ooooooo`00oooo0002ooooo`05o`00oooooooooooooooooooo00000_ooool01?l00?oooooo
oooooooo0002ooooo`05o`00ooooooooooooo`00oooo00000_ooool01?l00?oooooooooooooo0005
ooooo`?oo`0000?oooooo`00ooooool01_ooool00ol0003oooooooooo`0?ooooo`007?ooool00ol0
003oooooooooo`1;ooooo`03ool00?oooooooooo00Cooooo00?oo`00o`00ooooool04Oooool00ol0
003oooooooooo`0@ooooo`03o`00oooo003ooooo00Cooooo00?oo`00o`00ooooool0Boooool00ol0
003oooooooooo`0Sooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`04o`00oooooooooooo
o`00o`Kooooo00Go003oooooooooooooooooo`00o`06ooooo`03o`00oooooooo003o00?ooooo00?o
003oooooool00?l01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00?ooooo0_l0
0?l4ooooo`;o003o1Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00Co
003oooooooooooooo`000oooool00ol00?ooooooool00003ooooo`;o003o00Goooooool00?oooooo
ooooo`00o`03ooooo`04o`00ooooooooooooo`00o`Cooooo0_l00?l5ooooo`03o`00oooooooooooo
00Gooooo00Co003oooooooooooooo`000_ooool01?l00?oooooooooooooo0002ooooo`05o`00oooo
oooooooooooooooo00000_ooool2o`00o`09oooooooo003oooooooooool00?ooooooo`00oooooooo
o`0000;ooooo00Co003oooooool00?ooo`000_ooool01Ol00?ooooooo`00ooooooooo`0000;ooooo
00Co003oooooool00?ooo`000_ooool01Ol00?ooooooooooool00?ooo`0000;ooooo00Co003ooooo
ooooooooo`000_ooool00ol00?ooooooooooo`03ool00003ooooool00?oooooo00Kooooo00?o0000
ooooooooool03oooool001cooooo00?o0000ooooooooool0B_ooool00ol00?ooo`00ooooo`05oooo
o`03ool00?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol00?ooo`00ooooo`04oooo
o`03ool00?l00?oooooo04_ooooo00?o0000ooooooooool08_ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo00;ooooo00Co003ooooooooooooo003o0oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooo003o00?ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00;ooooo0_l00?l6ooooo`03o`00oooooooooooo00;ooooo0_l0
0?l5ooooo`;o003o1Oooool00ol00?ooooooooooo`07ooooo`03ool00?oooooooooo00;o003o00?o
ooooool00?ooool00oooool00ol00?ooooooool00002ooooo`03o`00oooooooooooo00?oo`0000?o
ooooo`00ooooool00oooool2o`00o`Gooooo0_l00?l9ooooo`04ool00?ooooooooooo`00o`;ooooo
00?oo`00ooooooooool00_l00?l2ooooo`03ool00?oooooooooo00;o003o00Goooooool00?oooooo
ooooo`00o`03ooooo`03ool00?oooooooooo00;ooooo00?o003oool00?ooool00oooool00ol00?oo
ooooool00002ooooo`04o`00oooooooo003oool000;ooooo00Go003oooooooooooooooooool00002
ooooo`04o`00ooooooooooooool000;ooooo00?o003oooooooooool00ooo00000ooooooo003ooooo
o`03ool000?ooooo00?o0000ooooooooool03oooool001cooooo00?o0000ooooooooool0B_ooool0
0ol00?ooo`00ooooo`05ooooo`03ool00?l00?oooooo017ooooo00?o0000ooooooooool04Oooool0
0ooo003oooooooooo`03ooooo`03ool00?l00?oooooo04_ooooo00?o0000ooooooooool08_ooool0
1?l0003oooooooooool00003ooooo`Go000000?o003oo`000?l000000ol000001Ooo003o003oo`00
0?l0003o003o00;o000000Coo`00o`000?l0003o003o0_l000001Ooo003o0000o`000?l0003o003o
00;o000000Coo`00o`00ool0003o003o0_l000001Ooo003o0000o`00ool0003o003o00;o000000?o
o`00o`000?l00?l00ol000000ooo003o0000o`00o`04o`000004ool00?l0003o0000o`00o`;o0000
00?oo`00o`000?l000000_l00?l2o`000004ool00?l0003o0000o`00o`;o000000Goo`00o`000?l0
003o0000o`00o`02o`000004ool00?l0003o0000o`00o`;o000000Coo`00o`000?l0003o00000_l0
0?l01Ol0003oo`00o`000?l0003o003o00;o00000ooo0004o`000004ool00?l0003o0000o`00o`?o
000000Coo`00o`000?l00?oo003o0_l000001?oo003o0000o`000?l00?l3o`000004ool00?l0003o
0000o`00o`;o000000?oo`00o`000?l000000_l00?l2o`000003ool00?l0003o000000;o003o00?o
0000ool00?l000000ol000000ol00?oo0000ool00002o`000004o`00ool0003o0000ool000;o0000
00Go003oo`000?l00?oo0000ool00004o`000003o`00oooo003o000000Co000000?o003oool00?l0
00001?l000001?oo003o0000o`000?l00?l2o`000003o`00oooo003o000000?o00000ooo0004o`00
017ooooo000Looooo`03o`000?oooooooooo04_ooooo00?oo`00ooooooooool01?ooool00ooo003o
003oooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o003oool00?ooool01?ooool00ooo003o
ooooooooo`1;ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`05ooooo`05o`00ooooooooooooool00?l00?l00_ooool01?l00?oooooooooooooo
0002ooooo`05o`00ooooooooooooool00?l00?l00_ooool01?l00?oooooooooooooo0002ooooo`08
o`00ooooooooooooool00?oooooo003oooooool00?l2ooooo`04ool00?oooooo003oo`00o`;ooooo
00Goo`00ooooool00?ooooooo`00o`02ooooo`03ool00?oooooo003o00?ooooo00Goo`00oooooooo
ooooooooo`00o`02ooooo`04ool00?ooooooooooo`00o`;ooooo00Goo`00ooooooooooooooooo`00
o`05ooooo`;o003o1Oooool00ol00?ooooooooooo`06ooooo`?oo`0000Koooooo`00oooooooooooo
ool00?ooool2o`00o`?ooooo00Coo`00oooooooooooo003o0_ooool01?oo003oooooooooool00?l6
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02Oooool00ol00?ooooooo`00o`04
ooooo`;o003o1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00Co003o
oooooooooooo003o0oooool00ol00?ooooooo`00o`06ooooo`06o`00ooooooooooooooooool00?oo
oooo0ooo0003ooooo`03o`000?oooooooooo00oooooo000Looooo`;o0000C?ooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol00?ooo`00
ooooo`04ooooo`03ool00?oooooooooo04_ooooo00?o0000ooooooooool08_ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo00Gooooo00?o003ooooooooo00000_oo0002ooooo`04
o`00ooooooooooooool000Gooooo00Goo`00o`00ooooooooooooo`00o`02ooooo`04ool00?oooooo
ooooo`00o`;ooooo00Goo`00ooooool00?ooooooo`00o`02ooooo`04ool00?ooooooooooo`00o`;o
oooo00Goo`00ooooool00?ooooooo`00o`02ooooo`04ool00?oooooo003oo`00o`;ooooo00Coo`00
oooooooooooo003o0oooool01?oo003oooooooooool00?l2ooooo`05ool00?ooooooooooooooool0
0?l01_ooool00ol00?ooooooooooo`03ooooo`;o003o1?ooool01Ol00?ooooooooooool00?oo0000
00;ooooo00Ko003oooooooooooooo`00ooooool00?l4ooooo`03ool00?oooooo003o00?ooooo00Co
o`00oooooooooooo003o1_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo
0_l00?l4ooooo`;o003o1Oooool2o`00o`Cooooo00?o003oooooool00?l01?ooool00ol00?oooooo
o`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool00oooool01?l00?oo
ooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`Cooooo00?o0000ooooooooool03oooool0
01Gooooo0ol00004ooooo`03o`000?oooooooooo04_ooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o003oool00?ooool01?ooool00ooo
003o003oooooo`1;ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`05ooooo`03o`00ooooooooo`0000;oo`001Oooool01?oo003oooooooooool0
0?l2ooooo`03ool00?l00?oooooo00Cooooo00?oo`00o`00ooooool00oooool00ooo003ooooooooo
o`04ooooo`04ool00?l00?ooooooo`00o`;ooooo00Goo`00ooooooooooooooooo`00o`02ooooo`04
ool00?oooooo003oo`00o`;ooooo00?oo`00ooooooooool00_l00?l2ooooo`04ool00?oooooooooo
o`00o`;ooooo00?oo`00ooooooooool01oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`000002ooooo`07o`00ooooooooooooool00?l00?oo
ooooo`00o`03ooooo`04ool00?oooooo003oo`00o`;ooooo00?oo`00ooooooooool01oooool00ol0
0?ooooooooooo`03ooooo`;o003o1Oooool2o`00o`Cooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l00oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooo003o00?ooooo00?o003oooooooooool01?ooool01?l0
0?ooooooooooool00?l4ooooo`03o`000?oooooooooo00oooooo000Dooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`1;ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo00?ooooo00?oo`00
o`00ooooool0Boooool00ol0003oooooooooo`0Sooooo`;o00001?ooool2o`0000Sooooo0ooo0002
ooooo`03o`00ooooooooo`0000;oo`0000Goooooo`00ooooooooooooool00003ooooo`07o`00oooo
ooooooooool00?l00?ooooooo`00o`02ooooo`05ool00?l00?ooooooooooool00?l00_ooool01?oo
003o003oooooool00?l2ooooo`03ool00?oooooo003o00Cooooo00Coo`00oooooooooooo003o0_oo
ool00ooo003oooooooooo`02o`00o`;ooooo00Coo`00oooooooooooo003o0_ooool01?oo003ooooo
ooooool00?l6ooooo`03o`00oooooooooooo00Cooooo0_l00?l4ooooo`05o`00ooooooooooooo`00
ool000001Oooool01?oo003oooooooooool00?l3ooooo`04ool00?oooooo003oo`00o`;ooooo00Co
o`00oooooooooooo003o1_ooool00ol00?ooooooooooo`03ooooo`;o003o1Oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oooooo
o`00o`06ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02?ooool01?l00?oooooo
ooooool00?l6ooooo`04o`00ooooooooooooooooo`;o00004Oooool001Cooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo04_ooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o003oool00?ooool01?ooool00ooo
003o003oooooo`1;ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01Oooool01?l0
0?ooooooooooool00?l3ooooo`03o`00ooooooooo`0000;oo`0000Koooooo`00ooooooooooooool0
0?l00?l2ooooo`07o`00ooooooooooooool00?l00?ooooooo`00o`02ooooo`05ool00?l00?oooooo
ooooool00?l00_ooool00ooo003o003oooooo`03ooooo`05ool00?oooooo003oooooool00?l00_oo
ool00ooo003oooooooooo`03ooooo`05ool00?ooooooooooooooool00?l00_ooool01?oo003ooooo
o`00ool00?l2ooooo`04ool00?ooooooooooo`00o`Kooooo00?o003oooooooooool01?ooool2o`00
o`Oooooo00Go003oo`000?ooooooooooo`00o`02ooooo`04ool00?l00?ooooooo`00o`?ooooo00Co
o`00oooooooooooo003o0_ooool01?oo003oooooooooool00?l<ooooo`03o`00oooooooooooo00[o
oooo0_l00?l5ooooo`;o003o1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooool00?l01?ooool00ol00?ooooooo`00o`06ooooo`05o`00oooooooooooooooo
ool00?l01oooool00ol0003oooooooooo`0?ooooo`005Oooool3o`0000Cooooo0ol0001;ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03
o`00oooo003ooooo00Cooooo00?oo`00ooooooooool0B_ooool2o`0002_ooooo00?o0000oooooooo
ool01Oooool01?l00?ooooooooooool00?l3ooooo`03o`00ooooooooo`0000;oo`001?ooool01Ooo
003o003ooooooooooooo003o00;ooooo00Coo`00oooooooooooo003o0_ooool01Ooo003o003ooooo
oooooooo003o00;ooooo00Coo`00oooooooooooo003o0_ooool01Ooo003oooooo`00oooooooo003o
00;ooooo00Coo`00ooooool00?oo003o0_ooool00ooo003oooooo`00o`04ooooo`04ool00?oooooo
ooooo`00o`;ooooo00Coo`00oooooooooooo003o3Oooool00ol00?ooooooooooo`03ooooo`05o`00
ooooooooooooo`00ool000000_ooool01Ol00?oooooooooooooo003o003o00Gooooo00?oo`00o`00
ooooool00oooool01?oo003oooooooooool00?l<ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool00oooool2o`00o`Gooooo0_l00?l4ooooo`03o`00oooooooo003o00Cooooo0_l00?l4
ooooo`03o`00oooooooo003o00Cooooo00?o003oooooool00?l00oooool01?l00?ooooooooooool0
0?l3ooooo`03o`00oooooooo003o00Gooooo00?o0000ooooooooool03oooool001Cooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo04_ooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?oo`00ooooooooool00ooo
ool00ooo003o003oooooo`1;ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01Ooo
ool00ol00?ooooooooooo`07ooooo`05o`00ooooooooooooo`00ooooool00ooo0005ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool01?oo003o003oooooool00?l2ooooo`05
ool00?ooooooooooooooool00?l00_ooool01?oo003oooooo`00ool00?l2ooooo`05ool00?oooooo
003oooooool00?l00_ooool01?oo003oooooo`00ool00?l2ooooo`03ool00?oooooooooo00kooooo
00?o003oooooooooool00oooool01Ol00?oooooooooooooooooo000000;ooooo00Oo003ooooooooo
ooooo`00o`00oooooooo003o00?ooooo00Coo`00o`00oooooooo003o0_ooool00ooo003ooooooooo
o`0=ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool2o`00o`Cooooo00?o
003oooooooooool01?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooool00?l01Oooool00ol0003oooooooooo`0?ooooo`005?ooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool0Boooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo017ooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`03ooooo`03ool00?l0
0?oooooo04_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`08ooooo`05o`00oooo
ooooooooooooool00?l01Oooool00ol00?ooooooool00002ool000;ooooo00Co003ooooooooooooo
o`000_ooool01Ol00?oooooooooooooo003o003o00;ooooo00Oo003oooooooooooooo`00o`00oooo
oooo003o00;ooooo00Goo`00ooooool00?ooooooo`00o`02ooooo`04ool00?l00?ooooooo`00o`;o
oooo00Goo`00ooooool00?ooooooo`00o`02ooooo`03ool00?oooooo003o00?ooooo00Coo`00oooo
oooooooo003o3Oooool00ol00?ooooooooooo`03ooooo`05o`00oooooooo003oooooool000001Ooo
ool01?oo003oooooooooool00?l3ooooo`04ool00?l00?ooooooo`00o`;ooooo00?oo`00ooooool0
0?l03Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool02Oooool2o`00o`Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooo003o00Kooooo00?o003oooooooooool00oooool00ol0003oooooooooo`0?ooooo`00
5Oooool3o`0000Cooooo00?o0000ooooooooool0Boooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`03ooooo`03ool0
0?l00?oooooo04_ooooo00?o0000ooooooooool0:Oooool2o`0000Kooooo00Co003ooooooooooooo
003o0oooool01?l00?ooooooooooool00?l2ooooo`03o`00ooooooooo`0000;oo`000_ooool00ol0
0?ooooooool00002ool00006ooooool00?oooooooooooooo003o003o0_ooool01Ol00?oooooooooo
oooo003o003o00Cooooo00?oo`00ooooool00?l01?ooool00ooo003oooooooooo`03ooooo`05ool0
0?ooooooooooooooool00?l00_ooool01?oo003oooooo`00ool00?l2ooooo`04ool00?oooooooooo
o`00o`gooooo00?o003oooooooooool01Oooool00ol00?ooooooo`000002ooooo`07o`00oooooooo
ooooool00?l00?ooooooo`00o`03ooooo`04ool00?l00?ooooooo`00o`;ooooo00?oo`00ooooool0
0?l05?ooool00ol00?ooooooooooo`03ooooo`;o003o1Oooool00ol00?ooooooooooo`03ooooo`;o
003o1Oooool2o`00o`Cooooo00?o003oooooool00?l01?ooool00ol00?ooooooo`00o`05ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool2o`00017ooooo000Looooo`;o0000
C?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo04_ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`05ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooo
oooo003o1Oooool01_l00?oooooooooooooooooo003oooooo`?oo`0000Koooooo`00oooooooooooo
ool00?l00?l2ooooo`04o`00ooooooooooooool000;ooooo00Go003oooooooooooooo`00o`00o`02
ooooo`07o`00ooooooooooooool00?l00?ooooooo`00o`02ooooo`03ool00?oooooo003o00Cooooo
00Coo`00oooooooooooo003o0_ooool01?oo003oooooooooool00?l=ooooo`03o`00oooooooooooo
00?ooooo00Go003oooooool00?ooooooo`000002ooooo`05o`00ooooooooooooool00?l00?l01Ooo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooo003o01Cooooo00?o003oooooooooool00ooo
ool2o`00o`Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooool00?l01?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooo
oooo003o00Cooooo00?o003oooooool00?l01Oooool00ol0003oooooooooo`0?ooooo`007?ooool0
0ol0003oooooooooo`1;ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool04Oooool0
0ol0003oooooooooo`0Aooooo`03ool00?oooooooooo00?ooooo00?oo`00o`00ooooool0Boooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo0ooo0004ooooo`03ool00?oooooo
oooo00Cooooo00Coo`00oooooooooooo003o0_ooool01Ooo003ooooooooooooooooo003o00;ooooo
00Coo`00o`00oooooooo003o0_ooool01Ooo003oooooo`00oooooooo003o00;ooooo00Coo`00oooo
ool00?oo003o0_ooool00ooo003oooooooooo`0>ooooo`03o`00oooooooooooo00?ooooo00Go003o
ooooooooooooooooo`000002ooooo`04o`00ooooooooooooool000;ooooo00So003ooooooooooooo
ooooool00?l00?ooooooo`00o`;ooooo00?oo`00ooooooooool05?ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03
ooooo`;o003o1?ooool00ol00?ooooooooooo`04ooooo`;o003o1?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooo003o00Gooooo00?o0000ooooooooool03oooool001cooooo00?o0000oooo
ooooool0Boooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ooo003oooooooooo`03ooooo`03ool00?l00?oooooo04_ooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`08ooooo`05o`00ooooooooooooooooool00?l01Oooool0
0ol00?ooooooooooo`04ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003ooooooooo00000_oo
0002ooooo`04o`00ooooooooooooool000;ooooo00Go003oooooooooooooo`00o`00o`02ooooo`07
o`00ooooooooooooool00?l00?ooooooo`00o`02ooooo`05ool00?oooooo003oooooool00?l00_oo
ool00ooo003oooooo`00o`03ooooo`03ool00?oooooo003o00kooooo00?o003oooooooooool00ooo
ool01Ol00?ooooooo`00oooooooo000000Gooooo00Coo`00oooooooooooo003o0oooool01?oo003o
003oooooool00?l2ooooo`03ool00?oooooo003o01[ooooo00?o003oooooooooool02_ooool2o`00
o`Kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo003o
00Kooooo00?o003oooooooooool00oooool00ol0003oooooooooo`0?ooooo`007?ooool00ol0003o
ooooooooo`1;ooooo`03ool00?oooooooooo00?ooooo0ooo000Booooo`03o`000?oooooooooo013o
oooo0ooo0004ooooo`03ool00?l00?oooooo04_ooooo00?o0000ooooooooool0:Oooool2o`0000Ko
oooo00Co003ooooooooooooo003o0oooool00ol00?ooooooo`00o`03ooooo`04o`00oooooooooooo
o`00o`?ooooo00Co003ooooooooooooo003o0_ooool00ol00?ooooooool00002ool000;ooooo00Co
003oooooooooooooo`001Oooool00ooo003o003oooooo`04ooooo`03ool00?oooooooooo00?ooooo
00Goo`00ooooooooooooooooo`00o`02ooooo`04ool00?l00?ooooooo`00o`;ooooo00?oo`00oooo
ool00?l05_ooool00ol00?ooooooo`000002ooooo`04o`00ooooooooooooool000;ooooo00So003o
ooooooooooooooooool00?l00?ooooooo`00o`;ooooo00?oo`00ooooool00?l06_ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`;o003o1?ooool2o`00o`Go
oooo0_l00?l6ooooo`03o`00oooooooooooo00Wooooo0_l0000Aooooo`007?ooool2o`0004cooooo
00?oo`00ooooooooool00oooool3ool001;ooooo00?o0000ooooooooool04?ooool3ool000Cooooo
00?oo`00ooooooooool0Boooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Gooooo
00?o003oooooool00?l01?ooool00ol00?ooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?o
oooo00?o003oooooooooool00oooool00ol00?ooooooool00002ool000;ooooo00?o003ooooooooo
00000_oo00001_oooooo003oooooooooooooo`00o`00o`;ooooo00Oo003oooooooooooooo`00o`00
oooooooo003o00;ooooo00?oo`00ooooool00?l01?ooool01?oo003oooooooooool00?l2ooooo`03
ool00?oooooo003o01Cooooo00Go003oooooool00?ooooooo`000002ooooo`03o`00ooooooooo`00
00;oo`001Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooo003o027ooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo0_l00?l5oooo
o`;o003o1?ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooo003o00Gooooo00?o0000oooo
ooooool03oooool001cooooo00?o0000ooooooooool0Boooool00ooo003oooooooooo`03ooooo`?o
o`004_ooool00ol0003oooooooooo`0@ooooo`?oo`001?ooool00ooo003o003oooooo`1;ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`09ooooo`?o
o`0000Goooooo`00ooooooooooooool00003ooooo`07o`00ooooooooooooool00?l00?ooooooo`00
o`02ooooo`05ool00?oooooo003oooooool00?l00_ooool01?oo003o003oooooool00?l2ooooo`03
ool00?oooooooooo01Cooooo00Go003oooooooooooooooooo`000002ooooo`03o`00ooooooooo`00
00;oo`0000?oooooo`00ooooool00_ooool01?oo003o003oooooool00?l2ooooo`03ool00?oooooo
oooo027ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool01?ooool2o`00o`Cooooo00?o003oooooool00?l01?ooool0
0ol00?ooooooo`00o`05ooooo`03o`000?oooooooooo00oooooo000Looooo`03o`000?oooooooooo
04_ooooo00?oo`00ooooooooool06?ooool00ol0003oooooooooo`0Gooooo`03ool00?l00?oooooo
04_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`04o`00oooooooooooo
o`00o`;ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooool00002ool00006ooooool0
0?oooooooooooooo003o003o0_ooool01ol00?oooooooooooooo003o003oooooool00?l00_ooool0
1Ooo003o003ooooooooooooo003o00;ooooo00?oo`00o`00ooooool00oooool00ooo003oooooo`00
o`0Dooooo`;o003o0_ooool00ol0003oooooooooo`02ooooo`?oo`0000?oooooo`00ooooool00_oo
ool01?oo003o003oooooool00?l2ooooo`03ool00?oooooo003o02Oooooo0_l00?l5ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`04ooooo`;o003o
1_ooool00ol0003oooooooooo`0?ooooo`007?ooool00ol0003oooooooooo`1;ooooo`03ool00?oo
oooooooo00Cooooo00?o003oooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00oooo
oooooooo00?ooooo00?oo`00o`00ooooool0Boooool00ol0003oooooooooo`0Yooooo`;o00001_oo
ool00ol00?ooooooo`00o`04ooooo`03o`00oooooooo003o00?ooooo00?o003oooooool00?l01?oo
ool00ol00?ooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo
003o1?ooool3ool000Gooooo00?oo`00ooooooooool00oooool01Ooo003ooooooooooooooooo003o
00;ooooo00Coo`00o`00oooooooo003o0_ooool00ooo003oooooo`00o`0Eooooo`04o`00oooooooo
ooooo`0000;ooooo00Co003ooooooooooooo003o0_ooool01Ol00?ooooooooooooooooooo`0000;o
oooo00Ko003oooooooooooooo`00ooooool00?lWooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool00oooool2o`00o`Gooooo0_l00?l6ooooo`03o`00oooooooooooo00Wooooo0_l0000A
ooooo`007?ooool2o`0004cooooo00?oo`00ooooooooool01?ooool00ol00?ooooooooooo`0Aoooo
o`03o`000?oooooooooo017ooooo00?o003oooooooooool00oooool00ooo003oooooooooo`1;oooo
o`03o`000?oooooooooo02;ooooo0ol00004ooooo`03o`000?oooooooooo00Gooooo00?o003ooooo
ool00?l01?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooo003o00Cooooo00?o003ooooo
ooooool00oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00?ooooo00?o003o
oooooooo00000_oo0002ooooo`04o`00ooooooooooooool000;ooooo00Go003oooooooooooooo`00
o`00o`02ooooo`04o`00ooooooooooooool000;ooooo00Ko003oooooooooooooo`00ooooool00?lD
ooooo`;o003o0_ooool01?l0003oooooooooool00?l2ooooo`03o`00oooooooooooo00Cooooo00?o
o`00ooooooooool00oooool00ooo003o003oooooo`0Wooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool00oooool2o`00o`Gooooo0_l00?l4ooooo`03o`00oooooooo003o00Cooooo0_l0
0?l6ooooo`03o`000?oooooooooo00oooooo000Looooo`03o`000?oooooooooo04_ooooo00?oo`00
ooooooooool01?ooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o003o
ooooooooool00oooool00ooo003o003oooooo`1;ooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00_ooooo00Go003o
oooooooooooo003oooooo`03ool000;ooooo00Co003oooooooooooooo`000_ooool01Ol00?oooooo
oooooooo003o003o00Gooooo00Coo`00o`00oooooooo003o0_ooool00ooo003oooooooooo`0Doooo
o`05o`00ooooooooooooooooool000000_ooool00ol00?ooooooo`00o`03ooooo`05o`00oooooooo
oooooooooooo00000_ooool01?l00?oooooooooooooo000Yooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo
0_l00?l5ooooo`;o003o1_ooool00ol0003oooooooooo`0?ooooo`003oooool3o`0000Cooooo0_l0
0004ooooo`03o`000?oooooooooo04_ooooo00?oo`00ooooooooool06?ooool00ol0003ooooooooo
o`0Aooooo`03o`00oooooooooooo00?ooooo00?oo`00o`00ooooool0Boooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00
o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o0_ooool01?l00?oo
ooooooooool00?l3ooooo`03o`00ooooooooo`0000;oo`0000Koooooo`00ooooooooooooool00?l0
0?l2ooooo`05o`00ooooooooooooool00?l00?l01?ooool00ooo003oooooooooo`0Dooooo`05o`00
ooooooooooooooooool000002?ooool01Ol00?ooooooooooooooooooo`0000;ooooo00Go003ooooo
ooooooooo`00o`00o`0_ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`04ooooo`;o003o1_ooool00ol0003oooooooooo`0?ooooo`004?ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Boooool0
0ooo003oooooooooo`04ooooo`03o`00oooooooooooo017ooooo00?o0000ooooooooool05oooool0
0ooo003o003oooooo`1;ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00oooool2
o`0000Kooooo00?o003oooooool00?l01?ooool2o`00o`Cooooo00?o003oooooool00?l01?ooool0
0ol00?ooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooool00?l01_oo
ool00ol00?ooooooooooo`03ooooo`?oo`001?ooool01Ooo003ooooooooooooooooo003o00;ooooo
00Coo`00o`00oooooooo003o0_ooool00ooo003oooooo`00o`0Eooooo`04o`00ooooooooooooo`00
00;ooooo00?o003oooooool00?l00oooool01Ol00?ooooooooooooooooooo`0000;ooooo00Go003o
ooooooooooooo`00o`00o`0_ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool02_ooool2o`00017ooooo000@ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000oooool3o`0004[ooooo0ooo0005ooooo`03o`00oooo
oooooooo017ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`02ooooo`?oo`00Booo
ool2o`0002Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`;o003o1Ooo
ool2o`00o`Cooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooo003o00Cooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l3ooooo`03o`00
ooooooooo`0000;oo`0000Koooooo`00ooooooooooooool00?l00?l2ooooo`04o`00oooooooooooo
ool000;ooooo00Ko003oooooooooooooo`00ooooool00?lDooooo`;o003o0_ooool01_l0003ooooo
ooooool00?ooooooo`00o`Oooooo00?oo`00ooooooooool00oooool00ooo003o003oooooo`0doooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool2o`00o`Gooooo0_l00?l6oooo
o`03o`000?oooooooooo00oooooo000@ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`1:ooooo`?oo`001Oooool00ol00?ooooooooooo`0Aoooo
o`03o`000?oooooooooo017ooooo00?o003oooooooooool00_ooool3ool004cooooo00?o0000oooo
ooooool08_ooool2o`0000Gooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`;o003o1_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00[ooooo00Go003ooooo
ooooooooooooo`00o`06ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003ooooooooo00000_oo
0005ooooo`04ool00?ooooooooooo`00o`;ooooo00?oo`00o`00ooooool05?ooool01Ol00?oooooo
oooooooooooo000000;ooooo00?o003oooooool00?l00oooool00ol00?ooooooooooo`03ool00005
ooooool00?oooooooooooooo0000=_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00?ooooo0_l00?l5ooooo`;o003o1_ooool00ol0003oooooooooo`0?ooooo`004?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0B_ooool3ool0
01Wooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`02ooooo`?oo`00C?ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooo003o00Kooooo00Oo003oooooooooooooooooo`00oooo
oooo003o00Cooooo00?o003oooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`04o`00
ooooooooooooo`00o`;ooooo00?o003ooooooooo00000_oo0002ooooo`04o`00ooooooooooooool0
00Gooooo00?oo`00ooooooooool05?ooool01Ol00?oooooooooooooooooo000000Sooooo00?o003o
ooooooooool00ooo00001_oooooo003oooooooooooooo`00o`00od;ooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo00oooooo000?ooooo`;o00001?oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo04_ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo01Oooooo00?o003oooooooooool0
Boooool00ol0003oooooooooo`0Yooooo`;o00001_ooool2o`00o`Gooooo0_l00?l4ooooo`03o`00
oooooooo003o00Cooooo0_l00?l4ooooo`03o`00oooooooo003o00Cooooo00?o003oooooool00?l0
1_ooool00ol00?ooooooooooo`09ooooo`?oo`000_ooool01?l00?oooooooooooooo0002ooooo`05
o`00ooooooooooooool00?l00?l06Oooool01_l0003oooooooooool00?ooooooo`00o`?ooooo00?o
003oooooooooool00ooo00001_oooooo003oooooooooooooo`00o`00occooooo00?o003ooooooooo
ool00oooool2o`00o`cooooo0_l0000Aooooo`004?ooool00ol0003oooooooooo`03ooooo`;o0000
1?ooool2o`0004cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Booooo`03o`00
0?oooooooooo017ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`1;ooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool01Oooool2o`00o`Gooooo0_l00?l4ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`04ooooo`03o`00
oooooooooooo00?ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooo`00o`03ooooo`04
o`00ooooooooooooo`00o`?ooooo00?o003ooooooooo00000_oo00001_oooooo003ooooooooooooo
o`00o`00oaWooooo00Ko0000oooooooooooo003oooooool00?l:ooooo`04o`00ooooooooooooool0
03gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00Gooooo00?o0000ooooooooool03oooool001cooooo00?o0000ooooooooool0C?ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol00?oo
ooooooooo`1Aooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01Oooool00ol00?oo
ooooooooo`04ooooo`;o003o1Oooool00ol00?ooooooooooo`03ooooo`;o003o3Oooool01Ol00?oo
oooooooooooooooo003o00;ooooo00Oo003oooooooooooooooooo`00oooooooo003o00?ooooo00Co
003ooooooooooooo003o1Oooool3ool00006ooooool00?oooooooooooooo003o003o6Oooool00ol0
003oooooooooo`02o`00o`Cooooo00Co003ooooooooooooo003o1_ooool00ooo003oooooooooo`11
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`0?
ooooo`007?ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo017ooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool01_ooool00ol00?ooooooooooo`09ooooo`;o003o1_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooo003o00Cooooo00?o003oooooool00?l00oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooool00002
ool000Cooooo00?oo`00ooooooooool06?ooool00ol0003oooooooooo`06ooooo`04o`00oooooooo
ooooo`00o`?ooooo00Co003oooooooooooooo`00@oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Gooooo00?o0000ooooooooool03oooool001cooooo00?o0000ooooooooool0C?oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o0000ooooooooool05ooo
ool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo02Wooooo0_l00006ooooo`;o003o1Ooo
ool00ol00?ooooooooooo`03ooooo`;o003o1Oooool2o`00o`Cooooo00?o003oooooool00?l01?oo
ool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00oooooo00Co003ooooooooooooo003o
0_ooool00ol00?ooooooool00002ool001Wooooo00Go0000ooooooooooooooooo`00o`04ooooo`04
o`00ooooooooooooo`00o`?ooooo00?o003ooooooooo00000_oo0012ooooo`03o`00oooooooooooo
00_ooooo0_l0000Aooooo`007?ooool2o`0004gooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`1;ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01Oooool2o`00o`Go
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Co
oooo00?o003oooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo
00?ooooo00?o003ooooooooo00000_oo000Iooooo`03o`000?oooooooooo00;o003o2oooool00ol0
0?ooooooool00002ool004Wooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`0?oooo
o`007?ooool00ol0003oooooooooo`1<ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool04_ooool00ol0003oooooooooo`0Booooo`03o`00oooooooooooo053ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`03ooooo`;o003o3?ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooo003o00Cooooo00?o003oooooool00?l00oooool01?l00?ooooooooooool00?l5oooo
o`06o`00ooooooooooooooooool00?oooooo0ooo000Iooooo`03o`000?oooooooooo00;o003o1?oo
ool01?l00?ooooooooooool00?l5ooooo`?oo`00BOooool00ol00?ooooooooooo`05ooooo`03o`00
0?oooooooooo00oooooo000Looooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool04_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo04_ooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00[ooooo0_l00?l6ooooo`03o`00oooo
oooooooo00;ooooo0_l00?l5ooooo`;o003o1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooo003o00?ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooo`00o`0Qooooo`04o`00
0?ooooooooooo`00o`Gooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool00?mB
ooooo`03o`000?oooooooooo00oooooo000Looooo`03o`000?oooooooooo04cooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo01Oooooo00?o003ooooo
ooooool0Boooool00ol0003oooooooooo`0Yooooo`;o00001_ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`;o003o1?ooool2o`00o`Gooooo0_l00?l6oooo
o`03o`00oooooooooooo00oooooo00?o003oooooool00?l00oooool01?l00?ooooooooooool00?lJ
ooooo`05o`000?ooooooooooooooool00?l01?ooool00ol00?ooooooo`00o`04ooooo`04o`00oooo
ooooooooo`00oe7ooooo0_l0000Aooooo`007?ooool2o`0004gooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`03ooooo`;o003o1Oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooo003o00Cooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00?ooooo00Co003ooooooooooooo003o6_ooool00ol0003oooooooooo`02o`00o`_ooooo
00Co003ooooooooooooo003oD_ooool00ol0003oooooooooo`0?ooooo`007?ooool00ol0003ooooo
ooooo`1<ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol0003ooooo
ooooo`0Booooo`03o`00oooooooooooo053ooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0<ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool00ol00?oooooo
o`00o`04ooooo`03o`00oooooooo003o00?ooooo00?o003oooooool00?l02_ooool01?l00?oooooo
ooooool00?lJooooo`04o`000?ooooooooooo`00o`Gooooo00?o003oooooool00?l0F_ooool00ol0
003oooooooooo`0?ooooo`003oooool3o`0000;ooooo1Ol00003ooooo`03o`000?oooooooooo057o
oooo00?o003oooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool0Boooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01;o
oooo0_l00?l5ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool2o`00o`Co
oooo00?o003oooooooooool01?ooool2o`00o`Cooooo00?o003oooooool00?l01?ooool00ol00?oo
ooooo`00o`0Qooooo`04o`000?ooooooooooo`00o`Gooooo00?o003oooooool00?l01?ooool00ol0
0?ooooooo`00o`1Cooooo`03o`000?oooooooooo00oooooo000@ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1<ooooo`03o`00oooooooooooo
01Oooooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo
02Wooooo0_l0000Cooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool2o`00
o`Gooooo0_l00?l5ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01?ooool00ol0
0?ooooooo`00o`03ooooo`04o`00ooooooooooooo`00oa[ooooo00Co0000oooooooooooo003o1Ooo
ool00ol00?ooooooo`00o`04ooooo`03o`00oooooooo003o05;ooooo0_l0000Aooooo`004?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0ol0001<ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool0B_ooool2o`0002_ooooo00?o0000ooooooooool04_ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`03o`00oooooooo
oooo00?ooooo0_l00?l5ooooo`;o003o1_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
003o00?ooooo00Co003ooooooooooooo003o6_ooool01?l0003oooooooooool00?l<ooooo`03o`00
oooooooo003o05?ooooo00?o0000ooooooooool03oooool0013ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04cooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool0D?oo
ool00ol0003oooooooooo`0Qooooo`Go00000oooool00ol0003oooooooooo`0Iooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`;o003o1Ooo
ool2o`00o`Cooooo00?o003oooooool00?l02_ooool01?l00?ooooooooooool00?lJooooo`04o`00
0?ooooooooooo`00o`Gooooo00?o003oooooool00?l0F_ooool00ol0003oooooooooo`0?ooooo`00
4?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00001Coooo
o`03o`00oooooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo04_ooooo00?o0000ooooooooool08_ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool2o`00o`Cooooo00?o003o
ooooool00?l01?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Co0000
oooooooooooo003o1Oooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooo003o05?ooooo00?o
0000ooooooooool03oooool000oooooo0_l00003ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`1<ooooo`03o`00oooooooooooo01Oooooo00?o0000ooooooooool05ooo
ool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00ooo
ool2o`0001[ooooo00?o003oooooooooool00oooool2o`00o`Gooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooo003o00Cooooo00?o003oooooool00?l01Ooo
ool00ol00?ooooooooooo`0Iooooo`03o`000?oooooooooo00Kooooo00?o003oooooool00?l01?oo
ool00ol00?ooooooo`00o`1Booooo`;o00004Oooool0013ooooo00?o0000ooooooooool00_ooool3
o`0000Cooooo0_l0001=ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool0
0ol0003oooooooooo`0Booooo`05o`00ooooooooooooooooool00?l0C_ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`;o003o2oooool2o`00o`Cooooo00?o
003oooooool00?l06oooool00ol0003oooooooooo`0=ooooo`03o`00oooooooo003o05?ooooo00?o
0000ooooooooool03oooool001cooooo00?o0000ooooooooool0C?ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol00?ooooooooooo`1@
ooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo01oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`;o003o1Ooo
ool2o`00o`Cooooo0_l00?l;ooooo`03o`00oooooooo003o01_ooooo00?o0000ooooooooool01ooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo057ooooo00?o0000ooooooooool03ooo
ool001cooooo00?o0000ooooooooool0DOooool00ol00?ooooooooooo`0Booooo`03o`000?oooooo
oooo01;ooooo00Go003oooooooooooooooooo`00o`1>ooooo`03o`000?oooooooooo027ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo02Kooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`;o003o
1?ooool00ol00?ooooooooooo`0Kooooo`03o`000?oooooooooo00Kooooo0_l00?l5ooooo`03o`00
oooooooooooo05?ooooo00?o0000ooooooooool03oooool001cooooo00?o0000ooooooooool0C?oo
ool00ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo01;ooooo00Go003ooooooooooooooooo
o`00o`1>ooooo`03o`000?oooooooooo02;ooooo0ol00004ooooo`;o00009oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Wooooo0_l00?l5ooooo`;o003o1_ooool00ol00?oooooo
ooooo`0Iooooo`03o`000?oooooooooo00Kooooo0_l00?l5ooooo`;o003oDoooool2o`00017ooooo
000Looooo`03o`000?oooooooooo04cooooo00Go003oooooooooooooooooo`00o`0Eooooo`03o`00
0?oooooooooo01Kooooo00?o003oooooooooool0C?ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo02Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00[ooooo0_l00?l4ooooo`03o`00oooooooo003o01_ooooo00?o0000ooooooooool0
1_ooool00ol00?ooooooooooo`04ooooo`;o003oE?ooool00ol0003oooooooooo`0?ooooo`007?oo
ool2o`0004kooooo00Co003ooooooooooooo003o5Oooool00ol0003oooooooooo`0Booooo`05o`00
ooooooooooooooooool00?l0C_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02co
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooool00?l06oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool0D_ooool00ol0003oooooooooo`0?ooooo`007?ooool00ol0003ooooo
ooooo`1@ooooo`03o`00oooooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol00?oooooo
ooooo`1@ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0;?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`;o003o1?ooool00ol00?oooooo
ooooo`0Kooooo`03o`000?oooooooooo00Kooooo0_l00?l5ooooo`03o`00oooooooooooo05?ooooo
00?o0000ooooooooool03oooool001cooooo00?o0000ooooooooool0I_ooool00ol0003ooooooooo
o`0Cooooo`04o`00ooooooooooooo`00odkooooo00?o0000ooooooooool0:Oooool2o`0002gooooo
00?o003oooooooooool02_ooool2o`00o`Gooooo0_l00?l5ooooo`03o`00oooooooooooo01[ooooo
00?o0000ooooooooool01_ooool2o`00o`Gooooo0_l00?mCooooo`;o00004Oooool001cooooo00?o
0000ooooooooool0COooool01?l00?ooooooooooool00?lEooooo`03o`000?oooooooooo01Kooooo
00?o003oooooooooool0C?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03?ooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`;o003o1?ooool2o`00oacooooo
00?o0000ooooooooool01_ooool00ol00?ooooooooooo`04ooooo`;o003oE?ooool00ol0003ooooo
ooooo`0?ooooo`007?ooool2o`0004kooooo00Co003ooooooooooooo003o5Oooool00ol0003ooooo
ooooo`0Cooooo`04o`00ooooooooooooo`00odkooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0cooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02_ooool2o`00oaco
oooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo05;o
oooo00?o0000ooooooooool03oooool000oooooo0ol00004ooooo`?o00000oooool00ol0003ooooo
ooooo`1=ooooo`04o`00ooooooooooooo`00oaGooooo00?o0000ooooooooool04oooool00ol00?oo
ooooooooo`1?ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0>Oooool2o`00o`Go
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Kooooo`03o`000?oooooooooo00Ko
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Cooooo`03o`000?oooooooooo00oo
oooo000@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1Vooooo`03o`000?oooooooooo01?ooooo00Co003ooooooooooooo003oC_ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo03Wooooo0_l00?l5ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0=ooooo`03o`00oooooooooooo05?o
oooo00?o0000ooooooooool03oooool0013ooooo00Co0000oooooooooooooooo1Ol00003ooooo`03
o`000?oooooooooo04gooooo00Co003ooooooooooooo003o5Oooool00ol0003oooooooooo`0Foooo
o`03o`00oooooooooooo04cooooo00?o0000ooooooooool0:Oooool2o`0003[ooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`03ooooo`;o003o7?ooool00ol0003oooooooooo`0=oooo
o`03o`00oooooooooooo05;ooooo0_l0000Aooooo`004?ooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool00_ooool3o`0004gooooo00Co003ooooooooooooo003o5Oooool0
0ol0003oooooooooo`0Cooooo`04o`00ooooooooooooo`00odgooooo0_l0000[ooooo`03o`000?oo
oooooooo04Kooooo0_l00?lLooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool0Dooo
ool00ol0003oooooooooo`0?ooooo`004?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
000000Cooooo00?o0000ooooooooool0COooool01?l00?ooooooooooool00?lEooooo`03o`000?oo
oooooooo01?ooooo00?o003oooooooooool0Coooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo043ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Kooooo`03o`000?oo
oooooooo00gooooo00?o003oooooooooool0Doooool00ol0003oooooooooo`0?ooooo`003oooool2
o`0000Gooooo0_l00004ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool04oooool0
1?l00?ooooooooooool00?m>ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0@?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool03Ooo
ool00ol00?ooooooooooo`1Cooooo`03o`000?oooooooooo00oooooo000@ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1=ooooo`03o`00oooooooo
oooo01Kooooo00?o0000ooooooooool05_ooool00ol00?ooooooooooo`1<ooooo`03o`000?oooooo
oooo02Wooooo0_l00017ooooo`;o003o7?ooool00ol0003oooooooooo`0=ooooo`03o`00oooooooo
oooo05;ooooo0_l0000Aooooo`007?ooool2o`0004kooooo00?o003oooooool00?l05_ooool00ol0
003oooooooooo`0Cooooo`03o`00oooooooo003o04oooooo00?o0000ooooooooool08_ooool3o`00
00Cooooo00?o0000ooooooooool0A_ooool00ol00?ooooooooooo`0Kooooo`03o`000?oooooooooo
00gooooo00?o003oooooooooool0Doooool00ol0003oooooooooo`0?ooooo`007?ooool00ol0003o
ooooooooo`1>ooooo`;o003o5_ooool00ol0003oooooooooo`0Dooooo`03o`00oooooooooooo04ko
oooo00?o0000ooooooooool08Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool0A_ooool00ol00?ooooooooooo`0Kooooo`03o`000?oooooooooo06?ooooo00?o0000oooo
ooooool03oooool001cooooo00?o0000ooooooooool0Coooool00ol00?ooooooooooo`0Dooooo`03
o`000?oooooooooo01Cooooo0_l00?m?ooooo`03o`000?oooooooooo02Gooooo00Go0000oooooooo
ooooooooo`00001Vooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool03oooool001co
oooo00?o0000ooooooooool0C_ooool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo01Go
oooo00?o003oooooooooool0COooool00ol0003oooooooooo`0Sooooo`;o00001?ooool2o`0001Ko
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Dooooo`;o00004Oooool001cooooo
0_l0001?ooooo`;o003o5_ooool00ol0003oooooooooo`0Dooooo`;o003oCoooool00ol0003ooooo
ooooo`0Uooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`00
7?ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0
8Oooool01Ol0003ooooooooooooooooo000000?oooooc_l0000Aooooo`007?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02;ooooo0ol0003Sooooo`007?oooooBo`000?oooooo2ooo
ool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOoo
ool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOoo
ool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool0027ooooo0_l0
000Oooooo`?o00007?ooool3o`0000Cooooo0_l0000Iooooo`?o00000oooool3o`0001Wooooo1Ol0
0003ooooo`;o00006?ooool5o`0000;ooooo0ol0001;ooooo`;o00007oooool3o`0001cooooo0ol0
0004ooooo`;o00006Oooool3o`0000?ooooo0ol0000Hooooo`Go00000oooool2o`0001Sooooo1Ol0
0002ooooo`?o0000;Oooool0023ooooo00Co0000oooooooooooo00007Oooool01Ol0003ooooooooo
oooooooo000001cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Iooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Gooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00006?ooool01_l0003oooooooooool0003oooooo`0000?o
oooo00?o0000ooooooooool0Aoooool01?l0003oooooooooool0000Mooooo`05o`000?oooooooooo
ooooool000007?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Wooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool0000Hooooo`06o`000?ooooooooooo`000?oooooo00000ooo
ool00ol0003oooooooooo`0Zooooo`008?ooool01?l0003oooooooooool0000Qooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Iooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0001Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`17ooooo`04
o`000?ooooooooooo`00027ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0001Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00006Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo02[ooooo000Pooooo`04o`000?ooooooooooo`00027ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Wooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0Aoooool01?l0003oooooooooool0000Qooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool0000Iooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool06?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02[ooooo000Pooooo`04o`000?oooooo
ooooo`0001gooooo1?l0000Mooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
6Oooool01?l0003oooooooooooooool4o`0001Wooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0001Oooooo00Ko0000ooooooooooooooooo`000?ooool4o`0004[ooooo
00Co0000oooooooooooo00007Oooool4o`0001gooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000Iooooo`04o`000?ooooooooooooooo`Co00006?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00005oooool01_l0003ooooooooooooooooo0000oooo
o`Co0000;Oooool0023ooooo00Co0000oooooooooooo00007Oooool00ol0003oooooooooo`0Moooo
o`;o00001?ooool01?l0003oooooooooool0000Hooooo`;o00000oooool00ol0003oooooooooo`0J
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Gooooo`07o`00
0?ooooooooooooooool0003oooooo`00001=ooooo`04o`000?ooooooooooo`0001gooooo00?o0000
ooooooooool07Oooool2o`0000Cooooo00Co0000oooooooooooo00006?ooool2o`0000?ooooo00?o
0000ooooooooool06Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00005oooool01ol0003ooooooooooooooooo0000ooooool00000<?ooool0027ooooo0_l0000Noooo
o`Go00007?ooool00ol0003oooooooooo`03ooooo`;o00006_ooool01?l0003oooooooooooooool5
o`0001Wooooo0ol00004ooooo`;o00006Oooool3o`0000;ooooo1Ol0001:ooooo`;o00007_ooool5
o`0001cooooo00?o0000ooooooooool00oooool2o`0001[ooooo00Co0000oooooooooooooooo1Ol0
000Hooooo`?o00001?ooool2o`0001Wooooo0ol00002ooooo`Go0000;?ooool00?oooooonOooool0
0?oooooonOooool00?oooooonOooool00?oooooonOooool001gooooodOl0000Sooooo`?o00001?oo
ooo@o`00013ooooo000Fooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo023ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool03_ooool001Gooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`3=ooooo`03o`000?oooooooooo01[ooooo1Ol00005ooooo`05o`000?ooooooooooooooool00000
c_ooool00ol0003oooooooooo`0>ooooo`005Oooool01?l0003oooooooooool00004ooooo`;o0000
0oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00Coo`00oooooooooooo
oooo0_l0000Tooooo`;o00001?ooool3o`000<[ooooo0ol0000@ooooo`005Oooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool09?ooool01Ol0003o
oooooooooooooooo00000<kooooo00?o0000ooooooooool03_ooool001Gooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo023ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool0
01Gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03o`000?oooooo
oooo027ooooo0ol00004ooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool0
01Kooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool0:?ooool2o`00
0<cooooo0_l0000@ooooo`007Oooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`007Oooool2o`0000?ooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`04ool00?ooooooooooooooo`;o
0000:_ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000Mooooo`03o`00
0?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`3<ooooo`03o`00
0?oooooooooo00kooooo000Mooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool0:?oo
ool2o`000<cooooo0_l0000@ooooo`007Oooool00ol0003oooooooooo`02ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`007Oooool00ol0
003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`02ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0c?ooool00ol0
003oooooooooo`0>ooooo`007Oooool01?l0003oooooooooooooool3ool000Gooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool00_ooool3ool000Cooooo0ooo0004ooooo`?oo`001Oooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02oooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>oooo
o`007Oooool2o`0000;ooooo0ooo0005ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo
ool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo
ool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool00oooool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000Cooooo0ooo0004ooooo`?o
o`001?ooool3ool000Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool01?oo003oooooooooooooool2o`00
02[ooooo0_l0003<ooooo`;o00004?ooool001gooooo00Co0000oooooooooooooooo0ooo0005oooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00?ooooo0ooo0004ooooo`?oo`001?ooool3ool000?ooooo0ooo0004oooo
o`?oo`001?ooool3ool000Cooooo0ooo0004ooooo`?oo`001?ooool3ool000Gooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool00_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0<cooooo00?o0000oooo
ooooool03_ooool001gooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool3ool000Cooooo0ooo0004ooooo`?o
o`001?ooool3ool001Sooooo0ooo0004ooooo`?oo`001?ooool3ool000Cooooo0ooo0004ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`00
7Oooool00ol0003oooooooooo`07ooooo`?oo`001Oooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`?oo`00
1?ooool3ool000Cooooo0ooo000dooooo`?oo`001?ooool3ool000?ooooo0ooo0005ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00?ooooo0ooo0003ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
c?ooool00ol0003oooooooooo`0>ooooo`007Oooool00ol0003oooooooooo`07ooooo`?oo`001Ooo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`03ooooo`?oo`001?ooool3ool004;ooooo0ooo0003ooooo`?oo`001Ooo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`03ooooo`?oo`000oooool00ol0003oooooooooo`0Xooooo`;o0000c?oo
ool2o`00013ooooo000Mooooo`03o`000?oooooooooo00Oooooo0ooo0005ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00?ooooo0ooo001?ooooo`?oo`001Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`?oo`000oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool0
01gooooo0_l0000@ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`02ooooo`?oo`00GOooool3ool000Gooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Sooooo0_l0000Rooooo`Go00000oooool00ol0
003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000Mooooo`03o`000?oooooooooo00oo
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;o
oooo0ooo001Mooooo`?oo`001Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`007Oooool00ol0003o
ooooooooo`0?ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`02ooooo`?oo`00GOooool3ool000Gooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool06_ooool5o`0000?o
oooo00?o0000ooooooooool00oooool3o`000<[ooooo0ol0000@ooooo`007Oooool00ol0003ooooo
ooooo`0?ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`1Zooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`09ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`3<ooooo`03o`000?oooooooooo00kooooo000Dooooo`Go00001?ooool00ol0003ooooooooo
o`0?ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool3ool006[ooooo0ooo
0005ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool02Oooool00ol0003ooooooooo
o`0Pooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`3<ooooo`03o`00
0?oooooooooo00kooooo000Eooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
3oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo0ooo001Zooooo`?oo`00
1Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool0
8?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0c?ooool00ol0003o
ooooooooo`0>ooooo`005_ooool00ol0003oooooooooo`04ooooo`;o00004?ooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00?ooooo0ooo001Zooooo`?oo`001Oooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00Sooooo0_l0000Sooooo`?o00001?ooool2o`000<cooooo
0_l0000@ooooo`005oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00oooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`1hooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool02Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0<cooooo00?o
0000ooooooooool03_ooool001Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo00oooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`1hooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo0<cooooo00?o0000ooooooooool03_ooool001Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`1hooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool02Oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool001Gooooo0ol00005
ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool3ool007Sooooo0ooo0005
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool0:?ooool2o`000<cooooo0_l0000@
ooooo`007Oooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo0ooo001hoooo
o`?oo`001Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0c?ooool00ol0003oooooooooo`0>ooooo`007Oooool2o`00013ooooo00?oo`00oooooooo
ool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool00oooool3ool007Sooooo0ooo0005ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Sooooo0_l0000Zooooo`03
o`000?oooooooooo01cooooo0ooo002Iooooo`?oo`004Oooool00ol0003oooooooooo`0>ooooo`00
7Oooool00ol0003oooooooooo`0>ooooo`?oo`001Oooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool0Q_ooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool00oooool3ool000[ooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0Looooo`?oo`00VOooool3ool0017ooooo00?o0000ooooooooool0
3_ooool001gooooo00?o0000ooooooooool03_ooool3ool000Gooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo08Kooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo0ooo000:ooooo`03o`000?oo
oooooooo02Sooooo0_l0000Mooooo`?oo`00VOooool3ool0013ooooo0_l0000@ooooo`007Oooool0
0ol0003oooooooooo`0>ooooo`?oo`001Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool0Q_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool00oooool3ool000[ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Mooooo`03ool00?oooooooooo00?ooooo0ooo002Cooooo`03ool00?oooooo
oooo013ooooo00?o0000ooooooooool03_ooool001gooooo00?o0000ooooooooool05_ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0Q_ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool04?ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo01gooooo00?oo`00ooooooooool00oooool3ool0
09?ooooo00?oo`00ooooooooool04?ooool00ol0003oooooooooo`0>ooooo`007Oooool00ol0003o
ooooooooo`0Fooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`26ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003o
ooooooooo`0@ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool07Oooool00ooo003o
ooooooooo`03ooooo`?oo`00Toooool00ooo003oooooooooo`0@ooooo`03o`000?oooooooooo00ko
oooo000Mooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo08Kooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo013ooooo00?o0000ooooooooool0:?ooool2o`0001kooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`2Booooo`03ool00?oooooooooo00?ooooo
0ooo0009ooooo`;o00004?ooool001gooooo0_l0000Gooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`26ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`0?ooooo`;o0000:_ooool00ol0003ooooooooo
o`0Mooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool3ool008cooooo00?o
o`00ooooooooool00oooool3ool000[ooooo00?o0000ooooooooool03_ooool001gooooo00?o0000
ooooooooool05_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool0Q_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool04?ooool00ol0003oooooooooo`0Qooooo`?o00001?ooool00ol0003oooooooooo`0M
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool3ool008cooooo00?oo`00
ooooooooool00oooool3ool000[ooooo00?o0000ooooooooool03_ooool001gooooo00?o0000oooo
ooooool05_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool0Q_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool04?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool07Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo0ooo0004oooo
o`?oo`00QOooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Wooooo00?o0000oooo
ooooool03_ooool001gooooo00?o0000ooooooooool05_ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool0Q_ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool04?ooool00ol0003oooooooooo`0Jooooo`Go
00000oooool00ol0003oooooooooo`03ooooo`?o00007Oooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool3ool008Gooooo00?oo`00oooooooo
ool01?ooool00ooo003oooooooooo`07ooooo`?o00004?ooool001gooooo00?o0000ooooooooool0
5_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
Q_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
4?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
7Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
0oooool3ool008Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`09ooooo`03o`00
0?oooooooooo00kooooo000Mooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo08Kooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo013ooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01gooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_oo
ool3ool007oooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`09ooooo`03o`000?oo
oooooooo00kooooo000Mooooo`;o00005oooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool0Q_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool03oooool2o`0002?ooooo0_l00005ooooo`03o`000?oooooo
oooo01gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool00_ooool3ool007oooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo000Mooooo`03o`000?oooooooooo
01Kooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`?oo`00Q_ooool3ool0
00Gooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0@ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool00oooool2o`0001kooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_ooool3ool0
07oooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`08ooooo`;o00004?ooool001go
oooo00?o0000ooooooooool05_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?o
oooo0ooo0026ooooo`?oo`001Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo013o
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Mooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool00oooool3ool007Sooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`03ooooo`?oo`000oooool00ol0003oooooooooo`0>ooooo`005_ooool3o`0000Cooooo
00?o0000ooooooooool05_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo
0ooo0026ooooo`?oo`001Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo013ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Mooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool00oooool3ool007Sooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`03ooooo`?oo`000oooool00ol0003oooooooooo`0>ooooo`005oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`2Dooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool04?ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo01gooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`03ooooo`?oo`001?ooool3ool0077ooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`03ooooo`?oo`000oooool00ol0003oooooooooo`0>ooooo`005?ooool5o`0000Cooooo00?o0000
ooooooooool05_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo09Cooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`0@ooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool07Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool00oooool3ool0077ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool03_ooool001Cooooo00Co0000oooo
oooooooo00001Oooool2o`0001Oooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`2D
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool03oooool2o`0002[ooooo0_l0000N
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03
ooooo`?oo`00LOooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00Coo`00
oooooooooooooooo0_l0000@ooooo`005Oooool00ol0003oooooo`000005ooooo`03o`000?oooooo
oooo01Kooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`2Dooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool04?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo01gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool00oooool3ool006[ooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool03_ooool0
01Kooooo0_l00005ooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`2Dooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool04?ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo01gooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool3ool0
06[ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00;ooooo00?o0000ooooooooool03_ooool001Oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Fooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0U?ooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooooooo013ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`0Mooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00?ooooo0ooo0004ooooo`?oo`00Hoooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_ooool00ol0003o
ooooooooo`0>ooooo`007Oooool00ol0003oooooooooo`0Fooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool0U?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo013ooooo
00?o0000ooooooooool0:?ooool2o`0001kooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`03ooooo`?oo`00Hoooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo
00Coo`00oooooooooooooooo0_l0000@ooooo`007Oooool00ol0003oooooooooo`0Fooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool0U?ooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo013ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Mooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool00oooool3ool006?ooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool0
3_ooool001gooooo0_l0000Gooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0U?oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00oooooo0_l0000Zooooo`03o`000?oo
oooooooo01gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo00;ooooo0ooo001Mooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo000Mooooo`03o`000?oooooo
oooo01Kooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`2Dooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool04?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo01gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00;ooooo0ooo001Mooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo000Mooooo`03o`000?oooooooooo
01Kooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`2Dooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool04?ooool00ol0003oooooooooo`0Xooooo`;o00007_ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_ooool3ool0
00Cooooo0ooo001Fooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool01?oo
003oooooooooooooool2o`00013ooooo000Mooooo`03o`000?oooooooooo01Kooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`2Dooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool04?ooool00ol0003oooooooooo`0Rooooo`;o00001?ooool00ol0003oooooooooo`0Moooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00?ooooo0ooo001Fooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo000Mooooo`03
o`000?oooooooooo01Kooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`2Dooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool04?ooool00ol0003oooooooooo`0Qooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool07Oooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03oooo
o`?oo`00E_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool00_ooool00ol0003oooooooooo`0>ooooo`007Oooool00ol0003oooooooooo`0Fooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool0U?ooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo013ooooo00?o0000ooooooooool08Oooool01?l0003oooooooooool00003oooo
o`04o`000?ooooooooooooooo`?oo`006Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00?ooooo0ooo001?ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo000Mooooo`;o00005oooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo09Cooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`0?ooooo`;o00008oooool01?l0003oooooooooool00003ooooo`?o000000Cooooo
ool00?oo003oo`001Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo0ooo
0005ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00ol0000@ooooo`007Oooool0
0ol0003oooooooooo`0Fooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0U?ooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo013ooooo00?o0000ooooooooool08Oooool0
1?l0003oooooooooool00003ooooo`04o`000?ooooooooooooooo`?oo`001Oooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0COooool3ool000Cooooo
0ooo0004ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo01Oooooo00?o0000ooooooooool03_ooool001gooooo00?o
0000ooooooooool05_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo09Cooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`0@ooooo`03o`000?oooooooooo027ooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`1Dooooo`?oo`001?ooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00kooooo000Mooooo`03o`000?oooooooooo01Kooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`2Dooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool04?ooool00ol0003oooooooooo`0Rooooo`;o00001?ooool00ol0003ooooooooo
o`09ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`1Dooooo`?oo`001?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`0Gooooo`03o`000?oooooooooo00kooooo000M
ooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`2D
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool04?ooool00ol0003oooooooooo`0X
ooooo`;o00002_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool0F_ooool3ool000Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo01Kooooo0_l0000@ooooo`007Oooool00ol0003oooooooooo`0Foooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0U?ooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo013ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`09oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`1Joooo
o`?oo`001Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool05oooool00ol0003oooooooooo`0>ooooo`007Oooool2o`0001Oooooo00?oo`00oooooooo
ool01?ooool00ooo003oooooooooo`2Dooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo
ool03oooool2o`0002[ooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool0F_ooool3ool000Cooooo0ooo0005ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool05oooool00ol0003oooooooooo`0>ooooo`00
7Oooool00ol0003oooooooooo`0Fooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
U?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo013ooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`1Qooooo`?oo`001Oooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo01Oooooo00?o0000ooooooooool03_ooool001gooooo00?o0000ooooooooool05_oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo09Cooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`0@ooooo`03o`000?oooooooooo02Sooooo0_l0000:ooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`1Qooooo`?oo`001Ooo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo01Kooooo0_l0000@ooooo`005Oooool3
o`0000Gooooo00?o0000ooooooooool05_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo09Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0@ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool0J?ooool3ool000Gooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool05oooool0
0ol0003oooooooooo`0>ooooo`005?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool05_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo09Cooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`0@ooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool02Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool0J?ooool3ool000Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool05oooool00ol0003oooooooooo`0>
ooooo`005?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool05_ooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo09Cooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`0@ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02Oooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0J?ooool3
ool000Cooooo0ooo0005ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`0Gooooo`03o`000?oooooooooo00kooooo000Dooooo`Co00001Oooool2o`00
01Oooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`2Dooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool03oooool2o`0002[ooooo0_l0000:ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`1_ooooo`?oo`001Oooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool05_ooool2o`00
013ooooo000Dooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo09Cooooo00?oo`00ooooooooool00oooool00ooo003o
ooooooooo`0@ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02?ooool3ool000Go
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`1_ooooo`?oo`001Oooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool05oooool00ol0003o
ooooooooo`0>ooooo`005Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`2Dooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool04?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Sooooo
0ooo0005ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0M_ooool3ool000Cooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Gooooo`03o`000?oooooooooo00kooooo
000Fooooo`;o00001Oooool00ol0003oooooooooo`0Fooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool0U?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo013ooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`08ooooo`?oo`001Oooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo07Kooooo0ooo0004ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool05oooool00ol0003oooooooooo`0>ooooo`007Oooool00ol0003oooooooooo`0F
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0U?ooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo013ooooo00?o0000ooooooooool0:?ooool2o`00017ooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`1fooooo`?oo`000oooool3ool000Gooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool05_ooool2o`00013ooooo000Mooooo`03o`000?oooooooooo01Kooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`2Dooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool04?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo013ooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`1looooo`?oo`001Oooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Goooo
o`03o`000?oooooooooo00kooooo000Mooooo`;o00005oooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo09Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0?ooooo`;o
00008oooool3o`0000Cooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo07cooooo0ooo0005ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo01Oooooo00?o0000oooooooo
ool03_ooool001gooooo00?o0000ooooooooool05_ooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo09Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0@ooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool0Poooool3ool000Gooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo01Oooooo00?o0000ooooooooool0
3_ooool001gooooo00?o0000ooooooooool05_ooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo09Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0@ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool00oooool3o`00013ooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`23ooooo`?oo`001Oooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool05Oooool3o`00013ooooo000Mooooo`03o`000?oooooo
oooo01Kooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`2Dooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool04?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo08?ooooo0ooo0005ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`0Gooooo`03o`000?oooooooooo00kooooo000Mooooo`03o`000?oooooooooo
01Kooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`2Dooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool04?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
08[ooooo0ooo0005ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool05oooool00ol0
003oooooooooo`0>ooooo`007Oooool00ol0003oooooooooo`0Fooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool0U?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo013o
oooo00?o0000ooooooooool08Oooool2o`0000Gooooo00?o0000ooooooooool03oooool3ool000Go
oooo00?oo`00ooooooooool0R_ooool3ool000Gooooo00?oo`00ooooooooool00oooool00ooo003o
ooooooooo`0Gooooo`03o`000?oooooooooo00kooooo000Mooooo`;o00005oooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo09Cooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`0?ooooo`;o00009?ooool00ol0003oooooooooo`03ooooo`;o00004?ooool3ool000Gooooo
00?oo`00ooooooooool0R_ooool3ool000Gooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`0Fooooo`;o00004?ooool001gooooo00?o0000ooooooooool05_ooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo09Cooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`0@ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03oooool3ool000Gooooo00?o
o`00ooooooooool0TOooool3ool000Cooooo00?oo`00ooooooooool05oooool00ol0003ooooooooo
o`0>ooooo`007Oooool00ol0003oooooooooo`0Fooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool0U?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo013ooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo097ooooo0ooo0004
ooooo`03ool00?oooooooooo01Oooooo00?o0000ooooooooool03_ooool001gooooo00?o0000oooo
ooooool05_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo09Cooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`0@ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool05oooool00ooo003oooooooooo`2Aooooo`?oo`001?ooool00ooo003oooooooooo`0Goooo
o`03o`000?oooooooooo00kooooo000Mooooo`03o`000?oooooooooo01Kooooo00?oo`00oooooooo
ool01?ooool00ooo003oooooooooo`2Dooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo
ool04?ooool00ol0003oooooooooo`0Xooooo`;o00005oooool3ool009Wooooo00?oo`00oooooooo
ool05_ooool2o`00013ooooo000Mooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`2Dooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
4?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01Kooooo0ooo002Hooooo`?oo`00
6?ooool00ol0003oooooooooo`0>ooooo`007Oooool2o`0001Oooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`2Dooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool03ooo
ool2o`0002[ooooo00?o0000ooooooooool05_ooool3ool009Sooooo0ooo000Hooooo`03o`000?oo
oooooooo00kooooo000Mooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`2Dooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool04?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0;7ooooo0ooo000Hooooo`03o`000?oooooo
oooo00kooooo000Mooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`2Dooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool04?ooool00ol0
003oooooooooo`0Xooooo`;o0000c?ooool2o`00013ooooo000Mooooo`03o`000?oooooooooo01Ko
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`2Dooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool04?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0<co
oooo00?o0000ooooooooool03_ooool001Gooooo0ol00005ooooo`03o`000?oooooooooo01Kooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`2Dooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool04?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0<cooooo
00?o0000ooooooooool03_ooool001Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo01Kooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`2Dooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool04?ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo0<cooooo00?o0000ooooooooool03_ooool001Cooooo00Go0000oooooooooooooooo
o`000004ooooo`;o00005oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo09Cooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`0?ooooo`;o0000:_ooool2o`000<cooooo
0_l0000@ooooo`005Oooool3o`0000Gooooo00?o0000ooooooooool05_ooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo09Cooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`0@ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0c?ooool00ol0003ooooooooo
o`0>ooooo`005?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool05_oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo09Cooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`0@ooooo`03o`000?oooooooooo023ooooo1Ol00003ooooo`03o`000?oo
oooooooo0<cooooo00?o0000ooooooooool03_ooool001Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`2Dooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool04?ooool00ol0003ooooooooo
o`0Qooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0c?ooool00ol0003ooooo
ooooo`0>ooooo`005Oooool3o`0000Gooooo00?o0000ooooooooool05_ooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo09Cooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`0@ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00oooool3o`000<[ooooo0ol0
000@ooooo`007Oooool00ol0003oooooooooo`0Fooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool0U?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo013ooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0<cooooo00?o0000
ooooooooool03_ooool001gooooo0_l0000Gooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool0U?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00oooooo0_l0000Roooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooo
oooo00kooooo000Mooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`2Dooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool04?ooool00ol0
003oooooooooo`0Pooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`3<
ooooo`03o`000?oooooooooo00kooooo000Mooooo`03o`000?oooooooooo01Kooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`2Dooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool04?ooool00ol0003oooooooooo`0Qooooo`?o00001?ooool2o`000<cooooo0_l0000@oooo
o`007Oooool00ol0003oooooooooo`0Fooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool0U?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo013ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000Mooooo`03o`00
0?oooooooooo01Kooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`2Dooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool04?ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo0<cooooo00?o0000ooooooooool03_ooool001gooooo00?o0000ooooooooool05Ooo
ool3ool000Gooooo00?oo`00ooooooooool0U?ooool00ooo003oooooooooo`02ooooo`?oo`004Ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_oo
ool001gooooo0_l0000Fooooo`?oo`001Oooool00ooo003oooooooooo`2Dooooo`03ool00?oooooo
oooo00;ooooo0ooo000@ooooo`;o0000:_ooool2o`000<cooooo0_l0000@ooooo`007Oooool00ol0
003oooooooooo`0Eooooo`?oo`001Oooool00ooo003oooooooooo`2Dooooo`03ool00?oooooooooo
00;ooooo0ooo000Aooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0c?ooool00ol0
003oooooooooo`0>ooooo`007Oooool00ol0003oooooooooo`0Mooooo`03ool00?oooooooooo09Co
oooo00?oo`00ooooooooool05_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0<co
oooo00?o0000ooooooooool03_ooool001gooooo00?o0000ooooooooool07Oooool00ooo003ooooo
ooooo`2Dooooo`03ool00?oooooooooo01Kooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`3<ooooo`03o`000?oooooooooo00kooooo000Mooooo`03o`000?oooooooooo01gooooo00?o
o`00ooooooooool0U?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`007Oooool00ol0003oooooooooo`0M
ooooo`03ool00?oooooooooo09Cooooo00?oo`00ooooooooool05_ooool00ol0003oooooooooo`0X
ooooo`;o0000c?ooool2o`00013ooooo000Mooooo`03o`000?oooooooooo01gooooo00?oo`00oooo
ooooool0U?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0c?ooool00ol0003oooooooooo`0>ooooo`007Oooool2o`0001kooooo00?oo`00oooooooo
ool0U?ooool00ooo003oooooooooo`0Eooooo`;o0000:_ooool00ol0003oooooooooo`3<ooooo`03
o`000?oooooooooo00kooooo000Mooooo`03o`000?oooooooooo01gooooo00?oo`00ooooooooool0
U?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
c?ooool00ol0003oooooooooo`0>ooooo`007Oooool00ol0003oooooooooo`0Mooooo`03ool00?oo
oooooooo09Cooooo00?oo`00ooooooooool05_ooool00ol0003oooooooooo`0Xooooo`;o0000c?oo
ool2o`00013ooooo000?ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool07Oooool0
0ooo003oooooooooo`2Dooooo`03ool00?oooooooooo01Kooooo00?o0000ooooooooool08Oooool3
o`0000Cooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`004?ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool07Oooool0
0ooo003oooooooooo`2Dooooo`03ool00?oooooooooo01Kooooo00?o0000ooooooooool08?ooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0c?ooool00ol0003ooooooooo
o`0>ooooo`004?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool07Oooool00ooo003oooooooooo`2Dooooo`03ool00?oooooooooo01Kooooo00?o
0000ooooooooool09?ooool01Ol0003ooooooooooooooooo00000<kooooo00?o0000ooooooooool0
3_ooool0013ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`;o0000
7Oooool3ool009Cooooo0ooo000Fooooo`;o00009?ooool2o`0000Cooooo0ol0003:ooooo`?o0000
4?ooool0013ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo01cooooo0ooo002Dooooo`?oo`005oooool00ol0003oooooooooo`0Tooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0>ooooo`003oooool2o`0000Cooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oo
oooo0ooo0005ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool00oooool3ool001Oo
oooo00?o0000ooooooooool08?ooool01Ol0003ooooooooooooooooo000000?oooood?l0000@oooo
o`004?ooool00ol0003oooooooooo`03ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo027ooooo0ol0003Tooooo`007OoooooAo`000?oooooo2oooool00?oooooonOoo
ool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOoo
ool00?oooooonOooool00001\
\>"],
  ImageRangeCache->{{{0, 503}, {310.438, 0}} -> {-0.0514703, -0.0309082, \
0.0041808, 0.0041808}, {{12.3125, 240.062}, {303, 162.25}} -> {-6.7051, \
-2.7039, 0.0502515, 0.122212}, {{262.875, 490.688}, {303, 162.25}} -> \
{-19.6896, -4.02429, 0.0512752, 0.0488862}, {{12.3125, 240.062}, {148.125, \
7.375}} -> {-4.99399, -14.5574, 0.146102, 0.0822519}, {{262.875, 490.688}, \
{148.125, 7.375}} -> {-42.1612, -11.7081, 0.147552, 0.0492634}}]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["DTFT vs. DFT: Example #4: (1+1/6)Hz cosine wave (higher fs)", "Section"],

Cell[CellGroupData[{

Cell["Sampled sequence", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(x[t_] := Cos[\ 2  \[Pi]\ \((1 + 1/6)\) t];\)\), "\n", 
    \(\(xd = \ sampler[x, fs = 20, {0, 3}];\)\), "\[IndentingNewLine]", 
    \(\(If[OddQ[Length[xd]], \ xd\  = \ Drop[xd, \(-1\)]];\)\), "\n", 
    \(\(gx\  = \ 
        DiscreteListPlot2[xd, \ Blue, \ Frame \[Rule] True, 
          Axes \[Rule] {True, False}, \ ImageSize \[Rule] 504, \ 
          AspectRatio \[Rule] 1/3];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
%%ImageSize: 504 168 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0161421 0.166558 0.158839 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18523 -0.0125 -6 -9 ]
[.18523 -0.0125 6 0 ]
[.34665 -0.0125 -6 -9 ]
[.34665 -0.0125 6 0 ]
[.50807 -0.0125 -6 -9 ]
[.50807 -0.0125 6 0 ]
[.66949 -0.0125 -6 -9 ]
[.66949 -0.0125 6 0 ]
[.83091 -0.0125 -6 -9 ]
[.83091 -0.0125 6 0 ]
[.99233 -0.0125 -6 -9 ]
[.99233 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00772 -12 -4.5 ]
[-0.0125 .00772 0 4.5 ]
[-0.0125 .08714 -24 -4.5 ]
[-0.0125 .08714 0 4.5 ]
[-0.0125 .16656 -6 -4.5 ]
[-0.0125 .16656 0 4.5 ]
[-0.0125 .24598 -18 -4.5 ]
[-0.0125 .24598 0 4.5 ]
[-0.0125 .3254 -6 -4.5 ]
[-0.0125 .3254 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18523 0 m
.18523 .00625 L
s
[(10)] .18523 -0.0125 0 1 Mshowa
.34665 0 m
.34665 .00625 L
s
[(20)] .34665 -0.0125 0 1 Mshowa
.50807 0 m
.50807 .00625 L
s
[(30)] .50807 -0.0125 0 1 Mshowa
.66949 0 m
.66949 .00625 L
s
[(40)] .66949 -0.0125 0 1 Mshowa
.83091 0 m
.83091 .00625 L
s
[(50)] .83091 -0.0125 0 1 Mshowa
.99233 0 m
.99233 .00625 L
s
[(60)] .99233 -0.0125 0 1 Mshowa
.125 Mabswid
.05609 0 m
.05609 .00375 L
s
.08838 0 m
.08838 .00375 L
s
.12066 0 m
.12066 .00375 L
s
.15295 0 m
.15295 .00375 L
s
.21751 0 m
.21751 .00375 L
s
.2498 0 m
.2498 .00375 L
s
.28208 0 m
.28208 .00375 L
s
.31437 0 m
.31437 .00375 L
s
.37893 0 m
.37893 .00375 L
s
.41122 0 m
.41122 .00375 L
s
.4435 0 m
.4435 .00375 L
s
.47579 0 m
.47579 .00375 L
s
.54036 0 m
.54036 .00375 L
s
.57264 0 m
.57264 .00375 L
s
.60492 0 m
.60492 .00375 L
s
.63721 0 m
.63721 .00375 L
s
.70178 0 m
.70178 .00375 L
s
.73406 0 m
.73406 .00375 L
s
.76634 0 m
.76634 .00375 L
s
.79863 0 m
.79863 .00375 L
s
.8632 0 m
.8632 .00375 L
s
.89548 0 m
.89548 .00375 L
s
.92776 0 m
.92776 .00375 L
s
.96005 0 m
.96005 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00772 m
.00625 .00772 L
s
[(-1)] -0.0125 .00772 1 0 Mshowa
0 .08714 m
.00625 .08714 L
s
[(-0.5)] -0.0125 .08714 1 0 Mshowa
0 .16656 m
.00625 .16656 L
s
[(0)] -0.0125 .16656 1 0 Mshowa
0 .24598 m
.00625 .24598 L
s
[(0.5)] -0.0125 .24598 1 0 Mshowa
0 .3254 m
.00625 .3254 L
s
[(1)] -0.0125 .3254 1 0 Mshowa
.125 Mabswid
0 .0236 m
.00375 .0236 L
s
0 .03949 m
.00375 .03949 L
s
0 .05537 m
.00375 .05537 L
s
0 .07125 m
.00375 .07125 L
s
0 .10302 m
.00375 .10302 L
s
0 .11891 m
.00375 .11891 L
s
0 .13479 m
.00375 .13479 L
s
0 .15067 m
.00375 .15067 L
s
0 .18244 m
.00375 .18244 L
s
0 .19833 m
.00375 .19833 L
s
0 .21421 m
.00375 .21421 L
s
0 .23009 m
.00375 .23009 L
s
0 .26186 m
.00375 .26186 L
s
0 .27775 m
.00375 .27775 L
s
0 .29363 m
.00375 .29363 L
s
0 .30951 m
.00375 .30951 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.02381 .32708 m
.02381 .33333 L
s
.18523 .32708 m
.18523 .33333 L
s
.34665 .32708 m
.34665 .33333 L
s
.50807 .32708 m
.50807 .33333 L
s
.66949 .32708 m
.66949 .33333 L
s
.83091 .32708 m
.83091 .33333 L
s
.99233 .32708 m
.99233 .33333 L
s
.125 Mabswid
.05609 .32958 m
.05609 .33333 L
s
.08838 .32958 m
.08838 .33333 L
s
.12066 .32958 m
.12066 .33333 L
s
.15295 .32958 m
.15295 .33333 L
s
.21751 .32958 m
.21751 .33333 L
s
.2498 .32958 m
.2498 .33333 L
s
.28208 .32958 m
.28208 .33333 L
s
.31437 .32958 m
.31437 .33333 L
s
.37893 .32958 m
.37893 .33333 L
s
.41122 .32958 m
.41122 .33333 L
s
.4435 .32958 m
.4435 .33333 L
s
.47579 .32958 m
.47579 .33333 L
s
.54036 .32958 m
.54036 .33333 L
s
.57264 .32958 m
.57264 .33333 L
s
.60492 .32958 m
.60492 .33333 L
s
.63721 .32958 m
.63721 .33333 L
s
.70178 .32958 m
.70178 .33333 L
s
.73406 .32958 m
.73406 .33333 L
s
.76634 .32958 m
.76634 .33333 L
s
.79863 .32958 m
.79863 .33333 L
s
.8632 .32958 m
.8632 .33333 L
s
.89548 .32958 m
.89548 .33333 L
s
.92776 .32958 m
.92776 .33333 L
s
.96005 .32958 m
.96005 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .00772 m
1 .00772 L
s
.99375 .08714 m
1 .08714 L
s
.99375 .16656 m
1 .16656 L
s
.99375 .24598 m
1 .24598 L
s
.99375 .3254 m
1 .3254 L
s
.125 Mabswid
.99625 .0236 m
1 .0236 L
s
.99625 .03949 m
1 .03949 L
s
.99625 .05537 m
1 .05537 L
s
.99625 .07125 m
1 .07125 L
s
.99625 .10302 m
1 .10302 L
s
.99625 .11891 m
1 .11891 L
s
.99625 .13479 m
1 .13479 L
s
.99625 .15067 m
1 .15067 L
s
.99625 .18244 m
1 .18244 L
s
.99625 .19833 m
1 .19833 L
s
.99625 .21421 m
1 .21421 L
s
.99625 .23009 m
1 .23009 L
s
.99625 .26186 m
1 .26186 L
s
.99625 .27775 m
1 .27775 L
s
.99625 .29363 m
1 .29363 L
s
.99625 .30951 m
1 .30951 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
0 .16656 m
1 .16656 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .16656 m
.02381 .3254 L
s
.03995 .16656 m
.03995 .31485 L
s
.05609 .16656 m
.05609 .2846 L
s
.07224 .16656 m
.07224 .23867 L
s
.08838 .16656 m
.08838 .18316 L
s
.10452 .16656 m
.10452 .12545 L
s
.12066 .16656 m
.12066 .07319 L
s
.1368 .16656 m
.1368 .03334 L
s
.15295 .16656 m
.15295 .01119 L
s
.16909 .16656 m
.16909 .00967 L
s
.18523 .16656 m
.18523 .029 L
s
.20137 .16656 m
.20137 .0666 L
s
.21751 .16656 m
.21751 .11747 L
s
.23366 .16656 m
.23366 .17487 L
s
.2498 .16656 m
.2498 .23116 L
s
.26594 .16656 m
.26594 .27887 L
s
.28208 .16656 m
.28208 .31166 L
s
.29822 .16656 m
.29822 .32518 L
s
.31437 .16656 m
.31437 .31762 L
s
.33051 .16656 m
.33051 .29 L
s
.34665 .16656 m
.34665 .24598 L
s
.36279 .16656 m
.36279 .19141 L
s
.37893 .16656 m
.37893 .13353 L
s
.39508 .16656 m
.39508 .08005 L
s
.41122 .16656 m
.41122 .03805 L
s
.42736 .16656 m
.42736 .01313 L
s
.4435 .16656 m
.4435 .00859 L
s
.45964 .16656 m
.45964 .02503 L
s
.47579 .16656 m
.47579 .06027 L
s
.49193 .16656 m
.49193 .10964 L
s
.50807 .16656 m
.50807 .16656 L
s
.52421 .16656 m
.52421 .22348 L
s
.54036 .16656 m
.54036 .27284 L
s
.5565 .16656 m
.5565 .30808 L
s
.57264 .16656 m
.57264 .32453 L
s
.58878 .16656 m
.58878 .31998 L
s
.60492 .16656 m
.60492 .29506 L
s
.62107 .16656 m
.62107 .25307 L
s
.63721 .16656 m
.63721 .19958 L
s
.65335 .16656 m
.65335 .14171 L
s
.66949 .16656 m
.66949 .08714 L
s
.68563 .16656 m
.68563 .04312 L
s
.70178 .16656 m
.70178 .01549 L
s
.71792 .16656 m
.71792 .00794 L
s
.73406 .16656 m
.73406 .02145 L
s
.7502 .16656 m
.7502 .05424 L
s
.76634 .16656 m
.76634 .10195 L
s
.78249 .16656 m
.78249 .15824 L
s
.79863 .16656 m
.79863 .21564 L
s
.81477 .16656 m
.81477 .26652 L
s
.83091 .16656 m
.83091 .30412 L
s
.84705 .16656 m
.84705 .32344 L
s
.8632 .16656 m
.8632 .32193 L
s
.87934 .16656 m
.87934 .29977 L
s
.89548 .16656 m
.89548 .25992 L
s
.91162 .16656 m
.91162 .20767 L
s
.92776 .16656 m
.92776 .14995 L
s
.94391 .16656 m
.94391 .09445 L
s
.96005 .16656 m
.96005 .04852 L
s
.97619 .16656 m
.97619 .01827 L
s
.005 w
.02381 .3254 Mdot
.03995 .31485 Mdot
.05609 .2846 Mdot
.07224 .23867 Mdot
.08838 .18316 Mdot
.10452 .12545 Mdot
.12066 .07319 Mdot
.1368 .03334 Mdot
.15295 .01119 Mdot
.16909 .00967 Mdot
.18523 .029 Mdot
.20137 .0666 Mdot
.21751 .11747 Mdot
.23366 .17487 Mdot
.2498 .23116 Mdot
.26594 .27887 Mdot
.28208 .31166 Mdot
.29822 .32518 Mdot
.31437 .31762 Mdot
.33051 .29 Mdot
.34665 .24598 Mdot
.36279 .19141 Mdot
.37893 .13353 Mdot
.39508 .08005 Mdot
.41122 .03805 Mdot
.42736 .01313 Mdot
.4435 .00859 Mdot
.45964 .02503 Mdot
.47579 .06027 Mdot
.49193 .10964 Mdot
.50807 .16656 Mdot
.52421 .22348 Mdot
.54036 .27284 Mdot
.5565 .30808 Mdot
.57264 .32453 Mdot
.58878 .31998 Mdot
.60492 .29506 Mdot
.62107 .25307 Mdot
.63721 .19958 Mdot
.65335 .14171 Mdot
.66949 .08714 Mdot
.68563 .04312 Mdot
.70178 .01549 Mdot
.71792 .00794 Mdot
.73406 .02145 Mdot
.7502 .05424 Mdot
.76634 .10195 Mdot
.78249 .15824 Mdot
.79863 .21564 Mdot
.81477 .26652 Mdot
.83091 .30412 Mdot
.84705 .32344 Mdot
.8632 .32193 Mdot
.87934 .29977 Mdot
.89548 .25992 Mdot
.91162 .20767 Mdot
.92776 .14995 Mdot
.94391 .09445 Mdot
.96005 .04852 Mdot
.97619 .01827 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 168},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000Z2000`400?l00000o`00003ooooooooi
ooooo`00;oooool2o`0004Cooooo0ol00004ooooo`;o0000?oooool5o`0000?ooooo0_l00010oooo
o`?o00001?ooool2o`0004;ooooo0ol00003ooooo`;o0000@?ooool3o`0000Cooooo0_l00010oooo
o`?o00001?ooool2o`0000cooooo000^ooooo`04o`000?ooooooooooo`0004Cooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool0000oooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo0000?_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo0000@_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0??ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000?_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00002oooool002kooooo00Co0000oooooooo
oooo0000A?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00043ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00012ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool0?Oooool5o`0000;ooooo00Co0000oooooooooooo0000@_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo03cooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000_ooooo000^ooooo`04o`000?ooooooooooo`0004Cooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00011ooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`0nooooo`;o00000oooool01?l0003oooooooooool0000ooooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo0000@_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo03cooooo1?l00003ooooo`04o`000?ooooooooooo`0000_o
oooo000^ooooo`04o`000?ooooooooooo`0004Cooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000nooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0012ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
o`000003ooooo`04o`000?ooooooooooo`0003kooooo1?l00003ooooo`04o`000?ooooooooooo`00
03kooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0000;ooooo`00;_ooool01?l0
003oooooooooool00013ooooo`;o00001?ooool01?l0003oooooooooool0000nooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool0000nooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00011ooooo`;o00000oooool01?l0003oooooooooool0
000nooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000?oooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`0000_ooooo000_ooooo`;o0000AOooool00ol0003ooooo
ooooo`03ooooo`;o0000@?ooool3o`0000Cooooo0_l00010ooooo`?o00001?ooool2o`0004?ooooo
00?o0000ooooooooool00_ooool2o`0003oooooo1Ol00003ooooo`;o0000@Oooool2o`0000Cooooo
0_l0000<ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00
oooooooiooooo`00oooooooiooooo`00oooooooiooooo`009Oooooooo`000<Wo00002oooool001_o
oooo0ol00007ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000;oooo
o`007?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`005?ooool5o`0000?ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0A_ooool00ol0003o
ooooooooo`16ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04_ooool2o`00oc;o
oooo00?o0000ooooooooool0A_ooool01Ol0003ooooooooooooooooo000000_ooooo000Looooo`03
o`000?oooooooooo00Kooooo1?l00019ooooo`;o003oN_ooool2o`00og_ooooo0_l00?mlooooo`Co
00002oooool001cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`12ooooo`;o003o
1_ooool2o`00og[ooooo0_l00?mlooooo`03o`00oooooooooooo07gooooo00?o0000ooooooooool0
2Oooool001_ooooo0_l00008ooooo`03o`000?oooooooooo04;ooooo0_l00?l6ooooo`03o`00oooo
oooooooo07;ooooo0_l00?l6ooooo`03o`00oooooooooooo07[ooooo00?o003oooooooooool0OOoo
ool00ol0003oooooooooo`09ooooo`007?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo04?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1booooo`;o003o1_ooool0
0ol00?ooooooooooo`1booooo`;o003o1_ooool00ol00?ooooooooooo`1mooooo`03o`000?oooooo
oooo00Wooooo000Uooooo`03o`000?oooooooooo04?ooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`1cooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0L_ooool2o`00
o`Kooooo00?o003oooooooooool0LOooool2o`00o`[ooooo00?o0000ooooooooool02Oooool002Go
oooo00?o0000ooooooooool0@oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo07?o
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1booooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool0LOooool2o`00o`[ooooo00?o0000ooooooooool02Oooool002Gooooo
00?o0000ooooooooool0@oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo07?ooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`1booooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool00oooool2o`00ofgooooo00?o003oooooooooool02?ooool00ol0003ooooo
ooooo`09ooooo`009Oooool3o`0004?ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`1cooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool2o`00ofcooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`03ooooo`;o003oKOooool00ol00?oooooooooo
o`06ooooo`?o00002oooool002Gooooo00?o0000ooooooooool0@oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo07?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04
ooooo`;o003oK?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool0Joooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Wooooo000Uoooo
o`03o`000?oooooooooo04?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04oooo
o`;o003oKOooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool0Joooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool0Joooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03
o`000?oooooooooo04?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`;o
003oKOooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool0Joooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool0Joooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`00
0?oooooooooo03_ooooo0_l00?l6ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`1[ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`1[ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`1[ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool0
2Oooool002Gooooo00?o0000ooooooooool0>oooool2o`00o`Kooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo06_ooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo06_ooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo06_ooooo00?o003oooooooooool02?oo
ool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`0looooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo06?ooooo0_l00?l6ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`1[ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`1[ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02Oooool0
02Gooooo0ol0000looooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo06?ooooo0_l00?l6ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1[ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1[ooooo`03o`00oooooooooooo
00Kooooo0ol0000;ooooo`009Oooool00ol0003oooooooooo`0looooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo06?o
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool0Hoooool2o`00o`Kooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo06_ooooo00?o003oooooooooool02?ooool00ol0003o
ooooooooo`09ooooo`009Oooool00ol0003oooooooooo`0looooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo06?ooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool0Hoooool2o`00o`Kooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo06_ooooo00?o003oooooooooool02?ooool00ol0003ooooo
ooooo`09ooooo`009Oooool00ol0003oooooooooo`0looooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo06?ooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool0I?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`1[ooooo`03o`00oooooooooooo00Sooooo00?o
0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool0??ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`1S
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo06Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0Hoooool2o`00o`Kooooo00?o003o
ooooooooool02?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`0loooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo06?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool0I?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Soooo
o`;o003o1_ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03
o`000?oooooooooo03cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool0Hoooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Tooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Cooooo0_l00?mNooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool02?ooool00ol0003oooooooooo`09ooooo`009Oooool3o`0003cooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
Hoooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`1Tooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo0_l00?mNooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool01_ooool3o`0000_ooooo000Uooooo`03o`000?oo
oooooooo03cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool0Hoooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Tooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool0GOooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Sooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool0??ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`1Sooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo0_l00?mNooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool0GOooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Sooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool0??ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`1Sooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo0_l00?mNooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool0GOooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Sooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool0??ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`1Sooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0G?ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo05gooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`08ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo03cooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool00oooool2o`00oekooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`1Looooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0GOooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02Oooool002Gooooo00?o
0000ooooooooool0??ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`03ooooo`;o003oG_ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo05cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`1Mooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02?ooool00ol0003ooooooooo
o`09ooooo`009Oooool00ol0003oooooooooo`0looooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool0G?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo05cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`1Mooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool02?ooool00ol0003oooooooooo`09ooooo`009Oooool3o`0003Cooooo0_l00?l6oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool0G?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo05cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Moooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01_ooool3o`0000_ooooo000Uooooo`03
o`000?oooooooooo03Cooooo0_l00?l6ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool0G?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo05cooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`1Mooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool02?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`0dooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Looooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool0G?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo05gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo03Cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo05Cooooo0_l00?l6ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool0G?ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo05gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`000?oo
oooooooo00Wooooo000@ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001oooool0
0ol0003oooooooooo`0dooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`1Dooooo`;o003o1_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo05cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Mooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`09ooooo`003oooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`0dooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`1Eooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`1Looooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0GOooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02Oooool000Sooooo1Ol00002
ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0dooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`1Eooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`1Dooooo`;o003o1_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo05gooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Wooooo000?
ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool01?ooool4o`0003?ooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo05Gooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo05Cooooo0_l0
0?l6ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0GOooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Gooooo1?l0000;ooooo`003oooool01?l0003oooooooooool0
0007ooooo`Co00001oooool00ol0003oooooooooo`0dooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`1Mooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool02?ooool00ol0003oooooooooo`09ooooo`003oooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0=?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0EOooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0EOooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0GOooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02Oooool0013ooooo0_l00008
ooooo`Go00001_ooool00ol0003oooooooooo`0dooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`1Eooooo`;o003o1_ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000oooo
ooooool0=?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool0EOooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool0EOooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool0EOooool2o`00o`Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08oooo
o`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo03Cooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo05Gooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo05Gooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo05Gooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o0000oooooooo
ool02Oooool002Gooooo00?o0000ooooooooool0=?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool01?ooool2o`00odoooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool0
2Oooool002Gooooo0ol0000dooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`04ooooo`;o003oCoooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01_ooool3o`0000_ooooo000Uooooo`03o`000?oooooo
oooo03Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo05Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo05Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool0COooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0
003oooooooooo`0dooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`1Eooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`1Eooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo04gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02Oooool002Go
oooo00?o0000ooooooooool0=?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool00oooool2o`00oe3ooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0COooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02?ooool00ol0003o
ooooooooo`09ooooo`009Oooool00ol0003oooooooooo`0dooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`03ooooo`;o003oD?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`1=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`08ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo03Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo05Gooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool0C_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`1=ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Wooooo000U
ooooo`03o`000?oooooooooo03Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Cooooo0_l00?m?ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo04kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool0COooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool02?ooool00ol0003oooooooooo`09ooooo`009Oooool3o`0003Cooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo0_l00?m?oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo04kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool0COooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01_ooool3o`0000_ooooo000Uooooo`03
o`000?oooooooooo03Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool0C_ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1>ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo04gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Sooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool0
=?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`1>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo04kooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
COooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
2?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`0/ooooo`;o003o1_oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`1>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo04kooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0COoo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02?oo
ool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`0/ooooo`;o003o1_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`1>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo04kooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0COooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02?ooool0
0ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`0]ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool0C_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1>ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
04gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Sooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool0;Oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo04Kooooo0_l00?l6ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo04ko
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool0COooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool02?ooool00ol0003oooooooooo`09ooooo`009Oooool3o`0002gooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`16ooooo`;o003o1_ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`1>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo04gooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Kooooo0ol0000;ooooo`009Oooool00ol0003ooooooooo
o`0]ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0Aoooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo04kooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0COooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02?ooool00ol0003ooooooooo
o`09ooooo`009Oooool00ol0003oooooooooo`0]ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool0Aoooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo04kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool0COooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool02?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`0]oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool0Aoooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo04Kooooo0_l00?l6ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo04gooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o0000oooo
ooooool02Oooool002Gooooo00?o0000ooooooooool0;Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo04Oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`16ooooo`;o
003o1_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`1=ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`00
0?oooooooooo02gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`17ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool0A_ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo04gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Sooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool0;Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo04Oooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`16ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0COoo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02?oo
ool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`0]ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool0Aoooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo04Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`15ooooo`;o003o1_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02?ooool0
0ol0003oooooooooo`09ooooo`009Oooool3o`0002gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`17ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0A_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo04Gooooo0_l00?l6ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`06ooooo`?o00002oooool002Go
oooo00?o0000ooooooooool0;Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo04Oo
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`16ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool0A_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Wo
oooo000Uooooo`03o`000?oooooooooo02gooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`17ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0A_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo04Kooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02?ooool00ol0003ooooo
ooooo`09ooooo`009Oooool00ol0003oooooooooo`0]ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool0Aoooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo04Kooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`03ooooo`;o003o@Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`08ooooo`03o`000?oooooooooo00Wooooo000Looooo`;o00001oooool00ol0003oooooooooo`0]
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0Aoooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo04Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`03
ooooo`;o003o@Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Wooooo000Koooo
o`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0;Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo04Oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`16
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0o
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02Oooool001_ooooo00Co0000oooo
oooooooo00001_ooool00ol0003oooooooooo`0]ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool0Aoooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo0_l00?m0
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0o
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02Oooool001_ooooo00Co0000oooo
oooooooo00001_ooool;o`000003o`00ool0003o000000Go000000?o003oo`000?l000001?l00000
0ol00?oo0000o`000004o`000003o`00ool0003o000000Go000000?o003oo`000?l000001?l00000
0ol00?oo0000o`000004o`000003o`00ool0003o000000Go000000?o003oo`000?l000001?l00000
0ol00?oo0000o`000004o`000003o`00ool0003o000000Go000000?o003oo`000?l000001?l00000
0ol00?oo0000o`000004o`000003o`00ool0003o000000Go000000?o003oo`000?l000001?l00000
0ol00?oo0000o`000004o`000003o`00ool0003o000000Go000000?o003oo`000?l000001?l00000
0ol00?oo0000o`000004o`000003o`00ool0003o000000Go000000?o003oo`000?l000001?l00000
0ol00?oo0000o`000004o`000003o`00ool0003o000000Go000000?o003oo`000?l000001?l00000
0ol00?oo0000o`000004o`000003o`00ool0003o000000Go000000?o003oo`000?l000001?l00000
0ol00?oo0000o`000004o`000003o`00ool0003o000000Go000000?o003oo`000?l000001?l00000
0ol00?oo0000o`000004o`0000;o003o1_l000000ol00?oo0000o`000004o`000003o`00ool0003o
000000Co000000?o003oo`000?l000001Ol000000ol00?oo0000o`000004o`000003o`00ool0003o
000000Co000000?o003oo`000?l000001Ol000000ol00?oo0000o`000004o`000003o`00ool0003o
000000Co000000?o003oo`000?l000001Ol000000ol00?oo0000o`000004o`000003o`00ool0003o
000000Co000000?o003oo`000?l000001Ol000000ol00?oo0000o`000004o`000003o`00ool0003o
000000Co000000?o003oo`000?l000001Ol000000ol00?oo0000o`000004o`000003o`00ool0003o
000000Co000000?o003oo`000?l000001Ol000000ol00?oo0000o`000004o`000003o`00ool0003o
000000Co000000?o003oo`000?l000001Ol000000ol00?oo0000o`000004o`000003o`00ool0003o
000000Co000000?o003oo`000?l000001Ol000000ol00?oo0000o`000004o`000003o`00ool0003o
000000Co000000?o003oo`000?l000001Ol000000ol00?oo0000o`000004o`000003o`00ool0003o
000000Wo00002oooool001_ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`08
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0?oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0Aoooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo04Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0U
ooooo`03o`000?oooooooooo00Wooooo000Kooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo03oooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo04Oooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`16ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool09Oooool00ol0003oooooooooo`09ooooo`007?ooool2o`0000Oooooo00?o0000oooo
ooooool02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo03kooooo0_l00?l6oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool0Aoooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo04Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Uoooo
o`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00Sooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0nooooo`;o003o1_ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo04Oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`16ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool09Oooool00ol0003oooooooooo`09ooooo`00
9Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
A_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo04Oooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`16ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
9Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool0A_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo04Oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`16ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool09Oooool00ol0003oooooooooo`09ooooo`009Oooool3
o`0000Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01?ooool2o`00odSooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`17ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0A_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02?ooooo0ol0000;ooooo`009Oooool00ol0
003oooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo0_l00?m8ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool0Aoooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
04Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Uooooo`03o`000?oooooooooo
00Wooooo000Uooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0C_ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo04Oooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`16ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool09Oooool00ol0003o
ooooooooo`09ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo04kooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`17ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool0A_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02Gooooo
00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool02?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`1>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo0_l00?m8ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool0A_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02Gooooo00?o
0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1>
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Cooooo0_l00?m8ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool0A_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02Gooooo00?o0000
ooooooooool02Oooool002Gooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1>oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo04kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`16oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool09Oooool00ol0003oooooooooo`09oooo
o`009Oooool3o`0000Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool0C_ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1>ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00?ooooo0_l00?m8ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool08oooool3o`0000_ooooo000Uooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
C_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`1>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00?ooooo0_l00?m8ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool09Oooool00ol0003oooooooooo`09ooooo`009Ooo
ool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo04kooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0C_oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`1=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool09Ooo
ool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo04kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool0C_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`1=ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool09Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0
003oooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo04kooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0C_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`1=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo0_l00?lWooooo`03o`000?oooooooooo
00Wooooo000Uooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0C_ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`1>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo04gooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool2o`00obOo
oooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool02?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`1>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo04kooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0COooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0]ooooo`03o`000?oooooooooo00Wooooo000Uooooo`?o00002?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`1>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo04kooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0COooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0[ooooo`?o00002oooool002Gooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1>
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo04kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0COooool2o`00o`Kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02gooooo00?o0000
ooooooooool02Oooool002Gooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1>oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo04kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool0COooool2o`00o`Kooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02gooooo00?o0000oooo
ooooool02Oooool002Gooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1>ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo04kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool0;Oooool00ol0003oooooooooo`09ooooo`00
9Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo04kooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
COooool2o`00o`Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo05Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo02gooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool02?oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`1>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo04gooooo0_l00?l6ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`1Eooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0]ooooo`03o`000?oo
oooooooo00Wooooo000Uooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0C_ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0]ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo
00Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool0C_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0]ooooo`03o`000?oooooooooo
00Wooooo000Uooooo`?o00002?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1=ooooo`;o003o1_ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0EOooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0EOooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0:oooool3o`0000_o
oooo000Uooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0COooool2o`00o`Kooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo05Gooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo05Gooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02gooooo
00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool02?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`1Eooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`1Eooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`1Eooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0]ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00Sooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo0_l00?mF
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1E
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`1E
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0]
ooooo`03o`000?oooooooooo00Wooooo000@ooooo`;o00001?ooool00ol0003oooooooooo`02oooo
o`?o00001oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`04ooooo`;o003oE_ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool0;Oooool00ol0003oooooooooo`09oooo
o`003oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`1Looooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0]ooooo`03o`000?oooooooooo00Wooooo000?ooooo`04o`000?oooooooooo
o`0000_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Looooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0]ooooo`03o`000?oooooo
oooo00Wooooo000?ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool01?ooool4
o`0000Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo05cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`03ooooo`;o003oEoooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0EOooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0:_ooool4
o`0000_ooooo000?ooooo`04o`000?ooooooooooo`0000Oooooo1?l00007ooooo`03o`000?oooooo
oooo00Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo05cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`03ooooo`;o003oEoooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0EOooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0;Oooool0
0ol0003oooooooooo`09ooooo`003oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool0G?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo05cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo05Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo02gooooo00?o0000ooooooooool02Oooool0013ooooo0_l00008ooooo`Go00001_ooool00ol0
003oooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`1Looooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0G?ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo0_l00?mGooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0]ooooo`03o`000?oooooooooo
00Wooooo000Uooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo05cooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`1Looooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool2o`00oeOo
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02go
oooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool02?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0G?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo05cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`1Mooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0]ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00Sooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo05cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`1Looooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool0GOooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo0_l0
0?l^ooooo`03o`000?oooooooooo00Wooooo000Uooooo`?o00002?ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0G?ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo05cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1M
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool2o`00obcooooo0ol0000;
ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`1Looooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool0G?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo05gooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0dooooo`03o`000?oooooooooo00Wooooo000Uooooo`03
o`000?oooooooooo00Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo05cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`1Looooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool0G?ooool2o`00o`Kooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool0=?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Looooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool0G?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo05cooooo0_l00?l6ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo03Cooooo00?o0000ooooooooool0
2Oooool002Gooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool0G?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo05cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Tooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo03Cooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool02?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0G?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo05_ooooo0_l00?l6ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo06Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool0=?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0
003oooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`1Looooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0Foooool2o`00
o`Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool0I?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0dooooo`03o`000?oooooooooo
00Wooooo000Uooooo`?o00002?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool0G?ooool2o`00o`Kooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0Hoooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`1Tooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo03;ooooo0ol0000;ooooo`009Oooool00ol0003ooooo
ooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`1Looooo`;o003o1_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`1Sooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo06Cooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool0=?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003ooooooooo
o`08ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`1Tooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo06?ooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0I?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0dooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00Sooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`03ooooo`;o003oI_ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`1S
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo06Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0=?ooool00ol0003oooooooooo`09
ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool00oooool2o`00ofKooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool0Hoooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Toooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo03Cooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000oooooooo
ool02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo06_ooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool0Hoooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`1Tooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo03Cooooo00?o0000oooooooo
ool02Oooool002Gooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo06_ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Cooooo0_l00?mUooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo06Cooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
=?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool0Joooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01?ooool2o`00ofGooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0I?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`0dooooo`03o`000?oooooooooo00Wooooo000Uooooo`?o00002?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo06_ooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo06_ooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo0_l00?mUooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo03;ooooo0ol0000;ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool0Joooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool0Joooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01?ooool2o`00ofGooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0=?ooool00ol0
003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool0Joooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool0Joooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool0Joooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool00oooool2o`00ocKooooo00?o0000ooooooooool02Oooool002Gooooo
00?o0000ooooooooool02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo06_ooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo06_ooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo06_ooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00?ooooo
0_l00?lfooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00Sooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`1[ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`1[ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`1Zooooo`;o003o1_ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo03_ooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000
ooooooooool02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo06_ooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo06_ooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo06[ooooo0_l00?l6
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0>oooool00ol0003oooooooooo`09
ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool0Joooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool0Joooool2o`00o`Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1boooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool0>oooool00ol0003oooooooooo`09oooo
o`009Oooool3o`0000Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`1Zooooo`;o
003o1_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo06_ooooo0_l00?l6ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool0L_ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo03Wooooo0ol0000;ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool0J_ooool2o`00o`Kooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`1cooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
L_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo03_ooooo00?o0000ooooooooool0
2Oooool002Gooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`04ooooo`;o003oM?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo07?ooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`1booooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0>ooo
ool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooo
oooo00Cooooo0_l00?mdooooo`03o`00oooooooooooo00Cooooo0_l00?mdooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool0L_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo03_ooooo00?o0000ooooooooool02Oooool001_ooooo0ol00007ooooo`03o`000?oooooooooo
00Sooooo00?o003oooooooooool0N_ooool00ol00?ooooooooooo`04ooooo`;o003oM?ooool00ol0
0?ooooooooooo`03ooooo`;o003oM?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
03_ooooo00?o0000ooooooooool02Oooool001cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`08ooooo`03o`00oooooooooooo07[ooooo00?o003oooooooooool0N_ooool00ol00?oo
ooooooooo`03ooooo`;o003oM?ooool00ol00?ooooooooooo`04ooooo`;o003o?Oooool00ol0003o
ooooooooo`09ooooo`007?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo
00?o003oooooooooool0N_ooool00ol00?ooooooooooo`1iooooo`;o003oNoooool2o`00o`Gooooo
0_l00?lmooooo`03o`000?oooooooooo00Wooooo000Looooo`03o`000?oooooooooo00Kooooo1?l0
0007ooooo`;o003oN_ooool2o`00og_ooooo0_l00?mkooooo`;o003o@Oooool4o`0000_ooooo000L
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool2o`00odSooooo00?o0000
ooooooooool0;oooool2o`00oaGooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`17
ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0A_ooool01Ol0003ooooooooooooo
oooo000000_ooooo000Kooooo`;o00002?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`05o`000?oooooo
ooooooooool000002oooool001cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`05o`000?ooooooooooooooool000002oooool002Goooooool00039o`0000_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 503}, {167, 0}} -> {-6.64967, -1.25203, 0.136372, \
0.0138588}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Magnitude plot of DTFT as a function of frequency", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(X\[Theta]\  = DTFT[xd, \[Theta]]\  // \ Simplify; 
    g1 = Plot[
        Abs[X\[Theta]\  /. \ \[Theta] \[Rule] \ 2  \[Pi]\ f/fs], {f, \(-fs\)/
            2, fs/2}, \ PlotStyle \[Rule] {Blue, \ Dashing[{ .01}]}, \ 
        PlotRange \[Rule] All, PlotPoints \[Rule] 200];\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.014711 0.0195659 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01471 -6 -4.5 ]
[-0.0125 .01471 0 4.5 ]
[-0.0125 .11254 -6 -4.5 ]
[-0.0125 .11254 0 4.5 ]
[-0.0125 .21037 -12 -4.5 ]
[-0.0125 .21037 0 4.5 ]
[-0.0125 .3082 -12 -4.5 ]
[-0.0125 .3082 0 4.5 ]
[-0.0125 .40603 -12 -4.5 ]
[-0.0125 .40603 0 4.5 ]
[-0.0125 .50386 -12 -4.5 ]
[-0.0125 .50386 0 4.5 ]
[-0.0125 .60169 -12 -4.5 ]
[-0.0125 .60169 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01471 m
.00625 .01471 L
s
[(0)] -0.0125 .01471 1 0 Mshowa
0 .11254 m
.00625 .11254 L
s
[(5)] -0.0125 .11254 1 0 Mshowa
0 .21037 m
.00625 .21037 L
s
[(10)] -0.0125 .21037 1 0 Mshowa
0 .3082 m
.00625 .3082 L
s
[(15)] -0.0125 .3082 1 0 Mshowa
0 .40603 m
.00625 .40603 L
s
[(20)] -0.0125 .40603 1 0 Mshowa
0 .50386 m
.00625 .50386 L
s
[(25)] -0.0125 .50386 1 0 Mshowa
0 .60169 m
.00625 .60169 L
s
[(30)] -0.0125 .60169 1 0 Mshowa
.125 Mabswid
0 .03428 m
.00375 .03428 L
s
0 .05384 m
.00375 .05384 L
s
0 .07341 m
.00375 .07341 L
s
0 .09297 m
.00375 .09297 L
s
0 .13211 m
.00375 .13211 L
s
0 .15167 m
.00375 .15167 L
s
0 .17124 m
.00375 .17124 L
s
0 .1908 m
.00375 .1908 L
s
0 .22994 m
.00375 .22994 L
s
0 .2495 m
.00375 .2495 L
s
0 .26907 m
.00375 .26907 L
s
0 .28863 m
.00375 .28863 L
s
0 .32777 m
.00375 .32777 L
s
0 .34733 m
.00375 .34733 L
s
0 .3669 m
.00375 .3669 L
s
0 .38646 m
.00375 .38646 L
s
0 .4256 m
.00375 .4256 L
s
0 .44516 m
.00375 .44516 L
s
0 .46473 m
.00375 .46473 L
s
0 .48429 m
.00375 .48429 L
s
0 .52343 m
.00375 .52343 L
s
0 .54299 m
.00375 .54299 L
s
0 .56256 m
.00375 .56256 L
s
0 .58212 m
.00375 .58212 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01471 m
1 .01471 L
s
.99375 .11254 m
1 .11254 L
s
.99375 .21037 m
1 .21037 L
s
.99375 .3082 m
1 .3082 L
s
.99375 .40603 m
1 .40603 L
s
.99375 .50386 m
1 .50386 L
s
.99375 .60169 m
1 .60169 L
s
.125 Mabswid
.99625 .03428 m
1 .03428 L
s
.99625 .05384 m
1 .05384 L
s
.99625 .07341 m
1 .07341 L
s
.99625 .09297 m
1 .09297 L
s
.99625 .13211 m
1 .13211 L
s
.99625 .15167 m
1 .15167 L
s
.99625 .17124 m
1 .17124 L
s
.99625 .1908 m
1 .1908 L
s
.99625 .22994 m
1 .22994 L
s
.99625 .2495 m
1 .2495 L
s
.99625 .26907 m
1 .26907 L
s
.99625 .28863 m
1 .28863 L
s
.99625 .32777 m
1 .32777 L
s
.99625 .34733 m
1 .34733 L
s
.99625 .3669 m
1 .3669 L
s
.99625 .38646 m
1 .38646 L
s
.99625 .4256 m
1 .4256 L
s
.99625 .44516 m
1 .44516 L
s
.99625 .46473 m
1 .46473 L
s
.99625 .48429 m
1 .48429 L
s
.99625 .52343 m
1 .52343 L
s
.99625 .54299 m
1 .54299 L
s
.99625 .56256 m
1 .56256 L
s
.99625 .58212 m
1 .58212 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .03428 m
.02395 .03427 L
.02408 .03425 L
.02423 .03421 L
.02437 .03416 L
.02462 .03403 L
.02489 .03383 L
.02519 .03355 L
.02551 .03318 L
.02608 .03234 L
.02722 .03 L
.02847 .02653 L
.02973 .0223 L
.03043 .01975 L
.03109 .01723 L
.03139 .01609 L
.03155 .01546 L
.03171 .01486 L
.03179 .0149 L
.03189 .01526 L
.03205 .0159 L
.03238 .01715 L
.03355 .02156 L
.03596 .0292 L
.03717 .03192 L
.03785 .03303 L
.03819 .03345 L
.0385 .03376 L
.03879 .034 L
.03894 .03409 L
.0391 .03417 L
.03918 .03421 L
.03926 .03424 L
.03941 .03428 L
.03949 .03429 L
.03958 .0343 L
.03967 .03431 L
.03976 .0343 L
.03991 .03429 L
.04006 .03425 L
.04019 .03421 L
.04033 .03415 L
.04065 .03395 L
.04095 .0337 L
.04147 .0331 L
.04204 .03222 L
.04319 .02979 L
.04573 .02188 L
.04631 .01972 L
.04694 .01736 L
Mistroke
.04724 .01619 L
.04739 .01562 L
.04752 .01509 L
.04765 .01482 L
.04778 .01533 L
.04805 .0164 L
.0492 .02077 L
.05046 .02517 L
.05165 .02878 L
.05274 .03139 L
.05332 .03249 L
.05388 .03331 L
.05417 .03364 L
.05447 .03393 L
.05463 .03405 L
.0548 .03417 L
.05495 .03425 L
.05511 .03431 L
.05525 .03435 L
.0554 .03438 L
.05553 .03439 L
.05566 .03439 L
.05581 .03437 L
.05595 .03434 L
.0561 .03428 L
.05625 .03421 L
.05652 .03404 L
.05676 .03384 L
.05732 .03321 L
.05789 .03235 L
.05849 .03118 L
.05959 .02847 L
.06208 .02016 L
.06267 .01789 L
.063 .01663 L
.0633 .01544 L
.06346 .01482 L
.06355 .01495 L
.06363 .01527 L
.064 .01668 L
.06464 .01916 L
.06589 .02376 L
.06706 .02756 L
.06826 .03073 L
.06878 .03185 L
.06934 .03285 L
.06967 .03333 L
.06996 .0337 L
.07027 .034 L
.07055 .03423 L
Mistroke
.07071 .03433 L
.07085 .0344 L
.07101 .03446 L
.07109 .03449 L
.07118 .03451 L
.07126 .03452 L
.07134 .03453 L
.07149 .03454 L
.07159 .03453 L
.07167 .03452 L
.07175 .0345 L
.07184 .03448 L
.07199 .03442 L
.07213 .03436 L
.07243 .03416 L
.07272 .03391 L
.07299 .03362 L
.07359 .03277 L
.07425 .03156 L
.07557 .02829 L
.07679 .02443 L
.07787 .02051 L
.07844 .01833 L
.07904 .01599 L
.07919 .01539 L
.07928 .01505 L
.07936 .01473 L
.07945 .01506 L
.07954 .0154 L
.07971 .01606 L
.08032 .01846 L
.08152 .02298 L
.0827 .02695 L
.08394 .03043 L
.085 .03267 L
.0856 .0336 L
.08588 .03393 L
.08617 .03423 L
.08633 .03436 L
.08648 .03447 L
.08663 .03456 L
.08677 .03463 L
.08693 .03469 L
.08702 .03471 L
.08711 .03473 L
.08726 .03474 L
.08734 .03475 L
.08742 .03474 L
.08758 .03472 L
.08772 .03468 L
Mistroke
.08786 .03463 L
.088 .03457 L
.08832 .03436 L
.08861 .03409 L
.08913 .03347 L
.0897 .03256 L
.09085 .03004 L
.09339 .02192 L
.09397 .01971 L
.09459 .01729 L
.09489 .01609 L
.09504 .0155 L
.09518 .01496 L
.0953 .01496 L
.09543 .01548 L
.09571 .01659 L
.09685 .02106 L
.0981 .02557 L
.0993 .02927 L
.10038 .03195 L
.10097 .03308 L
.10153 .03392 L
.10181 .03426 L
.10211 .03455 L
.10227 .03468 L
.10244 .03479 L
.10259 .03487 L
.10275 .03494 L
.10289 .03498 L
.10304 .03501 L
.10317 .03502 L
.1033 .03501 L
.10345 .03499 L
.10358 .03496 L
.10374 .0349 L
.10389 .03483 L
.10416 .03465 L
.1044 .03444 L
.10496 .03379 L
.10552 .0329 L
.10613 .03169 L
.10722 .0289 L
.10971 .0203 L
.1103 .01797 L
.11063 .01667 L
.11093 .01543 L
.11102 .01509 L
.11111 .01473 L
.1112 .01509 L
.1113 .01546 L
Mistroke
.11162 .01678 L
.11226 .01935 L
.11343 .02382 L
.11469 .02807 L
.11593 .03149 L
.11652 .03277 L
.11706 .03374 L
.1176 .03449 L
.11789 .0348 L
.1182 .03505 L
.11832 .03513 L
.11846 .03521 L
.11858 .03526 L
.11871 .03531 L
.11885 .03534 L
.119 .03536 L
.11914 .03536 L
.11927 .03534 L
.11943 .03531 L
.1195 .03529 L
.11959 .03525 L
.11988 .0351 L
.12005 .03498 L
.12022 .03483 L
.12054 .0345 L
.12117 .03361 L
.12174 .03255 L
.12289 .02973 L
.12399 .02632 L
.12515 .02211 L
.12578 .01961 L
.12638 .01718 L
.12663 .01617 L
.12676 .01561 L
.12689 .0151 L
.12703 .01489 L
.12718 .0155 L
.12744 .01658 L
.1286 .02129 L
.13086 .02925 L
.13148 .031 L
.13213 .03258 L
.1327 .03371 L
.13331 .03467 L
.13364 .03507 L
.13394 .03535 L
.13408 .03547 L
.13424 .03557 L
.13439 .03565 L
.13453 .0357 L
Mistroke
.13462 .03573 L
.13471 .03575 L
.13479 .03577 L
.13487 .03577 L
.13495 .03578 L
.13504 .03577 L
.13514 .03576 L
.13523 .03575 L
.13531 .03573 L
.13539 .0357 L
.13554 .03564 L
.1357 .03555 L
.13588 .03543 L
.13617 .03517 L
.13649 .03481 L
.13714 .03384 L
.13774 .03265 L
.13831 .0313 L
.14074 .02335 L
.14182 .01905 L
.14211 .01787 L
.14241 .01658 L
.14255 .01598 L
.1427 .01535 L
.14283 .01481 L
.14297 .0152 L
.14313 .01585 L
.14329 .01655 L
.14359 .01781 L
.14416 .02014 L
.14526 .02449 L
.14655 .02902 L
.14775 .0324 L
.14839 .03382 L
.14898 .03484 L
.14929 .03528 L
.14962 .03566 L
.1498 .03583 L
.14997 .03597 L
.15014 .03607 L
.15031 .03616 L
.15046 .03622 L
.1506 .03626 L
.15074 .03627 L
.15087 .03628 L
.15102 .03626 L
.15117 .03623 L
.15132 .03618 L
.15149 .0361 L
.15179 .03589 L
Mistroke
.15208 .03563 L
.15273 .03477 L
.15333 .0337 L
.15398 .03221 L
.15517 .02878 L
.1574 .02036 L
.15804 .01766 L
.15836 .01632 L
.1585 .01572 L
.15865 .01507 L
.15878 .01494 L
.15891 .01549 L
.15919 .0167 L
.15978 .01921 L
.16107 .02453 L
.1623 .029 L
.16348 .0325 L
.1641 .03398 L
.16476 .03523 L
.16531 .03602 L
.16562 .03636 L
.16577 .03648 L
.16592 .0366 L
.16605 .03668 L
.16619 .03675 L
.16632 .0368 L
.16644 .03684 L
.16658 .03686 L
.16671 .03687 L
.16685 .03686 L
.16699 .03684 L
.16713 .0368 L
.16728 .03673 L
.16742 .03665 L
.16755 .03657 L
.16787 .0363 L
.16816 .03596 L
.16876 .03508 L
.1694 .03379 L
.17056 .03073 L
.17163 .02713 L
.17291 .0221 L
.17353 .01944 L
.17411 .01691 L
.17438 .01571 L
.17451 .01512 L
.17463 .01484 L
.17476 .01541 L
.1749 .01602 L
.17519 .0173 L
Mistroke
.17635 .02237 L
.17866 .03101 L
.17929 .03287 L
.17996 .03454 L
.18059 .0358 L
.18086 .03624 L
.18116 .03666 L
.18143 .03697 L
.18171 .03723 L
.18187 .03734 L
.18201 .03742 L
.18216 .03749 L
.18229 .03753 L
.18244 .03756 L
.1826 .03757 L
.18273 .03756 L
.18288 .03753 L
.18304 .03748 L
.18312 .03744 L
.18321 .0374 L
.18351 .03719 L
.18379 .03693 L
.18405 .03662 L
.18464 .03571 L
.18516 .03467 L
.18572 .03332 L
.18813 .02506 L
.1894 .0196 L
.19004 .01671 L
.19022 .0159 L
.19031 .01546 L
.1904 .01504 L
.19049 .01477 L
.19058 .01519 L
.19074 .01593 L
.19327 .02698 L
.19446 .03136 L
.19558 .03464 L
.19618 .036 L
.19672 .03699 L
.19701 .03741 L
.19733 .03778 L
.1975 .03795 L
.19766 .03808 L
.19782 .0382 L
.19798 .03828 L
.19813 .03834 L
.19822 .03836 L
.19831 .03838 L
.19846 .03839 L
Mistroke
.19854 .03839 L
.19862 .03838 L
.19877 .03835 L
.1989 .03831 L
.19906 .03823 L
.1992 .03814 L
.19953 .03788 L
.19983 .03754 L
.20051 .03648 L
.20107 .03532 L
.20167 .03378 L
.20276 .03031 L
.20395 .02569 L
.20525 .01992 L
.20585 .01708 L
.20603 .01625 L
.20619 .01547 L
.20634 .01476 L
.20642 .01506 L
.2065 .01542 L
.20766 .02094 L
.20898 .02679 L
.21021 .03157 L
.2113 .03501 L
.21186 .03642 L
.21247 .03767 L
.21282 .03822 L
.21314 .03864 L
.21344 .03895 L
.2136 .03908 L
.21377 .03919 L
.21385 .03923 L
.21394 .03927 L
.21409 .03932 L
.21424 .03935 L
.21439 .03935 L
.21454 .03934 L
.21469 .0393 L
.21483 .03924 L
.21496 .03918 L
.21524 .03898 L
.21554 .03867 L
.21586 .03826 L
.21616 .03779 L
.21726 .03535 L
.21789 .03351 L
.21847 .03156 L
.21977 .02638 L
.22088 .02131 L
.22148 .01837 L
Mistroke
.22178 .0169 L
.22206 .01554 L
.22222 .01475 L
.22229 .01507 L
.22238 .01551 L
.22274 .01727 L
.22335 .02031 L
.22455 .026 L
.22576 .0311 L
.2269 .03512 L
.22754 .03691 L
.22822 .03847 L
.22853 .03902 L
.22885 .03952 L
.22912 .03986 L
.22928 .04002 L
.22943 .04015 L
.22958 .04026 L
.22971 .04034 L
.22986 .04041 L
.23001 .04046 L
.23015 .04048 L
.23029 .04048 L
.23043 .04046 L
.23055 .04043 L
.2307 .04037 L
.23083 .0403 L
.23114 .04006 L
.23145 .03974 L
.23177 .0393 L
.23236 .03822 L
.23292 .03691 L
.23397 .03369 L
.23522 .02882 L
.23639 .0234 L
.23744 .0181 L
.23773 .0166 L
.23789 .01578 L
.23804 .01502 L
.23816 .01506 L
.2383 .01576 L
.23858 .01725 L
.24096 .029 L
.24227 .03439 L
.24349 .03824 L
.24408 .03965 L
.24471 .04077 L
.24504 .0412 L
.24535 .0415 L
.24552 .04162 L
Mistroke
.24569 .04171 L
.24577 .04175 L
.24586 .04178 L
.24596 .0418 L
.24605 .04181 L
.2462 .04181 L
.24629 .0418 L
.24637 .04178 L
.24651 .04173 L
.24666 .04165 L
.2468 .04156 L
.24693 .04146 L
.24722 .04116 L
.24754 .04074 L
.24783 .04027 L
.24848 .0389 L
.24967 .03534 L
.25077 .03099 L
.25206 .02491 L
.25269 .02164 L
.25327 .01852 L
.25357 .01688 L
.25372 .01608 L
.25385 .01534 L
.25399 .01486 L
.25415 .01569 L
.25447 .01746 L
.25575 .02441 L
.258 .03494 L
.25858 .03713 L
.2592 .03912 L
.25973 .04056 L
.26031 .0418 L
.26063 .04234 L
.26092 .04274 L
.26106 .0429 L
.26122 .04305 L
.26136 .04316 L
.2615 .04325 L
.26158 .04329 L
.26167 .04333 L
.26183 .04337 L
.26192 .04338 L
.26201 .04339 L
.26209 .04338 L
.26218 .04337 L
.26234 .04332 L
.26243 .04329 L
.26251 .04324 L
.26267 .04314 L
Mistroke
.26281 .04302 L
.26309 .04272 L
.26339 .0423 L
.26401 .04114 L
.26454 .03982 L
.26511 .03808 L
.26642 .03299 L
.26762 .0272 L
.26872 .02119 L
.26933 .01772 L
.26947 .01688 L
.26962 .01598 L
.26975 .01522 L
.2699 .01504 L
.26998 .01552 L
.27007 .01603 L
.27022 .01695 L
.27058 .019 L
.27119 .02256 L
.27239 .02917 L
.27361 .03511 L
.27426 .03781 L
.27495 .04029 L
.27561 .04223 L
.2762 .0436 L
.27649 .04412 L
.2768 .04458 L
.27695 .04475 L
.2771 .04491 L
.27724 .04503 L
.27737 .04512 L
.27752 .04519 L
.2776 .04522 L
.27768 .04525 L
.27782 .04527 L
.27797 .04527 L
.2781 .04525 L
.27825 .0452 L
.27839 .04512 L
.27852 .04504 L
.2788 .04477 L
.27911 .04438 L
.27944 .04384 L
.27974 .04323 L
.28081 .04025 L
.28195 .03579 L
.28319 .02969 L
.28453 .02201 L
.28515 .01825 L
.28531 .01724 L
Mistroke
.28548 .01616 L
.28557 .01563 L
.28565 .01513 L
.2858 .01523 L
.28594 .01609 L
.28606 .0169 L
.28635 .01871 L
.28696 .02249 L
.28814 .02946 L
.2894 .03616 L
.29049 .04095 L
.29111 .04315 L
.29169 .04483 L
.29225 .04608 L
.29256 .04662 L
.29285 .04701 L
.29299 .04717 L
.29315 .04731 L
.29323 .04737 L
.29332 .04742 L
.29347 .0475 L
.29362 .04754 L
.29378 .04756 L
.29393 .04754 L
.29406 .04751 L
.2942 .04744 L
.29434 .04735 L
.2946 .04712 L
.2949 .04674 L
.29518 .04629 L
.29572 .04513 L
.29624 .0437 L
.29742 .03929 L
.29866 .03313 L
.29983 .02627 L
.30089 .0194 L
.30117 .01752 L
.30132 .01652 L
.30148 .01546 L
.30161 .01489 L
.30177 .01591 L
.30203 .01772 L
.30326 .0259 L
.30547 .03894 L
.30669 .04442 L
.30726 .04646 L
.3078 .04799 L
.30839 .04924 L
.3087 .04972 L
.30887 .04993 L
Mistroke
.30903 .05009 L
.30919 .05022 L
.30928 .05027 L
.30938 .05031 L
.30953 .05036 L
.30962 .05037 L
.3097 .05037 L
.30986 .05034 L
.31 .05029 L
.31008 .05025 L
.31016 .0502 L
.31032 .05007 L
.31063 .04972 L
.31096 .0492 L
.31157 .04786 L
.31215 .04609 L
.3127 .04408 L
.31393 .03823 L
.31523 .03046 L
.31637 .02263 L
.31668 .02046 L
.317 .01807 L
.31715 .01697 L
.31731 .01579 L
.31745 .01479 L
.3176 .01574 L
.31876 .02426 L
.31981 .03169 L
.32095 .03899 L
.32215 .04543 L
.32278 .04818 L
.32346 .05061 L
.32377 .05147 L
.32409 .05226 L
.32436 .05281 L
.32467 .05329 L
.32482 .05348 L
.32498 .05364 L
.32507 .05371 L
.32515 .05377 L
.32524 .05382 L
.32531 .05385 L
.32546 .05389 L
.32562 .05389 L
.32576 .05387 L
.32591 .0538 L
.32606 .0537 L
.32624 .05355 L
.32654 .05315 L
.32691 .0525 L
Mistroke
.32725 .05172 L
.32781 .05003 L
.32843 .04766 L
.32968 .04136 L
.33204 .02506 L
.33272 .01967 L
.33306 .01697 L
.3332 .01577 L
.33329 .01509 L
.33336 .01497 L
.3335 .01607 L
.33364 .01726 L
.33394 .01969 L
.33457 .02478 L
.33695 .04248 L
.33829 .05026 L
.33894 .05317 L
.33954 .05536 L
.34013 .05694 L
.34046 .05759 L
.34061 .05784 L
.34076 .05803 L
.34089 .05817 L
.34102 .05828 L
.34115 .05836 L
.3413 .05842 L
.34144 .05845 L
.34159 .05843 L
.34173 .05839 L
.34186 .05831 L
.342 .0582 L
.34216 .05803 L
.34243 .05764 L
.34276 .057 L
.34306 .05626 L
.34368 .05425 L
.34433 .05147 L
.34549 .04502 L
.34672 .03627 L
.34787 .02674 L
.34838 .02227 L
.34893 .01722 L
.34908 .01585 L
.34917 .01508 L
.34924 .01505 L
.34939 .01642 L
.34953 .01773 L
.35017 .02359 L
.35151 .03558 L
.35269 .04515 L
Mistroke
.35394 .0537 L
.35459 .05729 L
.3552 .06006 L
.35574 .06201 L
.35603 .0628 L
.35634 .06351 L
.35648 .06377 L
.35663 .06401 L
.35676 .06418 L
.3569 .06433 L
.35698 .0644 L
.35706 .06445 L
.35721 .06452 L
.35735 .06454 L
.35749 .06453 L
.35762 .06449 L
.35775 .0644 L
.35788 .06429 L
.358 .06416 L
.35828 .06373 L
.35856 .06318 L
.35916 .06142 L
.35971 .05923 L
.36094 .05236 L
.36208 .04383 L
.36316 .03424 L
.36434 .02251 L
.36462 .01953 L
.36478 .01787 L
.36493 .01629 L
.36501 .0154 L
.36511 .015 L
.36519 .01588 L
.36527 .0167 L
.36558 .02006 L
.36781 .04309 L
.36889 .05293 L
.37006 .06181 L
.37073 .06588 L
.37134 .06888 L
.37193 .07103 L
.37222 .07184 L
.37239 .07222 L
.37254 .07251 L
.37269 .07274 L
.37285 .07293 L
.37293 .07301 L
.37301 .07307 L
.37309 .07311 L
.37318 .07315 L
Mistroke
.37326 .07316 L
.37334 .07316 L
.37349 .07312 L
.37364 .07303 L
.37378 .0729 L
.37393 .07271 L
.37407 .07249 L
.37433 .07196 L
.37461 .07121 L
.37491 .07021 L
.37555 .06739 L
.37622 .06346 L
.37743 .05411 L
.37867 .04196 L
.37983 .02861 L
.38034 .02239 L
.38062 .01892 L
.38076 .0172 L
.38088 .01562 L
.38102 .01552 L
.38116 .01737 L
.38147 .02134 L
.38202 .02833 L
.38438 .05676 L
.38568 .06971 L
.38632 .0749 L
.3869 .07885 L
.38743 .0818 L
.388 .0842 L
.38832 .08515 L
.38846 .08549 L
.38861 .08579 L
.38875 .08601 L
.38889 .08619 L
.38904 .08632 L
.38918 .08638 L
.38927 .08639 L
.38935 .08638 L
.38951 .08631 L
.38959 .08624 L
.38967 .08616 L
.38986 .0859 L
.39001 .0856 L
.39016 .08526 L
.39049 .08427 L
.39077 .0832 L
.39107 .08178 L
.39168 .07815 L
.39292 .0678 L
.39404 .0552 L
Mistroke
.39536 .03737 L
.39593 .02873 L
.39624 .02399 L
.39641 .02134 L
.39657 .0188 L
.39671 .01649 L
.39687 .01546 L
.39702 .01777 L
.39715 .01993 L
.39769 .02875 L
.39888 .04798 L
.40017 .06767 L
.40139 .08392 L
.40258 .09664 L
.40325 .10209 L
.40356 .1042 L
.40386 .10587 L
.40413 .10714 L
.40438 .10808 L
.40466 .10886 L
.40481 .10918 L
.40495 .1094 L
.40509 .10955 L
.40524 .10963 L
.40537 .10963 L
.40551 .10956 L
.40566 .10941 L
.40574 .10928 L
.40582 .10915 L
.40611 .10844 L
.40626 .10793 L
.40641 .10736 L
.40668 .1061 L
.40729 .10223 L
.40782 .09775 L
.40839 .09175 L
.40969 .07391 L
.41089 .05286 L
.41145 .04166 L
.41206 .0289 L
.41235 .02249 L
.41249 .01928 L
.41263 .01629 L
.41275 .01587 L
.41288 .01879 L
.41315 .02503 L
.41564 .08283 L
.41688 .10954 L
.41823 .13413 L
.41885 .14339 L
Mistroke
.4195 .15147 L
.42005 .15685 L
.42037 .15923 L
.42066 .16099 L
.42082 .16173 L
.42098 .16237 L
.42112 .1628 L
.42127 .16316 L
.42135 .1633 L
.42143 .1634 L
.42152 .16346 L
.42161 .16348 L
.42176 .16341 L
.42185 .16331 L
.42193 .16318 L
.42208 .16281 L
.42223 .16233 L
.42251 .16108 L
.4228 .15922 L
.42312 .15659 L
.42369 .15036 L
.42429 .14157 L
.42536 .1201 L
.4265 .08937 L
.42713 .06913 L
.42773 .04789 L
.42828 .02648 L
.42843 .02035 L
.42852 .01694 L
.4286 .01572 L
.42873 .02149 L
.42889 .02796 L
.42994 .07555 L
.4346 .31692 L
.43697 .43386 L
.43822 .48714 L
.43956 .53471 L
.44023 .55419 L
.44086 .56978 L
.44147 .58221 L
.44204 .59118 L
.44257 .59744 L
.44284 .59975 L
.44314 .60163 L
.4433 .60234 L
.44344 .60282 L
.44352 .60302 L
.4436 .60318 L
.44376 .60332 L
.4439 .60328 L
Mistroke
.44406 .60306 L
.44421 .60267 L
.44434 .60218 L
.44448 .60149 L
.44462 .60069 L
.44493 .59836 L
.44523 .59539 L
.44555 .59145 L
.44613 .58238 L
.44666 .572 L
.44795 .53889 L
.44917 .49834 L
.4538 .29287 L
.45614 .18062 L
.45738 .1249 L
.45872 .0703 L
.45934 .0473 L
.45968 .03545 L
.46 .02491 L
.46014 .0204 L
.46027 .01624 L
.46042 .01789 L
.46056 .02206 L
.46117 .03951 L
.46226 .06607 L
.46288 .07843 L
.46346 .0882 L
.46408 .09666 L
.46464 .10273 L
.46524 .10754 L
.46557 .10947 L
.46588 .11083 L
.46615 .11166 L
.4663 .11198 L
.46643 .1122 L
.46656 .11232 L
.4667 .11239 L
.46682 .11238 L
.46694 .11231 L
.46708 .11216 L
.46721 .11195 L
.46736 .11165 L
.46751 .11124 L
.46782 .11014 L
.4681 .10885 L
.46869 .10538 L
.46931 .1006 L
.47041 .08967 L
.47292 .05787 L
.47405 .04229 L
Mistroke
.47468 .03384 L
.47528 .02604 L
.47583 .0191 L
.47598 .01726 L
.47606 .01626 L
.47614 .01533 L
.47629 .01589 L
.47643 .01749 L
.47748 .02883 L
.47866 .0393 L
.4793 .04393 L
.4799 .04754 L
.48046 .05023 L
.48097 .05216 L
.48124 .05299 L
.48153 .05372 L
.48184 .05432 L
.48199 .05456 L
.48213 .05473 L
.48227 .05486 L
.48241 .05497 L
.48256 .05504 L
.48272 .05507 L
.48285 .05507 L
.483 .05502 L
.48314 .05495 L
.48327 .05486 L
.48343 .0547 L
.48357 .05452 L
.48391 .05399 L
.4842 .05339 L
.48452 .05262 L
.48572 .04851 L
.48705 .04236 L
.48959 .02818 L
.4908 .02137 L
.49138 .0182 L
.49164 .01686 L
.49192 .01545 L
.49206 .01472 L
.4922 .01539 L
.49247 .0167 L
.49306 .01941 L
.49432 .02443 L
.4955 .0282 L
.49607 .02969 L
.4966 .03086 L
.49712 .03185 L
.4977 .03273 L
.49801 .03313 L
Mistroke
.4983 .03344 L
.49858 .03369 L
.49887 .03391 L
.49917 .03408 L
.4993 .03414 L
.49945 .03419 L
.49961 .03423 L
.4997 .03425 L
.49978 .03426 L
.49993 .03428 L
.50008 .03428 L
.50017 .03427 L
.50025 .03426 L
.50034 .03424 L
.50043 .03422 L
.50058 .03418 L
.50075 .03411 L
.50107 .03395 L
.50137 .03374 L
.50197 .03315 L
.50262 .03227 L
.50324 .03118 L
.50382 .02995 L
.5049 .02703 L
.50605 .02305 L
.50718 .01831 L
.50749 .01687 L
.50766 .01607 L
.50782 .0153 L
.50795 .01478 L
.50809 .0155 L
.5084 .01706 L
.5106 .0293 L
.513 .04262 L
.51426 .04846 L
.51496 .05103 L
.5156 .05293 L
.5159 .05361 L
.51618 .05415 L
.51633 .05439 L
.5165 .05462 L
.51665 .05478 L
.5168 .05491 L
.51688 .05496 L
.51697 .05501 L
.51713 .05506 L
.51721 .05507 L
.51731 .05507 L
.51739 .05505 L
.51748 .05503 L
Mistroke
.51763 .05494 L
.51772 .05487 L
.5178 .0548 L
.51795 .05463 L
.51811 .05441 L
.5184 .05387 L
.51868 .05322 L
.5193 .05123 L
.51983 .0489 L
.52042 .04567 L
.52164 .03687 L
.52276 .02641 L
.52306 .02317 L
.52339 .01955 L
.52355 .01774 L
.5237 .01599 L
.52384 .01502 L
.52398 .01677 L
.5246 .02442 L
.52527 .03321 L
.52762 .06525 L
.52887 .08133 L
.53021 .09615 L
.53087 .10204 L
.53149 .10657 L
.53205 .10961 L
.53237 .11086 L
.53267 .1117 L
.53281 .11199 L
.53297 .11222 L
.53311 .11235 L
.53325 .11239 L
.53337 .11237 L
.53351 .11227 L
.53365 .11208 L
.53378 .11183 L
.53393 .11145 L
.53408 .11099 L
.53435 .10988 L
.53464 .1083 L
.53496 .10614 L
.53555 .10088 L
.5361 .09442 L
.53735 .07397 L
.53865 .04425 L
.53896 .03589 L
.5393 .02645 L
.53946 .02167 L
.53961 .01705 L
.53974 .01661 L
Mistroke
.53989 .0213 L
.54106 .06195 L
.54233 .11273 L
.54456 .21379 L
.54692 .32784 L
.54951 .44634 L
.5507 .49355 L
.55197 .53655 L
.55317 .56836 L
.55369 .57917 L
.55427 .58888 L
.55485 .59619 L
.55517 .59913 L
.55531 .60022 L
.55546 .60119 L
.5556 .60189 L
.55574 .60249 L
.55587 .6029 L
.556 .60316 L
.55614 .60331 L
.55627 .60331 L
.55643 .60313 L
.55657 .6028 L
.55671 .6023 L
.55687 .60157 L
.55719 .59948 L
.55749 .59682 L
.55777 .59371 L
.5584 .58452 L
.55907 .57134 L
.56029 .53919 L
.56162 .49307 L
.56405 .38556 L
.56662 .25196 L
.56896 .12964 L
.57012 .07251 L
.57074 .04436 L
.57108 .02964 L
.57124 .02264 L
.57139 .01637 L
.57153 .01889 L
.57166 .02433 L
.57196 .03599 L
.57258 .05924 L
.57368 .09485 L
.57485 .12484 L
.57548 .13765 L
.57608 .14731 L
.57659 .15372 L
.57714 .1588 L
Mistroke
.57744 .16076 L
.5776 .16161 L
.57775 .16225 L
.57789 .16273 L
.57802 .16306 L
.57816 .16331 L
.57831 .16346 L
.57845 .16347 L
.57859 .16338 L
.57873 .16315 L
.57889 .16278 L
.57906 .16224 L
.57922 .16158 L
.57951 .15999 L
.58004 .15601 L
.58062 .15011 L
.58193 .13159 L
.58313 .10919 L
.58431 .08405 L
.58557 .05487 L
.58615 .04122 L
.58677 .02695 L
.58702 .02113 L
.58716 .01796 L
.58729 .01498 L
.58744 .01793 L
.58759 .02108 L
.58786 .02716 L
.59007 .07001 L
.59118 .08652 L
.59182 .09414 L
.59241 .09981 L
.59301 .1043 L
.59334 .10619 L
.59365 .10761 L
.59379 .10812 L
.59394 .10858 L
.59407 .10891 L
.59421 .1092 L
.5943 .10934 L
.59438 .10945 L
.59453 .10958 L
.59467 .10963 L
.59482 .1096 L
.59496 .1095 L
.59508 .10935 L
.59523 .1091 L
.59537 .1088 L
.59561 .10809 L
.59588 .10708 L
Mistroke
.59648 .10389 L
.59704 .0999 L
.59821 .08869 L
.5993 .07515 L
.60051 .05759 L
.60178 .03736 L
.60234 .02821 L
.60265 .02317 L
.60294 .01845 L
.60302 .01715 L
.60311 .01577 L
.6032 .01515 L
.60329 .01653 L
.6036 .02151 L
.60421 .031 L
.60645 .06104 L
.60758 .07249 L
.60822 .07751 L
.60881 .08115 L
.60935 .08368 L
.60966 .08475 L
.6098 .08516 L
.60994 .0855 L
.61007 .08577 L
.61021 .08601 L
.61034 .08617 L
.61046 .08628 L
.61059 .08636 L
.61073 .08639 L
.61088 .08636 L
.61102 .08628 L
.61117 .08612 L
.61125 .08602 L
.61133 .08589 L
.61162 .0853 L
.61196 .08431 L
.61228 .08311 L
.61286 .08029 L
.61348 .07637 L
.61465 .06673 L
.61572 .05576 L
.61682 .04285 L
.618 .02805 L
.61835 .02358 L
.61868 .01936 L
.61883 .01753 L
.61898 .01559 L
.61906 .01484 L
.61915 .01595 L
.6193 .01789 L
Mistroke
.6205 .03259 L
.62171 .04591 L
.62285 .05657 L
.62348 .06146 L
.62417 .06588 L
.6248 .06902 L
.6251 .07022 L
.62537 .07115 L
.62564 .07188 L
.62593 .07249 L
.62608 .07273 L
.62622 .07291 L
.62637 .07305 L
.62653 .07313 L
.62667 .07316 L
.62683 .07315 L
.62697 .07308 L
.6271 .07298 L
.62722 .07285 L
.62736 .07267 L
.62762 .0722 L
.62795 .07141 L
.62824 .07049 L
.62891 .06777 L
.62952 .06446 L
.63011 .06068 L
.6325 .04009 L
.63356 .02915 L
.63412 .02321 L
.63443 .01994 L
.63472 .01689 L
.63487 .01526 L
.63495 .01507 L
.63503 .0159 L
.63538 .01957 L
.63599 .02588 L
.63719 .03753 L
.63828 .04677 L
.63944 .05476 L
.64001 .05789 L
.64064 .06068 L
.64091 .06167 L
.64121 .06257 L
.64148 .06327 L
.64174 .06378 L
.6419 .06403 L
.64205 .06422 L
.64221 .06437 L
.6423 .06444 L
.64238 .06448 L
Mistroke
.64246 .06452 L
.64255 .06454 L
.6427 .06454 L
.64279 .06452 L
.64287 .06449 L
.64295 .06444 L
.64305 .06437 L
.6432 .06422 L
.64337 .06401 L
.64367 .06348 L
.64397 .06281 L
.64425 .06203 L
.64486 .05982 L
.64553 .05671 L
.64673 .04938 L
.64898 .03134 L
.65013 .02087 L
.65044 .01796 L
.65061 .01636 L
.6507 .01557 L
.65078 .01485 L
.65093 .01598 L
.6511 .01749 L
.65139 .02013 L
.6527 .03158 L
.65393 .04108 L
.65511 .04859 L
.65619 .05374 L
.6568 .05587 L
.65708 .05664 L
.65739 .05731 L
.65755 .05761 L
.65771 .05785 L
.65786 .05805 L
.658 .0582 L
.65817 .05833 L
.65826 .05838 L
.65835 .05842 L
.6585 .05845 L
.65859 .05844 L
.65867 .05843 L
.65883 .05838 L
.6589 .05833 L
.65899 .05827 L
.65914 .05814 L
.65928 .05798 L
.65959 .0575 L
.65993 .0568 L
.66056 .05504 L
.66113 .0529 L
Mistroke
.66222 .04755 L
.66337 .04039 L
.66452 .03201 L
.66515 .02705 L
.66575 .02223 L
.6663 .01768 L
.66646 .01644 L
.66654 .01575 L
.66662 .01511 L
.66676 .01543 L
.66691 .01667 L
.66796 .02508 L
.6702 .04066 L
.67081 .04409 L
.67147 .04723 L
.67203 .04949 L
.67264 .05143 L
.673 .05231 L
.67333 .05296 L
.67365 .05342 L
.67381 .05359 L
.6739 .05367 L
.67398 .05374 L
.67414 .05383 L
.67429 .05388 L
.67444 .0539 L
.67453 .05389 L
.67461 .05387 L
.67475 .05382 L
.67489 .05374 L
.67505 .05361 L
.6752 .05346 L
.67549 .05305 L
.67581 .05248 L
.67636 .05112 L
.67696 .04916 L
.67762 .04649 L
.67999 .03303 L
.68131 .0238 L
.68188 .01956 L
.68221 .01714 L
.68237 .01595 L
.68252 .01487 L
.68267 .01565 L
.68281 .01669 L
.68312 .01897 L
.68376 .02354 L
.6851 .03252 L
.68627 .0393 L
.68692 .04244 L
Mistroke
.68753 .04495 L
.68812 .04698 L
.68867 .04843 L
.68896 .04904 L
.68927 .04958 L
.68959 .04998 L
.68976 .05014 L
.68985 .0502 L
.68993 .05025 L
.69006 .05032 L
.69021 .05036 L
.69035 .05037 L
.69049 .05035 L
.69061 .05032 L
.69073 .05026 L
.69086 .05018 L
.691 .05006 L
.69131 .04972 L
.6916 .04927 L
.69215 .04812 L
.69275 .0464 L
.6933 .04446 L
.69454 .03892 L
.69675 .02582 L
.69734 .02194 L
.69766 .01978 L
.69796 .01775 L
.69822 .01602 L
.69836 .01505 L
.69849 .01526 L
.69864 .01623 L
.69879 .01727 L
.69908 .01917 L
.70027 .02687 L
.70159 .03447 L
.70274 .03995 L
.70334 .04229 L
.70397 .04433 L
.7043 .04519 L
.70466 .04598 L
.70498 .04657 L
.70528 .04699 L
.70543 .04715 L
.70559 .0473 L
.70568 .04736 L
.70576 .04742 L
.70592 .0475 L
.70605 .04754 L
.7062 .04756 L
.70636 .04755 L
Mistroke
.70651 .04751 L
.70666 .04744 L
.70674 .04739 L
.70682 .04733 L
.70711 .04706 L
.70745 .04661 L
.70776 .04606 L
.70834 .04475 L
.70896 .04292 L
.71012 .03839 L
.71119 .03316 L
.71229 .02699 L
.71347 .01983 L
.71381 .01766 L
.71399 .01659 L
.71414 .0156 L
.71429 .01472 L
.71444 .01566 L
.71476 .01766 L
.71596 .02494 L
.7171 .03121 L
.71832 .03695 L
.71891 .03927 L
.71947 .04115 L
.72001 .04265 L
.72052 .04377 L
.72081 .04427 L
.72113 .04469 L
.72127 .04485 L
.72141 .04498 L
.72155 .04509 L
.72168 .04516 L
.72182 .04522 L
.72198 .04526 L
.72213 .04527 L
.72226 .04526 L
.72234 .04524 L
.72242 .04522 L
.72257 .04515 L
.72273 .04505 L
.72291 .0449 L
.7232 .04458 L
.72346 .0442 L
.72405 .04306 L
.72458 .04174 L
.72513 .04005 L
.72751 .0297 L
.72857 .02393 L
.72913 .02073 L
.72972 .01728 L
Mistroke
.72987 .01639 L
.73003 .01544 L
.73013 .0149 L
.73021 .01503 L
.7303 .01553 L
.73038 .016 L
.73099 .01953 L
.73219 .02616 L
.73336 .032 L
.73443 .03645 L
.73558 .04016 L
.73622 .04162 L
.73651 .04215 L
.73682 .04261 L
.73708 .04292 L
.73722 .04305 L
.73737 .04317 L
.73751 .04325 L
.73764 .04331 L
.73776 .04336 L
.73788 .04338 L
.73802 .04339 L
.73817 .04337 L
.7383 .04334 L
.73844 .04328 L
.73859 .04319 L
.73875 .04308 L
.73904 .04279 L
.73933 .04241 L
.73964 .0419 L
.74019 .04074 L
.74086 .03896 L
.74146 .03699 L
.744 .02568 L
.74513 .01968 L
.7457 .01656 L
.74585 .01571 L
.74594 .01523 L
.74602 .01479 L
.74618 .0155 L
.74632 .01629 L
.74763 .0233 L
.74883 .02921 L
.74999 .03409 L
.75063 .03634 L
.75122 .03813 L
.75177 .03948 L
.75228 .04045 L
.75255 .04087 L
.75284 .04123 L
Mistroke
.75313 .04151 L
.7533 .04163 L
.75345 .04171 L
.7536 .04177 L
.75368 .04179 L
.75376 .0418 L
.75391 .04181 L
.75405 .0418 L
.75414 .04178 L
.75422 .04175 L
.75437 .04169 L
.75453 .04159 L
.75471 .04145 L
.75501 .04114 L
.75533 .04071 L
.75591 .03967 L
.75651 .03824 L
.75708 .03659 L
.75815 .0328 L
.76036 .02268 L
.76097 .01957 L
.76131 .01784 L
.76162 .01619 L
.76177 .01544 L
.76192 .01477 L
.762 .01519 L
.76208 .01564 L
.76224 .01644 L
.7628 .01934 L
.7652 .03058 L
.76651 .03529 L
.7671 .03696 L
.76774 .03844 L
.76804 .03899 L
.76836 .03948 L
.76863 .03983 L
.76893 .04013 L
.7691 .04026 L
.76926 .04035 L
.76942 .04042 L
.7695 .04044 L
.76958 .04046 L
.76973 .04048 L
.76989 .04047 L
.77004 .04044 L
.77018 .0404 L
.77031 .04033 L
.77046 .04024 L
.77072 .04002 L
.77104 .03967 L
Mistroke
.77132 .03927 L
.77188 .03826 L
.77241 .03705 L
.77359 .0335 L
.77483 .02868 L
.776 .02342 L
.77706 .01826 L
.77735 .01686 L
.7775 .01612 L
.77765 .01533 L
.77779 .01478 L
.77794 .01553 L
.77821 .01686 L
.77944 .0228 L
.78165 .03199 L
.78225 .03395 L
.78287 .03571 L
.78341 .03697 L
.78399 .03803 L
.78432 .0385 L
.78461 .03884 L
.78475 .03897 L
.78491 .03909 L
.78506 .03918 L
.78519 .03925 L
.78535 .03931 L
.78543 .03933 L
.78552 .03935 L
.78562 .03935 L
.78571 .03935 L
.78579 .03934 L
.78588 .03933 L
.78603 .03928 L
.78611 .03925 L
.7862 .0392 L
.78651 .039 L
.78679 .03873 L
.7871 .03835 L
.78772 .03731 L
.7883 .03605 L
.78884 .03463 L
.79135 .02539 L
.79262 .01963 L
.79292 .0182 L
.79324 .01667 L
.79351 .01537 L
.79367 .0148 L
.79381 .01549 L
.79489 .02055 L
.79606 .0257 L
Mistroke
.79731 .03056 L
.7985 .03425 L
.79902 .03552 L
.79957 .03663 L
.79989 .03715 L
.80017 .03754 L
.80046 .03787 L
.80073 .0381 L
.80088 .0382 L
.80101 .03827 L
.80116 .03833 L
.80132 .03837 L
.80148 .03839 L
.80156 .03839 L
.80164 .03839 L
.80179 .03836 L
.80194 .03831 L
.80208 .03825 L
.80222 .03817 L
.80247 .03798 L
.80278 .03767 L
.80306 .03732 L
.80364 .03635 L
.80428 .03498 L
.80557 .03126 L
.80689 .02637 L
.80813 .02105 L
.80868 .0186 L
.80925 .01596 L
.8094 .0153 L
.80955 .01484 L
.80964 .01525 L
.80972 .01562 L
.80988 .01636 L
.81046 .019 L
.81165 .02416 L
.81291 .02904 L
.81408 .03276 L
.81517 .03537 L
.81575 .03636 L
.81608 .03679 L
.81638 .0371 L
.81663 .0373 L
.81678 .03739 L
.81691 .03746 L
.81705 .03751 L
.8172 .03755 L
.81734 .03757 L
.81747 .03757 L
.81761 .03755 L
Mistroke
.81777 .03751 L
.81785 .03748 L
.81794 .03744 L
.81809 .03736 L
.81839 .03714 L
.81867 .03686 L
.81934 .03593 L
.81997 .0347 L
.82113 .03168 L
.82236 .02751 L
.82351 .02293 L
.82458 .01835 L
.82489 .01697 L
.82518 .01568 L
.82533 .01503 L
.82548 .0151 L
.82557 .01549 L
.82566 .01587 L
.82582 .01658 L
.82716 .02237 L
.82834 .02701 L
.82959 .03118 L
.83073 .03409 L
.83138 .03531 L
.83168 .03576 L
.83199 .03615 L
.83226 .03641 L
.8324 .03653 L
.83255 .03664 L
.83269 .03672 L
.83281 .03677 L
.83294 .03682 L
.83306 .03685 L
.8332 .03687 L
.83335 .03687 L
.83347 .03686 L
.83361 .03683 L
.83376 .03677 L
.83392 .0367 L
.83421 .0365 L
.83452 .03622 L
.83485 .03583 L
.83543 .03491 L
.83613 .03346 L
.83676 .03185 L
.83919 .02349 L
.84032 .0188 L
.84089 .01636 L
.84105 .01568 L
.84113 .01531 L
Mistroke
.84121 .01496 L
.84137 .01514 L
.84151 .01576 L
.84282 .0213 L
.84403 .02599 L
.84519 .02992 L
.84583 .03174 L
.84643 .03319 L
.84698 .03429 L
.84749 .0351 L
.84776 .03544 L
.84805 .03575 L
.84834 .03599 L
.8485 .03609 L
.84865 .03617 L
.84881 .03622 L
.84889 .03625 L
.84897 .03626 L
.84912 .03628 L
.84926 .03627 L
.84935 .03626 L
.84943 .03625 L
.84958 .03621 L
.84967 .03617 L
.84975 .03614 L
.84993 .03604 L
.8502 .03583 L
.85051 .03553 L
.85112 .03468 L
.85168 .03367 L
.85228 .03232 L
.85337 .02927 L
.85578 .0204 L
.85637 .01797 L
.85669 .01662 L
.85699 .01534 L
.85708 .01498 L
.85717 .01481 L
.85726 .01522 L
.85735 .0156 L
.85768 .01698 L
.85832 .01964 L
.85955 .02443 L
.86071 .02845 L
.86184 .03167 L
.86289 .03388 L
.86343 .03471 L
.86371 .03504 L
.86401 .03534 L
.86418 .03547 L
Mistroke
.86434 .03557 L
.86449 .03565 L
.86457 .03568 L
.86465 .03571 L
.86479 .03575 L
.86493 .03577 L
.86508 .03578 L
.86523 .03576 L
.86539 .03573 L
.86546 .03571 L
.86555 .03567 L
.86585 .03551 L
.86602 .03539 L
.8662 .03523 L
.86652 .03488 L
.86716 .03396 L
.86775 .03284 L
.86893 .02987 L
.87003 .02637 L
.87132 .02161 L
.87195 .0191 L
.87253 .01672 L
.87267 .01613 L
.87282 .0155 L
.87297 .0149 L
.8731 .01507 L
.87325 .01568 L
.87339 .01626 L
.87371 .01757 L
.875 .02265 L
.87724 .03009 L
.8784 .03283 L
.87905 .03395 L
.87935 .03437 L
.87963 .03469 L
.87989 .03493 L
.88018 .03514 L
.88033 .03522 L
.88047 .03528 L
.88062 .03532 L
.88078 .03535 L
.88091 .03536 L
.88106 .03535 L
.88121 .03533 L
.88134 .03529 L
.88146 .03525 L
.88159 .03518 L
.88185 .03501 L
.88215 .03476 L
.88248 .03439 L
Mistroke
.88307 .03352 L
.88365 .03243 L
.88419 .0312 L
.88671 .0233 L
.88732 .02098 L
.88798 .01838 L
.88828 .01716 L
.8886 .01586 L
.88874 .01533 L
.88888 .01475 L
.88903 .0153 L
.88918 .01589 L
.89142 .02453 L
.89265 .02852 L
.8933 .03031 L
.89398 .03194 L
.89458 .03309 L
.8949 .0336 L
.89524 .03406 L
.89556 .0344 L
.89584 .03465 L
.89612 .03483 L
.89626 .0349 L
.89641 .03496 L
.89657 .035 L
.89671 .03502 L
.89679 .03502 L
.89687 .03502 L
.89696 .03501 L
.89705 .03499 L
.8972 .03496 L
.89733 .03491 L
.89749 .03483 L
.89765 .03474 L
.89793 .03452 L
.89818 .03426 L
.89877 .0335 L
.89941 .03237 L
.89999 .0311 L
.9013 .02752 L
.90362 .01923 L
.90426 .01672 L
.90458 .01544 L
.90467 .01509 L
.90476 .01472 L
.90485 .01506 L
.90493 .01538 L
.90613 .02011 L
.90735 .02456 L
.90863 .02864 L
Mistroke
.90973 .03143 L
.91036 .03266 L
.91094 .03357 L
.91151 .03421 L
.91179 .03444 L
.91196 .03454 L
.9121 .03462 L
.91224 .03467 L
.91237 .03471 L
.91251 .03473 L
.91266 .03475 L
.91279 .03474 L
.91292 .03472 L
.91304 .03469 L
.91317 .03465 L
.91333 .03458 L
.91348 .03449 L
.91377 .03428 L
.91407 .03399 L
.91441 .03358 L
.91501 .03265 L
.91557 .03156 L
.91685 .02832 L
.91805 .02448 L
.91912 .02059 L
.91969 .01842 L
.9203 .01604 L
.92046 .01539 L
.92062 .01478 L
.92076 .01519 L
.92091 .01579 L
.92148 .01802 L
.92273 .02271 L
.92496 .02971 L
.92609 .03223 L
.92674 .03327 L
.92703 .03364 L
.92735 .03397 L
.92752 .03412 L
.92768 .03424 L
.92784 .03434 L
.92799 .03441 L
.92813 .03447 L
.92827 .03451 L
.92841 .03453 L
.92857 .03454 L
.92873 .03453 L
.92882 .03451 L
.9289 .03449 L
.92907 .03444 L
Mistroke
.92925 .03435 L
.92958 .03413 L
.92988 .03386 L
.93046 .03314 L
.93108 .03212 L
.93219 .02965 L
.93338 .0262 L
.93469 .02167 L
.93528 .01946 L
.93591 .01706 L
.93616 .01605 L
.93631 .0155 L
.93644 .01498 L
.9366 .01506 L
.93674 .01562 L
.93702 .01672 L
.93954 .02584 L
.94071 .02928 L
.94135 .03084 L
.94195 .03206 L
.9425 .03297 L
.94301 .03362 L
.9433 .0339 L
.94357 .03411 L
.94371 .03419 L
.94386 .03427 L
.94395 .0343 L
.94402 .03433 L
.94418 .03437 L
.94432 .03439 L
.94446 .03439 L
.94461 .03438 L
.94477 .03435 L
.94485 .03433 L
.94493 .0343 L
.94509 .03423 L
.94539 .03404 L
.94567 .03381 L
.94597 .0335 L
.9465 .03277 L
.94712 .03168 L
.9477 .03044 L
.94901 .02686 L
.9502 .02292 L
.95145 .0183 L
.95197 .01631 L
.95212 .01573 L
.95226 .01519 L
.95238 .01472 L
.95252 .01525 L
Mistroke
.95312 .01759 L
.95369 .01972 L
.95604 .02771 L
.95669 .02947 L
.95738 .03109 L
.95803 .03233 L
.95863 .03322 L
.95892 .03356 L
.95924 .03386 L
.95956 .03409 L
.95974 .03418 L
.95982 .03421 L
.9599 .03424 L
.96005 .03428 L
.96021 .0343 L
.96035 .03431 L
.96049 .03429 L
.96065 .03426 L
.96079 .03422 L
.96096 .03415 L
.96111 .03406 L
.96139 .03386 L
.96168 .03359 L
.9622 .03295 L
.96277 .03204 L
.96338 .0308 L
.96573 .0241 L
.96703 .01939 L
.96767 .01697 L
.96795 .0159 L
.96809 .01534 L
.96825 .01474 L
.9684 .01529 L
.96855 .01586 L
.96884 .01696 L
.96947 .01936 L
.9708 .02415 L
.97197 .02783 L
.97322 .03099 L
.97402 .03251 L
.97476 .03349 L
.97511 .03383 L
.9753 .03397 L
.97549 .03409 L
.97567 .03417 L
.97576 .0342 L
.97586 .03423 L
.97595 .03425 L
.97603 .03427 L
.97611 .03427 L
Mistroke
.97619 .03428 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005_ooool3o`0000Cooooo0_l0000iooooo`?o0000>oooool2o`0003cooooo0ol0000ioooo
o`?o00001?ooool2o`0000Oooooo000Gooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000=oooool01Ol0003ooooooooooooooooo000003Wooooo00Co0000oooooooooooo0000>_oo
ool01Ol0003ooooooooooooooooo000003Wooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00006ooooo`003oooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000aooooo`Go00001Oooool00ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`00
03kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Kooooo000Gooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000>oooool0
0ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`0003kooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo000Gooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000=oooool4o`0003[ooooo00Co0000oooooooooooo
0000>_ooool4o`0003[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006oooo
o`005_ooool2o`0000Cooooo00Co0000oooooooooooo0000=oooool00ol0003oooooooooo`0koooo
o`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool0>_ooool2o`0000Cooooo00Co0000
oooooooooooo00001_ooool001Oooooo00?o0000ooooooooool00oooool2o`0003Sooooo1Ol0000j
ooooo`;o0000>oooool5o`0003Wooooo00?o0000ooooooooool00oooool2o`0000Oooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Boooooooo00003?l00003
ooooo`002_ooool2o`0000Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`01oooo
o`002Oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo007ooooo0009ooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo007ooooo0009ooooo`04o`000?ooooooooooo`0000Gooooo0_l00006oooo
o`05o`00ooooooooooooooooool00?l02?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool01Oooool2o`00o`Oooooo00?o003oooooooooool01Oooool2o`00o`?ooooo00Go
003oooooooooooooooooo`00o`07ooooo`04o`00ooooooooooooooooo`;o003o1oooool01Ol00?oo
oooooooooooooooo003o00Sooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00Wooooo00Co003ooooooooooooooooo0_l00?l01?oooooo0000ooooool0
0?l3ooooo`03o`00oooooooooooo00[ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l04?ooool01?l00?ooooooooooooooool2o`00o`?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool01Ol00?oo
oooooooooooooooo003o00Kooooo0ol00003ooooo`002Oooool01?l0003oooooooooool00005oooo
o`03o`000?oooooooooo00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0oooool0
0ol00?ooooooooooo`02o`00o`?ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`;o003o0_oo
ool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0_ooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00
o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`03
o`00oooooooooooo00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o00Coooooo`00
0?l00?oo003o0oooool01Ol00?oooooooooooooooooo003o00Sooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l7
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?l3ooooo`05o`00oooooooo
ooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00o`;ooooo0_l00?l3ooooo`05o`00
ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00;ooooo0_l00?l3oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`01oooo
o`002Oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00Wooooo0_l00?l2oooo
o`;o003o0_ooool2o`00o`Oooooo0_l00?l2ooooo`;o003o1_ooool2o`00o`?ooooo00Co003ooooo
oooooooooooo0_l00?l6ooooo`;o003o1oooool2o`00o`;ooooo00Go003oooooooooooooooooo`00
o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00o`Oo
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool01Oooool01Ol00?oooooooooooooooooo003o00Kooooo00?o0000ooooooooool00oooool0
1Ol00?oooooooooooooooooo003o00Sooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o0_ooool2o`00o`?ooooo00Co
003ooooooooooooooooo0_l00?l6ooooo`;o003o2?ooool01?l00?ooooooooooool00?l3ooooo`;o
003o0_ooool2o`00o`?ooooo0_l00?l3ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00o`;o
oooo0_l00?l4ooooo`03o`00oooooooooooo00Gooooo00?o0000ooooooooool00Oooool000[ooooo
0_l00006ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool00oooool01Ol00?oooooo
o`00oooooooo003o00;ooooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`02ooooo`;o
003o0_ooool01?l00?ooooooooooooooool2o`00o`;ooooo00Co003ooooooooooooooooo0ol00?l3
ooooo`03o`00oooooooooooo00;o003o1oooool2o`00o`?ooooo00?o003oooooooooool00_l00?l2
ooooo`;o003o0_ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooooooo`;o003o1ooo
ool01Ol00?oooooooooooooooooo003o00Sooooo00?o003oooooooooool01Oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00?o003oooooool000001Oooool01Ol00?oooooooooooooooooo003o
00Sooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`03
o`00oooooooooooo00;o003o0_ooool2o`00o`;ooooo0_l00?l3ooooo`;o003o1_ooool2o`00o`Ko
oooo00?o003oooooooooool00oooool02_l00?ooooooooooool00?ooooooo`00oooooooo003ooooo
ool00?l2ooooo`;o003o00?oooooo`00ool00?l00oooool2o`00o`;ooooo00Wo003oooooool00?oo
ooooo`00oooooooo003oooooool00?l02Oooool00ol0003oooooooooo`01ooooo`004_ooool00ol0
003oooooooooo`03ooooo`;o003o00Goooooo`00oooooooo003oooooo`03o`00o`?ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooo`00o`03ooooo`07o`00oooooooo003oooooool00?oooooo
o`00o`02ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00?ooooo00Go003o
ooooool00?ooooooo`00o`02ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o
00Gooooo00Go003oooooooooooooooooo`00o`02ooooo`;o003o0_ooool00ol00?ooooooo`00o`02
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?l3ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo003o00?o003o0oooool01Ol00?oooooo
oooooooooooo003o00Sooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooooooooooo
ooooo`;o003o0oooool00ol00?ooooooooooo`02o`00o`;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o0_ooool00ol00?ooooooo`00o`03
ooooo`03o`00oooooooo003o00Cooooo0ol00?l02_oooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?l5ooooo`;o003o0oooool00ol00?ooooooo`00o`03ooooo`09o`00oooooooooooo
ooooool00?ooooooo`00oooooooo003o00Cooooo00Go003oooooool00?ooooooo`00o`03ooooo`04
o`00ooooooooooooo`00o`Kooooo00?o0000ooooooooool00Oooool001;ooooo0_l00004ooooo`04
o`00ooooooooooooooooo`;o003o1oooool00ol00?ooooooooooo`02o`00o`;ooooo0_l00?l3oooo
o`04o`00ooooooooooooooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l01?oooooo003oo`00ool0
0?l3ooooo`03o`00oooooooooooo00?o003o00Koooooo`00oooooooo003oooooool00?l5ooooo`03
o`00oooooooo003o00?ooooo00?o003oooooooooool01?ooool01ol00?ooooooo`00oooooooo003o
ooooool00?l00oooool00ol00?ooooooooooo`02o`00o`_ooooo0_l00?l2ooooo`03o`00oooooooo
oooo00Kooooo00Co003ooooooooooooooooo0_l00?l2ooooo`06o`00oooooooo003oo`00oooooooo
003o0_ooool00ol00?ooooooooooo`0:ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o
00?ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo00Oo003oooooool00?ooooooo`00oooo
oooo003o00;ooooo0_l00?l6ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l00_l0
0?l2ooooo`03o`00oooooooo003o00?ooooo00Ko003oooooool00?ooooooo`00ooooool3o`00o`;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02o`00o`?ooooo0_l00?l7ooooo`05
o`00ooooooooooooooooool00?l00oooool2o`00o`;ooooo00?o003oooooooooool00oooool2o`00
00?ooooo000Booooo`03o`000?oooooooooo02Gooooo00Go003oooooooooooooooooo`00o`03oooo
o`;o003o0_ooool2o`00o`;ooooo00?o003oooooooooool00_ooool2o`00o`03ooooool00?oooooo
00;ooooo0ol00?l01ooooooo003ooooooooooooo003oooooool00?l00oooool02Ol00?ooooooo`00
oooooooo003oooooool00?ooooooo`00o`02ooooo`04o`00ooooooooooooooooo`;o003o0oooool0
1Ol00?oooooooooooooooooo003o00?ooooo0_l00?l3ooooo`03o`00oooooooooooo00Gooooo00Co
003ooooooooooooooooo0_l00?l00ooooooo003oooooo`02ooooo`04o`000?ooooooooooo`00o`;o
oooo00Go003oooooooooooooooooo`00o`07ooooo`;o003o0oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0_ooool02Ol00?ooooooo`00
oooooooo003oooooool00?ooooooo`00o`03ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool01?ooool2o`00o`;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo0_l00?l2ooooo`03o`00oooooooooooo02Kooooo00?o0000ooooooooool00Oooool0
01;ooooo00?o0000ooooooooool0?_ooool2o`00o`;ooooo0_l00?l3ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooool00?l00oooool01Ol00?oooooooooooooooooo003o00;ooooo0_l00?l2
ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l01ooo
ool01?l00?ooooooooooooooool2o`00o`03ooooool00?oooooo00;ooooo00?o0000ooooooooool0
0_ooool2o`00o`?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooooooo003o
00Gooooo00Oo003oooooooooooooooooo`00oooooooo003o00?ooooo00?o003oooooooooool00_l0
0?l2ooooo`?o003o0_ooool01?l00?ooooooooooooooool2o`00occooooo00?o0000ooooooooool0
0Oooool001;ooooo00?o0000ooooooooool0Aoooool00ol00?ooooooooooo`02o`00o`;ooooo00?o
003oooooooooool00oooool01ol00?oooooooooooooooooo003oooooool00?l01_ooool00ol00?oo
ooooo`00o`02ooooo`;o003o1_ooool2o`00o`Oooooo00?o003oooooooooool02?ooool00ol0003o
ooooooooo`02ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool01Oooool2o`00o`;o
oooo00?o003oooooooooool00_ooool2o`00o`?ooooo00?o003oooooooooool00_l00?l4ooooo`03
o`00oooooooo003o00?ooooo00?o003oooooooooool00_l00?l2ooooo`;o003o0_ooool2o`00odWo
oooo00?o0000ooooooooool00Oooool001;ooooo00?o0000ooooooooool0Boooool00ol00?oooooo
ooooo`02o`00o`?ooooo0_l00?l6ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo
003o00;ooooo0_l00?l2ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol00?oooooooooo
o`04ooooo`05o`00ooooooooooooooooool000000_ooool3o`00o`Cooooo00?o003oooooooooool0
1_ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooooooo`;o003o0oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool2
o`00odgooooo00?o0000ooooooooool00Oooool001;ooooo0_l0001Dooooo`;o003o0_ooool02ol0
0?oooooooooooooooooo003oooooool00?ooooooo`00oooooooo003o00Gooooo00?o003ooooooooo
ool00_l00?l2ooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooooooo003o0_ooool00ol0
0?ooooooooooo`02ooooo`04o`000?ooooooooooooooo`;o003o1?ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00;o003o0_ooool00ol00?ooooooo`00o`02ooooo`;o003o00Sooooo
o`00ooooooooooooo`00oooooooo003oooooo`;o003o0oooool00ol00?ooooooooooo`1Cooooo`;o
00000oooool001;ooooo00?o0000ooooooooool0Eoooool2o`00o`;ooooo00Go003oooooool00?oo
ooooo`00o`0:ooooo`;o003o0_ooool2o`00o`[ooooo00Co003ooooooooooooo003o1?ooool01Ol0
003ooooooooooooooooo003o00;ooooo00?o003oooooooooool02?ooool2o`00o`;ooooo0_l00?l2
ooooo`05o`00oooooooo003oooooool00?l00oooool00ol00?ooooooooooo`02o`00o`;ooooo00?o
003oooooooooool0FOooool00ol0003oooooooooo`01ooooo`004_ooool00ol0003oooooooooo`1K
ooooo`;o003o0_ooool01Ol00?ooooooo`00oooooooo003o00?ooooo00?o003oooooooooool00_l0
0?l3ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o1oooool00ol0003ooooo
ooooo`04ooooo`03o`00oooooooooooo00;o003o1_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooool00?l00oooool01Ol00?oooooooooooooooooo003o05ko
oooo00?o0000ooooooooool00Oooool001;ooooo00?o0000ooooooooool0HOooool01ol00?oooooo
o`00oooooooo003oooooool00?l00oooool00ol00?ooooooooooo`02o`00o`Oooooo0_l00?l00ooo
oooo003oooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool00_l00?l6oooo
o`03o`00oooooooooooo00;ooooo00Ko003ooooooooooooo003oooooool00?l4ooooo`;o003oH_oo
ool00ol0003oooooooooo`01ooooo`004_ooool00ol0003oooooooooo`1Oooooo`;o003o0_ooool0
1Ol00?ooooooo`00oooooooo003o00;ooooo00Co003ooooooooooooooooo0_l00?l7ooooo`;o003o
2Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00;o003o1oooool01?l00?oooooo
ooooool00?l3ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0HOooool00ol0003o
ooooooooo`01ooooo`004_ooool2o`00067ooooo00?o003oooooooooool00_ooool00ol00?oooooo
o`00o`02ooooo`;o003o0_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo003o00Oooooo
00?o0000ooooooooool02?ooool00ol00?ooooooooooo`05ooooo`08o`00ooooooooooooo`00oooo
oooo003oooooool00?l3ooooo`03o`00oooooooooooo00;o003oHOooool2o`0000?ooooo000Boooo
o`03o`000?oooooooooo06Gooooo00?o003oooooooooool00_ooool2o`00o`;ooooo0_l00?l:oooo
o`03o`00oooooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`08oooo
o`;o003o0_ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`1Vooooo`03o`00
0?oooooooooo007ooooo000Booooo`03o`000?oooooooooo06Cooooo00?o003oooooooooool00_oo
ool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o
1oooool00ol0003oooooooooo`04ooooo`03o`00oooooooo003o00Sooooo00?o003oooooooooool0
0oooool01?l00?ooooooooooooooool3o`00ofKooooo00?o0000ooooooooool00Oooool001;ooooo
00?o0000ooooooooool0I?ooool01?l00?ooooooooooool00?l3ooooo`05o`00oooooooooooooooo
ool00?l01oooool2o`00o`03ooooool00?oooooo00Kooooo00?o0000ooooooooool01?ooool01Ol0
0?ooooooo`00oooooooo003o00Kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo06Gooooo00?o0000ooooooooool00Oooool001;ooooo00?o0000oooo
ooooool0I?ooool01_l00?ooooooooooool00?ooooooo`00o`Cooooo0_l00?l6ooooo`03o`00oooo
oooo003o00Wooooo00?o0000ooooooooool01?ooool01Ol00?ooooooo`00oooooooo003o00Kooooo
0_l00?l2ooooo`05o`00ooooooooooooooooool00?l0J_ooool00ol0003oooooooooo`01ooooo`00
4_ooool00ol0003oooooooooo`1Xooooo`;o003o1?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooo003o00Wooooo00?o0000ooooooooool01_ooool00ol00?ooooooo`00o`07ooooo`04o`00
ooooooooooooo`00o`?ooooo00?o003oooooooooool0J?ooool00ol0003oooooooooo`01ooooo`00
4_ooool2o`0006[ooooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooo003o00Oooooo00?o0000ooooooooool03oooool2o`00o`;ooooo00Go003oooooool00?oo
ooooo`00o`1Yooooo`;o00000oooool001;ooooo00?o0000ooooooooool0JOooool00ol00?oooooo
o`00o`03ooooo`03o`00oooooooooooo00Cooooo00Go003oooooooooooooooooo`00o`07ooooo`03
o`000?oooooooooo00Gooooo0_l00?l8ooooo`;o003o0_ooool00ol00?ooooooo`00o`1/ooooo`03
o`000?oooooooooo007ooooo0009ooooo`?o00001_ooool00ol0003oooooooooo`1Xooooo`04o`00
ooooooooooooo`00o`?ooooo00?o003oooooooooool01?ooool01?l00?ooooooo`00ool00?l8oooo
o`03o`000?oooooooooo00Gooooo0_l00?l00ooooooo003oooooo`05ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool0J_ooool00ol0003oooooooooo`01ooooo`002?ooool01Ol0003o
oooooooooooooooo000000Gooooo00?o0000ooooooooool0J?ooool2o`00o`Cooooo0_l00?l6oooo
o`03o`00oooooooo003o00Wooooo00?o0000ooooooooool01Oooool2o`00o`03ooooool00?oooooo
00Gooooo0_l00?l2ooooo`04o`00ooooooooooooo`00of_ooooo00?o0000ooooooooool00Oooool0
00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Xooooo`;o003o1?ooool00ol0
0?ooooooooooo`05ooooo`04o`00oooooooo003oo`00o`Sooooo00?o0000ooooooooool01_ooool0
0ol00?ooooooo`00o`07ooooo`04o`00ooooooooooooo`00ofkooooo00?o0000ooooooooool00Ooo
ool000cooooo00?o0000ooooooooool00oooool2o`0006cooooo00Co003ooooooooooooo003o2_oo
ool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01Ooo
ool01?l00?ooooooooooool00?m/ooooo`?o00000oooool000Sooooo1?l00006ooooo`03o`000?oo
oooooooo06_ooooo00?o003oooooooooool00_l00?lBooooo`03o`000?oooooooooo00oooooo0_l0
0?l2ooooo`03o`00oooooooooooo06cooooo00?o0000ooooooooool00Oooool000Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1/ooooo`04o`00ooooooooooooo`00o`Kooooo00?o
003oooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool0L?ooool00ol0003oooooooooo`01ooooo`002?ooool5o`0000Gooooo00?o0000
ooooooooool0K?ooool01?l00?ooooooo`00ool00?l6ooooo`03o`00oooooooooooo00Wooooo00?o
0000ooooooooool02?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo073ooooo00?o
0000ooooooooool00Oooool001;ooooo00?o0000ooooooooool0K_ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`06
ooooo`;o003oKoooool00ol0003oooooooooo`01ooooo`004_ooool2o`0006gooooo00?o003ooooo
ool00?l04oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Kooooo0_l00?m^oooo
o`;o00000oooool001;ooooo00?o0000ooooooooool0K?ooool01?l00?ooooooo`00ool00?lBoooo
o`03o`000?oooooooooo00oooooo00Co003oooooool00?oo003oKoooool00ol0003oooooooooo`01
ooooo`004_ooool00ol0003oooooooooo`1/ooooo`04o`00ooooooooooooo`00o`Kooooo00?o003o
ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo073ooooo00?o0000
ooooooooool00Oooool001;ooooo00?o0000ooooooooool0K?ooool01?l00?ooooooooooool00?l6
ooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo073ooooo00?o0000ooooooooool00Oooool001;ooooo00?o0000oooo
ooooool0KOooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00Wooooo00?o0000oooo
ooooool02?ooool00ol00?ooooooooooo`04ooooo`04o`00oooooooo003oo`00ofoooooo00?o0000
ooooooooool00Oooool001;ooooo0_l0001^ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool02Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Kooooo0_l00?m^oooo
o`;o00000oooool001;ooooo00?o0000ooooooooool0K?ooool2o`00o`03ooooool00?oooooo017o
oooo00?o0000ooooooooool03oooool01?l00?ooooooo`00ool00?m_ooooo`03o`000?oooooooooo
007ooooo000Booooo`03o`000?oooooooooo06cooooo00Co003ooooooooooooo003o1_ooool00ol0
0?ooooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o003oooooool00?l0L?ooool00ol0
003oooooooooo`01ooooo`004_ooool00ol0003oooooooooo`1/ooooo`;o003o00?oooooo`00oooo
ool01Oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooo`00o`1`ooooo`03o`000?oooooooooo007ooooo000Booooo`03o`00
0?oooooooooo06oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`09ooooo`03o`00
0?oooooooooo00Sooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1`ooooo`03o`00
0?oooooooooo007ooooo000Booooo`;o0000Moooool00ol00?ooooooooooo`09ooooo`03o`000?oo
oooooooo00Sooooo00?o003oooooooooool0M_ooool2o`0000?ooooo000Booooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`1gooooo`03o`000?oooooo
oooo007ooooo000Booooo`03o`000?oooooooooo06oooooo00?o003oooooooooool04?ooool00ol0
003oooooooooo`0?ooooo`03o`00oooooooooooo073ooooo00?o0000ooooooooool00Oooool001;o
oooo00?o0000ooooooooool0Koooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Wo
oooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo073o
oooo00?o0000ooooooooool00Oooool001;ooooo00?o0000ooooooooool0L?ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo073ooooo00?o0000ooooooooool00Oooool001;ooooo00?o
0000ooooooooool0M_ooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o
003oooooooooool0Moooool00ol0003oooooooooo`01ooooo`004_ooool2o`0008?ooooo00?o0000
ooooooooool02?ooool00ol00?ooooooooooo`1fooooo`;o00000oooool001;ooooo00?o0000oooo
ooooool0L?ooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o003ooooo
ooooool0L?ooool00ol0003oooooooooo`01ooooo`000oooool3o`0000Cooooo0_l00006ooooo`03
o`000?oooooooooo073ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`09ooooo`03
o`000?oooooooooo00oooooo00?o003oooooooooool0L?ooool00ol0003oooooooooo`01ooooo`00
1?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooooooo
ool0L?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o0000oooooooo
ool02?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo073ooooo00?o0000oooooooo
ool00Oooool000Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`03
o`000?oooooooooo073ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`09ooooo`03
o`000?oooooooooo00Sooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1`ooooo`03
o`000?oooooooooo007ooooo0004ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00001Oooool2o`0007Oooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`08ooooo`03
o`00oooooooooooo07Gooooo0ol00003ooooo`001?ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000Gooooo00?o0000ooooooooool0L?ooool00ol00?ooooooooooo`0?ooooo`03
o`000?oooooooooo00kooooo00?o003oooooooooool0LOooool00ol0003oooooooooo`01ooooo`00
0oooool2o`0000Cooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`1`ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03
o`00oooooooooooo077ooooo00?o0000ooooooooool00Oooool000Cooooo00?o0000ooooooooool0
0oooool2o`0000Kooooo00?o0000ooooooooool0L?ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo077ooooo00?o0000ooooooooool00Oooool001;ooooo00?o0000ooooooooool0L?oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool02?oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo077ooooo00?o0000ooooooooool00Ooo
ool001;ooooo0_l0001gooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol00?ooooooooooo`1eooooo`;o00000oooool001;ooooo00?o0000ooooooooool0P_ooool00ol0
003oooooooooo`09ooooo`03o`00oooooooooooo07Kooooo00?o0000ooooooooool00Oooool001;o
oooo00?o0000ooooooooool0L?ooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooooooo00ko
oooo00?o003oooooooooool0LOooool00ol0003oooooooooo`01ooooo`004_ooool00ol0003ooooo
ooooo`1`ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0LOooool00ol0003ooooo
ooooo`01ooooo`004_ooool00ol0003oooooooooo`1`ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool0LOooool00ol0003oooooooooo`01ooooo`004_ooool2o`0007Kooooo00?o003o
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo07Gooooo0_l00003
ooooo`004_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo00Wooooo00?o003ooooo
ooooool0M_ooool00ol0003oooooooooo`01ooooo`004_ooool00ol0003oooooooooo`1`ooooo`03
o`00oooooooooooo00oooooo00?o0000ooooooooool03_ooool00ol00?ooooooooooo`1aooooo`03
o`000?oooooooooo007ooooo000Booooo`03o`000?oooooooooo073ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o003oooooooooool0
LOooool00ol0003oooooooooo`01ooooo`004_ooool00ol0003oooooooooo`1`ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool0LOooool00ol0003oooooooooo`01ooooo`004_ooool2
o`00077ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1`ooooo`;o00000oooool0
01;ooooo00?o0000ooooooooool0MOooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo
00Wooooo00?o003oooooooooool0M_ooool00ol0003oooooooooo`01ooooo`004_ooool00ol0003o
ooooooooo`1`ooooo`03o`00oooooooooooo00oooooo00?o0000ooooooooool03_ooool00ol00?oo
ooooooooo`1aooooo`03o`000?oooooooooo007ooooo000Booooo`03o`000?oooooooooo073ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo00kooooo
00?o003oooooooooool0LOooool00ol0003oooooooooo`01ooooo`004_ooool00ol0003ooooooooo
o`1`ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02_ooool00ol0003ooooooooo
o`09ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0LOooool00ol0003ooooooooo
o`01ooooo`004_ooool00ol0003oooooooooo`1`ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool0LOooool00ol0003oooooooooo`01ooooo`004_ooool2o`0007Kooooo00?o003ooooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo07Gooooo0_l00003oooo
o`004_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo00Wooooo00?o003ooooooooo
ool0M_ooool00ol0003oooooooooo`01ooooo`000oooool3o`0000?ooooo0ol00006ooooo`03o`00
0?oooooooooo073ooooo00?o003oooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`00
oooooooooooo077ooooo00?o0000ooooooooool00Oooool000Cooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L?ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo077ooooo00?o0000ooooooooool00Oooool000Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo073ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`1aooooo`03o`000?oooooooooo007ooooo0004
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool2o`0007Kooooo00?o003o
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo07Cooooo0ol00003
ooooo`001?ooool01?l0003oooooooooooooool4o`0000Kooooo00?o0000ooooooooool0P_ooool0
0ol0003oooooooooo`09ooooo`03o`00oooooooooooo07Kooooo00?o0000ooooooooool00Oooool0
00?ooooo0_l00003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0L?ooool00ol0
0?ooooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o003oooooooooool0LOooool00ol0
003oooooooooo`01ooooo`001?ooool01?l0003oooooooooooooool5o`0000Gooooo00?o0000oooo
ooooool0L?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00[ooooo00?o0000oooo
ooooool03_ooool00ol00?ooooooooooo`1aooooo`03o`000?oooooooooo007ooooo000Booooo`03
o`000?oooooooooo073ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1aooooo`03
o`000?oooooooooo007ooooo000Booooo`;o0000LOooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo073ooooo0_l00003ooooo`004_ooool00ol0003oooooooooo`1eooooo`03o`00oooo
oooooooo00[ooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`1fooooo`03o`000?oo
oooooooo007ooooo000Booooo`03o`000?oooooooooo073ooooo00?o003oooooooooool03oooool0
0ol0003oooooooooo`0>ooooo`03o`00oooooooooooo077ooooo00?o0000ooooooooool00Oooool0
01;ooooo00?o0000ooooooooool0L?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00[ooooo00?o0000ooooooooool03_ooool00ol00?ooooooooooo`1aooooo`03o`000?oooooooooo
007ooooo000Booooo`03o`000?oooooooooo073ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`1aooooo`03o`000?oooooooooo007ooooo000Booooo`;o0000LOooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo073ooooo0_l00003ooooo`004_ooool00ol0003ooooooooo
o`1eooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol00?oooooooooo
o`1fooooo`03o`000?oooooooooo007ooooo000Booooo`03o`000?oooooooooo08;ooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`01ooooo`004_ooool00ol0003oooooooooo`1`oooo
o`03o`00oooooooooooo00oooooo00?o0000ooooooooool03_ooool00ol00?ooooooooooo`1aoooo
o`03o`000?oooooooooo007ooooo000Booooo`03o`000?oooooooooo073ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`1aooooo`03o`000?oooooooooo007ooooo000Booooo`03o`00
0?oooooooooo073ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1aooooo`03o`00
0?oooooooooo007ooooo000Booooo`;o0000M_ooool00ol00?ooooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo00?o003oooooooooool0MOooool2o`0000?ooooo000Booooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`1fooooo`03o`000?oooooo
oooo007ooooo000Booooo`03o`000?oooooooooo077ooooo00?o003oooooooooool03_ooool00ol0
003oooooooooo`0>ooooo`03o`00oooooooooooo077ooooo00?o0000ooooooooool00Oooool001;o
oooo00?o0000ooooooooool0LOooool01Ol00?oooooooooooooooooo003o00cooooo00?o0000oooo
ooooool02Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo077ooooo00?o0000oooo
ooooool00Oooool001;ooooo00?o0000ooooooooool0LOooool01Ol00?oooooooooooooooooo003o
00cooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
077ooooo00?o0000ooooooooool00Oooool001;ooooo0_l0001booooo`05o`00oooooooooooooooo
ool00?l03?ooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool0L?ooool2o`0000?ooooo000Booooo`03o`000?oooooooooo08;ooooo00?o0000oooooooo
ool02Oooool00ol00?ooooooooooo`1fooooo`03o`000?oooooooooo007ooooo0002ooooo`Go0000
0oooool2o`0000Kooooo00?o0000ooooooooool0LOooool00ol00?ooooooooooo`0>ooooo`03o`00
0?oooooooooo00kooooo00?o003oooooooooool0LOooool00ol0003oooooooooo`01ooooo`000ooo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooooooo
ool0LOooool01Ol00?oooooooooooooooooo003o00cooooo00?o0000ooooooooool03_ooool00ol0
0?ooooooooooo`1aooooo`03o`000?oooooooooo007ooooo0004ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`1aooooo`05o`00oooooooooooo
ooooool00?l03?ooool00ol0003oooooooooo`09ooooo`05o`00ooooooooooooooooool00?l0M?oo
ool00ol0003oooooooooo`01ooooo`001Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o
0000ooooooooool00oooool2o`0007;ooooo00Go003oooooooooooooooooo`00o`0<ooooo`03o`00
0?oooooooooo00Wooooo00Go003oooooooooooooooooo`00o`1booooo`?o00000oooool000;ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool0MOooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o003ooooo
ooooool0MOooool00ol0003oooooooooo`01ooooo`000_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool00Oooool000?ooooo0ol00004ooooo`;o00001_ooool00ol0
003oooooooooo`1aooooo`05o`00ooooooooooooooooool00?l03?ooool00ol0003oooooooooo`0=
ooooo`03o`00oooooooooooo07;ooooo00?o0000ooooooooool00Oooool001;ooooo00?o0000oooo
ooooool0LOooool01Ol00?oooooooooooooooooo003o00cooooo00?o0000ooooooooool02_ooool0
1?l00?ooooooooooool00?mdooooo`03o`000?oooooooooo007ooooo000Booooo`;o0000L_ooool0
1?l00?ooooooooooool00?l=ooooo`03o`000?oooooooooo00[ooooo00Co003ooooooooooooo003o
Loooool2o`0000?ooooo000Booooo`03o`000?oooooooooo07Cooooo00?o003oooooooooool02ooo
ool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo07Gooooo00?o0000ooooooooool00Ooo
ool001;ooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0:ooooo`03o`00oooooooo
oooo07Gooooo00?o0000ooooooooool00Oooool001;ooooo00?o0000ooooooooool0LOooool00ol0
0?ooooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool0L_ooool00ol0
003oooooooooo`01ooooo`004_ooool00ol0003oooooooooo`1aooooo`04o`00ooooooooooooo`00
o`gooooo00?o0000ooooooooool02_ooool01?l00?ooooooooooool00?mdooooo`03o`000?oooooo
oooo007ooooo000Booooo`;o0000L_ooool01?l00?ooooooooooool00?l=ooooo`03o`000?oooooo
oooo00[ooooo00Co003ooooooooooooo003oLoooool2o`0000?ooooo000Booooo`03o`000?oooooo
oooo077ooooo00Co003ooooooooooooo003o3Oooool00ol0003oooooooooo`0:ooooo`04o`00oooo
ooooooooo`00ogCooooo00?o0000ooooooooool00Oooool001;ooooo00?o0000ooooooooool0P_oo
ool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo07Gooooo00?o0000ooooooooool00Ooo
ool001;ooooo00?o0000ooooooooool0LOooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooo
oooo00gooooo00?o003oooooooooool0L_ooool00ol0003oooooooooo`01ooooo`004_ooool00ol0
003oooooooooo`1aooooo`04o`00ooooooooooooo`00o`gooooo00?o0000ooooooooool03Oooool0
0ol00?ooooooooooo`1booooo`03o`000?oooooooooo007ooooo000Booooo`03o`000?oooooooooo
077ooooo00Co003ooooooooooooo003o3Oooool00ol0003oooooooooo`0:ooooo`04o`00oooooooo
ooooo`00ogCooooo00?o0000ooooooooool00Oooool001;ooooo0_l0001booooo`04o`00oooooooo
ooooo`00o`gooooo00?o0000ooooooooool02_ooool01?l00?ooooooooooool00?mcooooo`;o0000
0oooool001;ooooo00?o0000ooooooooool0M?ooool00ol00?ooooooooooo`0;ooooo`03o`000?oo
oooooooo00[ooooo00?o003oooooooooool0MOooool00ol0003oooooooooo`01ooooo`004_ooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool00Oooool0
01;ooooo00?o0000ooooooooool0LOooool01?l00?ooooooooooool00?l=ooooo`03o`000?oooooo
oooo00gooooo00?o003oooooooooool0L_ooool00ol0003oooooooooo`01ooooo`004_ooool00ol0
003oooooooooo`1aooooo`04o`00ooooooooooooo`00o`gooooo00?o0000ooooooooool02_ooool0
1?l00?ooooooooooool00?mdooooo`03o`000?oooooooooo007ooooo000Booooo`;o0000L_ooool0
1?l00?ooooooooooool00?l=ooooo`03o`000?oooooooooo00[ooooo00Co003ooooooooooooo003o
Loooool2o`0000?ooooo000Booooo`03o`000?oooooooooo07Cooooo00?o003oooooooooool02ooo
ool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo07Gooooo00?o0000ooooooooool00Ooo
ool000;ooooo1Ol00002ooooo`?o00001_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooo
oooo00[ooooo00?o003oooooooooool0MOooool00ol0003oooooooooo`01ooooo`000oooool01_l0
003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1aooooo`03o`00oooooooooooo00kooooo00?o0000ooooooooool03Oooool00ol00?oooooooooo
o`1booooo`03o`000?oooooooooo007ooooo0004ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1aooooo`04o`00ooooooooooooo`00o`gooooo00?o
0000ooooooooool02_ooool01?l00?ooooooooooool00?mdooooo`03o`000?oooooooooo007ooooo
0005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool2o`0007;ooooo00Co
003ooooooooooooo003o3Oooool00ol0003oooooooooo`0:ooooo`04o`00ooooooooooooo`00og;o
oooo0ol00003ooooo`000_ooool01_l0003ooooooooooooooooo0000ooooo`Co00001_ooool00ol0
003oooooooooo`1aooooo`04o`00ooooooooooooo`00o`gooooo00?o0000ooooooooool02_ooool0
0ol00?ooooooooooo`1eooooo`03o`000?oooooooooo007ooooo0002ooooo`07o`000?oooooooooo
ooooool0003oooooo`000009ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool02_oo
ool00ol00?ooooooooooo`1eooooo`03o`000?oooooooooo007ooooo0003ooooo`?o00000_ooool5
o`0000Gooooo00?o0000ooooooooool0LOooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooo
oooo00gooooo00?o003oooooooooool0L_ooool00ol0003oooooooooo`01ooooo`004_ooool00ol0
003oooooooooo`1aooooo`04o`00ooooooooooooo`00o`gooooo00?o0000ooooooooool03Oooool0
0ol00?ooooooooooo`1booooo`03o`000?oooooooooo007ooooo000Booooo`;o0000L_ooool01?l0
0?ooooooooooool00?l=ooooo`03o`000?oooooooooo00[ooooo00Co003ooooooooooooo003oLooo
ool2o`0000?ooooo000Booooo`03o`000?oooooooooo077ooooo00Co003ooooooooooooo003o3Ooo
ool00ol0003oooooooooo`0:ooooo`04o`00ooooooooooooo`00ogCooooo00?o0000ooooooooool0
0Oooool001;ooooo00?o0000ooooooooool0M?ooool00ol00?ooooooooooo`0;ooooo`03o`000?oo
oooooooo00[ooooo00?o003oooooooooool0MOooool00ol0003oooooooooo`01ooooo`004_ooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool0L_ooool0
0ol0003oooooooooo`01ooooo`004_ooool00ol0003oooooooooo`1booooo`03o`00oooooooo003o
00gooooo00?o0000ooooooooool03Oooool00ol00?ooooooooooo`1booooo`03o`000?oooooooooo
007ooooo000Booooo`;o0000Loooool00ol00?ooooooo`00o`0=ooooo`03o`000?oooooooooo00[o
oooo00Co003ooooooooooooo003oLoooool2o`0000?ooooo000Booooo`03o`000?oooooooooo07;o
oooo00?o003oooooool00?l03Oooool00ol0003oooooooooo`0:ooooo`04o`00ooooooooooooo`00
ogCooooo00?o0000ooooooooool00Oooool001;ooooo00?o0000ooooooooool0M?ooool00ol00?oo
ooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool0M?ooool00ol0003o
ooooooooo`01ooooo`004_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo00_ooooo
00?o003oooooooooool0M?ooool00ol0003oooooooooo`01ooooo`004_ooool00ol0003ooooooooo
o`1booooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool03?ooool00ol00?oooooooooo
o`1cooooo`03o`000?oooooooooo007ooooo000Booooo`03o`000?oooooooooo07;ooooo00?o003o
ooooool00?l03Oooool00ol0003oooooooooo`0;ooooo`;o003oMOooool00ol0003oooooooooo`01
ooooo`004_ooool2o`0007?ooooo00?o003oooooool00?l03Oooool00ol0003oooooooooo`0;oooo
o`;o003oM?ooool2o`0000?ooooo000Booooo`03o`000?oooooooooo07;ooooo0_l00?l>ooooo`03
o`000?oooooooooo00_ooooo00?o003oooooooooool0M?ooool00ol0003oooooooooo`01ooooo`00
4_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool0
M?ooool00ol0003oooooooooo`01ooooo`004_ooool00ol0003oooooooooo`1booooo`03o`00oooo
oooooooo00gooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`1cooooo`03o`000?oo
oooooooo007ooooo000Booooo`03o`000?oooooooooo07;ooooo0_l00?l>ooooo`03o`000?oooooo
oooo00cooooo00?o003oooooooooool0Loooool00ol0003oooooooooo`01ooooo`004_ooool2o`00
07?ooooo0_l00?l>ooooo`03o`000?oooooooooo00_ooooo0_l00?mdooooo`;o00000oooool001;o
oooo00?o0000ooooooooool0L_ooool2o`00o`kooooo00?o0000ooooooooool02oooool2o`00ogGo
oooo00?o0000ooooooooool00Oooool000?ooooo0ol00004ooooo`;o00001_ooool00ol0003ooooo
ooooo`1cooooo`03o`00oooooooooooo00cooooo00?o0000ooooooooool02oooool00ol00?oooooo
ooooo`1dooooo`03o`000?oooooooooo007ooooo0002ooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo08;ooooo00?o0000oooooooo
ool03?ooool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo007ooooo0006ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`;o
003o3_ooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo07?ooooo00?o0000oooooooo
ool00Oooool000Cooooo0_l00003ooooo`04o`000?ooooooooooo`0000Gooooo0_l0001cooooo`;o
003o3_ooool00ol0003oooooooooo`0;ooooo`;o003oLoooool3o`0000?ooooo0006ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`22ooooo`03
o`000?oooooooooo08;ooooo00?o0000ooooooooool00Oooool000;ooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0P_ooool00ol0
003oooooooooo`22ooooo`03o`000?oooooooooo007ooooo0003ooooo`?o00001?ooool2o`0000Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`01ooooo`004_ooooooo`0000co0000
0oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-11.9245, -3.11951, \
0.0789178, 0.192068}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Phase plot of DTFT as a function of index k", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(g2 = 
        Plot[Arg[
            X\[Theta]\  /. \ \[Theta] \[Rule] \ 2  \[Pi]\ f/fs], {f, \(-fs\)/
              2, fs/2}, \ PlotStyle \[Rule] {Blue, \ Dashing[{ .01}]}, \ 
          PlotRange \[Rule] All, PlotPoints \[Rule] 200];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.307985 0.0969315 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01719 -12 -4.5 ]
[-0.0125 .01719 0 4.5 ]
[-0.0125 .11412 -12 -4.5 ]
[-0.0125 .11412 0 4.5 ]
[-0.0125 .21105 -12 -4.5 ]
[-0.0125 .21105 0 4.5 ]
[-0.0125 .30798 -6 -4.5 ]
[-0.0125 .30798 0 4.5 ]
[-0.0125 .40492 -6 -4.5 ]
[-0.0125 .40492 0 4.5 ]
[-0.0125 .50185 -6 -4.5 ]
[-0.0125 .50185 0 4.5 ]
[-0.0125 .59878 -6 -4.5 ]
[-0.0125 .59878 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01719 m
.00625 .01719 L
s
[(-3)] -0.0125 .01719 1 0 Mshowa
0 .11412 m
.00625 .11412 L
s
[(-2)] -0.0125 .11412 1 0 Mshowa
0 .21105 m
.00625 .21105 L
s
[(-1)] -0.0125 .21105 1 0 Mshowa
0 .30798 m
.00625 .30798 L
s
[(0)] -0.0125 .30798 1 0 Mshowa
0 .40492 m
.00625 .40492 L
s
[(1)] -0.0125 .40492 1 0 Mshowa
0 .50185 m
.00625 .50185 L
s
[(2)] -0.0125 .50185 1 0 Mshowa
0 .59878 m
.00625 .59878 L
s
[(3)] -0.0125 .59878 1 0 Mshowa
.125 Mabswid
0 .03658 m
.00375 .03658 L
s
0 .05596 m
.00375 .05596 L
s
0 .07535 m
.00375 .07535 L
s
0 .09474 m
.00375 .09474 L
s
0 .13351 m
.00375 .13351 L
s
0 .15289 m
.00375 .15289 L
s
0 .17228 m
.00375 .17228 L
s
0 .19167 m
.00375 .19167 L
s
0 .23044 m
.00375 .23044 L
s
0 .24983 m
.00375 .24983 L
s
0 .26921 m
.00375 .26921 L
s
0 .2886 m
.00375 .2886 L
s
0 .32737 m
.00375 .32737 L
s
0 .34676 m
.00375 .34676 L
s
0 .36614 m
.00375 .36614 L
s
0 .38553 m
.00375 .38553 L
s
0 .4243 m
.00375 .4243 L
s
0 .44369 m
.00375 .44369 L
s
0 .46308 m
.00375 .46308 L
s
0 .48246 m
.00375 .48246 L
s
0 .52123 m
.00375 .52123 L
s
0 .54062 m
.00375 .54062 L
s
0 .56001 m
.00375 .56001 L
s
0 .57939 m
.00375 .57939 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01719 m
1 .01719 L
s
.99375 .11412 m
1 .11412 L
s
.99375 .21105 m
1 .21105 L
s
.99375 .30798 m
1 .30798 L
s
.99375 .40492 m
1 .40492 L
s
.99375 .50185 m
1 .50185 L
s
.99375 .59878 m
1 .59878 L
s
.125 Mabswid
.99625 .03658 m
1 .03658 L
s
.99625 .05596 m
1 .05596 L
s
.99625 .07535 m
1 .07535 L
s
.99625 .09474 m
1 .09474 L
s
.99625 .13351 m
1 .13351 L
s
.99625 .15289 m
1 .15289 L
s
.99625 .17228 m
1 .17228 L
s
.99625 .19167 m
1 .19167 L
s
.99625 .23044 m
1 .23044 L
s
.99625 .24983 m
1 .24983 L
s
.99625 .26921 m
1 .26921 L
s
.99625 .2886 m
1 .2886 L
s
.99625 .32737 m
1 .32737 L
s
.99625 .34676 m
1 .34676 L
s
.99625 .36614 m
1 .36614 L
s
.99625 .38553 m
1 .38553 L
s
.99625 .4243 m
1 .4243 L
s
.99625 .44369 m
1 .44369 L
s
.99625 .46308 m
1 .46308 L
s
.99625 .48246 m
1 .48246 L
s
.99625 .52123 m
1 .52123 L
s
.99625 .54062 m
1 .54062 L
s
.99625 .56001 m
1 .56001 L
s
.99625 .57939 m
1 .57939 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30798 m
1 .30798 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .30798 m
.02608 .26522 L
.02847 .22013 L
.02964 .19804 L
.03089 .17441 L
.03126 .16743 L
.03145 .164 L
.03153 .16249 L
.03161 .16083 L
.03177 .46248 L
.03185 .4609 L
.03193 .45943 L
.03227 .453 L
.03355 .42884 L
.03823 .34068 L
.0406 .29587 L
.0432 .24695 L
.0444 .22428 L
.04568 .20012 L
.0463 .18838 L
.04689 .17733 L
.04715 .1725 L
.04742 .1674 L
.04756 .16473 L
.04771 .46632 L
.04786 .46366 L
.04799 .46117 L
.05268 .3727 L
.05767 .27865 L
.06016 .23159 L
.06126 .2109 L
.06185 .1999 L
.06247 .18805 L
.06277 .18251 L
.06308 .17668 L
.06334 .1717 L
.06349 .16888 L
.06363 .47078 L
.06377 .46811 L
.0639 .46559 L
.06415 .46088 L
.06472 .45031 L
.0671 .40542 L
.07174 .31795 L
.07409 .27365 L
.07667 .22491 L
.07785 .2026 L
.07851 .1903 L
.07883 .18424 L
.07898 .18129 L
Mistroke
.07913 .17862 L
.07927 .17592 L
.0794 .4779 L
.07955 .47521 L
.0797 .47231 L
.08033 .46051 L
.08142 .43984 L
.08637 .34648 L
.08884 .29996 L
.09114 .25658 L
.09336 .21482 L
.09399 .2028 L
.0946 .19143 L
.09486 .18647 L
.095 .18376 L
.09514 .18121 L
.09529 .48299 L
.09536 .48154 L
.09545 .47997 L
.09573 .47464 L
.1007 .38098 L
.10548 .29076 L
.10789 .24528 L
.10895 .22546 L
.11008 .204 L
.11039 .19818 L
.11072 .19203 L
.11085 .18949 L
.111 .18677 L
.11116 .48831 L
.1113 .48552 L
.11245 .46384 L
.11498 .41617 L
.11997 .3222 L
.12246 .2752 L
.12356 .25452 L
.12477 .23168 L
.12532 .22121 L
.12592 .20992 L
.1262 .20473 L
.12649 .19926 L
.12674 .19459 L
.12688 .19194 L
.12701 .494 L
.12715 .4912 L
.12732 .48816 L
.12761 .48264 L
.12816 .47231 L
.12939 .44912 L
.13432 .35616 L
Mistroke
.13677 .30993 L
.13907 .26665 L
.14127 .22517 L
.1419 .21323 L
.14221 .20734 L
.1425 .20188 L
.14264 .19934 L
.14276 .19695 L
.14291 .49871 L
.14304 .49621 L
.14363 .4851 L
.14828 .3974 L
.15323 .30413 L
.1557 .25767 L
.1569 .23498 L
.158 .21431 L
.15826 .20933 L
.15854 .20405 L
.15869 .20129 L
.15877 .50424 L
.15885 .50277 L
.15913 .49741 L
.16021 .47713 L
.16258 .43245 L
.16725 .34445 L
.16962 .29975 L
.17087 .27611 L
.17221 .25088 L
.17288 .23828 L
.17351 .2264 L
.17407 .21573 L
.17423 .21281 L
.17439 .20972 L
.17453 .20708 L
.17469 .50869 L
.17484 .50579 L
.17499 .50304 L
.17526 .49787 L
.17588 .48625 L
.17699 .46527 L
.18161 .37827 L
.18418 .32968 L
.18652 .28571 L
.18769 .26362 L
.18895 .23978 L
.18953 .22882 L
.18985 .22284 L
.19015 .21726 L
.19028 .21481 L
.1904 .2125 L
Mistroke
.19054 .51435 L
.19067 .51192 L
.19124 .50111 L
.19588 .41381 L
.2008 .32093 L
.20325 .27477 L
.20445 .25218 L
.20555 .23151 L
.20581 .2266 L
.20609 .22136 L
.20617 .21981 L
.20624 .21835 L
.20639 .52013 L
.20653 .51757 L
.20667 .5148 L
.20774 .49461 L
.21011 .45005 L
.21505 .35687 L
.21751 .31047 L
.21981 .26714 L
.22095 .24576 L
.22151 .23524 L
.22175 .23061 L
.22202 .2255 L
.22217 .2227 L
.22231 .5246 L
.22246 .52183 L
.22262 .51884 L
.22326 .50667 L
.22439 .48537 L
.22935 .39189 L
.23183 .34525 L
.23413 .30185 L
.23635 .25999 L
.23699 .24794 L
.2373 .24202 L
.23759 .23656 L
.23786 .2316 L
.23799 .2291 L
.23813 .53086 L
.23828 .5281 L
.23844 .52514 L
.23872 .51978 L
.2437 .42599 L
.24849 .33565 L
.25091 .29006 L
.25197 .27021 L
.2531 .24876 L
.25341 .24291 L
.25358 .23972 L
Mistroke
.25374 .23674 L
.25388 .2342 L
.25402 .53599 L
.2541 .53444 L
.25418 .53297 L
.25433 .53021 L
.25548 .5085 L
.25801 .46082 L
.26264 .37362 L
.26498 .3295 L
.26622 .30608 L
.26756 .28086 L
.26818 .26913 L
.26884 .2568 L
.2694 .24627 L
.26955 .24339 L
.26963 .2418 L
.26971 .24031 L
.26987 .54192 L
.27001 .53928 L
.2723 .49606 L
.27695 .40856 L
.2793 .36422 L
.28189 .31549 L
.28307 .29315 L
.28434 .26917 L
.28496 .25755 L
.28526 .25183 L
.2854 .24932 L
.28555 .24654 L
.28568 .24407 L
.2858 .54626 L
.28593 .54381 L
.28607 .54117 L
.28664 .5304 L
.2916 .43703 L
.29637 .34711 L
.29878 .30183 L
.29982 .28208 L
.30038 .27167 L
.30096 .26064 L
.30126 .25498 L
.30135 .25343 L
.30143 .25177 L
.30152 .25019 L
.30159 .55327 L
.30174 .55058 L
.30189 .54765 L
.30218 .5423 L
.30332 .52069 L
Mistroke
.30585 .47313 L
.31075 .38079 L
.31302 .33808 L
.31547 .2919 L
.31613 .27958 L
.31682 .26656 L
.3171 .2612 L
.31726 .25825 L
.31741 .25545 L
.31749 .55839 L
.31758 .55667 L
.31774 .55366 L
.31806 .54778 L
.32049 .50197 L
.32541 .40934 L
.32785 .36334 L
.33014 .32016 L
.33121 .30006 L
.33234 .27891 L
.33292 .26782 L
.33309 .26479 L
.33317 .26312 L
.33326 .26155 L
.33334 .5646 L
.33342 .563 L
.33357 .56022 L
.3347 .53896 L
.33963 .44605 L
.34439 .35659 L
.34677 .31165 L
.34782 .292 L
.34837 .28163 L
.34867 .27594 L
.34896 .27059 L
.34911 .26762 L
.3492 .26595 L
.34928 .56894 L
.34943 .56622 L
.34958 .56336 L
.35016 .55246 L
.3513 .53096 L
.35382 .48355 L
.35841 .39726 L
.36097 .34919 L
.36329 .30543 L
.36385 .29486 L
.36445 .28365 L
.36476 .27781 L
.36485 .2762 L
.36494 .27448 L
Mistroke
.36502 .27285 L
.3651 .57588 L
.36525 .5731 L
.36541 .57006 L
.36571 .56452 L
.36799 .52157 L
.37289 .42946 L
.37761 .34081 L
.37885 .31753 L
.3795 .30527 L
.38019 .29232 L
.38048 .28685 L
.38064 .28384 L
.38079 .28098 L
.38088 .27937 L
.38097 .58214 L
.38105 .58054 L
.38113 .57906 L
.38145 .57305 L
.38262 .55115 L
.38735 .46224 L
.3919 .3768 L
.39443 .32936 L
.39554 .30858 L
.39612 .29759 L
.39644 .29155 L
.3966 .28858 L
.39675 .28584 L
.39689 .58767 L
.39704 .58481 L
.39736 .5788 L
.39792 .56829 L
.39902 .54775 L
.40141 .50287 L
.40598 .41723 L
.40852 .36962 L
.41084 .32611 L
.41199 .3046 L
.4123 .29871 L
.41247 .29548 L
.41256 .2939 L
.41264 .29244 L
.41279 .59411 L
.41287 .59262 L
.41295 .59104 L
.41324 .58567 L
.41552 .54299 L
.4201 .45722 L
.42265 .40948 L
.42498 .36601 L
Mistroke
.42613 .34442 L
.42674 .33304 L
.42739 .32095 L
.42796 .31042 L
.42811 .30753 L
.42828 .30442 L
.42843 .30149 L
.42858 .60332 L
.42871 .60085 L
.42883 .59855 L
.42911 .59334 L
.42967 .58284 L
.43439 .49497 L
.4394 .40175 L
.44422 .31214 L
.44886 .22616 L
.4538 .13503 L
.45626 .08984 L
.45746 .0678 L
.45856 .04771 L
.4591 .0378 L
.45969 .02701 L
.45996 .02207 L
.46011 .01937 L
.46025 .01683 L
.46038 .31897 L
.46052 .3164 L
.46076 .31192 L
.46313 .26881 L
.46808 .17924 L
.47055 .13503 L
.47286 .09418 L
.474 .07409 L
.47507 .05521 L
.47567 .04482 L
.47583 .04198 L
.476 .03897 L
.47615 .0364 L
.47624 .33946 L
.47632 .3381 L
.47745 .31856 L
.48212 .23957 L
.48709 .16049 L
.48957 .12393 L
.49078 .10709 L
.49135 .09938 L
.49161 .09605 L
.49175 .09418 L
.49188 .09244 L
.49201 .09075 L
Mistroke
.49215 .39347 L
.4923 .39156 L
.49243 .38983 L
.49303 .38232 L
.49411 .36921 L
.49649 .34273 L
.50129 .29559 L
.50349 .27352 L
.50474 .25999 L
.50591 .2465 L
.50706 .23255 L
.50737 .2286 L
.50755 .22642 L
.50771 .22438 L
.50784 .22262 L
.50799 .52525 L
.50807 .52416 L
.50815 .52313 L
.5083 .5212 L
.51083 .48624 L
.51547 .41554 L
.51782 .37739 L
.5204 .33416 L
.52159 .31402 L
.52224 .30284 L
.52286 .29217 L
.52343 .28225 L
.52359 .27952 L
.52368 .27802 L
.52376 .27661 L
.52392 .57839 L
.52406 .5759 L
.52516 .55676 L
.52981 .47443 L
.53476 .38542 L
.53723 .34066 L
.53843 .31874 L
.539 .30834 L
.53925 .30377 L
.5394 .30117 L
.53953 .29873 L
.53966 .29641 L
.53979 .59842 L
.53994 .59574 L
.54007 .59329 L
.54067 .58246 L
.54174 .56276 L
.54411 .51927 L
.5489 .43116 L
.5535 .34607 L
Mistroke
.5584 .25523 L
.56311 .16755 L
.56552 .12275 L
.56812 .0742 L
.56934 .05141 L
.57001 .03896 L
.57064 .02731 L
.57091 .02222 L
.57117 .01738 L
.57131 .01472 L
.57147 .31633 L
.57161 .31369 L
.57174 .31125 L
.57295 .28862 L
.57768 .20021 L
.58223 .11513 L
.58476 .06785 L
.58586 .04713 L
.58645 .03616 L
.58677 .03013 L
.58693 .02717 L
.58707 .02444 L
.58722 .02175 L
.58737 .32343 L
.58752 .32057 L
.58769 .31743 L
.58825 .30694 L
.58934 .28644 L
.59174 .24162 L
.5966 .15049 L
.59883 .10853 L
.60127 .06274 L
.60191 .05072 L
.60227 .04413 L
.6026 .03792 L
.60291 .03211 L
.60299 .03052 L
.60308 .02884 L
.60316 .0274 L
.60324 .33035 L
.60339 .32762 L
.60354 .32468 L
.60382 .3194 L
.60625 .27391 L
.61124 .18021 L
.61374 .1333 L
.61605 .08991 L
.6172 .06818 L
.61829 .04778 L
.61855 .04279 L
Mistroke
.61883 .03754 L
.61898 .03478 L
.61906 .33775 L
.61914 .3363 L
.61942 .33102 L
.62067 .30754 L
.62538 .219 L
.62778 .17383 L
.63039 .12488 L
.63161 .10195 L
.6329 .07768 L
.634 .05696 L
.6343 .05128 L
.63447 .04815 L
.63463 .04518 L
.63477 .04243 L
.63486 .04087 L
.63493 .34395 L
.63507 .3414 L
.63521 .33869 L
.64023 .24421 L
.64507 .15316 L
.6473 .11135 L
.64856 .08763 L
.64917 .07606 L
.64973 .06553 L
.65002 .06013 L
.65033 .05427 L
.65047 .05158 L
.65062 .04873 L
.65075 .0463 L
.6509 .34814 L
.65098 .34658 L
.65106 .34509 L
.65121 .34231 L
.65154 .33603 L
.65214 .32469 L
.65469 .27684 L
.65929 .19019 L
.66186 .14183 L
.66419 .09796 L
.66536 .07601 L
.66597 .06446 L
.6663 .05814 L
.66647 .05506 L
.66662 .05225 L
.66676 .35412 L
.66689 .35161 L
.66719 .34607 L
.66781 .33433 L
Mistroke
.66891 .31368 L
.67353 .22669 L
.67586 .1827 L
.67844 .13412 L
.67962 .11201 L
.68088 .08816 L
.68147 .07719 L
.68178 .07121 L
.68208 .06564 L
.68233 .06088 L
.68248 .05821 L
.6826 .3603 L
.68275 .35764 L
.6829 .35475 L
.68318 .34951 L
.68811 .25661 L
.69286 .16715 L
.69525 .12221 L
.69629 .10256 L
.69743 .08113 L
.69773 .07544 L
.69805 .06938 L
.69821 .06644 L
.69835 .06367 L
.69849 .3657 L
.69863 .36301 L
.69977 .3415 L
.70229 .29405 L
.70724 .20082 L
.70971 .15436 L
.71201 .11103 L
.71314 .08961 L
.7137 .07907 L
.71395 .07444 L
.71408 .07198 L
.71422 .06933 L
.71437 .37105 L
.71451 .36842 L
.71481 .36265 L
.71546 .35048 L
.71659 .32919 L
.72156 .23564 L
.72403 .18894 L
.72634 .14552 L
.72856 .1036 L
.7292 .09153 L
.72952 .0856 L
.72981 .08014 L
.72995 .07757 L
.73007 .07517 L
Mistroke
.73021 .37719 L
.73035 .37444 L
.73094 .36337 L
.73563 .27506 L
.74061 .18118 L
.7431 .13423 L
.7442 .11357 L
.74478 .10259 L
.74541 .09074 L
.7457 .08522 L
.74586 .08221 L
.74601 .07941 L
.74614 .38153 L
.74627 .37896 L
.74656 .37353 L
.74764 .3531 L
.75002 .30826 L
.75502 .21406 L
.75753 .16686 L
.75863 .14613 L
.75984 .1233 L
.7604 .11275 L
.761 .10141 L
.76129 .09592 L
.76157 .0907 L
.76169 .08844 L
.76182 .08602 L
.76196 .38789 L
.76209 .38543 L
.76447 .3405 L
.76949 .24598 L
.772 .19854 L
.77432 .1549 L
.77658 .11228 L
.77713 .10193 L
.77743 .09622 L
.77758 .09342 L
.77772 .09082 L
.7778 .39386 L
.77788 .39229 L
.77806 .38897 L
.77837 .38316 L
.77897 .37178 L
.78352 .28597 L
.78837 .19457 L
.7906 .15257 L
.79186 .12876 L
.79248 .11716 L
.79304 .10662 L
.79333 .10118 L
Mistroke
.79348 .09832 L
.79356 .09675 L
.79364 .09529 L
.79378 .39716 L
.79393 .39424 L
.79421 .38911 L
.79546 .36558 L
.798 .31761 L
.80268 .22935 L
.80506 .18445 L
.80632 .16074 L
.80766 .13551 L
.80833 .12282 L
.80866 .1166 L
.80897 .11089 L
.80924 .10567 L
.80938 .10305 L
.80954 .40469 L
.80969 .4018 L
.80985 .3987 L
.81015 .39312 L
.81246 .34963 L
.81745 .25547 L
.81995 .20833 L
.82226 .16476 L
.82342 .14291 L
.82451 .12242 L
.82506 .11213 L
.82521 .10931 L
.82536 .10635 L
.8255 .40834 L
.82564 .40557 L
.82689 .38202 L
.83179 .28968 L
.83651 .20078 L
.83775 .17743 L
.83909 .15215 L
.8397 .14055 L
.84035 .12829 L
.84091 .11781 L
.84106 .11494 L
.84114 .11336 L
.84122 .11187 L
.84138 .41348 L
.84152 .41083 L
.84614 .32375 L
.85105 .2311 L
.85349 .1851 L
.85469 .16257 L
.85578 .14189 L
Mistroke
.85634 .13148 L
.85685 .1218 L
.85698 .11929 L
.85711 .11691 L
.85725 .4187 L
.85739 .41621 L
.85797 .40515 L
.86033 .36064 L
.86497 .27325 L
.86732 .229 L
.8699 .18028 L
.87108 .158 L
.87173 .14572 L
.87235 .13405 L
.87263 .12881 L
.87278 .12594 L
.87293 .12323 L
.87301 .12169 L
.8731 .42454 L
.87325 .42163 L
.87355 .41595 L
.87465 .39528 L
.8796 .302 L
.88206 .25552 L
.88436 .21216 L
.88657 .17046 L
.88721 .15845 L
.88781 .14708 L
.88836 .13687 L
.8885 .13407 L
.88866 .1311 L
.8888 .12857 L
.88894 .43029 L
.88909 .42752 L
.88923 .42494 L
.88954 .4191 L
.89016 .40732 L
.89128 .38626 L
.8938 .33883 L
.89851 .25 L
.90091 .20468 L
.90218 .18083 L
.90352 .15559 L
.90409 .14472 L
.90441 .13873 L
.90457 .13577 L
.90471 .13304 L
.90479 .43601 L
.90488 .43436 L
.90507 .43086 L
Mistroke
.90539 .42475 L
.90603 .41277 L
.90834 .36915 L
.91336 .27443 L
.91589 .22685 L
.91821 .18315 L
.91938 .16103 L
.91995 .15023 L
.9202 .14552 L
.92047 .14041 L
.92062 .13763 L
.92076 .43958 L
.92089 .43713 L
.92102 .43453 L
.92161 .42341 L
.92286 .39985 L
.92743 .31384 L
.92996 .26602 L
.93228 .22225 L
.93343 .20065 L
.93468 .17707 L
.93525 .16629 L
.93586 .1548 L
.93616 .14921 L
.9363 .14647 L
.93644 .14395 L
.93656 .44617 L
.93669 .44375 L
.93696 .43863 L
.94154 .35231 L
.94641 .26042 L
.94866 .21806 L
.94984 .19571 L
.9511 .17197 L
.95173 .16005 L
.95191 .15678 L
.95209 .15326 L
.95218 .15164 L
.95227 .14994 L
.95235 .14848 L
.95243 .45141 L
.95251 .44985 L
.95259 .44837 L
.95274 .4456 L
.95307 .43939 L
.95366 .42821 L
.95609 .38246 L
.96073 .29501 L
.96308 .25072 L
.96566 .20199 L
Mistroke
.96684 .17969 L
.9675 .16739 L
.96782 .16134 L
.96797 .15839 L
.96812 .15572 L
.96826 .45754 L
.96839 .455 L
.96869 .44942 L
.96932 .43761 L
.97041 .41694 L
.97507 .32918 L
.97619 .30799 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005_ooool3o`0000Cooooo0_l0000iooooo`?o0000>oooool2o`0003cooooo0ol0000ioooo
o`?o00001?ooool2o`0000Oooooo000Gooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000=oooool01Ol0003ooooooooooooooooo000003Wooooo00Co0000oooooooooooo0000>_oo
ool01Ol0003ooooooooooooooooo000003Wooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00006ooooo`003oooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000aooooo`Go00001Oooool00ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`00
03kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Kooooo000Gooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000>oooool0
0ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`0003kooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo000Gooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000=oooool4o`0003[ooooo00Co0000oooooooooooo
0000>_ooool4o`0003[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006oooo
o`005_ooool2o`0000Cooooo00Co0000oooooooooooo0000=oooool00ol0003oooooooooo`0koooo
o`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool0>_ooool2o`0000Cooooo00Co0000
oooooooooooo00001_ooool001Oooooo00?o0000ooooooooool00oooool2o`0003Sooooo1Ol0000j
ooooo`;o0000>oooool5o`0003Wooooo00?o0000ooooooooool00oooool2o`0000Oooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Aoooooooo00003Ol00003
ooooo`004Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo007ooooo0009ooooo`?o
00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool0?Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`01ooooo`002?ooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo007o
oooo0002ooooo`Go00001Oooool00ol0003oooooooooo`02ooooo`?o0000N?ooool00ol00?oooooo
ooooo`08ooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool0KOooool3o`0000?ooooo
000:ooooo`;o00001Oooool00ol0003oooooooooo`1hooooo`03o`00oooooooooooo00Sooooo00?o
0000ooooooooool04?ooool00ol00?ooooooooooo`1_ooooo`03o`000?oooooooooo007ooooo000<
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0N?ooool00ol00?ooooooooooo`08
ooooo`03o`000?oooooooooo00oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1[
ooooo`03o`000?oooooooooo007ooooo0008ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`23ooooo`03o`000?oooooooooo013ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo06Oooooo00?o0000ooooooooool00Oooool000Wooooo0ol00005
ooooo`03o`000?oooooooooo07Sooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0?
ooooo`;o003o1oooool00ol00?ooooooooooo`1Wooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo07Sooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0?oooo
o`;o003o0oooool01Ol00?oooooooooooooooooo003o06Wooooo00?o0000ooooooooool00Oooool0
017ooooo0_l0001iooooo`05o`00ooooooooooooooooool00?l01_ooool00ol0003oooooooooo`0?
ooooo`;o003o0oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo06;ooooo0_l00003
ooooo`004Oooool00ol0003oooooooooo`1hooooo`05o`00ooooooooooooooooool00?l01_ooool0
0ol0003oooooooooo`0?ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo06?ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool0O?ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo01?ooooo0_l00?l3
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`1Oooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo07cooooo00?o003oooooooooool01?ooool0
0ol0003oooooooooo`0@ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo0_l00?l3ooooo`03o`00oooooooooooo05[ooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool0Moooool2o`00o`?ooooo00?o003oooooooooool01?oo
ool00ol0003oooooooooo`0?ooooo`;o003o1oooool01Ol00?oooooooooooooooooo003o00?ooooo
0_l00?l3ooooo`05o`00ooooooooooooooooool00?l0F?ooool00ol0003oooooooooo`01ooooo`00
4Oooool2o`0007Sooooo0_l00?l3ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool0
3oooool2o`00o`;ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool0EOooool2o`0000?ooooo000Aooooo`03
o`000?oooooooooo07Oooooo0_l00?l3ooooo`03o`00oooooooooooo00Cooooo00?o0000oooooooo
ool03oooool01?l00?ooooooooooooooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`08
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`1Booooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo07cooooo00?o003oooooooooool01?ooool0
0ol0003oooooooooo`0Cooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`1@ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07cooooo
00?o003oooooooooool01?ooool00ol0003oooooooooo`0@ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l7ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`1>ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo07Oooooo0_l00?l3ooooo`03o`00oooooooooooo00Cooooo00?o0000oooo
ooooool03oooool2o`00o`Kooooo0_l00?l3ooooo`04o`00ooooooooooooooooo`;o003o0_ooool2
o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool0BOooool00ol0003oooooooooo`01ooooo`004Oooool2o`0007Sooooo0_l00?l3
ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool03oooool2o`00o`;ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l2ooooo`;o003o0ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o04Kooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1gooooo`;o003o
0oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00oooooo0_l00?l2ooooo`;o003o
0_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00;o003o0oooool00ol00?oooooo
ooooo`05ooooo`04o`00ooooooooooooooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o
04?ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Moooool2o`00o`;o
oooo00?o003oooooooooool01Oooool00ol0003oooooooooo`0?ooooo`04o`00oooooooooooooooo
o`;o003o0_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`11ooooo`03o`000?oooooooooo007o
oooo000Aooooo`03o`000?oooooooooo07_ooooo0_l00?l6ooooo`03o`000?oooooooooo013ooooo
00?o003oooooooooool00_l00?l2ooooo`;o003o0oooool01?l00?ooooooooooooooool2o`00o`Oo
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0?oooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`1gooooo`;o003o0oooool01Ol00?oooooooooooooo
oooo003o00;ooooo00?o0000ooooooooool03_ooool00ol00?ooooooo`00o`06ooooo`;o003o0ooo
ool01?l00?ooooooooooooooool2o`00o`;ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo03Sooooo00?o0000
ooooooooool00Oooool0017ooooo0_l0001hooooo`;o003o0oooool01Ol00?oooooooooooooooooo
003o00;ooooo00?o0000ooooooooool03_ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0_ooool2o`00o`;ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0gooooo`;o00000oooool0017ooooo00?o0000ooooooooool0Moooool2o`00o`;ooooo
00?o003oooooooooool00_ooool01?l00?ooooooooooool0000@ooooo`03o`00oooooooo003o00;o
oooo0_l00?l6ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00_l00?l2ooooo`03
o`00oooooooooooo00Kooooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0=?oo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1gooooo`;o003o0_ooool0
0ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00013ooooo00?o003oooooooooool00_oo
ool2o`00o`;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`;o003o0_oo
ool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0_ooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`?ooooo00Go003ooooooooo
ooooooooo`00o`0booooo`03o`000?oooooooooo007ooooo0008ooooo`Go00001?ooool00ol0003o
ooooooooo`1kooooo`;o003o0oooool01?l00?ooooooooooool0000Booooo`03o`00oooooooooooo
00;o003o0_ooool2o`00o`;ooooo0_l00?l3ooooo`03o`00oooooooooooo00Gooooo0_l00?l3oooo
o`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02o`00o`?ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o02kooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`1looooo`05o`00ooooooooooooooooool00?l00_ooool00ol0
003oooooooooo`0@ooooo`05o`00ooooooooooooooooool00?l00_ooool2o`00o`;ooooo0_l00?l3
ooooo`;o003o0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o0oooool0
1?l00?ooooooooooooooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00
ooooooooooooooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool0;?ooool00ol0003oooooooooo`01ooooo`000_ooool5o`0000?ooooo00?o0000oooooooo
ool01?ooool3o`0007Oooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol0
003oooooooooo`0>ooooo`03o`00oooooooo003o00Oooooo00?o003oooooooooool00_l00?l2oooo
o`03o`00oooooooo003o00;ooooo0_l00?l2ooooo`04o`00ooooooooooooooooo`;o003o0oooool0
1Ol00?oooooooooooooooooo003o00?ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l0
0oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l0:?ooool3o`0000?ooooo000;ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0Moooool2o`00o`;ooooo0_l00?l3ooooo`04o`00ooooooooooooo`00013ooooo00Oo003ooooo
ool00?ooooooo`00oooooooo003o00?ooooo00Co003ooooooooooooo003o1Oooool00ol00?oooooo
ooooo`02o`00o`;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l01?ooool00ol00?ooooooooooo`0Sooooo`03o`000?oooooooooo007ooooo0008
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1fooooo`03o`00oooo
oooo003o00;ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool0000@ooooo`07o`00
ooooooooooooooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool01Oooool2o`00o`;ooooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Co003ooooo
oooooooooooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l08Oooool00ol0003oooooooooo`01oooo
o`002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0Noooool2o`00
o`?ooooo00Co003ooooooooooooo00005?ooool00ol00?ooooooo`00o`02ooooo`;o003o0oooool0
1?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00o`?ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02o`00o`?ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`03o`00oooooooooooo00;o003o0oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o027ooooo00?o0000oooo
ooooool00Oooool000Wooooo0ol00005ooooo`03o`000?oooooooooo07_ooooo0_l00?l3ooooo`04
o`00ooooooooooooo`0001;ooooo00Go003oooooooooooooooooo`00o`02ooooo`;o003o0_ooool2
o`00o`;ooooo00?o003oooooool00?l01oooool00ol00?ooooooooooo`02o`00o`?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00;ooooo0_l00?l3ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_l00?l3ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`0Kooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000Moooool00ol00?oooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol0003oooooooooo`0>ooooo`03
o`00oooooooo003o00Oooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooo003o00;o
oooo0_l00?l3ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00o`?ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02o`00o`?ooooo00Co003ooooooooooooooooo0_l00?l3oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo0_l00003ooooo`004Ooo
ool00ol0003oooooooooo`1fooooo`03o`00oooooooo003o00;ooooo0_l00?l3ooooo`04o`00oooo
ooooooooo`00013ooooo00Go003oooooool00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00
o`Gooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_l00?l3ooooo`04o`00ooooooooooooooooo`;o003o0oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o01Wooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool0M_ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00;ooooo00Co003ooooo
oooooooo00004?ooool02Ol00?oooooooooooooooooo003oooooool00?ooooooo`00o`0:ooooo`05
o`00oooooooo003oooooool00?l00_ooool2o`00o`Oooooo00Co003ooooooooooooooooo0_l00?l2
ooooo`04o`00ooooooooooooooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooo
oooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0G
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07Kooooo00?o003ooooo
ool00?l00_ooool01?l00?ooooooooooooooool2o`00o`;ooooo00?o0000ooooooooool03_ooool0
2Ol00?oooooooooooooooooo003oooooool00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00
o`Gooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02o`00o`;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00o`?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo07_ooooo0_l00?l2ooooo`05o`00ooooooooooooooooool000004_oo
ool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`02ooooo`;o003o0_ooool00ol0
0?ooooooo`00o`07ooooo`03o`00oooooooooooo00;o003o0_ooool00ol00?ooooooooooo`03oooo
o`05o`00ooooooooooooooooool00?l00_ooool2o`00o`;ooooo0_l00?l4ooooo`03o`00oooooooo
oooo00;o003o0_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05
o`00ooooooooooooooooool00?l04?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`1fooooo`03o`00oooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool00ol0
003oooooooooo`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l00_ooool2o`00
o`;ooooo00Go003oooooool00?ooooooo`00o`05ooooo`03o`00oooooooooooo00;o003o0_ooool2
o`00o`;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`02o`00o`;ooooo00?o003o
ooooooooool00_ooool2o`00o`?ooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooo
oooooooo003o00Sooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooooooooooooooo
o`;o003o0oooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o
0000Moooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00;o003o0_ooool00ol0003o
ooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l01Oooool01?l00?ooooooooooool00?l3
ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooooooo00;ooooo0_l00?l3ooooo`04o`00
ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0_ooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`05ooooo`;o00000oooool0017ooooo00?o
0000ooooooooool0M_ooool01Ol00?ooooooo`00oooooooo003o00Gooooo00Co003ooooooooooooo
00003oooool02_l00?ooooooooooool00?ooooooo`00oooooooo003oooooool00?l:ooooo`05o`00
oooooooo003oooooool00?l00_ooool00ol00?ooooooooooo`06ooooo`06o`00ooooooooooooo`00
oooooooo003o0_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`04
o`00ooooooooooooooooo`;o003o0_ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l02?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool01_oo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`06ooooo`03o`00oooooooo
oooo06gooooo00Go003oooooool00?ooooooo`00o`04ooooo`;o003o0_ooool00ol0003ooooooooo
o`0=ooooo`03o`00oooooooooooo00;ooooo00Go003oooooool00?ooooooo`00o`05ooooo`04o`00
ooooooooooooo`00o`Gooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo
00;ooooo00Ko003ooooooooooooo003oooooool00?l2ooooo`05o`00ooooooooooooooooool00?l0
1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00o`?ooooo
00?o003oooooooooool01Oooool2o`00o`;ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool0
0?l00oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00Kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01_ooool01Ol00?oo
oooooooooooooooo003o06oooooo00?o003oooooool00?l00_ooool01Ol00?oooooooooooooooooo
000001;ooooo00go003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003o00;ooooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`02ooooo`;o003o0_ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;o003o0_ooool01?l00?oooooooooooooo
ool2o`00o`Cooooo00?o003oooooooooool00_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`;o003o1oooool01Ol00?oooooooooooooooooo003o00Sooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool02_ooool01Ol00?oooooooooooooooooo003o
06gooooo00Co003ooooooooooooo003o0oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooo
oooo00?ooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00Go003oooooool00?oo
ooooo`00o`05ooooo`03o`00oooooooooooo00;o003o0_ooool01ol00?oooooooooooooooooo003o
ooooool00?l00oooool00ol00?ooooooooooo`02o`00o`;ooooo00Oo003oooooooooooooooooo`00
oooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool2o`00o`?ooooo00?o003ooooooooo
ool01_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?l2
ooooo`;o003o1oooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`;o00001oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo06Gooooo00?o003ooooo
ool00?l00oooool00ol00?ooooooooooo`02o`00o`;ooooo00?o0000ooooooooool03Oooool01?l0
0?ooooooooooool00?l7ooooo`05o`00oooooooo003oooooool00?l00_ooool02Ol00?ooooooo`00
oooooooo003oooooool00?ooooooo`00o`04ooooo`;o003o0_ooool2o`00o`;ooooo00Oo003ooooo
ooooooooooooo`00oooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool00ol00?oooooo
o`00o`03ooooo`03o`00oooooooooooo00;o003o0_ooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool2o`00o`;ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l01oooool2
o`0000?ooooo000Aooooo`03o`000?oooooooooo00Kooooo00Go003oooooooooooooooooo`00o`08
ooooo`03o`00oooooooooooo063ooooo00Oo003oooooool00?ooooooo`00oooooooo003o00?ooooo
00Co003ooooooooooooo00003oooool02?l00?ooooooooooool00?ooooooo`00oooooooo003o0ooo
ool00ol00?ooooooo`00o`06ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`05ooooo`03
o`00oooooooooooo00;o003o0_ooool01Ol00?ooooooo`00oooooooo003o00Gooooo00?o003ooooo
ooooool00_l00?l2ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`07ooooo`;o003o0oooool01Ol00?oooooo
oooooooooooo003o00Sooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
1_ooool01Ol00?oooooooooooooooooo003o00Oooooo0_l00?l3ooooo`03o`00oooooooooooo05co
oooo00Go003oooooool00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`0000oooooo00?o003o
ooooooooool00_ooool01Ol00?ooooooo`00oooooooo003o00Gooooo00?o003oooooooooool01?oo
ool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`05ooooo`08o`00oooooooooooo
o`00oooooooo003oooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Ko003ooooooooooooo
003oooooool00?l2ooooo`04o`00ooooooooooooooooo`;o003o0oooool01?l00?ooooooooooool0
0?l4ooooo`;o003o0_ooool2o`00o`;ooooo00?o003oooooooooool00_ooool01?l00?oooooooooo
ooooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Ko
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01Oooool2o`00o`?ooooo
00Go003oooooooooooooooooo`00o`08ooooo`03o`00oooooooooooo063ooooo00?o003oooooool0
0?l00_ooool2o`00o`;ooooo00?o0000ooooooooool04Oooool03_l00?ooooooooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003o1_ooool02Ol00?ooooooo`00oooooooo
003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00?ooooo00Go003oooooool00?oo
ooooo`00o`02ooooo`04o`00ooooooooooooooooo`;o003o1?ooool00ol00?ooooooooooo`02o`00
o`;ooooo0_l00?l2ooooo`;o003o0oooool01?l00?ooooooooooooooool2o`00o`;ooooo0_l00?l2
ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooooooo0_l00?l7ooooo`05o`00oooo
ooooooooooooool00?l02?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`05ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`1Nooooo`03o`00oooooooo003o00;o
oooo00Go003oooooooooooooooooo`00000Booooo`0?o`00ooooooooooooooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003oooooool00?l01Oooool0
1Ol00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool00oooool01Ol00?oooooooooo
oooooooo003o00;ooooo0_l00?l2ooooo`;o003o0_ooool00ol00?ooooooo`00o`02ooooo`;o003o
0_ooool01?l00?ooooooooooooooool2o`00o`;ooooo0_l00?l8ooooo`03o`00oooooooooooo00;o
003o0oooool01?l00?ooooooooooooooool2o`00o`;ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`06ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00002oooool01Ol00?oo
oooooooooooooooo003o00?ooooo0_l00?l7ooooo`05o`00ooooooooooooooooool00?l0EOooool0
1?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00;o003o0_ooool00ol0003ooooooooo
o`0=ooooo`04o`00ooooooooooooo`00o`Oooooo00Oo003oooooool00?ooooooo`00oooooooo003o
00;ooooo00Go003oooooool00?ooooooo`00o`03ooooo`05o`00oooooooo003oooooool00?l00_oo
ool2o`00o`;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`02o`00o`;ooooo00Oo
003oooooooooooooooooo`00oooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool01?l0
0?ooooooooooooooool2o`00o`?ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00oooo
ooooooooooooool00?l00oooool2o`00o`;ooooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool01Oooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo00Gooooo0_l0
0?l7ooooo`04o`00ooooooooooooooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool0Doooool02?l00?ooooooooooool00?ooooooo`00oooooooo003o0ooo
ool01?l00?ooooooooooool0000?ooooo`03o`00oooooooooooo00;o003o0_ooool01ol00?oooooo
oooooooooooo003oooooool00?l01_ooool01ol00?ooooooo`00oooooooo003oooooool00?l01Ooo
ool00ol00?ooooooooooo`02o`00o`;ooooo00Oo003oooooooooooooooooo`00oooooooo003o00?o
oooo00?o003oooooooooool00_l00?l2ooooo`05o`00ooooooooooooooooool00?l01Oooool01?l0
0?ooooooooooool00?l3ooooo`;o003o0oooool2o`00o`;ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00Oooooo0_l00?l2ooooo`;o003o0oooool00ol00?oooooooooo
o`06ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Gooooo0_l00?l3
ooooo`03o`00oooooooooooo00Gooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o057ooooo00Ko003ooooooooooooo003oooooool00?l5oooo
o`04o`00ooooooooooooo`0000oooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooo
oooo003o00[ooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l01oooool02?l0
0?ooooooooooool00?ooooooo`00oooooooo003o0oooool00ol00?ooooooo`00o`03ooooo`04o`00
ooooooooooooo`00o`?ooooo00?o003oooooooooool00oooool01Ol00?oooooooooooooooooo003o
00;ooooo00Oo003oooooooooooooooooo`00oooooooo003o00;ooooo0_l00?l2ooooo`;o003o0ooo
ool00ol00?ooooooooooo`05ooooo`;o003o0_ooool2o`00o`?ooooo00?o003oooooooooool01_oo
ool00ol0003oooooooooo`01ooooo`002Oooool3o`0000Gooooo00?o0000ooooooooool01Oooool2
o`00o`?ooooo00Go003oooooooooooooooooo`00o`07ooooo`;o003o0oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1:ooooo`06o`00
ooooooooooooo`00oooooooo003o0oooool00ol00?ooooooo`00o`02ooooo`03o`000?oooooooooo
00gooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooool00?l01_ooool01ol00?ooooooo`00oooooooo003oooooool00?l01Oooool00ol00?oooooo
ooooo`02ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`05ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooool00?ooooooo`00o`02ooooo`;o003o0_ooool2o`00o`?ooooo00Ko003o
oooooooooooo003oooooool00?l2ooooo`;o003o0_ooool01?l00?ooooooooooooooool2o`00o`?o
oooo0_l00?l6ooooo`;o003o0oooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo007o
oooo000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool01?l00?oooooo
ooooooooool2o`00o`?ooooo00?o003oooooooooool01Oooool2o`00o`?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Coooool01Ol0
0?ooooooo`00oooooooo003o00Cooooo00?o0000ooooooooool04?ooool2o`00o`;ooooo0_l00?l2
ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00Gooooo
00Oo003oooooool00?ooooooo`00oooooooo003o00Kooooo00Wo003oooooooooooooooooo`00oooo
oooo003oooooool00?l00_ooool2o`00o`Cooooo00Go003oooooool00?ooooooo`00o`02ooooo`04
o`00ooooooooooooooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00_ooool2o`00o`;ooooo00?o003oooooooooool00_ooool2o`00o`;ooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo007ooooo0002oooo
o`Go00000oooool00ol0003oooooooooo`04ooooo`?o00002Oooool00ol00?ooooooooooo`02oooo
o`04o`00ooooooooooooooooo`;o003o1oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
@_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooo003o00Cooooo00?o0000oooooooo
ool03Oooool01?l00?ooooooooooool00?l4ooooo`0:o`00ooooooooooooo`00oooooooo003ooooo
ool00?ooooooo`00o`;ooooo0_l00?l6ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooo
oooo003o00;ooooo00?o003oooooooooool00oooool01Ol00?ooooooo`00oooooooo003o00;ooooo
00Oo003oooooooooooooooooo`00oooooooo003o00?ooooo00?o003oooooool00?l01?ooool01?l0
0?ooooooooooooooool2o`00o`Sooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooo
oooo00;ooooo0_l00?l2ooooo`;o003o0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00Cooooo0ol00003ooooo`002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Kooooo00?o003oooooooooool01Oooool01?l00?ooooooooooooooool2o`00o`;ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0@_ooool01?l00?oooooo
ooooool00?l3ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol0003oooooooooo`0=oooo
o`03o`00oooooooooooo00;o003o1_ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo
00;o003o0_ooool00ol00?ooooooo`00o`05ooooo`05o`00oooooooo003oooooool00?l00_ooool0
1ol00?oooooooooooooooooo003oooooool00?l00oooool01?l00?ooooooo`00ool00?l3ooooo`07
o`00ooooooooooooooooool00?ooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo0_l0
0?l2ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02o`00o`?ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`;o003o0oooool00ol00?oooooo
ooooo`06ooooo`03o`000?oooooooooo007ooooo000:ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool2o`00o`?ooooo00?o003oooooooooool01Oooool2o`00o`;ooooo0_l0
0?l3ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo03kooooo00Ko003ooooo
oooooooo003oooooool00?l5ooooo`04o`00ooooooooooooo`0000oooooo00?o003oooooooooool0
0_l00?l2ooooo`;o003o2oooool2o`00o`;ooooo00?o003oooooool00?l02Oooool00ol00?oooooo
o`00o`02ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`02ooooo`05
o`00ooooooooooooooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00;ooooo00Oo003o
ooooooooooooooooo`00oooooooo003o00;ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`03
o`00oooooooooooo00Gooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`Sooooo00?o0000oooooooo
ool00Oooool000Wooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo0_l00?l2ooooo`;o003o
0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o0oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool01_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0iooooo`06o`00oooooooooooo
o`00oooooooo003o0oooool00ol00?ooooooo`00o`02ooooo`03o`000?oooooo003o00gooooo00Go
003oooooooooooooooooo`00o`02ooooo`;o003o1_ooool00ol00?ooooooo`00o`06ooooo`07o`00
oooooooo003oooooool00?ooooooo`00o`05ooooo`03o`00oooooooo003o00;ooooo00?o003ooooo
ool00?l00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;ooooo00Wo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?l00oooool00ol00?ooooooooooo`04ooooo`07o`00
oooooooo003oooooool00?ooooooo`00o`02ooooo`04o`00ooooooooooooooooo`;o003o0_ooool0
0ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00;o003o0_ooool00ol00?ooooooooooo`07
ooooo`03o`000?oooooooooo007ooooo000:ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01Oooool2o`00o`;ooooo0_l00?l3ooooo`03o`00oooooooooooo00Gooooo0_l00?l2oooo
o`;o003o0oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`0mooooo`06o`00
ooooooooooooo`00oooooooo003o1?ooool00ol0003oooooo`00o`0@ooooo`;o003o0_ooool2o`00
o`;ooooo00Oo003oooooool00?ooooooo`00oooooooo003o00Sooooo00Wo003oooooool00?oooooo
o`00oooooooo003oooooool00?l01_ooool01ol00?ooooooo`00oooooooo003oooooool00?l00ooo
ool00ol00?ooooooo`00o`04ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o
00;ooooo0_l00?l3ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooo`00o`07ooooo`03o`00oooo
oooooooo00;o003o2?ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000[ooooo0_l00?l3
ooooo`04o`00ooooooooooooooooo`;o003o1_ooool2o`00o`?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0looooo`03o`00oooooooo003o00Cooooo00?o0000ooooool0
0?l04?ooool00ol00?ooooooooooo`02ooooo`0:o`00ooooooooooooo`00oooooooo003oooooool0
0?ooooooo`00o`;ooooo0_l00?l6ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`03oooo
o`04o`00ooooooooooooo`00o`?ooooo00Oo003oooooool00?ooooooo`00oooooooo003o00Cooooo
00?o003oooooool00?l00oooool00ol00?ooooooo`00o`04ooooo`;o003o0_ooool2o`00o`Sooooo
00?o003oooooooooool00_l00?l2ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`02oooo
o`;o003o1_ooool2o`00o`Oooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`06ooooo`03
o`00oooooooooooo00Cooooo0_l00?l3ooooo`;o003o1oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`06ooooo`05o`00ooooooooooooooooool00?l0<oooool01?l00?oooooo
ooooool00?l3ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol0003o003oo`00o`0<oooo
o`05o`00ooooooooooooooooool00?l01oooool2o`00o`;ooooo00?o003oooooool00?l00_ooool2
o`00o`;ooooo0_l00?l4ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00Co
oooo00?o003oooooool00?l00oooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooo003o00?o
oooo00Oo003oooooool00?ooooooo`00oooooooo003o00Cooooo0_l00?l2ooooo`05o`00oooooooo
ooooooooool00?l01Oooool00ol00?ooooooooooo`02o`00o`;ooooo00?o003oooooool00?l00_oo
ool2o`00o`;ooooo0_l00?l3ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool01Oooool2o`00o`?ooooo00?o003oooooooooool01Oooool2
o`00o`;ooooo0_l00?l7ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooooooo0_l0
0?l7ooooo`04o`00ooooooooooooooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o03?o
oooo00?o003oooooooooool00_l00?l2ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol0
003oooooo`00o`0<ooooo`04o`00ooooooooooooooooo`;o003o0_ooool01?l00?oooooooooooooo
ool2o`00o`Oooooo0_l00?l2ooooo`;o003o1_ooool01ol00?ooooooo`00oooooooo003oooooool0
0?l00_ooool00ol00?ooooooo`00o`05ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`04
ooooo`03o`00oooooooooooo00?ooooo00Go003oooooooooooooooooo`00o`02ooooo`09o`00oooo
ooooooooooooool00?ooooooo`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`06
ooooo`03o`00oooooooo003o00;ooooo0_l00?l3ooooo`03o`00oooooooooooo00Kooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool01Oooool2o`00o`;ooooo0_l00?l7oooo
o`;o003o0_ooool2o`00o`;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l0
0oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo02go
oooo00?o003oooooooooool00_l00?l6ooooo`06o`00ooooooooooooo`000?oooooo003o3?ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o1_ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00;o003o0_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo
003o00;ooooo00?o003oooooool00?l00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
003o00;ooooo00?o003oooooool00?l00oooool00ol00?ooooooo`00o`03ooooo`04o`00oooooooo
ooooo`00o`?ooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00Co003ooooooooo
oooooooo0_l00?l4ooooo`05o`00ooooooooooooooooool00?l00_ooool2o`00o`;ooooo00?o003o
ooooooooool01oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`05oooo
o`;o003o0_ooool2o`00o`;ooooo0_l00?l7ooooo`;o003o0_ooool2o`00o`;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0/ooooo`08o`00ooooooooooooo`00oooo
oooo003oooooool00?l2ooooo`03o`000?l00?oooooo017ooooo00?o003oooooooooool00_l00?l2
ooooo`;o003o0_ooool00ol00?ooooooo`00o`06ooooo`;o003o0_ooool01ol00?ooooooo`00oooo
oooo003oooooool00?l01_ooool2o`00o`;ooooo00?o003oooooool00?l00oooool00ol00?oooooo
o`00o`04ooooo`0=o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00o`03ooooo`0:o`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`;ooooo00Co
003ooooooooooooooooo0_l00?l2ooooo`03o`00oooooooo003o00Oooooo00Co003ooooooooooooo
003o2Oooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000Kooooo00Co003ooooooooooooo
oooo0_l00?l2ooooo`;o003o0_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;o
003o0_ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooooooo`;o003o0oooool01Ol0
0?oooooooooooooooooo003o00Oooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01?l00?ooooooooooooooool2o`00obkooooo00Ko003ooooooooooooo003oooooool00?l4oooo
o`03o`000?l00?oooooo013ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`;o003o0_ooool0
0ol00?ooooooo`00o`02ooooo`;o003o1_ooool2o`00o`;ooooo00?o003oooooool00?l01_ooool0
3ol00?oooooooooooooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
o`02ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`03ooooo`03o`00oooooooo003o00;o
oooo0_l00?l8ooooo`05o`00oooooooo003oooooool00?l00_ooool02Ol00?oooooooooooooooooo
003oooooool00?ooooooo`00o`08ooooo`;o003o1oooool2o`0000?ooooo000Aooooo`03o`000?oo
oooooooo00Wooooo00Co003ooooooooooooooooo0_l00?l2ooooo`03o`00oooooooo003o00Oooooo
00?o003oooooooooool00_l00?l3ooooo`04o`00ooooooooooooooooo`;o003o0oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool01Oooool2o`00o`?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool09?ooool0
1?l00?ooooooooooool00?l3ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol0003o003o
o`00o`0<ooooo`05o`00ooooooooooooooooool00?l01oooool2o`00o`;ooooo0_l00?l3ooooo`;o
003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`06
ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?o
oooo00?o003oooooool00?l00oooool00ol00?ooooooooooo`02ooooo`;o003o0_ooool01ol00?oo
oooooooooooooooo003oooooool00?l00oooool00ol00?ooooooooooo`02o`00o`;ooooo00Oo003o
ooooool00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`06ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o
003oooooool00?l01_ooool01ol00?oooooooooooooooooo003oooooool00?l00_ooool2o`00o`?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o0_ooool2
o`00o`?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0Voooo
o`03o`00oooooooooooo00;o003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o0000
o`00ool00?l03?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo
0_l00?l7ooooo`;o003o0_ooool2o`00o`Kooooo00Oo003oooooool00?ooooooo`00oooooooo003o
00?ooooo00Co003ooooooooooooo003o0oooool01ol00?ooooooo`00oooooooo003oooooool00?l0
0oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00?ooooo00?o003oooooool00?l0
0_ooool01Ol00?ooooooo`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`06oooo
o`03o`00oooooooo003o00;ooooo0_l00?l3ooooo`03o`00oooooooooooo00Kooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ol00?ooooooo`00o`02ooooo`;o
003o1_ooool00ol00?ooooooo`00o`02ooooo`;o003o0_ooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00o`;ooooo00?o003o
ooooooooool00_ooool01?l00?ooooooooooooooool2o`00o`_ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01oooooo00Co003ooooooooooooooooo
0_l00?l6ooooo`06o`00ooooooooooooo`000?oooooo003o3?ooool01Ol00?oooooooooooooooooo
003o00?ooooo0_l00?l;ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l6ooooo`03o`00oooooooo
003o00;ooooo0_l00?l4ooooo`03o`00oooooooo003o00?ooooo00?o003oooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00?ooooo00?o003oooooool00?l01?ooool0
2ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o00?ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`02o`00o`;ooooo00?o003oooooooooool01oooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooo003o00;o
oooo0_l00?l2ooooo`;o003o1oooool2o`00o`;ooooo0_l00?l2ooooo`04o`00oooooooooooooooo
o`;o003o1?ooool01?l00?ooooooooooool00?l3ooooo`;o003o0oooool01?l00?oooooooooooooo
ool2o`00o`;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`04
o`00ooooooooooooooooo`;o003o0oooool01?l00?ooooooooooool00?l2ooooo`03o`000?l00?oo
oooo00cooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o1_ooool2o`00o`Oooooo0_l0
0?l2ooooo`;o003o0_ooool01Ol00?oooooooooooooooooo003o00Cooooo0_l00?l2ooooo`03o`00
oooooooo003o00Gooooo00?o003oooooooooool00_ooool2o`00o`;ooooo00Wo003oooooool00?oo
ooooo`00oooooooo003oooooool00?l00oooool03?l00?ooooooooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00o`Cooooo0_l00?l2ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooool00?l00_ooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo00Cooooo00?o003oooooooooool00_ooool2o`00o`;ooooo0_l00?l7oooo
o`;o003o0_ooool2o`00o`;ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`;o003o0_ooool0
1?l00?ooooooooooooooool2o`00o`Oooooo0_l00?l2ooooo`;o003o0oooool01Ol00?oooooooooo
oooooooo003o00?ooooo0_l00?l2ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`02o`00o`Gooooo00?o0000o`00oooo
ool04?ooool01?l00?ooooooooooooooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0oooool00ol0
0?ooooooooooo`05ooooo`;o003o0_ooool00ol00?ooooooo`00o`06ooooo`04o`00oooooooooooo
ooooo`;o003o0_ooool01Ol00?ooooooo`00oooooooo003o00Cooooo0_l00?l2ooooo`03o`00oooo
oooo003o00?ooooo00?o003oooooool00?l00oooool00ol00?ooooooooooo`02ooooo`09o`00oooo
ooooooooooooool00?ooooooo`00oooooooo003o00;ooooo00Wo003oooooooooooooooooo`00oooo
oooo003oooooool00?l02?ooool2o`00o`Sooooo00?o0000ooooooooool00Oooool0017ooooo0_l0
000:ooooo`04o`00ooooooooooooooooo`;o003o0_ooool00ol00?ooooooo`00o`06ooooo`;o003o
0_ooool2o`00o`;ooooo0_l00?l3ooooo`;o003o0oooool00ol00?ooooooooooo`02o`00o`?ooooo
00?o003oooooooooool01Oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`04
o`00ooooooooooooooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool05oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l5ooooo`03o`000?l0
0?oo003o00cooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;o003o
0_ooool2o`00o`?ooooo0_l00?l6ooooo`;o003o0_ooool01ol00?ooooooo`00oooooooo003ooooo
ool00?l01_ooool2o`00o`;ooooo00?o003oooooool00?l00oooool01?l00?ooooooooooool00?l3
ooooo`03o`00oooooooo003o00?ooooo00Oo003oooooooooooooooooo`00oooooooo003o00Sooooo
00Oo003oooooool00?ooooooo`00oooooooo003o00Cooooo00Wo003oooooool00?ooooooo`00oooo
oooo003oooooool00?l01Oooool00ol00?ooooooooooo`05ooooo`;o00000oooool0017ooooo00?o
0000ooooooooool01_ooool00ol00?ooooooooooo`04ooooo`;o003o0_ooool01Ol00?ooooooo`00
oooooooo003o00Gooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooooooo00;ooooo
0_l00?l2ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00Sooooo00?o003ooooooooo
ool00_l00?l3ooooo`03o`00oooooooooooo00Gooooo0_l00?l7ooooo`05o`00oooooooooooooooo
ool00?l01?ooool00ol00?ooooooooooo`0Booooo`05o`00ooooooooooooooooool00?l00oooool2
o`00o`;ooooo00?o003oooooooooool00ol00?l<ooooo`05o`00ooooooooooooooooool00?l01ooo
ool2o`00o`?ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`;o003o1_ooool2o`00o`;ooooo
00?o003oooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`02ooooo`07o`00ooooooooooooooooool00?ooooooo`00
o`03ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`05ooooo`05o`00
ooooooooooooooooool00?l00_ooool02ol00?oooooooooooooooooo003oooooool00?ooooooo`00
oooooooo003o00?ooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`04ooooo`03o`00oooooooo003o00?ooooo00?o003oooooooooool01?oo
ool01ol00?ooooooo`00oooooooo003oooooool00?l00_ooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00o`;ooooo00?o003o
ooooooooool00_ooool01?l00?ooooooooooooooool2o`00o`_ooooo00?o003oooooooooool00_oo
ool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l04?ooool01?l00?ooooooooooooooool2
o`00o`Kooooo00Ko003ooooooooooooo0000ooooool00?l3ooooo`03o`00oooooooooooo00Kooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00[ooooo00Co003ooooooooo
oooooooo0_l00?l:ooooo`03o`00oooooooo003o00;ooooo0_l00?l6ooooo`07o`00oooooooooooo
ooooool00?ooooooo`00o`03ooooo`03o`00oooooooooooo00Cooooo00Oo003ooooooooooooooooo
o`00oooooooo003o00?ooooo00Ko003ooooooooooooo003oooooool00?l3ooooo`03o`00oooooooo
003o00?ooooo00?o003oooooooooool01?ooool01ol00?ooooooo`00oooooooo003oooooool00?l0
0_ooool2o`00o`Sooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?oo
ool01ol00?ooooooo`00oooooooo003oooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00oooooooo003oooooool00?l00_ooool01?l00?ooooooooooooooool2o`00o`?ooooo00?o003o
ooooooooool01Oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l3ooooo`;o003o0_oo
ool00ol00?ooooooooooo`06ooooo`04o`00ooooooooooooooooo`;o003o0oooool01Ol00?oooooo
oooooooooooo003o00Oooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
013ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00?o
0000ooooool00?l00oooool00ol00?ooooooooooo`06ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`05ooooo`;o003o1oooool2o`00o`;ooooo0_l00?l6ooooo`03o`00
oooooooo003o00;ooooo0_l00?l3ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
0_ooool2o`00o`;ooooo0_l00?l2ooooo`05o`00ooooooooooooooooool00?l01Oooool02_l00?oo
ooooooooool00?ooooooo`00oooooooo003oooooool00?l3ooooo`03o`00oooooooo003o00;ooooo
00?o003oooooool00?l00oooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003ooooooooo
ool01oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`07o`00
oooooooo003oooooool00?ooooooo`00o`02ooooo`;o003o1_ooool00ol00?ooooooo`00o`02oooo
o`;o003o0_ooool01?l00?ooooooooooooooool2o`00o`Cooooo00Co003ooooooooooooo003o0ooo
ool2o`00o`;ooooo00?o003oooooooooool00_ooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0ooo
ool01?l00?ooooooooooooooool2o`00o`;ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`0>ooooo`04o`00ooooooooooooooooo`;o003o1Oooool00ol00?ooooooooooo`0@
ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`;ooooo0_l00?l;ooooo`;o003o0_oo
ool2o`00o`Oooooo0_l00?l2ooooo`;o003o1?ooool00ol00?ooooooo`00o`04ooooo`;o003o0_oo
ool2o`00o`;ooooo00Go003oooooool00?ooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Oo003oooooooooooooooooo`00oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?ooooooo`00oooooooo003o00Gooooo00Go003oooooool00?ooooooo`00o`08ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`;o00002Oooool00ol00?ooooooo`00o`02ooooo`;o003o0_ooool0
0ol00?ooooooo`00o`06ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`03o`00oooooooo
003o00?ooooo00?o003oooooooooool00_l00?l7ooooo`04o`00ooooooooooooooooo`;o003o0_oo
ool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0_ooool2o`00o`?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`;o003o1oooool00ol00?ooooooooooo`0Booooo`;o
003o1Oooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00[ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`;o003o0_ooool2o`00o`?ooooo00?o003oooooooooool01Oooool2o`00
o`;ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`;ooooo00?o003o
ooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`;o003o1?ooool01ol00?ooooooo`00
oooooooo003oooooool00?l02?ooool01ol00?ooooooo`00oooooooo003oooooool00?l00oooool0
2?l00?ooooooooooool00?ooooooo`00oooooooo003o1Oooool00ol00?ooooooo`00o`07ooooo`;o
00000oooool0017ooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`04ooooo`;o003o
0_ooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00;o003o0_ooool01ol00?oooooo
oooooooooooo003oooooool00?l00_ooool2o`00o`?ooooo00?o003oooooooooool00_l00?l7oooo
o`;o003o0_ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0_ooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Kooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`;o003o0_ooool01_l00?ooooooooooool00?ooooooo`00o`?ooooo00?o003o
ooooooooool01_ooool01Ol00?oooooooooooooooooo003o00Oooooo0_l00?l2ooooo`;o003o0ooo
ool01?l00?ooooooooooooooool2o`00o`Kooooo0_l00?l2ooooo`;o003o1?ooool01?l00?oooooo
ooooool00?l3ooooo`;o003o1?ooool01?l00?ooooooooooool00?l3ooooo`07o`00oooooooooooo
ooooool00?ooooooo`00o`03ooooo`05o`00oooooooo003oooooool00?l00oooool00ol00?oooooo
ooooo`04ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`09o`00oooooooo003o
ooooool00?ooooooo`00oooooooo003o00?ooooo00?o003oooooooooool01_ooool00ol0003ooooo
ooooo`01ooooo`002_ooool2o`0000Gooooo00?o0000ooooooooool01?ooool00ol00?ooooooo`00
o`03ooooo`03o`00oooooooooooo00Cooooo00Oo003oooooool00?ooooooo`00oooooooo003o00Oo
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`;o003o1_ooool2o`00o`;o
oooo00?o003oooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`;o003o1?ooool01?l0
0?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00So
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00_ooool0
0ol0003oooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?l7ooooo`04o`00oooooooooooooooo
o`;o003o1oooool00ol00?ooooooooooo`02o`00o`?ooooo0_l00?l6ooooo`;o003o0_ooool00ol0
0?ooooooo`00o`03ooooo`03o`00oooooooooooo00Cooooo00Oo003oooooooooooooooooo`00oooo
oooo003o00?ooooo00?o003oooooooooool00_l00?l6ooooo`05o`00ooooooooooooooooool00?l0
1_ooool02ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o00Sooooo00?o
0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`08ooooo`07o`00oooooooo003ooooo
ool00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l01oooool2o`00o`;ooooo00Co
003ooooooooooooooooo0_l00?l2ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool0
1Oooool2o`00o`?ooooo0_l00?l6ooooo`;o003o1oooool01?l00?ooooooooooooooool2o`00o`?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Kooooo00Go003ooooo
ooooooooooooo`00o`07ooooo`06o`00ooooooooooooo`000?oooooo003o0oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00Oooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l6
ooooo`;o003o0oooool2o`00o`?ooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`02
ooooo`;o003o0oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooo003o00?ooooo00?o
003oooooooooool00_l00?l2ooooo`03o`00oooooooo003o00?ooooo00?o003oooooool00?l01?oo
ool02ol00?oooooooooooooooooo003oooooool00?ooooooo`00oooooooo003o00[ooooo00?o0000
ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04
ooooo`0;o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l01_ooool01ol0
0?ooooooo`00oooooooo003oooooool00?l00_ooool01?l00?ooooooooooooooool2o`00o`Cooooo
00?o003oooooool00?l01?ooool2o`00o`;ooooo00Oo003oooooooooooooooooo`00oooooooo003o
00;ooooo0_l00?l2ooooo`;o003o0_ooool00ol00?ooooooooooo`02ooooo`;o003o0oooool00ol0
0?ooooooooooo`02o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool01Oooool01?l00?ooooooooooooooool2o`00o`;ooooo00Co003ooooooooooooo
003o1Oooool01Ol00?oooooooooooooooooo003o00Sooooo00Go003oooooooooooooooooo`00o`03
ooooo`04o`00ooooooooooooooooo`;o003o1oooool01?l00?ooooooooooooooool2o`00o`;ooooo
0_l00?l7ooooo`;o003o0_ooool2o`00o`?ooooo00Co003ooooooooooooo003o1?ooool2o`00o`;o
oooo0_l00?l2ooooo`;o003o0_ooool01ol00?oooooooooooooooooo003oooooool00?l00_ooool0
1ol00?oooooooooooooooooo003oooooool00?l00oooool01Ol00?ooooooo`00oooooooo003o00;o
oooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`0:ooooo`03o`000?oooooooooo007o
oooo0009ooooo`04o`000?ooooooooooo`0000Cooooo1ol000002ol00?oo0000o`000?l0003o003o
o`000?l00?oo0000o`00ool0003o003o00;o000000?o003oo`000?l000000ol000001Ol00?oo0000
o`00ool0003o003o00;o000000Co003oo`000?l0003o00000_l00?l2o`000003o`00ool0003o003o
00?o000000?o003oo`000?l000000_l00?l6o`000003o`00ool0003o003o00;o00000_l00?l2o`00
00;o003o0_l000000ol00?oo0000o`000002o`000004o`00ool0003o0000o`0000;o003o0_l00002
o`00o`;o00000_l00?l3o`000005o`00ool0003o0000o`000?l00?l01?l000001Ol00?oo0000o`00
0?l0003o003o00?o000000Co003oo`000?l0003o00000_l00?l7o`000004o`00ool0003o0000o`00
00;o003o1Ol000000ol00?oo0000o`000007o`000003o`00ool0003o000000Ko000000Go003oo`00
0?l0003o0000o`00o`03o`000004o`00ool0003o0000o`0000;o003o0ol000000ol00?oo0000o`00
0005o`0000;o003o0_l00002o`00o`Oo000000Co003oo`000?l0003o00000_l00?l2o`0000;o003o
0_l00002o`00o`?o000000Co003oo`000?l0003o00000_l00?l3o`000008o`00ool0003o0000o`00
ool0003o003oo`000?l00?l8o`000007o`00ool0003o003oo`000?l00?oo0000o`00o`03o`000006
o`00ool0003o0000o`00ool0003o003o1ol000001Ol00?oo0000o`00ool0003o003o00Oo00000ooo
ool000Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`08ooooo`07o`00oooo
ooooooooooooool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00Oooooo00?o003ooooooooo
ool00_l00?l2ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`05ooooo`;o003o0_ooool2o`00o`?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`;o003o0_ooool01?l00?ooooooooooooooool2o`00o`?o
oooo00Co003ooooooooooooooooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l0
0?l2ooooo`06o`00oooooooo003oo`000?oooooo003o0_ooool2o`00o`?ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooooooo0_l00?l3
ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`;ooooo0_l00?l2ooooo`;o003o1ooo
ool2o`00o`;ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`?ooooo
00?o003oooooooooool00_ooool01Ol00?ooooooo`00oooooooo003o00?ooooo00Co003ooooooooo
oooo003o0oooool01ol00?ooooooo`00oooooooo003oooooool00?l00_ooool2o`00o`;ooooo00?o
003oooooool00?l01Oooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo007ooooo0009
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01_ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00;ooooo00Oo003oooooool00?ooooooo`00oooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`02ooooo`0;o`00ooooooooooooooooool00?ooooooo`00
oooooooo003oooooool00?l00oooool00ol00?ooooooooooo`02o`00o`Cooooo00Go003ooooooooo
ooooooooo`00o`02ooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`04o`00oooooooooooo
o`00o`Oooooo0_l00?l3ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?l7
ooooo`04o`00ooooooooooooooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo
00[o003oooooooooooooooooo`00oooooooo003oo`000?oooooo003o0_ooool2o`00o`?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`06ooooo`05o`00ooooooooooooooooool00?l01oooool2o`00o`;ooooo0_l00?l3oooo
o`05o`00ooooooooooooooooool00?l00oooool2o`00o`;ooooo0_l00?l4ooooo`03o`00oooooooo
oooo00Cooooo0_l00?l4ooooo`05o`00oooooooo003oooooool00?l00_ooool2o`00o`Kooooo00Go
003oooooooooooooooooo`00o`05ooooo`08o`00ooooooooooooo`00oooooooo003oooooool00?l3
ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool00Oooool000[ooooo0_l00005oooo
o`03o`000?oooooooooo00Kooooo00Go003oooooool00?ooooooo`00o`05ooooo`;o003o00Sooooo
o`00oooooooo003oooooool00?ooooooo`00o`Gooooo00Go003oooooooooooooooooo`00o`02oooo
o`07o`00ooooooooooooooooool00?ooooooo`00o`02ooooo`04o`00ooooooooooooooooo`;o003o
0_ooool00ol00?ooooooo`00o`0:ooooo`;o003o1?ooool00ol00?ooooooooooo`05ooooo`04o`00
ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02o`00o`?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`07ooooo`06o`00ooooooooooooo`000?oooooo003o0_ooool2o`00o`?ooooo
00Go003oooooooooooooooooo`00o`08ooooo`03o`00oooooooooooo00[ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00Gooooo0_l00?l3ooooo`03o`00oooooooooooo
00;ooooo00Co003ooooooooooooo003o0oooool2o`00o`Cooooo00Go003oooooooooooooooooo`00
o`02ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`03ooooo`03o`00oooooooooooo00;o
003o0_ooool2o`00o`;ooooo00Go003oooooooooooooooooo`00o`08ooooo`07o`00oooooooo003o
ooooool00?ooooooo`00o`03ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool01_ooool02Ol00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00o`06ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00Cooooo0_l0
0?l4ooooo`03o`00oooooooo003o00Cooooo0_l00?l2ooooo`;o003o0_ooool01Ol00?ooooooo`00
oooooooo003o00Gooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooo003o00?ooooo
00?o003oooooooooool00_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oo
ooooooooooooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`08ooooo`03o`00oooooooo
oooo00Gooooo00So003oooooooooooooooooo`00oooooooo003oo`0000Gooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`06ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Co003ooooooooooooooooo0_l00?l6ooooo`03o`00oooooooooooo00;ooooo
0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo00Oo003oooooooooooooooooo`00oooooooo003o
00;ooooo0_l00?l2ooooo`;o003o1?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003o
ooooooooool00oooool01Ol00?ooooooo`00oooooooo003o00?ooooo00?o003oooooooooool01?oo
ool00ol0003oooooooooo`01ooooo`004Oooool2o`0000Wooooo00Wo003oooooool00?ooooooo`00
oooooooo003oooooool00?l01?ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00
o`04ooooo`;o003o0_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo00Oo
003oooooool00?ooooooo`00oooooooo003o00;ooooo0_l00?l2ooooo`07o`00oooooooooooooooo
ool00?ooooooo`00o`02ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l3ooooo`05o`00oooooooo
ooooooooool00?l01?ooool00ol00?ooooooooooo`02o`00o`?ooooo00Co003ooooooooooooooooo
0_l00?l;ooooo`03o`00oooooooooooo00?ooooo00?o003oo`000?ooool02?ooool00ol00?oooooo
ooooo`0>ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`05ooooo`04
o`00ooooooooooooooooo`;o003o1oooool01?l00?ooooooooooooooool2o`00o`;ooooo0_l00?l2
ooooo`03o`00oooooooooooo00;ooooo0_l00?l2ooooo`;o003o0oooool01?l00?ooooooooooool0
0?l3ooooo`03o`00oooooooooooo00Kooooo0_l00?l2ooooo`03o`00oooooooo003o00?ooooo00?o
003oooooooooool00_l00?l8ooooo`05o`00oooooooo003oooooool00?l01Oooool2o`0000?ooooo
000Aooooo`03o`000?oooooooooo00Sooooo00Wo003oooooooooooooooooo`00oooooooo003ooooo
ool00?l00_ooool00ol00?ooooooooooo`03ooooo`0;o`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`03ooooo`05o`00oooooooo003ooooo
ool00?l00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00;ooooo0_l00?l3oooo
o`04o`00ooooooooooooo`00o`Cooooo0_l00?l2ooooo`04o`00ooooooooooooooooo`;o003o0ooo
ool01?l00?ooooooooooooooool2o`00o`;ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo0_l00?l2ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool00oooool01?l00?oo0000ooooool00?l2ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`0<ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`;o003o1oooool2o`00o`;o
oooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`?ooooo00Go003ooooo
ooooooooooooo`00o`02ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o0ooo
ool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00o`Kooooo00?o
003oooooooooool01_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`06
ooooo`03o`00oooooooooooo00?ooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00oooo
oooo003o00Gooooo00Oo003oooooool00?ooooooo`00oooooooo003o00Cooooo00Oo003oooooool0
0?ooooooo`00oooooooo003o00?ooooo00?o003oooooooooool00_l00?l8ooooo`03o`00oooooooo
oooo00;o003o0oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo003oooooool00?l01_oo
ool2o`00o`;ooooo0_l00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`;o003o0_ooool00ol00?ooooooooooo`06ooooo`0:o`00oooooooooooooooo
ool00?ooooooo`00ool0003oooooo`00o`;ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool0
0?l04?ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01oooool2o`00
o`;ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o0oooool01_l00?oooooo
ooooool00?ooooooo`00o`;ooooo0_l00?l6ooooo`07o`00ooooooooooooooooool00?ooooooo`00
o`03ooooo`03o`00oooooooooooo00;o003o0_ooool01Ol00?oooooooooooooooooo003o00Sooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01_ooool01Ol00?ooooooo`00
oooooooo003o00Gooooo00[o003ooooooooooooo003oooooool00?ooooooo`00oooooooo003o1Ooo
ool01Ol00?oooooooooooooooooo003o00;ooooo00Wo003oooooooooooooooooo`00oooooooo003o
ooooool00?l01?ooool2o`00o`;ooooo00?o003oooooool00?l02_ooool2o`00o`Cooooo00?o003o
ooooool00?l01Oooool01?l00?ooooooooooool00?l3ooooo`;o003o1?ooool00ol00?oooooooooo
o`02o`00o`;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool02_ooool01_l00?ooooooooooool0003oooooo`00o`;ooooo0_l00?l3oooo
o`05o`00ooooooooooooooooool00?l05Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool01Oooool2o`00o`?ooooo00?o003oooooooooool01Oooool01?l00?oooooooooo
ooooool2o`00o`?ooooo00?o003oooooooooool01Oooool01?l00?ooooooooooooooool2o`00o`Co
oooo00?o003oooooooooool00_l00?l3ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`02o`00o`;ooooo00Oo003oooooool00?ooooooo`00oooo
oooo003o00Kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01_ooool0
1Ol00?ooooooo`00oooooooo003o00?ooooo00?o003oooooooooool00_ooool2o`00o`;ooooo00?o
003oooooool00?l00oooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00Cooooo00Go
003oooooooooooooooooo`00o`04ooooo`;o003o0_ooool01Ol00?ooooooo`00oooooooo003o00So
oooo0_l00?l2ooooo`03o`00oooooooo003o00?ooooo00?o003oooooooooool00_l00?l6ooooo`03
o`00oooooooooooo00;ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0:ooooo`06o`00oooooooo003oo`000?oooooo003o0_ooool2
o`00o`?ooooo00Go003oooooooooooooooooo`00o`0Iooooo`05o`00ooooooooooooooooool00?l0
1oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?oo
ooooooooo`02ooooo`04o`00ooooooooooooooooo`;o003o0_ooool01Ol00?oooooooooooooooooo
003o00Cooooo00Co003ooooooooooooooooo0_l00?l2ooooo`;o003o0oooool01_l00?oooooooooo
ool00?ooooooo`00o`;ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`03o`00oooooooo003o
00?ooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000Oo
oooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l01Oooool02_l00?oooooooooo
ool00?ooooooo`00oooooooo003oooooool00?l3ooooo`03o`00oooooooo003o00Cooooo00?o003o
ooooool00?l00oooool00ol00?ooooooo`00o`02ooooo`0?o`00ooooooooooooooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00;ooooo00_o003ooooooooooooooooo
o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`;o003o0oooool00ol00?ooooooooooo`02
o`00o`?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02o`00o`?ooooo00Co003o
oooooooooooooooo0_l00?lAooooo`03o`00ool0003ooooo00Oooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l02?ooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooooooool2
o`00o`;ooooo0_l00?l2ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?oooooooooo
ooooool2o`00o`?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02o`00o`Kooooo
00Oo003oooooool00?ooooooo`00oooooooo003o00Gooooo0_l00003ooooo`004Oooool00ol0003o
ooooooooo`07ooooo`0:o`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`;ooooo
00?o003oooooooooool00oooool02ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003o00;ooooo00?o003oooooool00?l00oooool01Ol00?ooooooo`00oooooooo003o00Kooooo
00_o003oooooooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooo`00o`02ooooo`;o003o0_ooool2o`00o`?ooooo
00Co003ooooooooooooooooo0_l00?l6ooooo`;o003o0_ooool00ol00?ooooooooooo`02ooooo`;o
003o4?ooool01Ol00?ooooooo`000?oooooo003o00;ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o01gooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o0_ooool00ol00?oo
ooooooooo`06ooooo`;o003o0_ooool2o`00o`Cooooo00?o003oooooooooool00_l00?l2ooooo`;o
003o1?ooool01Ol00?ooooooo`00oooooooo003o00Kooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`03ooooo`05o`00oooooooo003ooooo
ool00?l00_ooool00ol00?ooooooooooo`05ooooo`07o`00oooooooo003oooooool00?ooooooo`00
o`04ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`03ooooo`05o`00oooooooo003ooooo
ool00?l01_ooool01ol00?ooooooo`00oooooooo003oooooool00?l00oooool01?l00?oooooooooo
ool00?l3ooooo`03o`00oooooooo003o00;ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`04
o`00ooooooooooooooooo`;o003o0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;o003o0oooool2o`00o`;ooooo00?o003oooooooooool02_ooool2o`00o`04ooooool0003ooooo
o`00o`;ooooo0_l00?l2ooooo`;o003o9Oooool01?l00?ooooooooooooooool2o`00o`?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Co003ooooooooooooooooo0_l00?l3ooooo`03o`00oooooooooooo00;o003o0oooool2o`00
o`Kooooo0_l00?l2ooooo`03o`00oooooooo003o00;ooooo0_l00?l2ooooo`;o003o0_ooool01Ol0
0?oooooooooooooooooo003o00Sooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool01_ooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooooooool00_l00?l2
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l00_ooool00ol00?ooooooo`00o`03
ooooo`03o`00oooooooo003o00Cooooo0_l00?l4ooooo`03o`00oooooooo003o00Gooooo00Co003o
oooooooooooo003o0oooool2o`00o`Cooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooo
oooooooo00;ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`03o`00oooooooooooo00[ooooo
00Ko003ooooooooooooo0000ooooool00?l2ooooo`;o003o0_ooool2o`00o`?ooooo00?o003ooooo
ooooool07oooool01?l00?ooooooooooooooool2o`00o`?ooooo00?o003oooooooooool01Oooool0
1?l00?ooooooooooooooool2o`00o`?ooooo00?o003oooooooooool01Oooool01?l00?oooooooooo
ooooool2o`00o`?ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`04o`00ooooooooooooo`00
o`?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`02o`00o`;ooooo0_l00?l2oooo
o`03o`00oooooooo003o00Kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool01_ooool2o`00o`;ooooo00?o003oooooooooool01_ooool2o`00o`;ooooo00?o003oooooool0
0?l01Oooool01Ol00?oooooooooooooooooo003o00Kooooo00Go003oooooool00?ooooooo`00o`03
ooooo`03o`00oooooooo003o00;ooooo00Go003oooooool00?ooooooo`00o`08ooooo`;o003o0_oo
ool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo00Oo003ooooooooooooooooo
o`00oooooooo003o00;ooooo0_l00?l2ooooo`04o`00ooooooooooooooooo`;o003o1oooool00ol0
0?ooooooooooo`0:ooooo`06o`00ooooooooooooo`000?oooooo003o0_ooool2o`00o`;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0Sooooo`;o003o0oooool01Ol00?oooooooooo
oooooooo003o00Oooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oo
ooooooooooooool2o`00o`?ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`;o003o0oooool0
1?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooooooo`;o003o0_ooool2o`00o`Cooooo
00?o003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000Oooooo0_l0
0?l2ooooo`05o`00oooooooo003oooooool00?l01Oooool02_l00?ooooooooooool00?ooooooo`00
oooooooo003oooooool00?l5ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l00ooo
ool01Ol00?ooooooo`00oooooooo003o00Cooooo00go003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003o00Cooooo00?o003oooooool00?l00oooool01Ol00?oooooo
o`00oooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo00;o003o0_ooool2o`00o`?ooooo0_l00?l?ooooo`;o003o00?oooooo`00
0?ooool01?ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo02Sooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo0_l00?l2ooooo`04o`00ooooooooooooooooo`;o003o0oooool01?l0
0?ooooooooooooooool2o`00o`?ooooo00?o003oooooooooool00_l00?l3ooooo`03o`00oooooooo
oooo00Gooooo0_l00?l4ooooo`03o`00oooooooooooo00?ooooo0_l00003ooooo`004Oooool00ol0
003oooooooooo`07ooooo`0:o`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`Ko
oooo0_l00?l2ooooo`03o`00oooooooo003o00?ooooo00Go003oooooool00?ooooooo`00o`02oooo
o`09o`00ooooooooooooooooool00?ooooooo`00oooooooo003o00Kooooo00go003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o00Cooooo00_o003ooooooooooooo
ooooo`00oooooooo003oooooool00?ooooooo`00o`02ooooo`;o003o0oooool01?l00?oooooooooo
ool00?l5ooooo`03o`00oooooooooooo00;o003o0_ooool00ol00?ooooooooooo`02ooooo`;o003o
4?ooool00ol00?ooooooo`000009ooooo`05o`00ooooooooooooooooool00?l0:_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00oooooooo
ooooooooool00?l01?ooool00ol00?ooooooooooo`02o`00o`;ooooo00?o003oooooooooool01_oo
ool2o`00o`;ooooo0_l00?l3ooooo`04o`00ooooooooooooooooo`;o003o1oooool01_l00?oooooo
ooooool00?ooooooo`00o`Kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool01oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooool00?l00_ooool00ol0
0?ooooooooooo`05ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`03ooooo`04o`00oooo
ooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Co
oooo00Oo003oooooool00?ooooooo`00oooooooo003o00?ooooo00Co003ooooooooooooo003o0ooo
ool01Ol00?ooooooo`00oooooooo003o00Cooooo0_l00?l3ooooo`06o`00ooooooooooooo`00oooo
oooo003o0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o0_ooool00ol0
0?ooooooo`00o`02ooooo`03o`00oooooooooooo00[ooooo0_l00?l02?oooooo0000ooooool00?oo
ooooo`00oooooooo003o0oooool00ol00?ooooooooooo`0`ooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04
ooooo`03o`00oooooooooooo00;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l0
0?l2ooooo`;o003o0oooool2o`00o`;ooooo0_l00?l6ooooo`03o`00oooooooooooo00Kooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?l2ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooo`00o`03ooooo`08o`00ooooooooooooo`00oooooooo
003oooooool00?l3ooooo`05o`00oooooooo003oooooool00?l01?ooool02Ol00?oooooooooooooo
oooo003oooooool00?ooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool0
0?l02?ooool2o`00o`;ooooo0_l00?l4ooooo`03o`00oooooooooooo00;o003o1oooool01_l00?oo
ooooooooool00?ooooooo`00o`;ooooo00?o003oooooooooool02_ooool02_l00?ooooooooooool0
003oooooo`00oooooooo003oooooool00?l2ooooo`;o003o<_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_l00?l3ooooo`03o`00oooooooooooo00Gooooo00Go003o
ooooooooooooooooo`00o`05ooooo`03o`00oooooooooooo00;o003o0_ooool01Ol00?oooooooooo
oooooooo003o00Sooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01_oo
ool2o`00o`;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`02o`00o`;ooooo0_l0
0?l6ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`04ooooo`05o`00oooooooo003ooooo
ool00?l00oooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool01oooool0
0ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o0ooo
ool00ol00?ooooooooooo`03ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02_ooool02_l00?oooooo
ooooool0003oooooo`00oooooooo003oooooool00?l2ooooo`;o003o0_ooool00ol00?oooooooooo
o`0aooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool2
o`00o`;ooooo00Go003oooooooooooooooooo`00o`08ooooo`;o003o0_ooool2o`00o`?ooooo00?o
003oooooooooool01Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`06
ooooo`;o003o0_ooool2o`00o`;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`02
o`00o`;ooooo0_l00?l6ooooo`03o`00oooooooooooo00;ooooo0_l00?l4ooooo`09o`00oooooooo
003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003oooooool00?l01Oooool01Ol00?oo
ooooo`00oooooooo003o00;ooooo00?o003oooooool00?l00oooool01Ol00?ooooooo`00oooooooo
003o00?ooooo00Co003ooooooooooooo003o0oooool01ol00?oooooooooooooooooo003oooooool0
0?l00_ooool2o`00o`;ooooo0_l00?l7ooooo`03o`00oooooooooooo00[ooooo0_l00?l00ooooooo
0000ooooo`04ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool0=Oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo0_l00?l3ooooo`04o`00ooooooooooooooooo`;o003o0oooool00ol00?oooooo
ooooo`02o`00o`?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02o`00o`?ooooo
00?o003oooooooooool01Oooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000Sooooo00?o
003oooooooooool00_l00?l2ooooo`;o003o1?ooool00ol00?ooooooooooo`02o`00o`;ooooo0_l0
0?l4ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooo003o00Gooooo00ko003ooooooooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00o`Cooooo00oo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?l00oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo
oooo00;o003o0_ooool01ol00?oooooooooooooooooo003oooooool00?l04?ooool00ol00?oooooo
o`000009ooooo`04o`00ooooooooooooo`00ocOooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00Kooooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l0
2?ooool00ol00?ooooooooooo`02o`00o`Kooooo0_l00003ooooo`004Oooool00ol0003ooooooooo
o`07ooooo`05o`00ooooooooooooooooool00?l00_ooool2o`00o`?ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02o`00o`;ooooo00Oo003oooooool00?ooooooo`00oooooooo003o
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01_oo
ool01ol00?ooooooo`00oooooooo003oooooool00?l00oooool00ol00?ooooooo`00o`04ooooo`05
o`00oooooooo003oooooool00?l00oooool00ol00?ooooooo`00o`03ooooo`08o`00oooooooooooo
o`00oooooooo003oooooool00?l5ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooool0
0?l00_ooool00ol00?ooooooooooo`0;ooooo`07o`00oooooooo0000ooooool00?ooooooo`00o`05
ooooo`03o`00oooooooooooo03gooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?o
oooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`Kooooo00?o003ooooo
ooooool01_ooool00ol0003oooooooooo`01ooooo`002Oooool3o`0000Gooooo00?o0000oooooooo
ool01_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o0oooool2o`00o`Ko
oooo0_l00?l2ooooo`03o`00oooooooo003o00?ooooo00?o003oooooooooool00_l00?l2ooooo`09
o`00ooooooooooooooooool00?ooooooo`00oooooooo003o00Sooooo00Go003oooooool00?oooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooool00?ooooooo`00o`05ooooo`03
o`00oooooooo003o00;ooooo0_l00?l4ooooo`03o`00oooooooo003o00Gooooo00Go003ooooooooo
ooooooooo`00o`02ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool02oooool02Ol0
0?ooooooo`000?oooooo003oooooool00?ooooooo`00o`02ooooo`;o003o@oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00?o003oooooooooool00_l00?l3ooooo`03o`00oooooooooooo00Go
oooo00Co003ooooooooooooooooo0_l00?l3ooooo`04o`00ooooooooooooooooo`;o003o0_ooool0
1Ol00?oooooooooooooooooo003o00Sooooo00?o0000ooooooooool00Oooool000[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`06ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01?l00?ooooooooooooooool2o`00o`;ooooo0_l00?l6ooooo`07o`00oooooooo003oooooool0
0?ooooooo`00o`03ooooo`03o`00oooooooooooo00;o003o1?ooool01Ol00?ooooooo`00oooooooo
003o00;ooooo00?o003oooooooooool01oooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooo
003o00Gooooo00?o003oooooool00?l01?ooool2o`00o`Cooooo00Go003oooooool00?ooooooo`00
o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0>ooooo`07o`000?oooooo003oooooool00?ooooooo`00o`02ooooo`;o003o0_ooool00ol00?oo
ooooooooo`12ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`;o003o0_ooool2o`00o`Oooooo00?o0000ooooooooool0
0Oooool000[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`;o003o0_oo
ool01Ol00?oooooooooooooooooo003o00Cooooo0_l00?l2ooooo`;o003o0oooool01?l00?oooooo
ooooool00?l3ooooo`03o`00oooooooooooo00?ooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00oooooooo003oooooool00?l00_ooool2o`00o`Sooooo00Go003oooooool00?ooooooo`00
o`02ooooo`09o`00ooooooooooooooooool00?ooooooo`00oooooooo003o00Gooooo00?o003ooooo
ooooool00_ooool01ol00?ooooooo`00oooooooo003oooooool00?l00_ooool2o`00o`;ooooo0_l0
0?l6ooooo`03o`00oooooooooooo00kooooo00?o0000ooooool00?l00oooool01?l00?oooooooooo
ool00?l3ooooo`03o`00oooooooooooo04;ooooo00Go003oooooooooooooooooo`00o`04ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l3ooooo`03o`00oooooooo
oooo00Gooooo00?o0000ooooooooool00Oooool000[ooooo00?o0000ooooooooool01?ooool3o`00
00Kooooo0_l00?l2ooooo`;o003o0_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00;o003o0_ooool2o`00o`?ooooo00Co003ooooooooooooo003o1?ooool2o`00o`?ooooo00Ko003o
oooooooooooo003oooooool00?l3ooooo`03o`00oooooooooooo00;o003o0_ooool01ol00?oooooo
o`00oooooooo003oooooool00?l00oooool00ol00?ooooooooooo`02o`00o`;ooooo00Go003ooooo
ool00?ooooooo`00o`03ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?oooooooooo
o`03ooooo`05o`00oooooooo003oooooool00?l00_ooool01ol00?oooooooooooooooooo003ooooo
ool00?l04_ooool00ol0003oooooooooo`06ooooo`05o`00ooooooooooooooooool00?l0A?ooool0
1Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Go
oooo0_l00?l2ooooo`;o003o1Oooool3o`0000?ooooo000:ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01oooool00ol00?ooooooooooo`02o`00o`;ooooo0_l00?l3ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_l00?l2ooooo`;o003o0_ooool00ol00?oooooo
o`00o`02ooooo`04o`00ooooooooooooooooo`;o003o0_ooool00ol00?ooooooooooo`03ooooo`05
o`00ooooooooooooooooool00?l00_ooool01ol00?ooooooo`00oooooooo003oooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00;ooooo00Wo003oooooool00?ooooooo`00oooooooo003o
ooooool00?l00oooool01_l00?ooooooooooool00?ooooooo`00o`Gooooo00?o003oooooool00?l0
0_ooool01ol00?oooooooooooooooooo003oooooool00?l04_ooool01Ol0003oooooo`00oooooooo
003o00Gooooo00Co003ooooooooooooo003oB?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00Gooooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o1oooool00ol0003o
ooooooooo`01ooooo`002Oooool2o`0000Kooooo00?o0000ooooooooool01_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;o003o0oooool00ol00?ooooooooooo`05ooooo`;o003o
0_ooool2o`00o`Cooooo00?o003oooooooooool00_l00?l2ooooo`09o`00ooooooooooooooooool0
0?ooooooo`00oooooooo003o00Gooooo00?o003oooooooooool00_l00?l2ooooo`07o`00oooooooo
ooooooooool00?ooooooo`00o`03ooooo`06o`00ooooooooooooo`00oooooooo003o0oooool01ol0
0?ooooooo`00oooooooo003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo003o00Gooooo
00?o003oooooooooool00_l00?l2ooooo`05o`00oooooooo003oooooool00?l04?ooool02ol0003o
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o053ooooo00Go003ooooooooooooo
ooooo`00o`07ooooo`04o`00ooooooooooooooooo`;o003o0oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`08ooooo`03o`000?oooooooooo007ooooo000:
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Gooooo
0_l00?l4ooooo`05o`00ooooooooooooooooool00?l00_ooool2o`00o`Cooooo00Go003oooooool0
0?ooooooo`00o`02ooooo`04o`00ooooooooooooooooo`;o003o1?ooool00ol00?ooooooo`00o`04
ooooo`;o003o1_ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooo003o00Cooooo00Oo003o
ooooool00?ooooooo`00oooooooo003o00Gooooo00So003ooooooooooooo003oooooool00?oooooo
o`00oa3ooooo00_o0000ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`02oooo
o`03o`00oooooooooooo04oooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l2ooooo`;o003o
1oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`06ooooo`05o`00oooo
ooooooooooooool00?l02?ooool01?l00?ooooooooooooooool2o`00o`Kooooo00Go003ooooooooo
ooooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool01_l00?ooooooooooool0
0?ooooooo`00o`;ooooo0_l00?l8ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool00_ooool02Ol00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00o`03ooooo`03o`00oooooooo003o00Kooooo00?o
003oooooooooool03_ooool02Ol0003oooooo`00oooooooo003oooooool00?ooooooo`00o`04oooo
o`03o`00oooooooooooo05?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0oooool00ol00?oooooooooo
o`05ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00001oooool01?l00?oooooooooooooo
ool2o`00o`;ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooooooool2o`00o`;ooooo
0_l00?l6ooooo`03o`00oooooooooooo00;ooooo0_l00?l3ooooo`03o`00oooooooooooo00;o003o
1?ooool00ol00?ooooooooooo`02o`00o`;ooooo0_l00?l2ooooo`03o`00oooooooo003o00?ooooo
00Co003ooooooooooooo003o0oooool01Ol00?ooooooo`00oooooooo003o00?ooooo00?o003ooooo
ool00?l01?ooool00ol00?ooooooooooo`03ooooo`09o`00oooooooo003oooooool00?ooooooo`00
oooooooo003o00;ooooo00?o003oooooool00?l04_ooool00ol0003oooooooooo`03ooooo`03o`00
oooooooo003o00Cooooo00?o003oooooooooool0Doooool01Ol00?oooooooooooooooooo003o00?o
oooo0_l00?l3ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`04ooooo`;o00000oooool0017ooooo00?o0000ooooooooool01_ooool01?l00?oooooo
ooooooooool2o`00o`;ooooo0_l00?l7ooooo`;o003o0_ooool2o`00o`?ooooo00?o003ooooooooo
ool00_l00?l3ooooo`04o`00ooooooooooooooooo`;o003o0_ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo00;o003o0_ooool2o`00o`;ooooo00?o003oooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00;ooooo0_l00?l2ooooo`05o`00oooooooo003oooooool00?l00ooo
ool00ol00?ooooooo`00o`06ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`04ooooo`03
o`00oooooooo003o01;ooooo00Co0000oooooooooooo003o1_ooool01?l00?ooooooooooool00?mI
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`07ooooo`04o`00oooo
ooooooooooooo`;o003o1oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`06ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?l3ooooo`03o`00oooo
oooooooo00Gooooo0_l00?l2ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool00_l00?l2ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`03ooooo`03o`00oooooooo
oooo00;o003o1?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooo003o00;ooooo00?o003o
ooooool00?l01Oooool01Ol00?ooooooo`00oooooooo003o00;ooooo00Go003oooooool00?oooooo
o`00o`0@ooooo`04o`000?oooooo003oo`00o`;ooooo00Go003oooooooooooooooooo`00o`1Poooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooo
oooo00Kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01_ooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`04o`00ooooooooooooooooo`;o
003o0_ooool01?l00?ooooooooooooooool2o`00o`;ooooo00?o003oooooooooool00_ooool01?l0
0?ooooooooooooooool2o`00o`;ooooo00Go003oooooooooooooooooo`00o`04ooooo`;o003o2?oo
ool01ol00?ooooooo`00oooooooo003oooooool00?l01?ooool01Ol00?ooooooo`00oooooooo003o
00Oooooo00So003ooooooooooooo003oooooool00?ooooooo`00oa3ooooo00Co0000ooooool00?oo
003o0_ooool01Ol00?ooooooo`00oooooooo003o063ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`08ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo00Kooooo00Go003oooooooooooooooooo`00
o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`05ooooo`04o`00
ooooooooooooooooo`;o003o1?ooool00ol00?ooooooooooo`02o`00o`?ooooo00Ko003ooooooooo
oooo003oooooool00?l2ooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooooooo003o1?oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`02ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`05ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool03_ooool01?l0003oooooo`00ool00?l2ooooo`05o`00oooooooo
003oooooool00?l00_ooool00ol00?ooooooooooo`1Tooooo`05o`00ooooooooooooooooool00?l0
1?ooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00001ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo0_l00?l6ooooo`03o`00oooooooooooo00;ooooo0_l00?l3ooooo`03
o`00oooooooooooo00;o003o0_ooool00ol00?ooooooo`00o`02ooooo`;o003o1_ooool2o`00o`;o
oooo00?o003oooooool00?l00_ooool01?l00?ooooooooooooooool2o`00o`;ooooo00Oo003ooooo
ooooooooooooo`00oooooooo003o00?ooooo00?o003oooooooooool01?ooool02Ol00?ooooooo`00
oooooooo003oooooool00?ooooooo`00o`0Gooooo`03o`000?oooooooooo00?ooooo00?o003ooooo
ool00?l01?ooool00ol00?ooooooooooo`1Tooooo`05o`00ooooooooooooooooool00?l01?ooool0
0ol00?ooooooooooo`04ooooo`;o00000oooool0017ooooo00?o0000ooooooooool01_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00ooo
ool2o`00o`?ooooo00?o003oooooooooool00_l00?l3ooooo`04o`00ooooooooooooooooo`;o003o
0_ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooooooo`;o003o0_ooool2o`00o`;o
oooo0_l00?l4ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00o`;ooooo00Go003oooooool0
0?ooooooo`00o`03ooooo`03o`00oooooooo003o00Kooooo00Oo003oooooool00?ooooooo`00oooo
oooo003o00?ooooo00Co003ooooooooooooo003o4_ooool00ol0003oooooooooo`07ooooo`03o`00
oooooooo003o06_ooooo00Go003oooooooooooooooooo`00o`08ooooo`03o`000?oooooooooo007o
oooo000Aooooo`03o`000?oooooooooo00Kooooo00Go003oooooooooooooooooo`00o`03ooooo`;o
003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l2ooooo`;o003o0_ooool2o`00
o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Ooo
ool00ol00?ooooooooooo`02o`00o`;ooooo00Oo003oooooooooooooooooo`00oooooooo003o00?o
oooo00?o003oooooooooool00_l00?l4ooooo`03o`00oooooooo003o00?ooooo00?o003oooooool0
0?l00_ooool2o`00o`Kooooo00?o003oooooool00?l00oooool01_l00?ooooooooooool00?oooooo
o`00oa3ooooo00Co0000ooooool00?oo003o1_ooool00ol00?ooooooooooo`1_ooooo`03o`00oooo
oooooooo00Kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo0_l00?l3ooooo`03o`00oooooooooooo00Gooooo0_l0
0?l2ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo
oooo0_l00?l2ooooo`03o`00oooooooooooo00Kooooo0_l00?l2ooooo`05o`00oooooooooooooooo
ool00?l01?ooool2o`00o`;ooooo00?o003oooooooooool00_ooool02?l00?ooooooooooool00?oo
ooooo`00oooooooo003o1?ooool2o`00o`Kooooo00Oo003oooooooooooooooooo`00oooooooo003o
00;ooooo00?o003oooooool00?l04?ooool01?l0003oooooo`00ool00?l2ooooo`05o`00oooooooo
003oooooool00?l0LOooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo00Kooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`05ooooo`;o003o0_ooool2o`00o`?ooooo
00Co003ooooooooooooooooo0_l00?l3ooooo`03o`00oooooooooooo00;o003o0oooool00ol00?oo
ooooooooo`06ooooo`04o`00ooooooooooooo`00o`Cooooo0_l00?l6ooooo`;o003o1?ooool00ol0
0?ooooooo`00o`04ooooo`;o003o0_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool03_ooool01?l0003oooooo`00ool00?l2ooooo`07o`00oooooooo
003oooooool00?ooooooo`00o`1_ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool0
0Oooool0017ooooo0_l00007ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00_ooool2o`00o`?ooooo0_l00?l7ooooo`03o`00oooooooooooo00;o003o0oooool0
1?l00?ooooooooooooooool2o`00o`;ooooo00?o003oooooooooool00oooool01Ol00?oooooooooo
oooooooo003o00;ooooo0_l00?l2ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo
003o00Kooooo00?o003oooooooooool03_ooool00ol0003oooooo`00o`03ooooo`03o`00oooooooo
003o00?ooooo00?o003oooooooooool0MOooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo
00[ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02o`00o`?ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`;o
003o0_ooool2o`00o`?ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`;o003o0_ooool02ol0
0?oooooooooooooooooo003oooooool00?ooooooo`00oooooooo003o00Kooooo00Oo003oooooool0
0?ooooooo`00oooooooo003o00?ooooo00Co003ooooooooooooo003o4_ooool00ol0003ooooooooo
o`05ooooo`05o`00ooooooooooooooooool00?l0N?ooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`04o`00ooooooooooooooooo`;o003o0_ooool2o`00o`?ooooo00Co003ooooooooo
oooooooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`;o003o0_ooool2o`00o`?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
o`00o`;ooooo0_l00?l2ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`02ooooo`;o003o
0oooool01_l00?ooooooooooool00?ooooooo`00o`?ooooo00?o003oooooooooool00_l00?lAoooo
o`04o`000?oooooo003oo`00o`Kooooo00?o003oooooool00?l0N?ooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo00Gooooo00Co003ooooo
oooooooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oooooooooo
ooooool2o`00o`;ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooooooool2o`00o`;o
oooo00Co003ooooooooooooooooo0_l00?l4ooooo`03o`00oooooooooooo00;o003o0oooool00ol0
0?ooooooooooo`02o`00o`;ooooo00?o003oooooooooool00_ooool2o`00o`Kooooo00Oo003ooooo
ool00?ooooooo`00oooooooo003o00;ooooo0_l00?lAooooo`04o`000?oooooo003oo`00o`;ooooo
00Go003oooooool00?ooooooo`00o`1jooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo01?ooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_l00?l3ooooo`04o`00ooooooooooooooooo`;o003o0oooool01?l00?ooooooooooool0
0?l4ooooo`;o003o1_ooool2o`00o`?ooooo00Co003ooooooooooooo003o1?ooool2o`00o`;ooooo
0_l00?l6ooooo`03o`00oooooooo003o00;ooooo0_l00?lAooooo`04o`000?oooooo003oo`00o`;o
oooo00Oo003oooooool00?ooooooo`00oooooooo003o07Sooooo00?o0000ooooooooool00Oooool0
017ooooo0_l0000Hooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;o003o
0oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00;o003o0oooool00ol00?oooooo
ooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02o`00o`;ooooo0_l00?l4ooooo`03o`00oooooooo003o00Gooooo00?o003ooooooooo
ool03oooool01?l0003oooooo`00ool00?l2ooooo`;o003o1?ooool00ol00?ooooooooooo`1eoooo
o`;o00000oooool0017ooooo00?o0000ooooooooool05oooool01Ol00?oooooooooooooooooo003o
00Oooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l3
ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00o`?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`;o003o0_ooool01?l00?ooooooooooooooool2o`00
o`Cooooo00?o003oooooooooool01?ooool2o`00o`;ooooo00Oo003oooooool00?ooooooo`00oooo
oooo003o00;ooooo00?o003oooooooooool04?ooool00ol0003oooooooooo`03ooooo`;o003o1?oo
ool00ol00?ooooooooooo`1fooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool2
o`00o`;ooooo0_l00?l2ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`06ooooo`;o003o
0_ooool2o`00o`Cooooo00Co003ooooooooooooo003o4_ooool00ol0003oooooo`00o`07ooooo`03
o`00oooooooo003o07Sooooo00?o0000ooooooooool00Oooool000Sooooo1Ol00004ooooo`03o`00
0?oooooooooo01oooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o0oooool01?l00?oooooooooo
ooooool2o`00o`?ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooo`00o`02ooooo`;o
003o1_ooool2o`00o`;ooooo00?o003oooooool00?l00_ooool2o`00oa7ooooo00?o0000ooooool0
0?l00oooool2o`00o`;ooooo00?o003oooooooooool0N?ooool00ol0003oooooooooo`01ooooo`00
2Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`02o`00o`;ooooo00?o003oooooooooool0
0_ooool2o`00o`;ooooo0_l00?l6ooooo`03o`00oooooooo003o00;ooooo0_l00?lAooooo`03o`00
0?oooooo003o00?ooooo0_l00?l2ooooo`03o`00oooooooooooo07Sooooo00?o0000ooooooooool0
0Oooool000[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Sooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o
003o0oooool00ol00?ooooooooooo`06ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003ooooo
ooooool01Oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0_ooool2
o`00o`Kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooo
003o00?ooooo0_l00?l2ooooo`03o`00oooooooo003o07Sooooo00?o0000ooooooooool00Oooool0
00_ooooo00?o0000ooooooooool00oooool3o`0002Sooooo00Go003oooooooooooooooooo`00o`03
ooooo`04o`00ooooooooooooooooo`;o003o0oooool00ol00?ooooooooooo`05ooooo`;o003o0_oo
ool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o
003o0oooool00ol00?ooooooooooo`05ooooo`;o003o0_ooool2o`00o`;ooooo00?o003ooooooooo
ool05Oooool00ol0003oooooooooo`03ooooo`;o003o1?ooool00ol00?ooooooooooo`1dooooo`?o
00000oooool000Sooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo02co
oooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00
ooooooooooooooooo`;o003o0_ooool01?l00?ooooooooooooooool2o`00o`Oooooo0_l00?l2oooo
o`;o003o1?ooool01?l00?ooooooooooool00?lBooooo`03o`000?oooooooooo00Oooooo0_l00?mi
ooooo`03o`000?oooooooooo007ooooo0008ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`0`ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00oooooooooooooooo
ool00?l01?ooool01?l00?ooooooooooool00?l3ooooo`;o003o0oooool2o`00o`Kooooo0_l00?l4
ooooo`03o`00oooooooooooo00;o003o4Oooool00ol0003oooooo`00o`07ooooo`03o`00oooooooo
oooo07Sooooo00?o0000ooooooooool00Oooool000Wooooo0ol00005ooooo`03o`000?oooooooooo
033ooooo00Go003oooooooooooooooooo`00o`08ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oooooo
ooooo`02o`00o`;ooooo00?o003oooooooooool00_ooool2o`00o`Kooooo00Co003ooooooooooooo
oooo0_l00?l3ooooo`;o003o4Oooool00ol0003oooooo`00o`03ooooo`;o003o0_ooool00ol00?oo
ooooooooo`1hooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo03Cooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`05o`00ooooooooooooooooool0
0?l01?ooool00ol00?ooooooooooo`05ooooo`;o003o0oooool00ol00?ooooooooooo`05ooooo`04
o`00ooooooooooooooooo`;o003o1_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00oooooo00?o0000ooooool00?l00oooool2o`00o`;ooooo0_l00?miooooo`03o`000?oooooooooo
007ooooo000Aooooo`;o0000>_ooool00ol00?ooooooooooo`05ooooo`04o`00oooooooooooooooo
o`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`;o003o
0_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o0000ooooool00?l0
0oooool2o`00o`?ooooo00?o003oooooooooool0M_ooool2o`0000?ooooo000Aooooo`03o`000?oo
oooooooo03Wooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00
o`;ooooo0_l00?l7ooooo`;o003o0_ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`0B
ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool0Moooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`0mooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo0_l00?l3ooooo`03o`00oooooooooooo00Gooooo0_l00?l3ooooo`04o`00
ooooooooooooooooo`;o003o4Oooool00ol0003oooooooooo`07ooooo`;o003oNOooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`11ooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?l2
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool2o`00o`;ooooo0_l00?l3
ooooo`;o003o4Oooool00ol0003oooooooooo`03ooooo`;o003o0_ooool00ol00?ooooooooooo`1h
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04Gooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooooooo`;o003o1_ooool2o`00o`?ooooo
00?o003oooooooooool04?ooool00ol0003oooooooooo`03ooooo`;o003o0_ooool2o`00ogWooooo
00?o0000ooooooooool00Oooool0017ooooo0_l00016ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o0oooool01?l00?ooooooooooool00?l4
ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo07Kooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1:oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l0
0?l7ooooo`04o`00ooooooooooooooooo`;o003o0_ooool2o`00o`?ooooo00?o003oooooooooool0
4?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
Moooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1>ooooo`05o`00oooo
ooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00o`Oooooo00Co003ooooooooo
oooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l04_ooool00ol0003oooooooooo`07
ooooo`;o003oNOooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1>oooo
o`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00o`?ooooo00?o
003oooooooooool01Oooool2o`00o`;ooooo0_l00?l3ooooo`03o`00oooooooooooo013ooooo00?o
0000ooooooooool00oooool01Ol00?oooooooooooooooooo003o07[ooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool0D_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Oooooo0_l00?l3ooooo`03
o`00oooooooooooo013ooooo00?o0000ooooooooool00oooool01Ol00?oooooooooooooooooo003o
07[ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001Cooooo`05o`00oooooooooooooooo
ool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol0003ooooooooo
o`03ooooo`04o`00ooooooooooooooooo`;o003oN?ooool2o`0000?ooooo000Aooooo`03o`000?oo
oooooooo05Kooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`1gooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo05[ooooo0_l00?l7ooooo`05o`00ooooooooooooooooool00?l0
1?ooool01Ol00?oooooooooooooooooo003o01;ooooo00?o0000ooooooooool01oooool2o`00ogWo
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Goooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0Booooo`03
o`000?oooooooooo00Oooooo00?o003oooooooooool0N?ooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`1Oooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo
oooo0_l00?l3ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool00oooool01Ol00?oo
oooooooooooooooo003o07[ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001Tooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03
o`000?oooooooooo00?ooooo00Go003oooooooooooooooooo`00o`1iooooo`;o00000oooool0017o
oooo00?o0000ooooooooool0Hoooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o003ooooo
ooooool0N?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Wooooo`04
o`00ooooooooooooooooo`;o003o0oooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo
00Oooooo00?o003oooooooooool0N?ooool00ol0003oooooooooo`01ooooo`002Oooool3o`0000Go
oooo00?o0000ooooooooool0Joooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013o
oooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`1hooooo`03o`000?oooooooooo007o
oooo0008ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1[ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol0003oooooooooo`07ooooo`03
o`00oooooooooooo07Sooooo00?o0000ooooooooool00Oooool000cooooo00?o0000ooooooooool0
0_ooool3o`00073ooooo00?o003oooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`00
oooooooooooo07Kooooo0ol00003ooooo`002_ooool2o`0000Gooooo00?o0000ooooooooool0L?oo
ool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool00Ooo
ool000cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`23ooooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool00Oooool000Sooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`01
ooooo`002Oooool3o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`01oooo
o`004Oooooooo`0000go00000oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-11.9139, -3.65495, \
0.0788464, 0.0387345}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Magnitude plot of DFT as a function of frequency", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fft\  = \ DFT[xd];\)\), "\n", 
    \(\(g3 = 
        DiscreteListPlot[\({#[\([1]\)], \ Abs[#[\([2]\)]]} &\)\  /@ \ fft, 
          Red, \ PlotRange \[Rule] All, \ Frame \[Rule] True, \ 
          Axes \[Rule] False];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0161421 0.0147151 0.0289582 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18523 -0.0125 -6 -9 ]
[.18523 -0.0125 6 0 ]
[.34665 -0.0125 -6 -9 ]
[.34665 -0.0125 6 0 ]
[.50807 -0.0125 -6 -9 ]
[.50807 -0.0125 6 0 ]
[.66949 -0.0125 -6 -9 ]
[.66949 -0.0125 6 0 ]
[.83091 -0.0125 -6 -9 ]
[.83091 -0.0125 6 0 ]
[.99233 -0.0125 -6 -9 ]
[.99233 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15951 -6 -4.5 ]
[-0.0125 .15951 0 4.5 ]
[-0.0125 .3043 -12 -4.5 ]
[-0.0125 .3043 0 4.5 ]
[-0.0125 .44909 -12 -4.5 ]
[-0.0125 .44909 0 4.5 ]
[-0.0125 .59388 -12 -4.5 ]
[-0.0125 .59388 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18523 0 m
.18523 .00625 L
s
[(10)] .18523 -0.0125 0 1 Mshowa
.34665 0 m
.34665 .00625 L
s
[(20)] .34665 -0.0125 0 1 Mshowa
.50807 0 m
.50807 .00625 L
s
[(30)] .50807 -0.0125 0 1 Mshowa
.66949 0 m
.66949 .00625 L
s
[(40)] .66949 -0.0125 0 1 Mshowa
.83091 0 m
.83091 .00625 L
s
[(50)] .83091 -0.0125 0 1 Mshowa
.99233 0 m
.99233 .00625 L
s
[(60)] .99233 -0.0125 0 1 Mshowa
.125 Mabswid
.05609 0 m
.05609 .00375 L
s
.08838 0 m
.08838 .00375 L
s
.12066 0 m
.12066 .00375 L
s
.15295 0 m
.15295 .00375 L
s
.21751 0 m
.21751 .00375 L
s
.2498 0 m
.2498 .00375 L
s
.28208 0 m
.28208 .00375 L
s
.31437 0 m
.31437 .00375 L
s
.37893 0 m
.37893 .00375 L
s
.41122 0 m
.41122 .00375 L
s
.4435 0 m
.4435 .00375 L
s
.47579 0 m
.47579 .00375 L
s
.54036 0 m
.54036 .00375 L
s
.57264 0 m
.57264 .00375 L
s
.60492 0 m
.60492 .00375 L
s
.63721 0 m
.63721 .00375 L
s
.70178 0 m
.70178 .00375 L
s
.73406 0 m
.73406 .00375 L
s
.76634 0 m
.76634 .00375 L
s
.79863 0 m
.79863 .00375 L
s
.8632 0 m
.8632 .00375 L
s
.89548 0 m
.89548 .00375 L
s
.92776 0 m
.92776 .00375 L
s
.96005 0 m
.96005 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15951 m
.00625 .15951 L
s
[(5)] -0.0125 .15951 1 0 Mshowa
0 .3043 m
.00625 .3043 L
s
[(10)] -0.0125 .3043 1 0 Mshowa
0 .44909 m
.00625 .44909 L
s
[(15)] -0.0125 .44909 1 0 Mshowa
0 .59388 m
.00625 .59388 L
s
[(20)] -0.0125 .59388 1 0 Mshowa
.125 Mabswid
0 .04367 m
.00375 .04367 L
s
0 .07263 m
.00375 .07263 L
s
0 .10159 m
.00375 .10159 L
s
0 .13055 m
.00375 .13055 L
s
0 .18846 m
.00375 .18846 L
s
0 .21742 m
.00375 .21742 L
s
0 .24638 m
.00375 .24638 L
s
0 .27534 m
.00375 .27534 L
s
0 .33326 m
.00375 .33326 L
s
0 .36221 m
.00375 .36221 L
s
0 .39117 m
.00375 .39117 L
s
0 .42013 m
.00375 .42013 L
s
0 .47805 m
.00375 .47805 L
s
0 .50701 m
.00375 .50701 L
s
0 .53596 m
.00375 .53596 L
s
0 .56492 m
.00375 .56492 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18523 .61178 m
.18523 .61803 L
s
.34665 .61178 m
.34665 .61803 L
s
.50807 .61178 m
.50807 .61803 L
s
.66949 .61178 m
.66949 .61803 L
s
.83091 .61178 m
.83091 .61803 L
s
.99233 .61178 m
.99233 .61803 L
s
.125 Mabswid
.05609 .61428 m
.05609 .61803 L
s
.08838 .61428 m
.08838 .61803 L
s
.12066 .61428 m
.12066 .61803 L
s
.15295 .61428 m
.15295 .61803 L
s
.21751 .61428 m
.21751 .61803 L
s
.2498 .61428 m
.2498 .61803 L
s
.28208 .61428 m
.28208 .61803 L
s
.31437 .61428 m
.31437 .61803 L
s
.37893 .61428 m
.37893 .61803 L
s
.41122 .61428 m
.41122 .61803 L
s
.4435 .61428 m
.4435 .61803 L
s
.47579 .61428 m
.47579 .61803 L
s
.54036 .61428 m
.54036 .61803 L
s
.57264 .61428 m
.57264 .61803 L
s
.60492 .61428 m
.60492 .61803 L
s
.63721 .61428 m
.63721 .61803 L
s
.70178 .61428 m
.70178 .61803 L
s
.73406 .61428 m
.73406 .61803 L
s
.76634 .61428 m
.76634 .61803 L
s
.79863 .61428 m
.79863 .61803 L
s
.8632 .61428 m
.8632 .61803 L
s
.89548 .61428 m
.89548 .61803 L
s
.92776 .61428 m
.92776 .61803 L
s
.96005 .61428 m
.96005 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15951 m
1 .15951 L
s
.99375 .3043 m
1 .3043 L
s
.99375 .44909 m
1 .44909 L
s
.99375 .59388 m
1 .59388 L
s
.125 Mabswid
.99625 .04367 m
1 .04367 L
s
.99625 .07263 m
1 .07263 L
s
.99625 .10159 m
1 .10159 L
s
.99625 .13055 m
1 .13055 L
s
.99625 .18846 m
1 .18846 L
s
.99625 .21742 m
1 .21742 L
s
.99625 .24638 m
1 .24638 L
s
.99625 .27534 m
1 .27534 L
s
.99625 .33326 m
1 .33326 L
s
.99625 .36221 m
1 .36221 L
s
.99625 .39117 m
1 .39117 L
s
.99625 .42013 m
1 .42013 L
s
.99625 .47805 m
1 .47805 L
s
.99625 .50701 m
1 .50701 L
s
.99625 .53596 m
1 .53596 L
s
.99625 .56492 m
1 .56492 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .04367 L
s
.03995 .01472 m
.03995 .07221 L
s
.05609 .01472 m
.05609 .15288 L
s
.07224 .01472 m
.07224 .52758 L
s
.08838 .01472 m
.08838 .60332 L
s
.10452 .01472 m
.10452 .23099 L
s
.12066 .01472 m
.12066 .1544 L
s
.1368 .01472 m
.1368 .12051 L
s
.15295 .01472 m
.15295 .10109 L
s
.16909 .01472 m
.16909 .08839 L
s
.18523 .01472 m
.18523 .0794 L
s
.20137 .01472 m
.20137 .07268 L
s
.21751 .01472 m
.21751 .06747 L
s
.23366 .01472 m
.23366 .06332 L
s
.2498 .01472 m
.2498 .05994 L
s
.26594 .01472 m
.26594 .05715 L
s
.28208 .01472 m
.28208 .05482 L
s
.29822 .01472 m
.29822 .05285 L
s
.31437 .01472 m
.31437 .05118 L
s
.33051 .01472 m
.33051 .04976 L
s
.34665 .01472 m
.34665 .04855 L
s
.36279 .01472 m
.36279 .04751 L
s
.37893 .01472 m
.37893 .04663 L
s
.39508 .01472 m
.39508 .04589 L
s
.41122 .01472 m
.41122 .04528 L
s
.42736 .01472 m
.42736 .04477 L
s
.4435 .01472 m
.4435 .04437 L
s
.45964 .01472 m
.45964 .04406 L
s
.47579 .01472 m
.47579 .04384 L
s
.49193 .01472 m
.49193 .04372 L
s
.50807 .01472 m
.50807 .04367 L
s
.52421 .01472 m
.52421 .04372 L
s
.54036 .01472 m
.54036 .04384 L
s
.5565 .01472 m
.5565 .04406 L
s
.57264 .01472 m
.57264 .04437 L
s
.58878 .01472 m
.58878 .04477 L
s
.60492 .01472 m
.60492 .04528 L
s
.62107 .01472 m
.62107 .04589 L
s
.63721 .01472 m
.63721 .04663 L
s
.65335 .01472 m
.65335 .04751 L
s
.66949 .01472 m
.66949 .04855 L
s
.68563 .01472 m
.68563 .04976 L
s
.70178 .01472 m
.70178 .05118 L
s
.71792 .01472 m
.71792 .05285 L
s
.73406 .01472 m
.73406 .05482 L
s
.7502 .01472 m
.7502 .05715 L
s
.76634 .01472 m
.76634 .05994 L
s
.78249 .01472 m
.78249 .06332 L
s
.79863 .01472 m
.79863 .06747 L
s
.81477 .01472 m
.81477 .07268 L
s
.83091 .01472 m
.83091 .0794 L
s
.84705 .01472 m
.84705 .08839 L
s
.8632 .01472 m
.8632 .10109 L
s
.87934 .01472 m
.87934 .12051 L
s
.89548 .01472 m
.89548 .1544 L
s
.91162 .01472 m
.91162 .23099 L
s
.92776 .01472 m
.92776 .60332 L
s
.94391 .01472 m
.94391 .52758 L
s
.96005 .01472 m
.96005 .15288 L
s
.97619 .01472 m
.97619 .07221 L
s
.015 w
.02381 .04367 Mdot
.03995 .07221 Mdot
.05609 .15288 Mdot
.07224 .52758 Mdot
.08838 .60332 Mdot
.10452 .23099 Mdot
.12066 .1544 Mdot
.1368 .12051 Mdot
.15295 .10109 Mdot
.16909 .08839 Mdot
.18523 .0794 Mdot
.20137 .07268 Mdot
.21751 .06747 Mdot
.23366 .06332 Mdot
.2498 .05994 Mdot
.26594 .05715 Mdot
.28208 .05482 Mdot
.29822 .05285 Mdot
.31437 .05118 Mdot
.33051 .04976 Mdot
.34665 .04855 Mdot
.36279 .04751 Mdot
.37893 .04663 Mdot
.39508 .04589 Mdot
.41122 .04528 Mdot
.42736 .04477 Mdot
.4435 .04437 Mdot
.45964 .04406 Mdot
.47579 .04384 Mdot
.49193 .04372 Mdot
.50807 .04367 Mdot
.52421 .04372 Mdot
.54036 .04384 Mdot
.5565 .04406 Mdot
.57264 .04437 Mdot
.58878 .04477 Mdot
.60492 .04528 Mdot
.62107 .04589 Mdot
.63721 .04663 Mdot
.65335 .04751 Mdot
.66949 .04855 Mdot
.68563 .04976 Mdot
.70178 .05118 Mdot
.71792 .05285 Mdot
.73406 .05482 Mdot
.7502 .05715 Mdot
.76634 .05994 Mdot
.78249 .06332 Mdot
.79863 .06747 Mdot
.81477 .07268 Mdot
.83091 .0794 Mdot
.84705 .08839 Mdot
.8632 .10109 Mdot
.87934 .12051 Mdot
.89548 .1544 Mdot
.91162 .23099 Mdot
.92776 .60332 Mdot
.94391 .52758 Mdot
.96005 .15288 Mdot
.97619 .07221 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005Oooool2o`0002Gooooo0ol00004ooooo`;o00008Oooool5o`0000?ooooo0_l0000Roooo
o`?o00001?ooool2o`0002?ooooo0ol00003ooooo`;o00008_ooool3o`0000Cooooo0_l0000Roooo
o`?o00001?ooool2o`0000Cooooo000Dooooo`04o`000?ooooooooooo`0002Gooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool0000Qooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00008?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00008oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool07_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool001Cooooo00Co0000oooooooo
oooo00009Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002;ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000Tooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool07_ooool5o`0000;ooooo00Co0000oooooooooooo00009?ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000?ooooo000Dooooo`04o`000?ooooooooooo`0002Gooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool0000Sooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`0Pooooo`;o00000oooool01?l0003oooooooooool0000Poooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00009?ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo01kooooo1?l00003ooooo`04o`000?ooooooooooo`0000?o
oooo000Dooooo`04o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000Pooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
000Tooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool07oooool00ol0003ooooo
o`000003ooooo`04o`000?ooooooooooo`00023ooooo1?l00003ooooo`04o`000?ooooooooooo`00
023ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00003ooooo`005?ooool01?l0
003oooooooooool0000Tooooo`;o00001?ooool01?l0003oooooooooool0000Pooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool0000Pooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool0000Rooooo`;o00000oooool01?l0003oooooooooool0
000Pooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00008Oooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo000Eooooo`;o00009_ooool00ol0003ooooo
ooooo`03ooooo`;o00008_ooool3o`0000Cooooo0_l0000Rooooo`?o00001?ooool2o`0002Cooooo
00?o0000ooooooooool00_ooool2o`00027ooooo1Ol00003ooooo`;o00008oooool2o`0000Cooooo
0_l00004ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
4?ooooooo`0000co00001Oooool000Sooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooool000001Oooool000Oooooo00Co0000oooooooooooo00001Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooo000000Gooooo0007ooooo`04o`000?ooooooooooo`0000Gooooo00?o
0000ooooooooool0ooooool8ooooo`03o`000?oooooooooo00?ooooo0007ooooo`04o`000?oooooo
ooooo`0000Gooooo0_l00004ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooo
ooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05
ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00oooooooooooooooo
ool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03
ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooo
oooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo
ool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooo
oooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000ooo
ool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooo
ooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo
00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00
ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`00
00?ooooo00?oo`00ooooooooool00_ooool01?oo003oooooooooooooool3o`0000Gooooo0007oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00oooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo
00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooooooo
ool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004
ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oo
oooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo
00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003
ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oo
oooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo
003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooooooo
00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool00ooo
003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooo
ooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo
00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`001oooool01?l0003oooooooooool00005ooooo`03
o`000?oooooooooo00?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo
00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00
ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooooooooooo
ool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`00
00?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00
ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool00004ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05
ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00oooooooooooooooo
ool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03
ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooo
oooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo
ool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooo
oooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000ooo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool000Sooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo00Goo`00ooooooooooooooooool0
0003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool0
0?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;o
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool0
1Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?o
oooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooooooo00000oooool0
0ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooooooo
o`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Co
oooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooo
ooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool0
0003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?o
oooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooo
ooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
0004ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool0
0?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?o
oooo00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool00oooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`00
00?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00
ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool00004ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05
ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00oooooooooooooooo
ool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03
ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooo
oooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo
ool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooo
oooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000ooo
ool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooo
ooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo
00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00oooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`03oooo
o`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooo
oooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo0000
0oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003o
ooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooo
oooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003o
ooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooooooo
o`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Go
o`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003o
ooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02oooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Go
o`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooooooo
ooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003oooo
o`05ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?o
o`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oo
oooooooo00?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo
00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooo
ooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo
00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooooooo
ool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004
ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oo
oooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo
00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003
ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oo
oooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo
003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooooooo
00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool00oooool0013o
oooo00Co0000oooooooooooooooo0ooo0003ooooo`05ool00?oooooooooooooooooo00001?ooool0
1Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?o
oooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooooooo00000oooool0
0ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooooooo
o`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Co
oooo00?oo`00ooooooooool00ooo00001Oooooooo`00ool00?oo003ooooo00?oo`000_ooool3ool0
0005oooooooo003oo`00ool00?ooool00ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`0000Go
ooooool00?oo003oo`00ooooo`03ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?o
o`000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo
00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooooooo
ool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004
ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oo
oooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo
00?o0000ooooooooool00oooool0013ooooo0_l00002ooooo`?oo`000oooool01Ooo003ooooooooo
ooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;o
oooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooo
ooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooool00002ool000;ooooo0ooo00001Ooooooo
o`00ool00?oo003ooooo00?oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo0002
ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool00004oooooooo003oo`00ool000;ooooo
0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`000_ooool3ool00005oooooooo003oo`00ool0
0?ooool00ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`0000Goooooool00?oo003oo`00oooo
o`03ool000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooooooo
00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool00ooo
003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooo
ooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo
00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool2o`0000Gooooo000@ooooo`04o`000?ooooooooooooooo`?oo`000oooool01Ooo003o
ooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooo
oooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003o
ooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ool0
0005oooooooo003oo`00ool00?ooool00ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`0000Go
ooooool00?oo003oo`00ooooo`03ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?o
o`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo00001?ooooooo`00ool00?oo0002
ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool000;ooooo0ooo00001Oooooooo`00ool0
0?oo003ooooo00?oo`0000Coooooool00?oo003oo`000_ooool3ool00005oooooooo003oo`00ool0
0?ooool00ooo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool000?ooooo00Goo`00
ooooooooooooooooool00004ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooo
ooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`00
00Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00
ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`07ooooo`05ool00?oooooo
oooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0
0_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003o
ooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooo
oooooooooooo00000oooool00ooo003oooooooooo`03ool000;ooooo0ooo00001Oooooooo`00ool0
0?oo003ooooo00?oo`0000Coooooool00?oo003oo`000_ooool3ool00005oooooooo003oo`00ool0
0?ooool00ooo000iooooo`?oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo0002
ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool000;ooooo0ooo0002ooooo`03ool00?oo
oooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo
00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo
003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo000@ooooo`03o`000?oooooooooo00Oooooo00Goo`00ooooooooooooooooool0
0004ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool0
0?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooo
oooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00ooo0000
1Oooooooo`00ool00?oo003ooooo00?oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool0
0ooo001Looooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool000;ooooo0ooo00001Ooooooo
o`00ool00?oo003ooooo00?oo`000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00
ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`00
00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo000@ooooo`03o`000?oooooooooo00Oooooo00Goo`00ooooooooooooooooool00004oooo
o`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooo
oooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo0000
0oooool01Ooo003oooooooooooooooooo`0000;ooooo0ooo0002ooooo`?oo`0000Goooooool00?oo
003oo`00ooooo`03ool007Kooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Cooooo
ool00?oo003oo`000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo0000
0oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003oooo
o`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`03ooooo`004?ooool00ol0
003oooooooooo`07ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo
00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooooooo
ool00ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`0000Coooooool00?oo003oo`00O_ooool3
ool00005oooooooo003oo`00ool00?ooool00ooo0002ooooo`?oo`000oooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooo
oooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
013ooooo00?o0000ooooooooool01oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00
ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooooooooooo
ool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03
ool00?oooooooooo00?oo`0000Coooooool00?oo003oo`00Soooool3ool000;ooooo0ooo0003oooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Go
o`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooooooo
ooooool00003ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`004?ooool2o`0000Oooooo0ooo0002ooooo`03ool00?oooooooooo00;ooooo
00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooo
ooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00002
ooooo`?oo`0000Coooooool00?oo003oo`00V?ooool3ool00004oooooooo003oo`00ool000?ooooo
00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooo
ooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003
ooooo`03ool00?oooooooooo00?oo`001?ooool2o`0000Gooooo000@ooooo`03o`000?oooooooooo
00Kooooo0ooo0002ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003
ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00oooooooo00000_oo0002ooooo`?oo`00X?ooool3ool00004oooooooo
003oo`00ool000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooo
oooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool0
0ooo003oooooooooo`03ool000Gooooo00?o0000ooooooooool00oooool0013ooooo00?o0000oooo
ooooool01_ooool3ool000;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooooooo
o`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooool00002ool000;ooooo0ooo002Pooooo`?oo`0000Co
ooooool00?oo003oo`000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00oooooooo
ooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003
ooooo`03ool00?oooooooooo00?oo`001Oooool00ol0003oooooooooo`03ooooo`004?ooool00ol0
003oooooooooo`0;ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003
ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00oooooooo00000_oo002Yooooo`?oo`000oooool01Ooo003ooooooooo
ooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;o
oooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00Sooooo00?o0000oooo
ooooool00oooool0013ooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`02ooooo`05
ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooo
oooooooo00000oooool00ooo003oooooooooo`03ool00;;ooooo0ooo0002ooooo`03ool00?oooooo
oooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Go
o`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00Sooooo00?o0000ooooooooool0
0oooool0013ooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`02ooooo`05ool00?oo
oooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo
00000oooool00ooo003oooooooooo`03ool00;;ooooo0ooo0002ooooo`03ool00?oooooooooo00;o
oooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooo
ooooooooooooool00003ooooo`03ool00?oooooooooo00Sooooo00?o0000ooooooooool00oooool0
013ooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooo
oooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000ooo
ool00ooo003oooooooooo`03ool00;;ooooo0ooo0002ooooo`03ool00?oooooooooo00;ooooo00Go
o`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooooooo
ooooool00003ooooo`03ool00?oooooooooo00Sooooo00?o0000ooooooooool00oooool0013ooooo
00?o0000ooooooooool02oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo
00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000_ooool3ool0
0;[ooooo0ooo0003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02
ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`08ooooo`03o`000?oo
oooooooo00?ooooo000@ooooo`;o00003?ooool00ooo003oooooooooo`02ooooo`05ool00?oooooo
oooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo0000
0_ooool3ool00;[ooooo0ooo0003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003o
ooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`07oooo
o`;o00001Oooool0013ooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`02ooooo`05
ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooo
oooooooo00000_ooool3ool00;[ooooo0ooo0003ooooo`05ool00?oooooooooooooooooo00000ooo
ool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooo
ooooo`08ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo00_ooooo00?o
o`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0
0_ooool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00ooooooooooooooooool00003oooo
o`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooo
oooo00Sooooo00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool02oooool00ooo
003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02
ooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo003oooooooooooooooooo`0000?ooooo
00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooooooo
ool02?ooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`0;ooooo`03ool0
0?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00ooo0032ooooo`?oo`000oooool01Ooo003oooooooooooooooooo`00
00Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00Sooooo00?o0000
ooooooooool00oooool0013ooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`02oooo
o`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00?oo`00`_ooool3ool000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oo
oooooooooooooooo00000oooool00ooo003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo
000@ooooo`03o`000?oooooooooo00_ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ool00<;ooooo
0ooo0003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`00
00?ooooo00?oo`00ooooooooool02?ooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003o
ooooooooo`0;ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0boooool01Ooo003ooooooooooooooooo
o`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00Sooooo00?o
0000ooooooooool00oooool0013ooooo0_l0000<ooooo`03ool00?oooooooooo00;ooooo00Goo`00
ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0booo
ool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`03
ool00?oooooooooo00Oooooo0_l00005ooooo`004?ooool00ol0003oooooooooo`0;ooooo`03ool0
0?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool0boooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00oooo
ooooooooooooool00003ooooo`03ool00?oooooooooo00Sooooo00?o0000ooooooooool00oooool0
013ooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooo
oooooooo00000oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo0<_ooooo00Goo`00
ooooooooooooooooool00004ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooo
ooooo`08ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo00_ooooo00?o
o`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`3;ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003o
ooooooooooooooooo`0000?ooooo00?oo`00ooooooooool02?ooool00ol0003oooooooooo`03oooo
o`004?ooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooo
ooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0boooool01Ooo
003oooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oo
oooooooo00Sooooo00?o0000ooooooooool00oooool000Oooooo0ol00006ooooo`03o`000?oooooo
oooo00[ooooo0ooo0003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooooooo
o`03ool00<cooooo0ooo0002ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooooooooooo
ool00002ooooo`?oo`002Oooool00ol0003oooooooooo`03ooooo`001_ooool01Ol0003ooooooooo
oooooooo000000Gooooo00?o0000ooooooooool02_ooool3ool000?ooooo00Goo`00oooooooooooo
ooooool00003ooooo`03ool00?oooooooooo00?oo`00c?ooool3ool000;ooooo00?oo`00oooooooo
ool00_ooool01Ooo003oooooooooooooooooo`0000;ooooo0ooo0009ooooo`03o`000?oooooooooo
00?ooooo000:ooooo`03o`000?oooooooooo00?ooooo0_l0000;ooooo`?oo`000oooool01Ooo003o
ooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00ooo003<ooooo`?oo`000_ooool00ooo
003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000_ooool3ool000Oooooo0ol00005
ooooo`002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo013ooooo00Goo`00oooo
ooooooooooooool00003ooooo`03ool00?oooooooooo0=Cooooo00?oo`00ooooooooool00_ooool0
1Ooo003oooooooooooooooooo`0000kooooo00?o0000ooooooooool00oooool000Kooooo1?l00006
ooooo`03o`000?oooooooooo013ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oo
oooooooo0=Cooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000kooooo
00?o0000ooooooooool00oooool000Kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0@ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`3Dooooo`03ool0
0?oooooooooo00;ooooo00Goo`00ooooooooooooooooool0000>ooooo`03o`000?oooooooooo00?o
oooo0006ooooo`Go00001Oooool00ol0003oooooooooo`0@ooooo`05ool00?oooooooooooooooooo
00000oooool00ooo003oooooooooo`3Dooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooo
ooooooooool0000>ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo013o
oooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo0=Cooooo00?oo`00oooo
ooooool00_ooool01Ooo003oooooooooooooooooo`0000kooooo00?o0000ooooooooool00oooool0
013ooooo00?o0000ooooooooool04?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00
ooooooooool0e?ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00003_oo
ool00ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`0@ooooo`05ool00?oooooo
oooooooooooo00000oooool00ooo003oooooooooo`3Dooooo`03ool00?oooooooooo00;ooooo00Go
o`00ooooooooooooooooool0000>ooooo`03o`000?oooooooooo00?ooooo000@ooooo`;o00004Ooo
ool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0e?ooool00ooo003ooooo
ooooo`02ooooo`05ool00?oooooooooooooooooo00003Oooool2o`0000Gooooo000@ooooo`03o`00
0?oooooooooo013ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo0=Co
oooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000kooooo00?o0000oooo
ooooool00oooool0013ooooo00?o0000ooooooooool04?ooool01Ooo003oooooooooooooooooo`00
00?ooooo00?oo`00ooooooooool0e?ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooo
oooooooo00003_ooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`0@oooo
o`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`3Dooooo`03ool00?oooooo
oooo00;ooooo00Goo`00ooooooooooooooooool0000>ooooo`03o`000?oooooooooo00?ooooo000@
ooooo`03o`000?oooooooooo013ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oo
oooooooo0=Cooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000kooooo
00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool04?ooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00?oo`00ooooooooool0e?ooool00ooo003oooooooooo`02ooooo`05ool0
0?oooooooooooooooooo00003_ooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003ooooo
ooooo`0@ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`3Dooooo`03
ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool0000>ooooo`03o`000?oooooooooo
00?ooooo000@ooooo`03o`000?oooooooooo013ooooo00Goo`00ooooooooooooooooool00003oooo
o`03ool00?oooooooooo0=Cooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooooooo
o`0000kooooo00?o0000ooooooooool00oooool0013ooooo0_l0000Aooooo`05ool00?oooooooooo
oooooooo00000oooool00ooo003oooooooooo`3Dooooo`03ool00?oooooooooo00;ooooo00Goo`00
ooooooooooooooooool0000=ooooo`;o00001Oooool0013ooooo00?o0000ooooooooool04?ooool0
1Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0e?ooool00ooo003ooooooooo
o`02ooooo`05ool00?oooooooooooooooooo00003_ooool00ol0003oooooooooo`03ooooo`004?oo
ool00ol0003oooooooooo`0@ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooo
ooooo`3Dooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool0000>ooooo`03
o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo013ooooo00Goo`00oooooooooooo
ooooool00002ooooo`?oo`00e?ooool3ool000?ooooo00Goo`00ooooooooooooooooool0000>oooo
o`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo013ooooo00Goo`00oooooooo
ooooooooool00002ooooo`?oo`00e?ooool3ool000?ooooo00Goo`00ooooooooooooooooool0000>
ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo013ooooo00Goo`00oooo
ooooooooooooool00002ooooo`?oo`00e?ooool3ool000?ooooo00Goo`00ooooooooooooooooool0
000>ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo013ooooo00Goo`00
ooooooooooooooooool0003Oooooo`05ool00?oooooooooooooooooo00003_ooool00ol0003ooooo
ooooo`03ooooo`004?ooool00ol0003oooooooooo`0@ooooo`05ool00?oooooooooooooooooo0000
goooool01Ooo003oooooooooooooooooo`0000kooooo00?o0000ooooooooool00oooool0013ooooo
0_l0000Aooooo`05ool00?oooooooooooooooooo0000goooool01Ooo003oooooooooooooooooo`00
00gooooo0_l00005ooooo`004?ooool00ol0003oooooooooo`0@ooooo`05ool00?oooooooooooooo
oooo0000goooool01Ooo003oooooooooooooooooo`0000kooooo00?o0000ooooooooool00oooool0
013ooooo00?o0000ooooooooool04?ooool01Ooo003oooooooooooooooooo`000=oooooo00Goo`00
ooooooooooooooooool0000>ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooo
oooo013ooooo00Goo`00ooooooooooooooooool0003Oooooo`05ool00?oooooooooooooooooo0000
3_ooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`0@ooooo`05ool00?oo
oooooooooooooooo0000goooool01Ooo003oooooooooooooooooo`0000kooooo00?o0000oooooooo
ool00oooool0013ooooo00?o0000ooooooooool04?ooool01Ooo003oooooooooooooooooo`000=oo
oooo00Goo`00ooooooooooooooooool0000>ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03
o`000?oooooooooo013ooooo00Goo`00ooooooooooooooooool0003Oooooo`05ool00?oooooooooo
oooooooo00003_ooool00ol0003oooooooooo`03ooooo`004?ooool2o`00017ooooo00Goo`00oooo
ooooooooooooool0003Oooooo`05ool00?oooooooooooooooooo00003Oooool2o`0000Gooooo000@
ooooo`03o`000?oooooooooo013ooooo00Goo`00ooooooooooooooooool0003Oooooo`05ool00?oo
oooooooooooooooo00003_ooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003ooooooooo
o`0@ooooo`05ool00?oooooooooooooooooo0000goooool01Ooo003oooooooooooooooooo`0000ko
oooo00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool04?ooool01Ooo003ooooo
ooooooooooooo`000=oooooo00Goo`00ooooooooooooooooool0000>ooooo`03o`000?oooooooooo
00?ooooo000@ooooo`03o`000?oooooooooo013ooooo00Goo`00ooooooooooooooooool0003Ooooo
o`05ool00?oooooooooooooooooo00003_ooool00ol0003oooooooooo`03ooooo`0000Coooooo`00
0?l0003o00001?ooool2o`0000Kooooo00?o0000ooooooooool04?ooool01Ooo003ooooooooooooo
ooooo`000=oooooo00Goo`00ooooooooooooooooool0000>ooooo`03o`000?oooooooooo00?ooooo
0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Oooool00ol0003ooooo
ooooo`0@ooooo`05ool00?oooooooooooooooooo0000goooool01Ooo003oooooooooooooooooo`00
00kooooo00?o0000ooooooooool00oooool000;ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00005ooooo`03o`000?oooooooooo013ooooo00Goo`00ooooooooooooooooool0003O
ooooo`05ool00?oooooooooooooooooo00003_ooool00ol0003oooooooooo`03ooooo`000_ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo0_l0000Aooooo`05ool00?oo
oooooooooooooooo0000goooool01Ooo003oooooooooooooooooo`0000cooooo0ol00005ooooo`00
0_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooooooo
ool04?ooool01Ooo003oooooooooooooooooo`000=oooooo00Goo`00ooooooooooooooooool0000>
ooooo`03o`000?oooooooooo00?ooooo00000ooooooo0000o`000004ooooo`04o`000?oooooooooo
o`0000Gooooo00?o0000ooooooooool04?ooool01Ooo003oooooooooooooooooo`000=oooooo00Go
o`00ooooooooooooooooool0000>ooooo`03o`000?oooooooooo00?ooooo0002ooooo`03o`000?oo
oooooooo00?ooooo0_l00006ooooo`03o`000?oooooooooo013ooooo00Goo`00oooooooooooooooo
ool0003Oooooo`05ool00?oooooooooooooooooo00003_ooool00ol0003oooooooooo`03ooooo`00
4?ooool00ol0003oooooooooo`0@ooooo`05ool00?oooooooooooooooooo0000goooool01Ooo003o
ooooooooooooooooo`0000kooooo00?o0000ooooooooool00oooool0013ooooo00?o0000oooooooo
ool04?ooool01Ooo003oooooooooooooooooo`000=oooooo00Goo`00ooooooooooooooooool0000>
ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo013ooooo00Goo`00oooo
ooooooooooooool0003Oooooo`05ool00?oooooooooooooooooo00003_ooool00ol0003ooooooooo
o`03ooooo`004?ooool00ol0003oooooooooo`0@ooooo`05ool00?oooooooooooooooooo0000gooo
ool01Ooo003oooooooooooooooooo`0000kooooo00?o0000ooooooooool00oooool0013ooooo0_l0
000Aooooo`05ool00?oooooooooooooooooo0000goooool01Ooo003oooooooooooooooooo`0000go
oooo0_l00005ooooo`004?ooool00ol0003oooooooooo`0@ooooo`05ool00?oooooooooooooooooo
0000goooool01Ooo003oooooooooooooooooo`0000kooooo00?o0000ooooooooool00oooool0013o
oooo00?o0000ooooooooool04?ooool01Ooo003oooooooooooooooooo`000=oooooo00Goo`00oooo
ooooooooooooool0000>ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo
013ooooo00Goo`00ooooooooooooooooool0003Oooooo`05ool00?oooooooooooooooooo00003_oo
ool00ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`0@ooooo`05ool00?oooooo
oooooooooooo0000goooool01Ooo003oooooooooooooooooo`0000kooooo00?o0000ooooooooool0
0oooool0013ooooo00?o0000ooooooooool04?ooool01Ooo003oooooooooooooooooo`000=oooooo
00Goo`00ooooooooooooooooool0000>ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`00
0?oooooooooo013ooooo00Goo`00ooooooooooooooooool0003Oooooo`05ool00?oooooooooooooo
oooo00003_ooool00ol0003oooooooooo`03ooooo`004?ooool2o`00017ooooo00Goo`00oooooooo
ooooooooool0003Oooooo`05ool00?oooooooooooooooooo00003Oooool2o`0000Gooooo000@oooo
o`03o`000?oooooooooo013ooooo00Goo`00ooooooooooooooooool0003Oooooo`05ool00?oooooo
oooooooooooo00003_ooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`0@
ooooo`05ool00?oooooooooooooooooo0000goooool01Ooo003oooooooooooooooooo`0000kooooo
00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool04?ooool01Ooo003ooooooooo
ooooooooo`000=oooooo00Goo`00ooooooooooooooooool0000>ooooo`03o`000?oooooooooo00?o
oooo000@ooooo`03o`000?oooooooooo013ooooo00Goo`00ooooooooooooooooool0003Oooooo`05
ool00?oooooooooooooooooo00003_ooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003o
ooooooooo`0@ooooo`05ool00?oooooooooooooooooo0000goooool01Ooo003ooooooooooooooooo
o`0000kooooo00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool04?ooool01Ooo
003oooooooooooooooooo`000=oooooo00Goo`00ooooooooooooooooool0000>ooooo`03o`000?oo
oooooooo00?ooooo000@ooooo`03o`000?oooooooooo013ooooo00Goo`00ooooooooooooooooool0
003Oooooo`05ool00?oooooooooooooooooo00003_ooool00ol0003oooooooooo`03ooooo`004?oo
ool2o`00017ooooo00Goo`00ooooooooooooooooool0003Oooooo`05ool00?oooooooooooooooooo
00003Oooool2o`0000Gooooo000@ooooo`03o`000?oooooooooo013ooooo00Goo`00oooooooooooo
ooooool0003Oooooo`05ool00?oooooooooooooooooo00003_ooool00ol0003oooooooooo`03oooo
o`004?ooool00ol0003oooooooooo`0@ooooo`05ool00?oooooooooooooooooo0000goooool01Ooo
003oooooooooooooooooo`0000kooooo00?o0000ooooooooool00oooool0013ooooo00?o0000oooo
ooooool04?ooool01Ooo003oooooooooooooooooo`000=oooooo00Goo`00ooooooooooooooooool0
000>ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo013ooooo00Goo`00
ooooooooooooooooool0003Oooooo`05ool00?oooooooooooooooooo00003_ooool00ol0003ooooo
ooooo`03ooooo`004?ooool00ol0003oooooooooo`0@ooooo`05ool00?oooooooooooooooooo0000
goooool01Ooo003oooooooooooooooooo`0000kooooo00?o0000ooooooooool00oooool0013ooooo
00?o0000ooooooooool04?ooool01Ooo003oooooooooooooooooo`000=oooooo00Goo`00oooooooo
ooooooooool0000>ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo013o
oooo00Goo`00ooooooooooooooooool0003Oooooo`05ool00?oooooooooooooooooo00003_ooool0
0ol0003oooooooooo`03ooooo`004?ooool2o`00017ooooo00Goo`00ooooooooooooooooool0003O
ooooo`05ool00?oooooooooooooooooo00003Oooool2o`0000Gooooo000@ooooo`03o`000?oooooo
oooo013ooooo00Goo`00ooooooooooooooooool0003Oooooo`05ool00?oooooooooooooooooo0000
3_ooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`0@ooooo`05ool00?oo
oooooooooooooooo0000goooool01Ooo003oooooooooooooooooo`0000kooooo00?o0000oooooooo
ool00oooool0013ooooo00?o0000ooooooooool04?ooool01Ooo003oooooooooooooooooo`000=oo
oooo00Goo`00ooooooooooooooooool0000>ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03
o`000?oooooooooo013ooooo00Goo`00ooooooooooooooooool0003Oooooo`05ool00?oooooooooo
oooooooo00003_ooool00ol0003oooooooooo`03ooooo`0000Coooooo`000?l0003o00000oooool3
o`0000Kooooo00?o0000ooooooooool04?ooool01Ooo003oooooooooooooooooo`000=oooooo00Go
o`00ooooooooooooooooool0000>ooooo`03o`000?oooooooooo00?ooooo0002ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo013ooooo
00Goo`00ooooooooooooooooool0003Oooooo`05ool00?oooooooooooooooooo00003_ooool00ol0
003oooooooooo`03ooooo`000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool04?ooool01Ooo003oooooooooooooooooo`000=oooooo00Goo`00oooo
ooooooooooooool0000>ooooo`03o`000?oooooooooo00?ooooo0002ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool2o`00017ooooo00Goo`00ooooooooooooooooool0003O
ooooo`05ool00?oooooooooooooooooo00003?ooool3o`0000Gooooo0002ooooo`04o`000?oooooo
ooooooooo`Co00001_ooool00ol0003oooooooooo`0@ooooo`05ool00?oooooooooooooooooo0000
goooool01Ooo003oooooooooooooooooo`0000kooooo00?o0000ooooooooool00oooool00003oooo
ool0003o000000?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`05ool0
0?oooooooooooooooooo0000goooool01Ooo003oooooooooooooooooo`0000kooooo00?o0000oooo
ooooool00oooool000;ooooo00Co0000oooooooooooooooo1Ol00005ooooo`03o`000?oooooooooo
013ooooo00Goo`00ooooooooooooooooool0003Oooooo`05ool00?oooooooooooooooooo00003_oo
ool00ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`0@ooooo`05ool00?oooooo
oooooooooooo0000goooool01Ooo003oooooooooooooooooo`0000kooooo00?o0000ooooooooool0
0oooool0013ooooo00?o0000ooooooooool04?ooool01Ooo003oooooooooooooooooo`000=oooooo
00Goo`00ooooooooooooooooool0000>ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`00
0?oooooooooo013ooooo00Goo`00ooooooooooooooooool0003Oooooo`05ool00?oooooooooooooo
oooo00003_ooool00ol0003oooooooooo`03ooooo`004?ooool2o`00017ooooo00Goo`00oooooooo
ooooooooool0003Oooooo`05ool00?oooooooooooooooooo00003Oooool2o`0000Gooooo000@oooo
o`03o`000?oooooooooo013ooooo00Goo`00ooooooooooooooooool0003Oooooo`05ool00?oooooo
oooooooooooo00003_ooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`0@
ooooo`05ool00?oooooooooooooooooo0000goooool01Ooo003oooooooooooooooooo`0000kooooo
00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool04?ooool01Ooo003ooooooooo
ooooooooo`000=oooooo00Goo`00ooooooooooooooooool0000>ooooo`03o`000?oooooooooo00?o
oooo000@ooooo`03o`000?oooooooooo013ooooo00Goo`00ooooooooooooooooool0003Oooooo`05
ool00?oooooooooooooooooo00003_ooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003o
ooooooooo`0@ooooo`05ool00?oooooooooooooooooo0000goooool01Ooo003ooooooooooooooooo
o`0000kooooo00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool04?ooool01Ooo
003oooooooooooooooooo`000=oooooo00Goo`00ooooooooooooooooool0000>ooooo`03o`000?oo
oooooooo00?ooooo000@ooooo`03o`000?oooooooooo013ooooo00Goo`00ooooooooooooooooool0
003Oooooo`05ool00?oooooooooooooooooo00003_ooool00ol0003oooooooooo`03ooooo`004?oo
ool2o`00017ooooo00Goo`00ooooooooooooooooool0003Oooooo`05ool00?oooooooooooooooooo
00003Oooool2o`0000Gooooo000@ooooo`03o`000?oooooooooo013ooooo00Goo`00oooooooooooo
ooooool0003Oooooo`05ool00?oooooooooooooooooo00003_ooool00ol0003oooooooooo`03oooo
o`004?ooool00ol0003oooooooooo`0@ooooo`05ool00?oooooooooooooooooo0000goooool01Ooo
003oooooooooooooooooo`0000kooooo00?o0000ooooooooool00oooool0013ooooo00?o0000oooo
ooooool04?ooool01Ooo003oooooooooooooooooo`000=oooooo00Goo`00ooooooooooooooooool0
000>ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo013ooooo00Goo`00
ooooooooooooooooool0003Oooooo`05ool00?oooooooooooooooooo00003_ooool00ol0003ooooo
ooooo`03ooooo`004?ooool00ol0003oooooooooo`0>ooooo`?oo`000oooool00ooo003ooooooooo
o`3Mooooo`03ool00?ooooooo`0000;oo`003_ooool00ol0003oooooooooo`03ooooo`004?ooool0
0ol0003oooooooooo`0>ooooo`?oo`000oooool00ooo003oooooooooo`3Mooooo`03ool00?oooooo
o`0000;oo`003_ooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`0>oooo
o`?oo`000oooool00ooo003oooooooooo`3Mooooo`03ool00?ooooooo`0000;oo`003_ooool00ol0
003oooooooooo`03ooooo`004?ooool2o`0001Gooooo00?oo`00ooooooooool0gOooool00ooo003o
ooooooooo`0?ooooo`;o00001Oooool0013ooooo00?o0000ooooooooool05?ooool00ooo003ooooo
ooooo`3Mooooo`03ool00?oooooooooo013ooooo00?o0000ooooooooool00oooool0013ooooo00?o
0000ooooooooool05?ooool00ooo003oooooooooo`3Mooooo`03ool00?oooooooooo013ooooo00?o
0000ooooooooool00oooool0013ooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`3M
ooooo`03ool00?oooooooooo013ooooo00?o0000ooooooooool00oooool0013ooooo00?o0000oooo
ooooool05?ooool00ooo003oooooooooo`3Mooooo`03ool00?oooooooooo013ooooo00?o0000oooo
ooooool00oooool0013ooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`3Mooooo`03
ool00?oooooooooo013ooooo00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool0
5?ooool00ooo003oooooooooo`3Mooooo`03ool00?oooooooooo013ooooo00?o0000ooooooooool0
0oooool0013ooooo0_l0000Eooooo`03ool00?oooooooooo0=gooooo00?oo`00ooooooooool03ooo
ool2o`0000Gooooo000@ooooo`03o`000?oooooooooo01Cooooo00?oo`00ooooooooool0gOooool0
0ooo003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo
01Cooooo00?oo`00ooooooooool0gOooool00ooo003oooooooooo`0@ooooo`03o`000?oooooooooo
00?ooooo000@ooooo`03o`000?oooooooooo01Cooooo00?oo`00ooooooooool0gOooool00ooo003o
ooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo01Cooooo
00?oo`00ooooooooool0gOooool00ooo003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo
000@ooooo`03o`000?oooooooooo01Cooooo00?oo`00ooooooooool0gOooool00ooo003ooooooooo
o`0@ooooo`03o`000?oooooooooo00?ooooo0005o`0000?ooooo0_l00006ooooo`03o`000?oooooo
oooo01Cooooo00?oo`00ooooooooool0gOooool00ooo003oooooooooo`0@ooooo`03o`000?oooooo
oooo00?ooooo00001Ooooooo0000oooooooooooo000000;ooooo00Co0000oooooooooooo00001Ooo
ool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo0=gooooo00?oo`00ooooooooool04?oo
ool00ol0003oooooooooo`03ooooo`000_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Gooooo0_l0000Eooooo`03ool00?oooooooooo0=gooooo00?oo`00ooooooooool03_oo
ool3o`0000Gooooo0003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01Cooooo00?oo`00ooooooooool0gOooool00ooo003ooooooooo
o`0@ooooo`03o`000?oooooooooo00?ooooo00001Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`0Cooooo`?oo`00g?ooool3ool001;ooooo
00?o0000ooooooooool00oooool00005o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00005ooooo`03o`000?oooooooooo01?ooooo0ooo003Looooo`?oo`004_ooool00ol0003o
ooooooooo`03ooooo`0000Coooooo`000?l0003o00001?ooool2o`0000Kooooo00?o0000oooooooo
ool04oooool3ool00=cooooo0ooo000Booooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooool000001Oooool0013oooooool0000<o`0000Gooooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.20018, -2.10681, \
0.232596, 0.129655}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Phase plot of DFT as a function of index k", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fft\  = \ DFT[xd];\)\), "\n", 
    \(\(g4 = 
        DiscreteListPlot[\({#[\([1]\)], \ 
                Arg[#[\([2]\)] + 0.0000001]} &\)\  /@ \ fft, Red, \ 
          PlotRange \[Rule] {\(-\[Pi]\), \ \[Pi]}, \ Frame \[Rule] True, \ 
          Axes \[Rule] False];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0161421 0.309017 0.0983632 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18523 -0.0125 -6 -9 ]
[.18523 -0.0125 6 0 ]
[.34665 -0.0125 -6 -9 ]
[.34665 -0.0125 6 0 ]
[.50807 -0.0125 -6 -9 ]
[.50807 -0.0125 6 0 ]
[.66949 -0.0125 -6 -9 ]
[.66949 -0.0125 6 0 ]
[.83091 -0.0125 -6 -9 ]
[.83091 -0.0125 6 0 ]
[.99233 -0.0125 -6 -9 ]
[.99233 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01393 -12 -4.5 ]
[-0.0125 .01393 0 4.5 ]
[-0.0125 .11229 -12 -4.5 ]
[-0.0125 .11229 0 4.5 ]
[-0.0125 .21065 -12 -4.5 ]
[-0.0125 .21065 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40738 -6 -4.5 ]
[-0.0125 .40738 0 4.5 ]
[-0.0125 .50574 -6 -4.5 ]
[-0.0125 .50574 0 4.5 ]
[-0.0125 .60411 -6 -4.5 ]
[-0.0125 .60411 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18523 0 m
.18523 .00625 L
s
[(10)] .18523 -0.0125 0 1 Mshowa
.34665 0 m
.34665 .00625 L
s
[(20)] .34665 -0.0125 0 1 Mshowa
.50807 0 m
.50807 .00625 L
s
[(30)] .50807 -0.0125 0 1 Mshowa
.66949 0 m
.66949 .00625 L
s
[(40)] .66949 -0.0125 0 1 Mshowa
.83091 0 m
.83091 .00625 L
s
[(50)] .83091 -0.0125 0 1 Mshowa
.99233 0 m
.99233 .00625 L
s
[(60)] .99233 -0.0125 0 1 Mshowa
.125 Mabswid
.05609 0 m
.05609 .00375 L
s
.08838 0 m
.08838 .00375 L
s
.12066 0 m
.12066 .00375 L
s
.15295 0 m
.15295 .00375 L
s
.21751 0 m
.21751 .00375 L
s
.2498 0 m
.2498 .00375 L
s
.28208 0 m
.28208 .00375 L
s
.31437 0 m
.31437 .00375 L
s
.37893 0 m
.37893 .00375 L
s
.41122 0 m
.41122 .00375 L
s
.4435 0 m
.4435 .00375 L
s
.47579 0 m
.47579 .00375 L
s
.54036 0 m
.54036 .00375 L
s
.57264 0 m
.57264 .00375 L
s
.60492 0 m
.60492 .00375 L
s
.63721 0 m
.63721 .00375 L
s
.70178 0 m
.70178 .00375 L
s
.73406 0 m
.73406 .00375 L
s
.76634 0 m
.76634 .00375 L
s
.79863 0 m
.79863 .00375 L
s
.8632 0 m
.8632 .00375 L
s
.89548 0 m
.89548 .00375 L
s
.92776 0 m
.92776 .00375 L
s
.96005 0 m
.96005 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01393 m
.00625 .01393 L
s
[(-3)] -0.0125 .01393 1 0 Mshowa
0 .11229 m
.00625 .11229 L
s
[(-2)] -0.0125 .11229 1 0 Mshowa
0 .21065 m
.00625 .21065 L
s
[(-1)] -0.0125 .21065 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .40738 m
.00625 .40738 L
s
[(1)] -0.0125 .40738 1 0 Mshowa
0 .50574 m
.00625 .50574 L
s
[(2)] -0.0125 .50574 1 0 Mshowa
0 .60411 m
.00625 .60411 L
s
[(3)] -0.0125 .60411 1 0 Mshowa
.125 Mabswid
0 .0336 m
.00375 .0336 L
s
0 .05327 m
.00375 .05327 L
s
0 .07295 m
.00375 .07295 L
s
0 .09262 m
.00375 .09262 L
s
0 .13196 m
.00375 .13196 L
s
0 .15164 m
.00375 .15164 L
s
0 .17131 m
.00375 .17131 L
s
0 .19098 m
.00375 .19098 L
s
0 .23033 m
.00375 .23033 L
s
0 .25 m
.00375 .25 L
s
0 .26967 m
.00375 .26967 L
s
0 .28934 m
.00375 .28934 L
s
0 .32869 m
.00375 .32869 L
s
0 .34836 m
.00375 .34836 L
s
0 .36803 m
.00375 .36803 L
s
0 .38771 m
.00375 .38771 L
s
0 .42705 m
.00375 .42705 L
s
0 .44673 m
.00375 .44673 L
s
0 .4664 m
.00375 .4664 L
s
0 .48607 m
.00375 .48607 L
s
0 .52542 m
.00375 .52542 L
s
0 .54509 m
.00375 .54509 L
s
0 .56476 m
.00375 .56476 L
s
0 .58443 m
.00375 .58443 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18523 .61178 m
.18523 .61803 L
s
.34665 .61178 m
.34665 .61803 L
s
.50807 .61178 m
.50807 .61803 L
s
.66949 .61178 m
.66949 .61803 L
s
.83091 .61178 m
.83091 .61803 L
s
.99233 .61178 m
.99233 .61803 L
s
.125 Mabswid
.05609 .61428 m
.05609 .61803 L
s
.08838 .61428 m
.08838 .61803 L
s
.12066 .61428 m
.12066 .61803 L
s
.15295 .61428 m
.15295 .61803 L
s
.21751 .61428 m
.21751 .61803 L
s
.2498 .61428 m
.2498 .61803 L
s
.28208 .61428 m
.28208 .61803 L
s
.31437 .61428 m
.31437 .61803 L
s
.37893 .61428 m
.37893 .61803 L
s
.41122 .61428 m
.41122 .61803 L
s
.4435 .61428 m
.4435 .61803 L
s
.47579 .61428 m
.47579 .61803 L
s
.54036 .61428 m
.54036 .61803 L
s
.57264 .61428 m
.57264 .61803 L
s
.60492 .61428 m
.60492 .61803 L
s
.63721 .61428 m
.63721 .61803 L
s
.70178 .61428 m
.70178 .61803 L
s
.73406 .61428 m
.73406 .61803 L
s
.76634 .61428 m
.76634 .61803 L
s
.79863 .61428 m
.79863 .61803 L
s
.8632 .61428 m
.8632 .61803 L
s
.89548 .61428 m
.89548 .61803 L
s
.92776 .61428 m
.92776 .61803 L
s
.96005 .61428 m
.96005 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01393 m
1 .01393 L
s
.99375 .11229 m
1 .11229 L
s
.99375 .21065 m
1 .21065 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .40738 m
1 .40738 L
s
.99375 .50574 m
1 .50574 L
s
.99375 .60411 m
1 .60411 L
s
.125 Mabswid
.99625 .0336 m
1 .0336 L
s
.99625 .05327 m
1 .05327 L
s
.99625 .07295 m
1 .07295 L
s
.99625 .09262 m
1 .09262 L
s
.99625 .13196 m
1 .13196 L
s
.99625 .15164 m
1 .15164 L
s
.99625 .17131 m
1 .17131 L
s
.99625 .19098 m
1 .19098 L
s
.99625 .23033 m
1 .23033 L
s
.99625 .25 m
1 .25 L
s
.99625 .26967 m
1 .26967 L
s
.99625 .28934 m
1 .28934 L
s
.99625 .32869 m
1 .32869 L
s
.99625 .34836 m
1 .34836 L
s
.99625 .36803 m
1 .36803 L
s
.99625 .38771 m
1 .38771 L
s
.99625 .42705 m
1 .42705 L
s
.99625 .44673 m
1 .44673 L
s
.99625 .4664 m
1 .4664 L
s
.99625 .48607 m
1 .48607 L
s
.99625 .52542 m
1 .52542 L
s
.99625 .54509 m
1 .54509 L
s
.99625 .56476 m
1 .56476 L
s
.99625 .58443 m
1 .58443 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .30902 m
.02381 .30902 L
s
.03995 .30902 m
.03995 .41161 L
s
.05609 .30902 m
.05609 .44276 L
s
.07224 .30902 m
.07224 .45797 L
s
.08838 .30902 m
.08838 .15935 L
s
.10452 .30902 m
.10452 .16772 L
s
.12066 .30902 m
.12066 .17505 L
s
.1368 .30902 m
.1368 .18178 L
s
.15295 .30902 m
.15295 .18814 L
s
.16909 .30902 m
.16909 .19424 L
s
.18523 .30902 m
.18523 .20017 L
s
.20137 .30902 m
.20137 .20596 L
s
.21751 .30902 m
.21751 .21166 L
s
.23366 .30902 m
.23366 .21729 L
s
.2498 .30902 m
.2498 .22286 L
s
.26594 .30902 m
.26594 .22839 L
s
.28208 .30902 m
.28208 .23387 L
s
.29822 .30902 m
.29822 .23933 L
s
.31437 .30902 m
.31437 .24476 L
s
.33051 .30902 m
.33051 .25017 L
s
.34665 .30902 m
.34665 .25556 L
s
.36279 .30902 m
.36279 .26094 L
s
.37893 .30902 m
.37893 .26631 L
s
.39508 .30902 m
.39508 .27167 L
s
.41122 .30902 m
.41122 .27702 L
s
.42736 .30902 m
.42736 .28236 L
s
.4435 .30902 m
.4435 .2877 L
s
.45964 .30902 m
.45964 .29303 L
s
.47579 .30902 m
.47579 .29836 L
s
.49193 .30902 m
.49193 .30369 L
s
.50807 .30902 m
.50807 .30902 L
s
.52421 .30902 m
.52421 .31434 L
s
.54036 .30902 m
.54036 .31967 L
s
.5565 .30902 m
.5565 .325 L
s
.57264 .30902 m
.57264 .33034 L
s
.58878 .30902 m
.58878 .33567 L
s
.60492 .30902 m
.60492 .34102 L
s
.62107 .30902 m
.62107 .34637 L
s
.63721 .30902 m
.63721 .35172 L
s
.65335 .30902 m
.65335 .35709 L
s
.66949 .30902 m
.66949 .36247 L
s
.68563 .30902 m
.68563 .36786 L
s
.70178 .30902 m
.70178 .37327 L
s
.71792 .30902 m
.71792 .37871 L
s
.73406 .30902 m
.73406 .38416 L
s
.7502 .30902 m
.7502 .38965 L
s
.76634 .30902 m
.76634 .39517 L
s
.78249 .30902 m
.78249 .40074 L
s
.79863 .30902 m
.79863 .40637 L
s
.81477 .30902 m
.81477 .41207 L
s
.83091 .30902 m
.83091 .41787 L
s
.84705 .30902 m
.84705 .42379 L
s
.8632 .30902 m
.8632 .4299 L
s
.87934 .30902 m
.87934 .43625 L
s
.89548 .30902 m
.89548 .44298 L
s
.91162 .30902 m
.91162 .45032 L
s
.92776 .30902 m
.92776 .45868 L
s
.94391 .30902 m
.94391 .16007 L
s
.96005 .30902 m
.96005 .17528 L
s
.97619 .30902 m
.97619 .20643 L
s
.015 w
.02381 .30902 Mdot
.03995 .41161 Mdot
.05609 .44276 Mdot
.07224 .45797 Mdot
.08838 .15935 Mdot
.10452 .16772 Mdot
.12066 .17505 Mdot
.1368 .18178 Mdot
.15295 .18814 Mdot
.16909 .19424 Mdot
.18523 .20017 Mdot
.20137 .20596 Mdot
.21751 .21166 Mdot
.23366 .21729 Mdot
.2498 .22286 Mdot
.26594 .22839 Mdot
.28208 .23387 Mdot
.29822 .23933 Mdot
.31437 .24476 Mdot
.33051 .25017 Mdot
.34665 .25556 Mdot
.36279 .26094 Mdot
.37893 .26631 Mdot
.39508 .27167 Mdot
.41122 .27702 Mdot
.42736 .28236 Mdot
.4435 .2877 Mdot
.45964 .29303 Mdot
.47579 .29836 Mdot
.49193 .30369 Mdot
.50807 .30902 Mdot
.52421 .31434 Mdot
.54036 .31967 Mdot
.5565 .325 Mdot
.57264 .33034 Mdot
.58878 .33567 Mdot
.60492 .34102 Mdot
.62107 .34637 Mdot
.63721 .35172 Mdot
.65335 .35709 Mdot
.66949 .36247 Mdot
.68563 .36786 Mdot
.70178 .37327 Mdot
.71792 .37871 Mdot
.73406 .38416 Mdot
.7502 .38965 Mdot
.76634 .39517 Mdot
.78249 .40074 Mdot
.79863 .40637 Mdot
.81477 .41207 Mdot
.83091 .41787 Mdot
.84705 .42379 Mdot
.8632 .4299 Mdot
.87934 .43625 Mdot
.89548 .44298 Mdot
.91162 .45032 Mdot
.92776 .45868 Mdot
.94391 .16007 Mdot
.96005 .17528 Mdot
.97619 .20643 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005Oooool2o`0002Gooooo0ol00004ooooo`;o00008Oooool5o`0000?ooooo0_l0000Roooo
o`?o00001?ooool2o`0002?ooooo0ol00003ooooo`;o00008Oooool3o`0000Cooooo0_l0000Roooo
o`?o00001?ooool2o`0000Gooooo000Dooooo`04o`000?ooooooooooo`0002Gooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool0000Qooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00008?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00008oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool07Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool001Cooooo00Co0000oooooooo
oooo00009Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002;ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000Tooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool07_ooool5o`0000;ooooo00Co0000oooooooooooo00008oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000Cooooo000Dooooo`04o`000?ooooooooooo`0002Gooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool0000Sooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`0Pooooo`;o00000oooool01?l0003oooooooooool0000Poooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00008oooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo01kooooo1?l00003ooooo`04o`000?ooooooooooo`0000Co
oooo000Dooooo`04o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000Pooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
000Tooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool07oooool00ol0003ooooo
o`000003ooooo`04o`000?ooooooooooo`0001oooooo1?l00003ooooo`04o`000?ooooooooooo`00
023ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`005?ooool01?l0
003oooooooooool0000Tooooo`;o00001?ooool01?l0003oooooooooool0000Pooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool0000Pooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool0000Rooooo`;o00000oooool01?l0003oooooooooool0
000Oooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00008Oooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`0000Cooooo000Eooooo`;o00009_ooool00ol0003ooooo
ooooo`03ooooo`;o00008_ooool3o`0000Cooooo0_l0000Rooooo`?o00001?ooool2o`0002Cooooo
00?o0000ooooooooool00_ooool2o`00023ooooo1Ol00003ooooo`;o00008oooool2o`0000Cooooo
0_l00005ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
4?ooooooo`0000_o00001_ooool000Sooooo0ol00005ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooool000001_ooool000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooool000001_ooool00003ooooool0003o000000?o00001Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04
ooooo`002Oooool2o`0000Gooooo0ol0003oooooo`Kooooo0_l00006ooooo`002oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`00
1oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0ooooool7ooooo`03
o`000?oooooooooo00Cooooo0008ooooo`?o00001Oooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00Cooooo000@ooooo`;o0000ooooool7ooooo`;o00001_ooool0013ooooo00?o0000oooo
ooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03o`000?oooooooooo0?oo
oooo1oooool00ol0003oooooooooo`04ooooo`004?ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00Cooooo000@ooooo`;o0000ooooool7ooooo`;o00001_ooool0013ooooo00?o0000oooo
ooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03o`000?oooooooooo0?oo
oooo1oooool00ol0003oooooooooo`04ooooo`004?ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00Cooooo000@ooooo`;o0000ooooool7ooooo`;o00001_ooool0013ooooo00?o0000oooo
ooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03o`000?oooooooooo0?oo
oooo1oooool00ol0003oooooooooo`04ooooo`004?ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00Cooooo000@ooooo`;o0000ooooool7ooooo`;o00001_ooool0013ooooo00?o0000oooo
ooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03o`000?oooooooooo0?oo
oooo1oooool00ol0003oooooooooo`04ooooo`001oooool5o`0000Cooooo00?o0000ooooooooool0
ooooool7ooooo`03o`000?oooooooooo00Cooooo0008ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo00000ooooooo0000o`00
0003o`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o
0000ooooooooool01?ooool000[ooooo00?o0000ooooooooool00oooool3o`000?oooooo1_ooool2
o`0000Kooooo0007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`3o
ooooo`Oooooo00?o0000ooooooooool01?ooool000Oooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`002?ooool3o`00
00Gooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03
o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`004?ooool2o`000?oooooo
1oooool2o`0000Kooooo000@ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooooooo
o`04ooooo`004?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool01?ooool0
013ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03
o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`004?ooool2o`000?oooooo
1oooool2o`0000Kooooo000@ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooooooo
o`04ooooo`004?ooool00ol0003oooooooooo`0Cooooo`?oo`00h?ooool3ool000gooooo00?o0000
ooooooooool01?ooool0013ooooo00?o0000ooooooooool04oooool3ool00>3ooooo0ooo000=oooo
o`03o`000?oooooooooo00Cooooo000@ooooo`03o`000?oooooooooo01?ooooo0ooo00001?oooooo
o`00ool00?oo003Looooo`?oo`003Oooool00ol0003oooooooooo`04ooooo`004?ooool2o`0001Ko
oooo00?oo`00oooooooo00000_oo003Mooooo`03ool00?oooooooooo00_ooooo0_l00006ooooo`00
4?ooool00ol0003oooooooooo`0Eooooo`03ool00?ooooooo`0000;oo`000_ooool3ool00=Sooooo
00?oo`00ooooooooool00ooo0009ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03o`000?oo
oooooooo01Gooooo00Goo`00ooooooooooooooooool00002ooooo`?oo`0000Coooooool00?oo003o
o`00e?ooool00ooo003oooooooooo`03ool000Wooooo00?o0000ooooooooool01?ooool0013ooooo
00?o0000ooooooooool05Oooool01Ooo003oooooooooooooooooo`0000;ooooo0ooo00001?oooooo
o`00ool00?oo003Dooooo`03ool00?oooooooooo00?oo`002Oooool00ol0003oooooooooo`04oooo
o`004?ooool00ol0003oooooooooo`0Eooooo`05ool00?oooooooooooooooooo00000oooool00ooo
003oooooooooo`03ool00004oooooooo003oo`00ool00=3ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo000@ooooo`;o00005_ooool01Ooo
003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002ooooo`?oo`00d?oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Kooooo0_l00006ooooo`004?ooool0
0ol0003oooooooooo`0Eooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0000;ooooo0ooo0002ooooo`?oo`00boooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00Oooooo00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool05Ooo
ool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`03
ool00?oooooooooo00?oo`0000Coooooool00?oo003oo`00aoooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00Oooooo00?o0000ooooooooool01?ooool000Sooooo0ol00005ooooo`03
o`000?oooooooooo01Gooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooo
oooooooo00001?ooool00ooo003oooooooooo`03ool00004oooooooo003oo`00ool00<Oooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo0009
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05Oooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooooooo
00000_ooool3ool00004oooooooo003oo`00ool00<?ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooool00002ool000Gooooo00?o0000ooooooooool01?ooool00003ooooool0003o000000?o
00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00Goo`00oooooooo
ooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00?oo`00ooooooooool00ooo00001?ooooooo`00ool00?oo002oooooo`03ool0
0?oooooooooo00;ooooo00?oo`00oooooooo00000_oo0005ooooo`03o`000?oooooooooo00Cooooo
0009ooooo`03o`000?oooooooooo00Cooooo0ol0000Eooooo`05ool00?oooooooooooooooooo0000
0oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003oooo
o`03ool00?oooooooooo00?oo`0000Coooooool00?oo003oo`00_oooool00ooo003oooooooooo`02
ooooo`03ool00?ooooooo`0000;oo`001?ooool2o`0000Kooooo0009ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool05Oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00
ooooooooooooooooool00004ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooo
ooooo`02ooooo`03ool00?ooooooo`0000;oo`000_ooool3ool00;[ooooo00?oo`00ooooooooool0
0_ooool01Ooo003oooooooooooooooooo`0000Gooooo00?o0000ooooooooool01?ooool000Sooooo
0_l00006ooooo`03o`000?oooooooooo01Gooooo00Goo`00ooooooooooooooooool00003ooooo`05
ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00
ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000;ooooo0ooo00001?ooooooo`00ool0
0?oo002fooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00005ooooo`03
o`000?oooooooooo00Cooooo0009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
5Oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004oooo
o`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooo
oooooooooooo00000_ooool3ool00004oooooooo003oo`00ool00;Kooooo00?oo`00ooooooooool0
0_ooool01Ooo003oooooooooooooooooo`0000Gooooo00?o0000ooooooooool01?ooool0013ooooo
00?o0000ooooooooool05Oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooo
ooooooooool00004ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02
ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`03ool00004oooooooo
003oo`00ool00;;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Go
oooo00?o0000ooooooooool01?ooool0013ooooo0_l0000Fooooo`05ool00?oooooooooooooooooo
00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003
ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oo
oooooooooooooooo00000_ooool3ool00004oooooooo003oo`00ool00:kooooo00?oo`00oooooooo
ool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo0_l00006ooooo`004?ooool00ol0003o
ooooooooo`0Eooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooooooo
o`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool3ool00004
oooooooo003oo`00ool00:kooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooooooo
o`0000Gooooo00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool05Oooool01Ooo
003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oo
oooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo
00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00oooooooo00000_oo0002oooo
o`?oo`00ZOooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001Oooool0
0ol0003oooooooooo`04ooooo`004?ooool00ol0003oooooooooo`0Eooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00oooooooooooooooo
ool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05
ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0000;ooooo0ooo0000
1?ooooooo`00ool00?oo002Uooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooooooooooo
ool00005ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03o`000?oooooooooo01Gooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003o
ooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooooooo
o`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooooooo0000
0_ooool3ool00004oooooooo003oo`00ool00:Gooooo00?oo`00ooooooooool00_ooool01Ooo003o
ooooooooooooooooo`0000Gooooo00?o0000ooooooooool01?ooool0013ooooo0_l0000Fooooo`05
ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00
ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooooooooooo
ool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`00
00?ooooo00?oo`00ooooooooool00ooo00001?ooooooo`00ool00?oo002Qooooo`03ool00?oooooo
oooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`;o00001_ooool0013ooooo00?o0000
ooooooooool05Oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool00004ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05
ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00
ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool3ool000;ooooo
0ooo002Looooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00005ooooo`03
o`000?oooooooooo00Cooooo000@ooooo`03o`000?oooooooooo01Gooooo00Goo`00oooooooooooo
ooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003ooooooooooooooooo
o`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Go
o`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003o
ooooooooooooooooo`0000;ooooo0ooo0002ooooo`?oo`0000Coooooool00?oo003oo`00V?ooool0
0ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001Oooool00ol0003ooooooooo
o`04ooooo`004?ooool00ol0003oooooooooo`0Eooooo`05ool00?oooooooooooooooooo00000ooo
ool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`03
ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooo
oooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool00004ooooo`03ool00?oooooooooo00?oo`0000Coooooool00?oo003oo`00V?ooool00ooo003o
ooooooooo`02ooooo`05ool00?oooooooooooooooooo00001Oooool00ol0003oooooooooo`04oooo
o`004?ooool00ol0003oooooooooo`0Eooooo`05ool00?oooooooooooooooooo00000oooool01Ooo
003oooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oo
oooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004
ooooo`05ool00?oooooooooooooooooo00000_ooool3ool00004oooooooo003oo`00ool009Cooooo
00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Gooooo00?o0000oooooooo
ool01?ooool0013ooooo0_l0000Fooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003o
ooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooo
oooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000
1?ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004oooo
o`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`03ool00004oooooooo003o
o`00ool0093ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo
0_l00006ooooo`004?ooool00ol0003oooooooooo`0Eooooo`05ool00?oooooooooooooooooo0000
0oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003oooo
o`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooo
oooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooo
ooooool00004ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`03ool0
0004oooooooo003oo`00ool0093ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooo
ooooo`0000Gooooo00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool05Oooool0
1Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool0
0?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooo
oooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool0
0003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooool00002ool000;ooooo0ooo002;ooooo`03
ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00005ooooo`03o`000?oooooooooo
00Cooooo000@ooooo`03o`000?oooooooooo01Gooooo00Goo`00ooooooooooooooooool00003oooo
o`05ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?o
o`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooo
ooooool00004ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooooooo
o`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Go
o`00ooooooooooooooooool00002ooooo`?oo`0000Coooooool00?oo003oo`00Qoooool00ooo003o
ooooooooo`02ooooo`05ool00?oooooooooooooooooo00001Oooool00ol0003oooooooooo`04oooo
o`004?ooool00ol0003oooooooooo`0Eooooo`05ool00?oooooooooooooooooo00000oooool01Ooo
003oooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oo
oooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004
ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oo
oooooooooooooooo00000_ooool3ool00004oooooooo003oo`00ool008Oooooo00?oo`00oooooooo
ool00_ooool01Ooo003oooooooooooooooooo`0000Gooooo00?o0000ooooooooool01?ooool0013o
oooo00?o0000ooooooooool05Oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooo
ooooooooooooool00004ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooooooo
o`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Co
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool0
1Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00?oo`00ooooooooool00ooo00001?ooooooo`00ool00?oo0023ooooo`03
ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00005ooooo`03o`000?oooooooooo
00Cooooo000@ooooo`;o00005_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooo
ooooooooooooool00004ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooooooo
o`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Co
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool0
1Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002ooooo`?oo`000_ooool3ool007ko
oooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo0_l00006oooo
o`004?ooool00ol0003oooooooooo`0Eooooo`05ool00?oooooooooooooooooo00000oooool01Ooo
003oooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oo
oooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004
ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oo
oooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo0ooo0002ooooo`?o
o`0000Coooooool00?oo003oo`00N_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooo
oooooooo00001Oooool00ol0003oooooooooo`04ooooo`002Oooool2o`0000Gooooo00?o0000oooo
ooooool05Oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
0004ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool0
0?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00oooo
ooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?o
oooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00?oo`0000Coooooool0
0?oo003oo`00N_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001Ooo
ool00ol0003oooooooooo`04ooooo`002?ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo01Gooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo
003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oo
oooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00oooooooo
ooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0000;ooooo
0ooo00001?ooooooo`00ool00?oo001fooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooo
ooooooooool00005ooooo`03o`000?oooooooooo00Cooooo0008ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool00_ooool3ool0013ooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo
00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooo
ooooooooool00004ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooo
ooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo
00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo
003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00ooo00001?ooooooo`00ool00?oo
001booooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00005ooooo`03o`00
0?oooooooooo00Cooooo0008ooooo`04o`000?ooooooooooo`0000Cooooo0ol00002ooooo`?oo`00
0oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003o
ooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooo
oooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo0000
0oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003oooo
o`05ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?o
o`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooo
ooooool00004ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`03ool0
0004oooooooo003oo`00ool000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oo
oooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00oooooooo
ooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo
00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooo
ooooooooool00004ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooo
ooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo
00Goo`00ooooooooooooooooool00004ooooo`;o00001_ooool000Sooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`02ooooo`?oo`000oooool01Ooo003oooooooooooooooooo`00
00?ooooo00?oo`00ooooooooool0Koooool3ool000;ooooo0ooo0002ooooo`03ool00?oooooooooo
00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?oo
ool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooo
oooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000ooo
ool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`05
ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0001;ooooo00?o0000
ooooooooool01?ooool000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`08
ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`1dooooo`?oo`0000Co
ooooool00?oo003oo`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooo
ooooooooool00004ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02
ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo
00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooo
ooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooooooo
00004_ooool00ol0003oooooooooo`04ooooo`002Oooool2o`0000Gooooo00?o0000ooooooooool0
2?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0M?ooool3ool00005
oooooooo003oo`00ool00?ooool00ooo0003ooooo`05ool00?oooooooooooooooooo00000oooool0
0ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooooooo
o`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Co
oooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooo
ooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooo
oooo00004_ooool00ol0003oooooooooo`04ooooo`004?ooool00ol0003oooooooooo`08ooooo`05
ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`1hooooo`?oo`0000Coooooool0
0?oo003oo`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo
ool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooo
oooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000ooo
ool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`05
ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0001;ooooo00?o0000
ooooooooool01?ooool0013ooooo0_l00009ooooo`05ool00?oooooooooooooooooo00000oooool0
0ooo003oooooooooo`1looooo`?oo`0000Coooooool00?oo003oo`000oooool01Ooo003ooooooooo
ooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;o
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool0
1Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooo
oooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool0
000Aooooo`;o00001_ooool0013ooooo00?o0000ooooooooool02?ooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00?oo`00ooooooooool0P?ooool3ool000;ooooo0ooo0002ooooo`03ool00?oo
oooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo
00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo
003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooooooo
00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool0000B
ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03o`000?oooooooooo00Sooooo00Goo`00oooo
ooooooooooooool00003ooooo`03ool00?oooooooooo083ooooo0ooo0002ooooo`?oo`000_ooool0
0ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooooooo
o`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Co
oooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooo
ooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooo
oooo00004_ooool00ol0003oooooooooo`04ooooo`004?ooool00ol0003oooooooooo`08ooooo`05
ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`25ooooo`?oo`0000Coooooool0
0?oo003oo`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo
ool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05
ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00oooooooooooooooo
ool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`00
01;ooooo00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool02?ooool01Ooo003o
ooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0ROooool3ool00004oooooooo003oo`00
ool000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooooooo0000
0oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003oooo
o`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooo
oooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooo
ooooool00004ooooo`05ool00?oooooooooooooooooo00004_ooool00ol0003oooooooooo`04oooo
o`004?ooool2o`0000Wooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo
08Wooooo0ooo00001?ooooooo`00ool00?oo0003ooooo`05ool00?oooooooooooooooooo00001?oo
ool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05
ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00oooooooooooooooo
ool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`00
017ooooo0_l00006ooooo`004?ooool00ol0003oooooooooo`08ooooo`05ool00?oooooooooooooo
oooo00000oooool00ooo003oooooooooo`2=ooooo`?oo`000_ooool3ool000;ooooo00?oo`00oooo
ooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
0004ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool0
0?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00oooo
ooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003ooooooooo
ooooooooo`0001;ooooo00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool02?oo
ool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0T_ooool3ool00004oooo
oooo003oo`00ool000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooo
oooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo
ool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05
ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00
ooooooooooooooooool0000Booooo`03o`000?oooooooooo00Cooooo000@ooooo`03o`000?oooooo
oooo00Sooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo09;ooooo0ooo
00001Oooooooo`00ool00?oo003ooooo00?oo`000oooool01Ooo003oooooooooooooooooo`0000?o
oooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooo
ooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
0004ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Co
oooo00Goo`00ooooooooooooooooool0000Booooo`03o`000?oooooooooo00Cooooo000@ooooo`03
o`000?oooooooooo00Sooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo
09Kooooo0ooo00001?ooooooo`00ool00?oo0003ooooo`05ool00?oooooooooooooooooo00000ooo
ool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooo
ooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`00
00Cooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?oo
ool01Ooo003oooooooooooooooooo`0001;ooooo00?o0000ooooooooool01?ooool0013ooooo0_l0
0009ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`2Jooooo`?oo`00
00Coooooool00?oo003oo`000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00oooo
ooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool0
0003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?o
oooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooooooo00004Oooool2
o`0000Kooooo000@ooooo`03o`000?oooooooooo00Sooooo00Goo`00ooooooooooooooooool00003
ooooo`03ool00?oooooooooo09kooooo0ooo0002ooooo`?oo`000_ooool00ooo003oooooooooo`02
ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oo
oooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00oooooooo
ooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003ooooooooooooo
ooooo`0001;ooooo00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool02?ooool0
1Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0W_ooool3ool000;ooooo0ooo
0002ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool0
0?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
0004ooooo`05ool00?oooooooooooooooooo00004_ooool00ol0003oooooooooo`04ooooo`004?oo
ool00ol0003oooooooooo`08ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooo
ooooo`2Sooooo`?oo`0000Coooooool00?oo003oo`000oooool01Ooo003oooooooooooooooooo`00
00?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00
ooooooooooooooooool00004ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooo
ooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool0000Booooo`03o`000?oooooooooo
00Cooooo000@ooooo`03o`000?oooooooooo00Sooooo00Goo`00ooooooooooooooooool00003oooo
o`03ool00?oooooooooo0:Oooooo0ooo00001?ooooooo`00ool00?oo0003ooooo`05ool00?oooooo
oooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooo
ooooool00004ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooooooo
o`0000Cooooo00Goo`00ooooooooooooooooool0000Booooo`03o`000?oooooooooo00Cooooo000@
ooooo`03o`000?oooooooooo00Sooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oo
oooooooo0:Oooooo0ooo00001?ooooooo`00ool00?oo0003ooooo`05ool00?oooooooooooooooooo
00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004
ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo
00Goo`00ooooooooooooooooool0000Booooo`03o`000?oooooooooo00Cooooo000@ooooo`;o0000
2Oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0Zoooool3ool000;o
oooo0ooo0002ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003oooo
o`05ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00Go
o`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooooooo00004Oooool2o`0000Ko
oooo000@ooooo`03o`000?oooooooooo00Sooooo00Goo`00ooooooooooooooooool00003ooooo`03
ool00?oooooooooo0;3ooooo0ooo00001?ooooooo`00ool00?oo0003ooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00oooooooooooooooo
ool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`00
01;ooooo00?o0000ooooooooool01?ooool000Sooooo0ol00005ooooo`03o`000?oooooooooo00So
oooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo0;3ooooo0ooo00001?oo
ooooo`00ool00?oo0003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo00001?ooool01Ooo003oooooooooooooooooo`0001;ooooo00?o0000ooooooooool01?ooool0
00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`05ool00?oooooooooo
oooooooo00000oooool00ooo003oooooooooo`2dooooo`?oo`0000Coooooool00?oo003oo`000ooo
ool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooo
oooooooo00004_ooool00ol0003oooooooooo`04ooooo`002Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Sooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooo
oooo0;Sooooo0ooo00001?ooooooo`00ool00?oo0003ooooo`05ool00?oooooooooooooooooo0000
1?ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004oooo
o`05ool00?oooooooooooooooooo00004_ooool00ol0003oooooooooo`04ooooo`002Oooool00ol0
003oooooooooo`04ooooo`?o00001_ooool3ool000?ooooo00Goo`00ooooooooooooooooool0002j
ooooo`?oo`0000Coooooool00?oo003oo`000oooool01Ooo003oooooooooooooooooo`0000Cooooo
00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo
003oooooooooooooooooo`00017ooooo0_l00006ooooo`002Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Kooooo0ooo0003ooooo`05ool00?oooooooooooooooooo0000__ooool3
ool000;ooooo0ooo0002ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool0
0003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0001;o
oooo00?o0000ooooooooool01?ooool000Sooooo0_l00006ooooo`03o`000?oooooooooo00Kooooo
0ooo0003ooooo`05ool00?oooooooooooooooooo0000`oooool3ool00004oooooooo003oo`00ool0
00?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?oo
ool01Ooo003oooooooooooooooooo`0001;ooooo00?o0000ooooooooool01?ooool000Wooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`05ool00?oooooooooooooooooo0000
`oooool3ool00004oooooooo003oo`00ool000?ooooo00Goo`00ooooooooooooooooool00003oooo
o`05ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0001;ooooo00?o
0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool03?ooool01Ooo003ooooooooooooo
ooooo`000<Oooooo0ooo00001?ooooooo`00ool00?oo0003ooooo`05ool00?oooooooooooooooooo
00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00004_ooool00ol0
003oooooooooo`04ooooo`004?ooool2o`0000gooooo00Goo`00ooooooooooooooooool0003;oooo
o`?oo`000_ooool3ool000;ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooo
oooooooooooo00004Oooool2o`0000Kooooo000@ooooo`03o`000?oooooooooo00cooooo00Goo`00
ooooooooooooooooool0003;ooooo`?oo`000_ooool3ool000;ooooo00Goo`00oooooooooooooooo
ool00004ooooo`05ool00?oooooooooooooooooo00004_ooool00ol0003oooooooooo`04ooooo`00
4?ooool00ol0003oooooooooo`0<ooooo`05ool00?oooooooooooooooooo0000d?ooool3ool00004
oooooooo003oo`00ool000;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooooooo
o`0001;ooooo00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool03?ooool01Ooo
003oooooooooooooooooo`000=Cooooo0ooo0002ooooo`03ool00?oooooooooo00;ooooo00Goo`00
ooooooooooooooooool0000Booooo`03o`000?oooooooooo00Cooooo000@ooooo`03o`000?oooooo
oooo00_ooooo0ooo0002ooooo`03ool00?oooooooooo0=;ooooo0ooo00001?ooooooo`00ool00?oo
0003ooooo`05ool00?oooooooooooooooooo00004_ooool00ol0003oooooooooo`04ooooo`004?oo
ool2o`0000cooooo0ooo0002ooooo`03ool00?oooooooooo0=Kooooo0ooo0003ooooo`05ool00?oo
oooooooooooooooo00004Oooool2o`0000Kooooo000@ooooo`03o`000?oooooooooo00_ooooo0ooo
0002ooooo`03ool00?oooooooooo0=Kooooo0ooo00001?ooooooo`00ool00?oo0003ooooo`03ool0
0?oooooooooo013ooooo00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool04?oo
ool00ooo003oooooooooo`3Jooooo`?oo`000oooool00ooo003oooooooooo`0@ooooo`03o`000?oo
oooooooo00Cooooo000@ooooo`03o`000?oooooooooo00oooooo0ooo003Kooooo`?oo`000_ooool3
ool0017ooooo00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool03oooool3ool0
0>3ooooo0ooo000Aooooo`03o`000?oooooooooo00Cooooo000@ooooo`;o00004?ooool3ool00>3o
oooo0ooo000@ooooo`;o00001_ooool0013ooooo00?o0000ooooooooool0ooooool7ooooo`03o`00
0?oooooooooo00Cooooo000@ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooooooo
o`04ooooo`004?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool01?ooool0
013ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo000@ooooo`03
o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`004?ooool2o`000?oooooo
1oooool2o`0000Kooooo000@ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooooooo
o`04ooooo`001oooool5o`0000Cooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooo
oooo00Cooooo0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0ooooool7
ooooo`03o`000?oooooooooo00Cooooo0009ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo000:ooooo`03o`000?oooooooooo00?o
oooo0ol0003oooooo`Kooooo0_l00006ooooo`001oooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo0007ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000oooooooo
ool01?ooool000Sooooo0ol00005ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooo
ooooo`04ooooo`004?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool01?oo
ool0013ooooo0_l0003oooooo`Oooooo0_l00006ooooo`004?ooool00ol0003oooooooooo`3ooooo
o`Oooooo00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool0ooooool7ooooo`03
o`000?oooooooooo00Cooooo000@ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooo
ooooo`04ooooo`004?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool01?oo
ool0013ooooo0_l0003oooooo`Oooooo0_l00006ooooo`004?ooool00ol0003oooooooooo`3ooooo
o`Oooooo00?o0000ooooooooool01?ooool0013ooooo00?o0000ooooooooool0ooooool7ooooo`03
o`000?oooooooooo00Cooooo000@ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooo
ooooo`04ooooo`004?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool01?oo
ool0013ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo000@oooo
o`;o0000ooooool7ooooo`;o00001_ooool0013ooooo00?o0000ooooooooool0ooooool7ooooo`03
o`000?oooooooooo00Cooooo000@ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooo
ooooo`04ooooo`004?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool01?oo
ool0013ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00Cooooo000@oooo
o`;o0000ooooool7ooooo`;o00001_ooool0013ooooo00?o0000ooooooooool0ooooool7ooooo`03
o`000?oooooooooo00Cooooo0008ooooo`?o00001Oooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool01?ooool000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`002oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`002Oooool2
o`0000Gooooo0ol0003oooooo`Kooooo0_l00006ooooo`002oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`04ooooo`001oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooo`000006oooo
o`002?ooool3o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000006ooooo`00
4?ooooooo`0000_o00001_ooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.36541, -3.6139, 0.233724, \
0.0383558}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Rearrange and scale DFT result", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g5 = 
        DiscreteListPlot[FourierRearrange[Abs[Last\  /@ \ fft], fs], Red, 
          PlotRange \[Rule] All, ImageSize \[Rule] 504, \ 
          Frame \[Rule] True, \ Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g6\  = \ Show[g1, g5];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.0147151 0.0195658 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11254 -6 -4.5 ]
[-0.0125 .11254 0 4.5 ]
[-0.0125 .21037 -12 -4.5 ]
[-0.0125 .21037 0 4.5 ]
[-0.0125 .3082 -12 -4.5 ]
[-0.0125 .3082 0 4.5 ]
[-0.0125 .40603 -12 -4.5 ]
[-0.0125 .40603 0 4.5 ]
[-0.0125 .50386 -12 -4.5 ]
[-0.0125 .50386 0 4.5 ]
[-0.0125 .60169 -12 -4.5 ]
[-0.0125 .60169 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11254 m
.00625 .11254 L
s
[(5)] -0.0125 .11254 1 0 Mshowa
0 .21037 m
.00625 .21037 L
s
[(10)] -0.0125 .21037 1 0 Mshowa
0 .3082 m
.00625 .3082 L
s
[(15)] -0.0125 .3082 1 0 Mshowa
0 .40603 m
.00625 .40603 L
s
[(20)] -0.0125 .40603 1 0 Mshowa
0 .50386 m
.00625 .50386 L
s
[(25)] -0.0125 .50386 1 0 Mshowa
0 .60169 m
.00625 .60169 L
s
[(30)] -0.0125 .60169 1 0 Mshowa
.125 Mabswid
0 .03428 m
.00375 .03428 L
s
0 .05385 m
.00375 .05385 L
s
0 .07341 m
.00375 .07341 L
s
0 .09298 m
.00375 .09298 L
s
0 .13211 m
.00375 .13211 L
s
0 .15168 m
.00375 .15168 L
s
0 .17124 m
.00375 .17124 L
s
0 .19081 m
.00375 .19081 L
s
0 .22994 m
.00375 .22994 L
s
0 .2495 m
.00375 .2495 L
s
0 .26907 m
.00375 .26907 L
s
0 .28864 m
.00375 .28864 L
s
0 .32777 m
.00375 .32777 L
s
0 .34733 m
.00375 .34733 L
s
0 .3669 m
.00375 .3669 L
s
0 .38647 m
.00375 .38647 L
s
0 .4256 m
.00375 .4256 L
s
0 .44516 m
.00375 .44516 L
s
0 .46473 m
.00375 .46473 L
s
0 .48429 m
.00375 .48429 L
s
0 .52343 m
.00375 .52343 L
s
0 .54299 m
.00375 .54299 L
s
0 .56256 m
.00375 .56256 L
s
0 .58212 m
.00375 .58212 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11254 m
1 .11254 L
s
.99375 .21037 m
1 .21037 L
s
.99375 .3082 m
1 .3082 L
s
.99375 .40603 m
1 .40603 L
s
.99375 .50386 m
1 .50386 L
s
.99375 .60169 m
1 .60169 L
s
.125 Mabswid
.99625 .03428 m
1 .03428 L
s
.99625 .05385 m
1 .05385 L
s
.99625 .07341 m
1 .07341 L
s
.99625 .09298 m
1 .09298 L
s
.99625 .13211 m
1 .13211 L
s
.99625 .15168 m
1 .15168 L
s
.99625 .17124 m
1 .17124 L
s
.99625 .19081 m
1 .19081 L
s
.99625 .22994 m
1 .22994 L
s
.99625 .2495 m
1 .2495 L
s
.99625 .26907 m
1 .26907 L
s
.99625 .28864 m
1 .28864 L
s
.99625 .32777 m
1 .32777 L
s
.99625 .34733 m
1 .34733 L
s
.99625 .3669 m
1 .3669 L
s
.99625 .38647 m
1 .38647 L
s
.99625 .4256 m
1 .4256 L
s
.99625 .44516 m
1 .44516 L
s
.99625 .46473 m
1 .46473 L
s
.99625 .48429 m
1 .48429 L
s
.99625 .52343 m
1 .52343 L
s
.99625 .54299 m
1 .54299 L
s
.99625 .56256 m
1 .56256 L
s
.99625 .58212 m
1 .58212 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .03428 m
.02395 .03427 L
.02408 .03425 L
.02423 .03421 L
.02437 .03416 L
.02462 .03403 L
.02489 .03383 L
.02519 .03355 L
.02551 .03319 L
.02608 .03234 L
.02722 .03 L
.02847 .02654 L
.02973 .02231 L
.03043 .01975 L
.03109 .01724 L
.03139 .01609 L
.03155 .01546 L
.03171 .01487 L
.03179 .0149 L
.03189 .01527 L
.03205 .01591 L
.03238 .01715 L
.03355 .02156 L
.03596 .02921 L
.03717 .03192 L
.03785 .03303 L
.03819 .03345 L
.0385 .03377 L
.03879 .034 L
.03894 .03409 L
.0391 .03418 L
.03918 .03421 L
.03926 .03424 L
.03941 .03428 L
.03949 .03429 L
.03958 .03431 L
.03967 .03431 L
.03976 .03431 L
.03991 .03429 L
.04006 .03426 L
.04019 .03421 L
.04033 .03415 L
.04065 .03395 L
.04095 .0337 L
.04147 .03311 L
.04204 .03223 L
.04319 .02979 L
.04573 .02188 L
.04631 .01973 L
.04694 .01736 L
Mistroke
.04724 .01619 L
.04739 .01562 L
.04752 .01509 L
.04765 .01482 L
.04778 .01533 L
.04805 .0164 L
.0492 .02077 L
.05046 .02517 L
.05165 .02878 L
.05274 .03139 L
.05332 .03249 L
.05388 .03331 L
.05417 .03365 L
.05447 .03394 L
.05463 .03406 L
.0548 .03417 L
.05495 .03425 L
.05511 .03432 L
.05525 .03436 L
.0554 .03439 L
.05553 .0344 L
.05566 .03439 L
.05581 .03437 L
.05595 .03434 L
.0561 .03429 L
.05625 .03422 L
.05652 .03405 L
.05676 .03384 L
.05732 .03322 L
.05789 .03235 L
.05849 .03118 L
.05959 .02847 L
.06208 .02016 L
.06267 .0179 L
.063 .01664 L
.0633 .01545 L
.06346 .01483 L
.06355 .01495 L
.06363 .01527 L
.064 .01669 L
.06464 .01916 L
.06589 .02377 L
.06706 .02756 L
.06826 .03074 L
.06878 .03185 L
.06934 .03286 L
.06967 .03333 L
.06996 .0337 L
.07027 .03401 L
.07055 .03423 L
Mistroke
.07071 .03433 L
.07085 .0344 L
.07101 .03447 L
.07109 .03449 L
.07118 .03451 L
.07126 .03453 L
.07134 .03454 L
.07149 .03454 L
.07159 .03453 L
.07167 .03452 L
.07175 .0345 L
.07184 .03448 L
.07199 .03443 L
.07213 .03436 L
.07243 .03416 L
.07272 .03391 L
.07299 .03362 L
.07359 .03278 L
.07425 .03157 L
.07557 .02829 L
.07679 .02443 L
.07787 .02052 L
.07844 .01834 L
.07904 .016 L
.07919 .01539 L
.07928 .01505 L
.07936 .01474 L
.07945 .01507 L
.07954 .01541 L
.07971 .01607 L
.08032 .01847 L
.08152 .02299 L
.0827 .02695 L
.08394 .03044 L
.085 .03268 L
.0856 .0336 L
.08588 .03394 L
.08617 .03423 L
.08633 .03437 L
.08648 .03447 L
.08663 .03456 L
.08677 .03463 L
.08693 .03469 L
.08702 .03471 L
.08711 .03473 L
.08726 .03475 L
.08734 .03475 L
.08742 .03475 L
.08758 .03472 L
.08772 .03469 L
Mistroke
.08786 .03464 L
.088 .03457 L
.08832 .03436 L
.08861 .0341 L
.08913 .03348 L
.0897 .03257 L
.09085 .03005 L
.09339 .02193 L
.09397 .01972 L
.09459 .01729 L
.09489 .01609 L
.09504 .0155 L
.09518 .01496 L
.0953 .01497 L
.09543 .01549 L
.09571 .01659 L
.09685 .02106 L
.0981 .02558 L
.0993 .02927 L
.10038 .03196 L
.10097 .03308 L
.10153 .03392 L
.10181 .03426 L
.10211 .03455 L
.10227 .03468 L
.10244 .0348 L
.10259 .03488 L
.10275 .03494 L
.10289 .03498 L
.10304 .03501 L
.10317 .03502 L
.1033 .03502 L
.10345 .035 L
.10358 .03496 L
.10374 .03491 L
.10389 .03483 L
.10416 .03466 L
.1044 .03445 L
.10496 .0338 L
.10552 .03291 L
.10613 .0317 L
.10722 .0289 L
.10971 .0203 L
.1103 .01797 L
.11063 .01667 L
.11093 .01544 L
.11102 .0151 L
.11111 .01473 L
.1112 .01509 L
.1113 .01546 L
Mistroke
.11162 .01679 L
.11226 .01935 L
.11343 .02382 L
.11469 .02808 L
.11593 .0315 L
.11652 .03278 L
.11706 .03374 L
.1176 .0345 L
.11789 .0348 L
.1182 .03505 L
.11832 .03514 L
.11846 .03521 L
.11858 .03526 L
.11871 .03531 L
.11885 .03534 L
.119 .03536 L
.11914 .03536 L
.11927 .03535 L
.11943 .03531 L
.1195 .03529 L
.11959 .03526 L
.11988 .0351 L
.12005 .03498 L
.12022 .03483 L
.12054 .0345 L
.12117 .03361 L
.12174 .03255 L
.12289 .02973 L
.12399 .02633 L
.12515 .02211 L
.12578 .01961 L
.12638 .01719 L
.12663 .01617 L
.12676 .01562 L
.12689 .0151 L
.12703 .01489 L
.12718 .01551 L
.12744 .01659 L
.1286 .0213 L
.13086 .02925 L
.13148 .031 L
.13213 .03259 L
.1327 .03372 L
.13331 .03467 L
.13364 .03507 L
.13394 .03536 L
.13408 .03547 L
.13424 .03557 L
.13439 .03565 L
.13453 .03571 L
Mistroke
.13462 .03573 L
.13471 .03576 L
.13479 .03577 L
.13487 .03578 L
.13495 .03578 L
.13504 .03578 L
.13514 .03577 L
.13523 .03575 L
.13531 .03573 L
.13539 .0357 L
.13554 .03564 L
.1357 .03555 L
.13588 .03543 L
.13617 .03518 L
.13649 .03482 L
.13714 .03384 L
.13774 .03265 L
.13831 .0313 L
.14074 .02335 L
.14182 .01905 L
.14211 .01787 L
.14241 .01658 L
.14255 .01599 L
.1427 .01536 L
.14283 .01482 L
.14297 .0152 L
.14313 .01586 L
.14329 .01655 L
.14359 .01781 L
.14416 .02014 L
.14526 .02449 L
.14655 .02902 L
.14775 .03241 L
.14839 .03382 L
.14898 .03484 L
.14929 .03528 L
.14962 .03566 L
.1498 .03584 L
.14997 .03597 L
.15014 .03608 L
.15031 .03617 L
.15046 .03622 L
.1506 .03626 L
.15074 .03628 L
.15087 .03628 L
.15102 .03627 L
.15117 .03624 L
.15132 .03618 L
.15149 .0361 L
.15179 .0359 L
Mistroke
.15208 .03563 L
.15273 .03478 L
.15333 .0337 L
.15398 .03222 L
.15517 .02878 L
.1574 .02037 L
.15804 .01767 L
.15836 .01632 L
.1585 .01573 L
.15865 .01507 L
.15878 .01495 L
.15891 .0155 L
.15919 .0167 L
.15978 .01921 L
.16107 .02453 L
.1623 .029 L
.16348 .0325 L
.1641 .03398 L
.16476 .03524 L
.16531 .03603 L
.16562 .03636 L
.16577 .03649 L
.16592 .0366 L
.16605 .03668 L
.16619 .03676 L
.16632 .03681 L
.16644 .03684 L
.16658 .03687 L
.16671 .03688 L
.16685 .03687 L
.16699 .03684 L
.16713 .0368 L
.16728 .03674 L
.16742 .03666 L
.16755 .03657 L
.16787 .0363 L
.16816 .03597 L
.16876 .03508 L
.1694 .0338 L
.17056 .03073 L
.17163 .02713 L
.17291 .02211 L
.17353 .01944 L
.17411 .01692 L
.17438 .01571 L
.17451 .01512 L
.17463 .01484 L
.17476 .01541 L
.1749 .01602 L
.17519 .01731 L
Mistroke
.17635 .02237 L
.17866 .03102 L
.17929 .03288 L
.17996 .03455 L
.18059 .0358 L
.18086 .03625 L
.18116 .03667 L
.18143 .03697 L
.18171 .03723 L
.18187 .03734 L
.18201 .03742 L
.18216 .03749 L
.18229 .03753 L
.18244 .03756 L
.1826 .03758 L
.18273 .03757 L
.18288 .03754 L
.18304 .03749 L
.18312 .03745 L
.18321 .03741 L
.18351 .0372 L
.18379 .03693 L
.18405 .03663 L
.18464 .03571 L
.18516 .03467 L
.18572 .03333 L
.18813 .02506 L
.1894 .01961 L
.19004 .01671 L
.19022 .01591 L
.19031 .01547 L
.1904 .01505 L
.19049 .01477 L
.19058 .0152 L
.19074 .01594 L
.19327 .02699 L
.19446 .03136 L
.19558 .03464 L
.19618 .036 L
.19672 .03699 L
.19701 .03741 L
.19733 .03779 L
.1975 .03796 L
.19766 .03809 L
.19782 .0382 L
.19798 .03828 L
.19813 .03834 L
.19822 .03837 L
.19831 .03838 L
.19846 .0384 L
Mistroke
.19854 .03839 L
.19862 .03839 L
.19877 .03836 L
.1989 .03831 L
.19906 .03824 L
.1992 .03815 L
.19953 .03788 L
.19983 .03755 L
.20051 .03649 L
.20107 .03532 L
.20167 .03378 L
.20276 .03031 L
.20395 .02569 L
.20525 .01993 L
.20585 .01709 L
.20603 .01626 L
.20619 .01547 L
.20634 .01477 L
.20642 .01506 L
.2065 .01543 L
.20766 .02094 L
.20898 .02679 L
.21021 .03157 L
.2113 .03501 L
.21186 .03643 L
.21247 .03767 L
.21282 .03823 L
.21314 .03865 L
.21344 .03896 L
.2136 .03908 L
.21377 .03919 L
.21385 .03924 L
.21394 .03927 L
.21409 .03932 L
.21424 .03935 L
.21439 .03936 L
.21454 .03934 L
.21469 .0393 L
.21483 .03925 L
.21496 .03918 L
.21524 .03898 L
.21554 .03868 L
.21586 .03827 L
.21616 .0378 L
.21726 .03536 L
.21789 .03351 L
.21847 .03156 L
.21977 .02638 L
.22088 .02132 L
.22148 .01837 L
Mistroke
.22178 .0169 L
.22206 .01554 L
.22222 .01475 L
.22229 .01508 L
.22238 .01551 L
.22274 .01727 L
.22335 .02031 L
.22455 .02601 L
.22576 .03111 L
.2269 .03512 L
.22754 .03691 L
.22822 .03848 L
.22853 .03903 L
.22885 .03952 L
.22912 .03986 L
.22928 .04003 L
.22943 .04016 L
.22958 .04027 L
.22971 .04035 L
.22986 .04041 L
.23001 .04046 L
.23015 .04048 L
.23029 .04048 L
.23043 .04047 L
.23055 .04043 L
.2307 .04038 L
.23083 .0403 L
.23114 .04007 L
.23145 .03975 L
.23177 .0393 L
.23236 .03823 L
.23292 .03691 L
.23397 .0337 L
.23522 .02882 L
.23639 .02341 L
.23744 .0181 L
.23773 .01661 L
.23789 .01579 L
.23804 .01502 L
.23816 .01507 L
.2383 .01577 L
.23858 .01726 L
.24096 .02901 L
.24227 .0344 L
.24349 .03824 L
.24408 .03965 L
.24471 .04078 L
.24504 .0412 L
.24535 .0415 L
.24552 .04163 L
Mistroke
.24569 .04172 L
.24577 .04175 L
.24586 .04178 L
.24596 .0418 L
.24605 .04181 L
.2462 .04181 L
.24629 .0418 L
.24637 .04178 L
.24651 .04173 L
.24666 .04166 L
.2468 .04157 L
.24693 .04146 L
.24722 .04117 L
.24754 .04075 L
.24783 .04027 L
.24848 .0389 L
.24967 .03535 L
.25077 .031 L
.25206 .02491 L
.25269 .02164 L
.25327 .01853 L
.25357 .01689 L
.25372 .01608 L
.25385 .01535 L
.25399 .01486 L
.25415 .01569 L
.25447 .01746 L
.25575 .02442 L
.258 .03495 L
.25858 .03713 L
.2592 .03913 L
.25973 .04057 L
.26031 .0418 L
.26063 .04235 L
.26092 .04274 L
.26106 .0429 L
.26122 .04305 L
.26136 .04316 L
.2615 .04325 L
.26158 .04329 L
.26167 .04333 L
.26183 .04338 L
.26192 .04339 L
.26201 .04339 L
.26209 .04339 L
.26218 .04337 L
.26234 .04333 L
.26243 .04329 L
.26251 .04325 L
.26267 .04314 L
Mistroke
.26281 .04302 L
.26309 .04273 L
.26339 .04231 L
.26401 .04115 L
.26454 .03982 L
.26511 .03808 L
.26642 .033 L
.26762 .0272 L
.26872 .0212 L
.26933 .01772 L
.26947 .01688 L
.26962 .01599 L
.26975 .01522 L
.2699 .01505 L
.26998 .01552 L
.27007 .01603 L
.27022 .01695 L
.27058 .01901 L
.27119 .02256 L
.27239 .02918 L
.27361 .03511 L
.27426 .03781 L
.27495 .04029 L
.27561 .04224 L
.2762 .04361 L
.27649 .04413 L
.2768 .04458 L
.27695 .04475 L
.2771 .04491 L
.27724 .04503 L
.27737 .04512 L
.27752 .0452 L
.2776 .04523 L
.27768 .04525 L
.27782 .04528 L
.27797 .04527 L
.2781 .04525 L
.27825 .0452 L
.27839 .04513 L
.27852 .04504 L
.2788 .04478 L
.27911 .04438 L
.27944 .04384 L
.27974 .04323 L
.28081 .04026 L
.28195 .03579 L
.28319 .0297 L
.28453 .02202 L
.28515 .01825 L
.28531 .01725 L
Mistroke
.28548 .01616 L
.28557 .01564 L
.28565 .01514 L
.2858 .01523 L
.28594 .0161 L
.28606 .0169 L
.28635 .01871 L
.28696 .0225 L
.28814 .02947 L
.2894 .03617 L
.29049 .04095 L
.29111 .04316 L
.29169 .04483 L
.29225 .04609 L
.29256 .04663 L
.29285 .04701 L
.29299 .04717 L
.29315 .04731 L
.29323 .04737 L
.29332 .04743 L
.29347 .0475 L
.29362 .04755 L
.29378 .04756 L
.29393 .04755 L
.29406 .04751 L
.2942 .04745 L
.29434 .04736 L
.2946 .04713 L
.2949 .04675 L
.29518 .0463 L
.29572 .04513 L
.29624 .0437 L
.29742 .03929 L
.29866 .03314 L
.29983 .02628 L
.30089 .0194 L
.30117 .01753 L
.30132 .01653 L
.30148 .01547 L
.30161 .01489 L
.30177 .01592 L
.30203 .01773 L
.30326 .0259 L
.30547 .03894 L
.30669 .04442 L
.30726 .04646 L
.3078 .048 L
.30839 .04925 L
.3087 .04972 L
.30887 .04993 L
Mistroke
.30903 .05009 L
.30919 .05022 L
.30928 .05027 L
.30938 .05031 L
.30953 .05036 L
.30962 .05037 L
.3097 .05037 L
.30986 .05035 L
.31 .05029 L
.31008 .05025 L
.31016 .0502 L
.31032 .05008 L
.31063 .04973 L
.31096 .0492 L
.31157 .04786 L
.31215 .04609 L
.3127 .04408 L
.31393 .03823 L
.31523 .03047 L
.31637 .02263 L
.31668 .02046 L
.317 .01807 L
.31715 .01697 L
.31731 .0158 L
.31745 .01479 L
.3176 .01575 L
.31876 .02426 L
.31981 .0317 L
.32095 .039 L
.32215 .04544 L
.32278 .04818 L
.32346 .05061 L
.32377 .05148 L
.32409 .05226 L
.32436 .05281 L
.32467 .05329 L
.32482 .05348 L
.32498 .05364 L
.32507 .05372 L
.32515 .05377 L
.32524 .05382 L
.32531 .05385 L
.32546 .05389 L
.32562 .0539 L
.32576 .05387 L
.32591 .05381 L
.32606 .0537 L
.32624 .05355 L
.32654 .05316 L
.32691 .0525 L
Mistroke
.32725 .05172 L
.32781 .05003 L
.32843 .04767 L
.32968 .04137 L
.33204 .02506 L
.33272 .01968 L
.33306 .01697 L
.3332 .01578 L
.33329 .0151 L
.33336 .01497 L
.3335 .01608 L
.33364 .01726 L
.33394 .01969 L
.33457 .02479 L
.33695 .04248 L
.33829 .05026 L
.33894 .05317 L
.33954 .05536 L
.34013 .05695 L
.34046 .05759 L
.34061 .05784 L
.34076 .05803 L
.34089 .05818 L
.34102 .05828 L
.34115 .05837 L
.3413 .05843 L
.34144 .05845 L
.34159 .05844 L
.34173 .05839 L
.34186 .05831 L
.342 .0582 L
.34216 .05804 L
.34243 .05764 L
.34276 .05701 L
.34306 .05626 L
.34368 .05425 L
.34433 .05147 L
.34549 .04503 L
.34672 .03628 L
.34787 .02674 L
.34838 .02227 L
.34893 .01723 L
.34908 .01586 L
.34917 .01508 L
.34924 .01505 L
.34939 .01643 L
.34953 .01773 L
.35017 .02359 L
.35151 .03558 L
.35269 .04515 L
Mistroke
.35394 .05371 L
.35459 .05729 L
.3552 .06006 L
.35574 .06201 L
.35603 .06281 L
.35634 .06351 L
.35648 .06377 L
.35663 .06401 L
.35676 .06418 L
.3569 .06433 L
.35698 .0644 L
.35706 .06445 L
.35721 .06452 L
.35735 .06455 L
.35749 .06453 L
.35762 .06449 L
.35775 .06441 L
.35788 .0643 L
.358 .06417 L
.35828 .06374 L
.35856 .06318 L
.35916 .06143 L
.35971 .05924 L
.36094 .05236 L
.36208 .04383 L
.36316 .03424 L
.36434 .02251 L
.36462 .01953 L
.36478 .01787 L
.36493 .0163 L
.36501 .0154 L
.36511 .015 L
.36519 .01589 L
.36527 .01671 L
.36558 .02006 L
.36781 .04309 L
.36889 .05294 L
.37006 .06181 L
.37073 .06589 L
.37134 .06888 L
.37193 .07104 L
.37222 .07185 L
.37239 .07222 L
.37254 .07251 L
.37269 .07274 L
.37285 .07293 L
.37293 .07301 L
.37301 .07307 L
.37309 .07312 L
.37318 .07315 L
Mistroke
.37326 .07317 L
.37334 .07317 L
.37349 .07313 L
.37364 .07304 L
.37378 .07291 L
.37393 .07272 L
.37407 .0725 L
.37433 .07196 L
.37461 .07122 L
.37491 .07021 L
.37555 .0674 L
.37622 .06346 L
.37743 .05412 L
.37867 .04197 L
.37983 .02861 L
.38034 .0224 L
.38062 .01892 L
.38076 .01721 L
.38088 .01563 L
.38102 .01552 L
.38116 .01738 L
.38147 .02134 L
.38202 .02833 L
.38438 .05676 L
.38568 .06972 L
.38632 .0749 L
.3869 .07886 L
.38743 .0818 L
.388 .0842 L
.38832 .08516 L
.38846 .08549 L
.38861 .0858 L
.38875 .08602 L
.38889 .08619 L
.38904 .08632 L
.38918 .08638 L
.38927 .08639 L
.38935 .08638 L
.38951 .08631 L
.38959 .08624 L
.38967 .08616 L
.38986 .0859 L
.39001 .0856 L
.39016 .08526 L
.39049 .08427 L
.39077 .0832 L
.39107 .08179 L
.39168 .07816 L
.39292 .0678 L
.39404 .0552 L
Mistroke
.39536 .03738 L
.39593 .02873 L
.39624 .02399 L
.39641 .02134 L
.39657 .0188 L
.39671 .0165 L
.39687 .01546 L
.39702 .01778 L
.39715 .01993 L
.39769 .02875 L
.39888 .04798 L
.40017 .06767 L
.40139 .08392 L
.40258 .09664 L
.40325 .10209 L
.40356 .1042 L
.40386 .10588 L
.40413 .10714 L
.40438 .10808 L
.40466 .10887 L
.40481 .10918 L
.40495 .10941 L
.40509 .10955 L
.40524 .10963 L
.40537 .10963 L
.40551 .10956 L
.40566 .10941 L
.40574 .10929 L
.40582 .10915 L
.40611 .10844 L
.40626 .10793 L
.40641 .10737 L
.40668 .1061 L
.40729 .10223 L
.40782 .09776 L
.40839 .09175 L
.40969 .07391 L
.41089 .05286 L
.41145 .04167 L
.41206 .02891 L
.41235 .02249 L
.41249 .01929 L
.41263 .01629 L
.41275 .01587 L
.41288 .01879 L
.41315 .02503 L
.41564 .08284 L
.41688 .10955 L
.41823 .13413 L
.41885 .14339 L
Mistroke
.4195 .15147 L
.42005 .15685 L
.42037 .15923 L
.42066 .16099 L
.42082 .16173 L
.42098 .16237 L
.42112 .16281 L
.42127 .16316 L
.42135 .16331 L
.42143 .1634 L
.42152 .16346 L
.42161 .16348 L
.42176 .16341 L
.42185 .16331 L
.42193 .16318 L
.42208 .16281 L
.42223 .16233 L
.42251 .16108 L
.4228 .15922 L
.42312 .15659 L
.42369 .15037 L
.42429 .14157 L
.42536 .1201 L
.4265 .08938 L
.42713 .06914 L
.42773 .0479 L
.42828 .02648 L
.42843 .02035 L
.42852 .01694 L
.4286 .01572 L
.42873 .02149 L
.42889 .02796 L
.42994 .07555 L
.4346 .31692 L
.43697 .43386 L
.43822 .48714 L
.43956 .53471 L
.44023 .55419 L
.44086 .56978 L
.44147 .58221 L
.44204 .59118 L
.44257 .59744 L
.44284 .59975 L
.44314 .60163 L
.4433 .60234 L
.44344 .60282 L
.44352 .60302 L
.4436 .60318 L
.44376 .60332 L
.4439 .60328 L
Mistroke
.44406 .60306 L
.44421 .60267 L
.44434 .60218 L
.44448 .60149 L
.44462 .60069 L
.44493 .59836 L
.44523 .59539 L
.44555 .59145 L
.44613 .58238 L
.44666 .572 L
.44795 .53889 L
.44917 .49834 L
.4538 .29287 L
.45614 .18062 L
.45738 .12491 L
.45872 .07031 L
.45934 .0473 L
.45968 .03546 L
.46 .02491 L
.46014 .02041 L
.46027 .01624 L
.46042 .01789 L
.46056 .02206 L
.46117 .03952 L
.46226 .06608 L
.46288 .07844 L
.46346 .0882 L
.46408 .09666 L
.46464 .10274 L
.46524 .10754 L
.46557 .10947 L
.46588 .11084 L
.46615 .11166 L
.4663 .11199 L
.46643 .1122 L
.46656 .11233 L
.4667 .11239 L
.46682 .11238 L
.46694 .11231 L
.46708 .11216 L
.46721 .11195 L
.46736 .11165 L
.46751 .11124 L
.46782 .11015 L
.4681 .10885 L
.46869 .10538 L
.46931 .1006 L
.47041 .08967 L
.47292 .05788 L
.47405 .0423 L
Mistroke
.47468 .03384 L
.47528 .02604 L
.47583 .01911 L
.47598 .01726 L
.47606 .01626 L
.47614 .01533 L
.47629 .01589 L
.47643 .0175 L
.47748 .02883 L
.47866 .0393 L
.4793 .04394 L
.4799 .04754 L
.48046 .05024 L
.48097 .05217 L
.48124 .05299 L
.48153 .05373 L
.48184 .05433 L
.48199 .05456 L
.48213 .05473 L
.48227 .05487 L
.48241 .05497 L
.48256 .05504 L
.48272 .05508 L
.48285 .05507 L
.483 .05503 L
.48314 .05496 L
.48327 .05486 L
.48343 .05471 L
.48357 .05453 L
.48391 .054 L
.4842 .05339 L
.48452 .05262 L
.48572 .04851 L
.48705 .04236 L
.48959 .02819 L
.4908 .02137 L
.49138 .0182 L
.49164 .01687 L
.49192 .01546 L
.49206 .01472 L
.4922 .0154 L
.49247 .0167 L
.49306 .01941 L
.49432 .02443 L
.4955 .0282 L
.49607 .0297 L
.4966 .03086 L
.49712 .03186 L
.4977 .03274 L
.49801 .03313 L
Mistroke
.4983 .03345 L
.49858 .0337 L
.49887 .03391 L
.49917 .03408 L
.4993 .03414 L
.49945 .03419 L
.49961 .03424 L
.4997 .03425 L
.49978 .03427 L
.49993 .03428 L
.50008 .03428 L
.50017 .03427 L
.50025 .03426 L
.50034 .03425 L
.50043 .03423 L
.50058 .03418 L
.50075 .03412 L
.50107 .03395 L
.50137 .03374 L
.50197 .03316 L
.50262 .03227 L
.50324 .03118 L
.50382 .02996 L
.5049 .02703 L
.50605 .02305 L
.50718 .01831 L
.50749 .01688 L
.50766 .01607 L
.50782 .01531 L
.50795 .01479 L
.50809 .01551 L
.5084 .01707 L
.5106 .02931 L
.513 .04262 L
.51426 .04846 L
.51496 .05103 L
.5156 .05293 L
.5159 .05362 L
.51618 .05415 L
.51633 .0544 L
.5165 .05462 L
.51665 .05479 L
.5168 .05491 L
.51688 .05497 L
.51697 .05501 L
.51713 .05507 L
.51721 .05508 L
.51731 .05507 L
.51739 .05506 L
.51748 .05503 L
Mistroke
.51763 .05494 L
.51772 .05487 L
.5178 .0548 L
.51795 .05463 L
.51811 .05441 L
.5184 .05387 L
.51868 .05323 L
.5193 .05123 L
.51983 .0489 L
.52042 .04568 L
.52164 .03688 L
.52276 .02642 L
.52306 .02318 L
.52339 .01955 L
.52355 .01774 L
.5237 .016 L
.52384 .01503 L
.52398 .01678 L
.5246 .02443 L
.52527 .03321 L
.52762 .06526 L
.52887 .08134 L
.53021 .09615 L
.53087 .10205 L
.53149 .10657 L
.53205 .10961 L
.53237 .11086 L
.53267 .1117 L
.53281 .112 L
.53297 .11223 L
.53311 .11235 L
.53325 .1124 L
.53337 .11237 L
.53351 .11227 L
.53365 .11209 L
.53378 .11184 L
.53393 .11145 L
.53408 .11099 L
.53435 .10988 L
.53464 .1083 L
.53496 .10614 L
.53555 .10088 L
.5361 .09442 L
.53735 .07397 L
.53865 .04425 L
.53896 .03589 L
.5393 .02645 L
.53946 .02167 L
.53961 .01705 L
.53974 .01662 L
Mistroke
.53989 .0213 L
.54106 .06196 L
.54233 .11274 L
.54456 .2138 L
.54692 .32784 L
.54951 .44634 L
.5507 .49355 L
.55197 .53655 L
.55317 .56836 L
.55369 .57917 L
.55427 .58888 L
.55485 .59619 L
.55517 .59913 L
.55531 .60022 L
.55546 .60119 L
.5556 .60189 L
.55574 .60249 L
.55587 .6029 L
.556 .60316 L
.55614 .60331 L
.55627 .60331 L
.55643 .60313 L
.55657 .6028 L
.55671 .6023 L
.55687 .60157 L
.55719 .59948 L
.55749 .59682 L
.55777 .59371 L
.5584 .58452 L
.55907 .57134 L
.56029 .53919 L
.56162 .49307 L
.56405 .38556 L
.56662 .25196 L
.56896 .12965 L
.57012 .07251 L
.57074 .04436 L
.57108 .02965 L
.57124 .02264 L
.57139 .01637 L
.57153 .0189 L
.57166 .02433 L
.57196 .03599 L
.57258 .05924 L
.57368 .09486 L
.57485 .12484 L
.57548 .13766 L
.57608 .14732 L
.57659 .15373 L
.57714 .1588 L
Mistroke
.57744 .16077 L
.5776 .16161 L
.57775 .16225 L
.57789 .16273 L
.57802 .16306 L
.57816 .16332 L
.57831 .16346 L
.57845 .16347 L
.57859 .16338 L
.57873 .16316 L
.57889 .16278 L
.57906 .16224 L
.57922 .16158 L
.57951 .16 L
.58004 .15601 L
.58062 .15011 L
.58193 .1316 L
.58313 .10919 L
.58431 .08405 L
.58557 .05487 L
.58615 .04123 L
.58677 .02695 L
.58702 .02114 L
.58716 .01796 L
.58729 .01499 L
.58744 .01794 L
.58759 .02109 L
.58786 .02716 L
.59007 .07001 L
.59118 .08653 L
.59182 .09414 L
.59241 .09981 L
.59301 .1043 L
.59334 .1062 L
.59365 .10761 L
.59379 .10812 L
.59394 .10858 L
.59407 .10892 L
.59421 .1092 L
.5943 .10934 L
.59438 .10945 L
.59453 .10959 L
.59467 .10964 L
.59482 .10961 L
.59496 .10951 L
.59508 .10936 L
.59523 .10911 L
.59537 .1088 L
.59561 .10809 L
.59588 .10708 L
Mistroke
.59648 .1039 L
.59704 .0999 L
.59821 .08869 L
.5993 .07515 L
.60051 .05759 L
.60178 .03737 L
.60234 .02821 L
.60265 .02318 L
.60294 .01845 L
.60302 .01715 L
.60311 .01578 L
.6032 .01515 L
.60329 .01653 L
.6036 .02151 L
.60421 .031 L
.60645 .06104 L
.60758 .07249 L
.60822 .07752 L
.60881 .08115 L
.60935 .08368 L
.60966 .08475 L
.6098 .08517 L
.60994 .0855 L
.61007 .08577 L
.61021 .08601 L
.61034 .08618 L
.61046 .08629 L
.61059 .08636 L
.61073 .08639 L
.61088 .08636 L
.61102 .08628 L
.61117 .08613 L
.61125 .08603 L
.61133 .0859 L
.61162 .0853 L
.61196 .08431 L
.61228 .08312 L
.61286 .0803 L
.61348 .07638 L
.61465 .06673 L
.61572 .05576 L
.61682 .04286 L
.618 .02806 L
.61835 .02359 L
.61868 .01937 L
.61883 .01753 L
.61898 .0156 L
.61906 .01484 L
.61915 .01595 L
.6193 .01789 L
Mistroke
.6205 .03259 L
.62171 .04591 L
.62285 .05658 L
.62348 .06146 L
.62417 .06588 L
.6248 .06902 L
.6251 .07023 L
.62537 .07116 L
.62564 .07188 L
.62593 .0725 L
.62608 .07274 L
.62622 .07291 L
.62637 .07305 L
.62653 .07314 L
.62667 .07317 L
.62683 .07315 L
.62697 .07308 L
.6271 .07298 L
.62722 .07285 L
.62736 .07268 L
.62762 .0722 L
.62795 .07141 L
.62824 .0705 L
.62891 .06777 L
.62952 .06447 L
.63011 .06069 L
.6325 .0401 L
.63356 .02916 L
.63412 .02321 L
.63443 .01994 L
.63472 .0169 L
.63487 .01527 L
.63495 .01507 L
.63503 .0159 L
.63538 .01957 L
.63599 .02589 L
.63719 .03753 L
.63828 .04677 L
.63944 .05477 L
.64001 .0579 L
.64064 .06068 L
.64091 .06167 L
.64121 .06258 L
.64148 .06327 L
.64174 .06378 L
.6419 .06403 L
.64205 .06422 L
.64221 .06438 L
.6423 .06444 L
.64238 .06449 L
Mistroke
.64246 .06452 L
.64255 .06454 L
.6427 .06454 L
.64279 .06452 L
.64287 .06449 L
.64295 .06444 L
.64305 .06438 L
.6432 .06423 L
.64337 .06401 L
.64367 .06349 L
.64397 .06281 L
.64425 .06204 L
.64486 .05982 L
.64553 .05671 L
.64673 .04938 L
.64898 .03134 L
.65013 .02088 L
.65044 .01797 L
.65061 .01636 L
.6507 .01558 L
.65078 .01485 L
.65093 .01598 L
.6511 .0175 L
.65139 .02014 L
.6527 .03158 L
.65393 .04109 L
.65511 .04859 L
.65619 .05375 L
.6568 .05587 L
.65708 .05664 L
.65739 .05731 L
.65755 .05762 L
.65771 .05786 L
.65786 .05806 L
.658 .0582 L
.65817 .05833 L
.65826 .05838 L
.65835 .05842 L
.6585 .05845 L
.65859 .05845 L
.65867 .05844 L
.65883 .05838 L
.6589 .05834 L
.65899 .05828 L
.65914 .05815 L
.65928 .05799 L
.65959 .05751 L
.65993 .0568 L
.66056 .05504 L
.66113 .0529 L
Mistroke
.66222 .04756 L
.66337 .04039 L
.66452 .03201 L
.66515 .02706 L
.66575 .02224 L
.6663 .01769 L
.66646 .01644 L
.66654 .01576 L
.66662 .01512 L
.66676 .01544 L
.66691 .01667 L
.66796 .02509 L
.6702 .04067 L
.67081 .04409 L
.67147 .04723 L
.67203 .04949 L
.67264 .05143 L
.673 .05232 L
.67333 .05296 L
.67365 .05342 L
.67381 .05359 L
.6739 .05367 L
.67398 .05374 L
.67414 .05383 L
.67429 .05388 L
.67444 .0539 L
.67453 .05389 L
.67461 .05388 L
.67475 .05383 L
.67489 .05374 L
.67505 .05362 L
.6752 .05346 L
.67549 .05306 L
.67581 .05249 L
.67636 .05112 L
.67696 .04916 L
.67762 .04649 L
.67999 .03303 L
.68131 .0238 L
.68188 .01957 L
.68221 .01714 L
.68237 .01596 L
.68252 .01488 L
.68267 .01565 L
.68281 .01669 L
.68312 .01897 L
.68376 .02354 L
.6851 .03252 L
.68627 .0393 L
.68692 .04244 L
Mistroke
.68753 .04496 L
.68812 .04698 L
.68867 .04844 L
.68896 .04905 L
.68927 .04958 L
.68959 .04999 L
.68976 .05014 L
.68985 .05021 L
.68993 .05026 L
.69006 .05032 L
.69021 .05036 L
.69035 .05037 L
.69049 .05036 L
.69061 .05032 L
.69073 .05026 L
.69086 .05018 L
.691 .05007 L
.69131 .04972 L
.6916 .04927 L
.69215 .04812 L
.69275 .0464 L
.6933 .04446 L
.69454 .03892 L
.69675 .02583 L
.69734 .02194 L
.69766 .01978 L
.69796 .01776 L
.69822 .01602 L
.69836 .01505 L
.69849 .01526 L
.69864 .01623 L
.69879 .01728 L
.69908 .01917 L
.70027 .02688 L
.70159 .03448 L
.70274 .03995 L
.70334 .0423 L
.70397 .04433 L
.7043 .04519 L
.70466 .04598 L
.70498 .04657 L
.70528 .04699 L
.70543 .04715 L
.70559 .0473 L
.70568 .04737 L
.70576 .04742 L
.70592 .0475 L
.70605 .04754 L
.7062 .04756 L
.70636 .04755 L
Mistroke
.70651 .04751 L
.70666 .04744 L
.70674 .04739 L
.70682 .04734 L
.70711 .04706 L
.70745 .04661 L
.70776 .04606 L
.70834 .04476 L
.70896 .04293 L
.71012 .03839 L
.71119 .03316 L
.71229 .027 L
.71347 .01984 L
.71381 .01767 L
.71399 .0166 L
.71414 .01561 L
.71429 .01472 L
.71444 .01567 L
.71476 .01766 L
.71596 .02494 L
.7171 .03121 L
.71832 .03696 L
.71891 .03927 L
.71947 .04115 L
.72001 .04266 L
.72052 .04377 L
.72081 .04427 L
.72113 .0447 L
.72127 .04485 L
.72141 .04499 L
.72155 .04509 L
.72168 .04516 L
.72182 .04523 L
.72198 .04527 L
.72213 .04528 L
.72226 .04527 L
.72234 .04525 L
.72242 .04522 L
.72257 .04515 L
.72273 .04505 L
.72291 .0449 L
.7232 .04458 L
.72346 .04421 L
.72405 .04307 L
.72458 .04175 L
.72513 .04005 L
.72751 .0297 L
.72857 .02393 L
.72913 .02073 L
.72972 .01728 L
Mistroke
.72987 .0164 L
.73003 .01545 L
.73013 .0149 L
.73021 .01503 L
.7303 .01553 L
.73038 .01601 L
.73099 .01953 L
.73219 .02617 L
.73336 .03201 L
.73443 .03646 L
.73558 .04016 L
.73622 .04163 L
.73651 .04215 L
.73682 .04261 L
.73708 .04292 L
.73722 .04305 L
.73737 .04317 L
.73751 .04326 L
.73764 .04332 L
.73776 .04336 L
.73788 .04338 L
.73802 .04339 L
.73817 .04337 L
.7383 .04334 L
.73844 .04328 L
.73859 .0432 L
.73875 .04308 L
.73904 .04279 L
.73933 .04241 L
.73964 .04191 L
.74019 .04074 L
.74086 .03896 L
.74146 .03699 L
.744 .02568 L
.74513 .01968 L
.7457 .01657 L
.74585 .01571 L
.74594 .01524 L
.74602 .01479 L
.74618 .01551 L
.74632 .0163 L
.74763 .02331 L
.74883 .02921 L
.74999 .0341 L
.75063 .03634 L
.75122 .03813 L
.75177 .03948 L
.75228 .04046 L
.75255 .04087 L
.75284 .04124 L
Mistroke
.75313 .04152 L
.7533 .04163 L
.75345 .04171 L
.7536 .04177 L
.75368 .04179 L
.75376 .04181 L
.75391 .04181 L
.75405 .0418 L
.75414 .04178 L
.75422 .04175 L
.75437 .04169 L
.75453 .04159 L
.75471 .04145 L
.75501 .04114 L
.75533 .04071 L
.75591 .03968 L
.75651 .03825 L
.75708 .0366 L
.75815 .03281 L
.76036 .02268 L
.76097 .01958 L
.76131 .01784 L
.76162 .01619 L
.76177 .01544 L
.76192 .01478 L
.762 .01519 L
.76208 .01565 L
.76224 .01645 L
.7628 .01934 L
.7652 .03058 L
.76651 .03529 L
.7671 .03696 L
.76774 .03844 L
.76804 .03899 L
.76836 .03949 L
.76863 .03984 L
.76893 .04013 L
.7691 .04026 L
.76926 .04036 L
.76942 .04042 L
.7695 .04045 L
.76958 .04047 L
.76973 .04048 L
.76989 .04048 L
.77004 .04045 L
.77018 .0404 L
.77031 .04033 L
.77046 .04024 L
.77072 .04002 L
.77104 .03967 L
Mistroke
.77132 .03928 L
.77188 .03827 L
.77241 .03706 L
.77359 .0335 L
.77483 .02868 L
.776 .02343 L
.77706 .01827 L
.77735 .01686 L
.7775 .01612 L
.77765 .01534 L
.77779 .01478 L
.77794 .01554 L
.77821 .01687 L
.77944 .0228 L
.78165 .03199 L
.78225 .03395 L
.78287 .03571 L
.78341 .03698 L
.78399 .03804 L
.78432 .0385 L
.78461 .03884 L
.78475 .03897 L
.78491 .03909 L
.78506 .03919 L
.78519 .03926 L
.78535 .03931 L
.78543 .03933 L
.78552 .03935 L
.78562 .03936 L
.78571 .03935 L
.78579 .03935 L
.78588 .03933 L
.78603 .03928 L
.78611 .03925 L
.7862 .03921 L
.78651 .039 L
.78679 .03873 L
.7871 .03835 L
.78772 .03732 L
.7883 .03606 L
.78884 .03464 L
.79135 .02539 L
.79262 .01963 L
.79292 .0182 L
.79324 .01668 L
.79351 .01537 L
.79367 .0148 L
.79381 .0155 L
.79489 .02055 L
.79606 .02571 L
Mistroke
.79731 .03056 L
.7985 .03425 L
.79902 .03552 L
.79957 .03663 L
.79989 .03715 L
.80017 .03755 L
.80046 .03787 L
.80073 .0381 L
.80088 .0382 L
.80101 .03827 L
.80116 .03833 L
.80132 .03838 L
.80148 .03839 L
.80156 .03839 L
.80164 .03839 L
.80179 .03836 L
.80194 .03831 L
.80208 .03826 L
.80222 .03817 L
.80247 .03798 L
.80278 .03767 L
.80306 .03732 L
.80364 .03636 L
.80428 .03498 L
.80557 .03126 L
.80689 .02637 L
.80813 .02105 L
.80868 .0186 L
.80925 .01597 L
.8094 .0153 L
.80955 .01484 L
.80964 .01525 L
.80972 .01563 L
.80988 .01636 L
.81046 .019 L
.81165 .02416 L
.81291 .02905 L
.81408 .03276 L
.81517 .03537 L
.81575 .03636 L
.81608 .03679 L
.81638 .0371 L
.81663 .03731 L
.81678 .0374 L
.81691 .03746 L
.81705 .03752 L
.8172 .03756 L
.81734 .03757 L
.81747 .03757 L
.81761 .03756 L
Mistroke
.81777 .03752 L
.81785 .03749 L
.81794 .03745 L
.81809 .03736 L
.81839 .03714 L
.81867 .03687 L
.81934 .03593 L
.81997 .0347 L
.82113 .03168 L
.82236 .02751 L
.82351 .02293 L
.82458 .01836 L
.82489 .01698 L
.82518 .01568 L
.82533 .01503 L
.82548 .0151 L
.82557 .0155 L
.82566 .01588 L
.82582 .01658 L
.82716 .02237 L
.82834 .02701 L
.82959 .03118 L
.83073 .03409 L
.83138 .03532 L
.83168 .03576 L
.83199 .03615 L
.83226 .03642 L
.8324 .03653 L
.83255 .03664 L
.83269 .03672 L
.83281 .03678 L
.83294 .03682 L
.83306 .03685 L
.8332 .03687 L
.83335 .03687 L
.83347 .03686 L
.83361 .03683 L
.83376 .03678 L
.83392 .0367 L
.83421 .03651 L
.83452 .03622 L
.83485 .03583 L
.83543 .03491 L
.83613 .03347 L
.83676 .03185 L
.83919 .02349 L
.84032 .01881 L
.84089 .01636 L
.84105 .01569 L
.84113 .01532 L
Mistroke
.84121 .01496 L
.84137 .01515 L
.84151 .01577 L
.84282 .02131 L
.84403 .026 L
.84519 .02993 L
.84583 .03174 L
.84643 .03319 L
.84698 .0343 L
.84749 .0351 L
.84776 .03545 L
.84805 .03576 L
.84834 .036 L
.8485 .0361 L
.84865 .03617 L
.84881 .03623 L
.84889 .03625 L
.84897 .03627 L
.84912 .03628 L
.84926 .03628 L
.84935 .03627 L
.84943 .03625 L
.84958 .03621 L
.84967 .03618 L
.84975 .03614 L
.84993 .03604 L
.8502 .03583 L
.85051 .03553 L
.85112 .03469 L
.85168 .03367 L
.85228 .03233 L
.85337 .02928 L
.85578 .0204 L
.85637 .01798 L
.85669 .01663 L
.85699 .01534 L
.85708 .01499 L
.85717 .01482 L
.85726 .01523 L
.85735 .01561 L
.85768 .01698 L
.85832 .01964 L
.85955 .02444 L
.86071 .02846 L
.86184 .03167 L
.86289 .03389 L
.86343 .03471 L
.86371 .03505 L
.86401 .03534 L
.86418 .03547 L
Mistroke
.86434 .03558 L
.86449 .03565 L
.86457 .03569 L
.86465 .03572 L
.86479 .03576 L
.86493 .03578 L
.86508 .03578 L
.86523 .03577 L
.86539 .03573 L
.86546 .03571 L
.86555 .03568 L
.86585 .03552 L
.86602 .03539 L
.8662 .03524 L
.86652 .03489 L
.86716 .03396 L
.86775 .03285 L
.86893 .02987 L
.87003 .02637 L
.87132 .02162 L
.87195 .0191 L
.87253 .01673 L
.87267 .01614 L
.87282 .0155 L
.87297 .0149 L
.8731 .01507 L
.87325 .01569 L
.87339 .01627 L
.87371 .01757 L
.875 .02266 L
.87724 .0301 L
.8784 .03283 L
.87905 .03395 L
.87935 .03437 L
.87963 .03469 L
.87989 .03494 L
.88018 .03514 L
.88033 .03522 L
.88047 .03528 L
.88062 .03533 L
.88078 .03536 L
.88091 .03536 L
.88106 .03536 L
.88121 .03533 L
.88134 .03529 L
.88146 .03525 L
.88159 .03519 L
.88185 .03502 L
.88215 .03476 L
.88248 .0344 L
Mistroke
.88307 .03353 L
.88365 .03243 L
.88419 .03121 L
.88671 .0233 L
.88732 .02099 L
.88798 .01838 L
.88828 .01716 L
.8886 .01587 L
.88874 .01533 L
.88888 .01476 L
.88903 .0153 L
.88918 .01589 L
.89142 .02453 L
.89265 .02853 L
.8933 .03032 L
.89398 .03194 L
.89458 .03309 L
.8949 .0336 L
.89524 .03406 L
.89556 .03441 L
.89584 .03466 L
.89612 .03484 L
.89626 .0349 L
.89641 .03496 L
.89657 .035 L
.89671 .03502 L
.89679 .03502 L
.89687 .03502 L
.89696 .03501 L
.89705 .035 L
.8972 .03496 L
.89733 .03491 L
.89749 .03483 L
.89765 .03474 L
.89793 .03452 L
.89818 .03427 L
.89877 .0335 L
.89941 .03237 L
.89999 .03111 L
.9013 .02752 L
.90362 .01923 L
.90426 .01672 L
.90458 .01545 L
.90467 .0151 L
.90476 .01472 L
.90485 .01506 L
.90493 .01539 L
.90613 .02011 L
.90735 .02456 L
.90863 .02865 L
Mistroke
.90973 .03143 L
.91036 .03267 L
.91094 .03358 L
.91151 .03421 L
.91179 .03444 L
.91196 .03455 L
.9121 .03462 L
.91224 .03467 L
.91237 .03471 L
.91251 .03474 L
.91266 .03475 L
.91279 .03475 L
.91292 .03473 L
.91304 .0347 L
.91317 .03466 L
.91333 .03458 L
.91348 .0345 L
.91377 .03429 L
.91407 .03399 L
.91441 .03359 L
.91501 .03266 L
.91557 .03157 L
.91685 .02832 L
.91805 .02448 L
.91912 .02059 L
.91969 .01842 L
.9203 .01605 L
.92046 .0154 L
.92062 .01478 L
.92076 .0152 L
.92091 .0158 L
.92148 .01803 L
.92273 .02272 L
.92496 .02971 L
.92609 .03223 L
.92674 .03328 L
.92703 .03365 L
.92735 .03398 L
.92752 .03412 L
.92768 .03424 L
.92784 .03434 L
.92799 .03442 L
.92813 .03447 L
.92827 .03451 L
.92841 .03453 L
.92857 .03454 L
.92873 .03453 L
.92882 .03452 L
.9289 .0345 L
.92907 .03444 L
Mistroke
.92925 .03435 L
.92958 .03413 L
.92988 .03386 L
.93046 .03315 L
.93108 .03212 L
.93219 .02965 L
.93338 .0262 L
.93469 .02168 L
.93528 .01946 L
.93591 .01706 L
.93616 .01606 L
.93631 .01551 L
.93644 .01498 L
.9366 .01507 L
.93674 .01563 L
.93702 .01672 L
.93954 .02584 L
.94071 .02928 L
.94135 .03084 L
.94195 .03206 L
.9425 .03298 L
.94301 .03362 L
.9433 .0339 L
.94357 .03411 L
.94371 .0342 L
.94386 .03427 L
.94395 .0343 L
.94402 .03433 L
.94418 .03437 L
.94432 .03439 L
.94446 .0344 L
.94461 .03438 L
.94477 .03435 L
.94485 .03433 L
.94493 .0343 L
.94509 .03423 L
.94539 .03405 L
.94567 .03381 L
.94597 .0335 L
.9465 .03277 L
.94712 .03169 L
.9477 .03044 L
.94901 .02686 L
.9502 .02292 L
.95145 .0183 L
.95197 .01631 L
.95212 .01574 L
.95226 .01519 L
.95238 .01473 L
.95252 .01526 L
Mistroke
.95312 .01759 L
.95369 .01973 L
.95604 .02771 L
.95669 .02947 L
.95738 .03109 L
.95803 .03234 L
.95863 .03323 L
.95892 .03357 L
.95924 .03387 L
.95956 .03409 L
.95974 .03418 L
.95982 .03422 L
.9599 .03425 L
.96005 .03428 L
.96021 .03431 L
.96035 .03431 L
.96049 .0343 L
.96065 .03427 L
.96079 .03422 L
.96096 .03415 L
.96111 .03406 L
.96139 .03387 L
.96168 .0336 L
.9622 .03295 L
.96277 .03205 L
.96338 .0308 L
.96573 .0241 L
.96703 .0194 L
.96767 .01698 L
.96795 .01591 L
.96809 .01534 L
.96825 .01475 L
.9684 .0153 L
.96855 .01586 L
.96884 .01696 L
.96947 .01936 L
.9708 .02415 L
.97197 .02783 L
.97322 .031 L
.97402 .03251 L
.97476 .0335 L
.97511 .03383 L
.9753 .03397 L
.97549 .03409 L
.97567 .03418 L
.97576 .03421 L
.97586 .03424 L
.97595 .03426 L
.97603 .03427 L
.97611 .03428 L
Mistroke
.97619 .03428 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.03968 .01472 m
.03968 .03431 L
s
.05556 .01472 m
.05556 .0344 L
s
.07143 .01472 m
.07143 .03454 L
s
.0873 .01472 m
.0873 .03475 L
s
.10317 .01472 m
.10317 .03502 L
s
.11905 .01472 m
.11905 .03536 L
s
.13492 .01472 m
.13492 .03578 L
s
.15079 .01472 m
.15079 .03628 L
s
.16667 .01472 m
.16667 .03688 L
s
.18254 .01472 m
.18254 .03757 L
s
.19841 .01472 m
.19841 .03839 L
s
.21429 .01472 m
.21429 .03935 L
s
.23016 .01472 m
.23016 .04048 L
s
.24603 .01472 m
.24603 .04181 L
s
.2619 .01472 m
.2619 .04339 L
s
.27778 .01472 m
.27778 .04527 L
s
.29365 .01472 m
.29365 .04755 L
s
.30952 .01472 m
.30952 .05036 L
s
.3254 .01472 m
.3254 .05388 L
s
.34127 .01472 m
.34127 .05842 L
s
.35714 .01472 m
.35714 .0645 L
s
.37302 .01472 m
.37302 .07308 L
s
.38889 .01472 m
.38889 .08619 L
s
.40476 .01472 m
.40476 .10909 L
s
.42063 .01472 m
.42063 .16084 L
s
.43651 .01472 m
.43651 .41241 L
s
.45238 .01472 m
.45238 .36124 L
s
.46825 .01472 m
.46825 .10807 L
s
.48413 .01472 m
.48413 .05356 L
s
.5 .01472 m
.5 .03428 L
s
.51587 .01472 m
.51587 .05356 L
s
.53175 .01472 m
.53175 .10807 L
s
.54762 .01472 m
.54762 .36124 L
s
.56349 .01472 m
.56349 .41241 L
s
.57937 .01472 m
.57937 .16084 L
s
.59524 .01472 m
.59524 .10909 L
s
.61111 .01472 m
.61111 .08619 L
s
.62698 .01472 m
.62698 .07308 L
s
.64286 .01472 m
.64286 .0645 L
s
.65873 .01472 m
.65873 .05842 L
s
.6746 .01472 m
.6746 .05388 L
s
.69048 .01472 m
.69048 .05036 L
s
.70635 .01472 m
.70635 .04755 L
s
.72222 .01472 m
.72222 .04527 L
s
.7381 .01472 m
.7381 .04339 L
s
.75397 .01472 m
.75397 .04181 L
s
.76984 .01472 m
.76984 .04048 L
s
.78571 .01472 m
.78571 .03935 L
s
.80159 .01472 m
.80159 .03839 L
s
.81746 .01472 m
.81746 .03757 L
s
.83333 .01472 m
.83333 .03688 L
s
.84921 .01472 m
.84921 .03628 L
s
.86508 .01472 m
.86508 .03578 L
s
.88095 .01472 m
.88095 .03536 L
s
.89683 .01472 m
.89683 .03502 L
s
.9127 .01472 m
.9127 .03475 L
s
.92857 .01472 m
.92857 .03454 L
s
.94444 .01472 m
.94444 .0344 L
s
.96032 .01472 m
.96032 .03431 L
s
.97619 .01472 m
.97619 .03428 L
s
.015 w
.03968 .03431 Mdot
.05556 .0344 Mdot
.07143 .03454 Mdot
.0873 .03475 Mdot
.10317 .03502 Mdot
.11905 .03536 Mdot
.13492 .03578 Mdot
.15079 .03628 Mdot
.16667 .03688 Mdot
.18254 .03757 Mdot
.19841 .03839 Mdot
.21429 .03935 Mdot
.23016 .04048 Mdot
.24603 .04181 Mdot
.2619 .04339 Mdot
.27778 .04527 Mdot
.29365 .04755 Mdot
.30952 .05036 Mdot
.3254 .05388 Mdot
.34127 .05842 Mdot
.35714 .0645 Mdot
.37302 .07308 Mdot
.38889 .08619 Mdot
.40476 .10909 Mdot
.42063 .16084 Mdot
.43651 .41241 Mdot
.45238 .36124 Mdot
.46825 .10807 Mdot
.48413 .05356 Mdot
.5 .03428 Mdot
.51587 .05356 Mdot
.53175 .10807 Mdot
.54762 .36124 Mdot
.56349 .41241 Mdot
.57937 .16084 Mdot
.59524 .10909 Mdot
.61111 .08619 Mdot
.62698 .07308 Mdot
.64286 .0645 Mdot
.65873 .05842 Mdot
.6746 .05388 Mdot
.69048 .05036 Mdot
.70635 .04755 Mdot
.72222 .04527 Mdot
.7381 .04339 Mdot
.75397 .04181 Mdot
.76984 .04048 Mdot
.78571 .03935 Mdot
.80159 .03839 Mdot
.81746 .03757 Mdot
.83333 .03688 Mdot
.84921 .03628 Mdot
.86508 .03578 Mdot
.88095 .03536 Mdot
.89683 .03502 Mdot
.9127 .03475 Mdot
.92857 .03454 Mdot
.94444 .0344 Mdot
.96032 .03431 Mdot
.97619 .03428 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005_ooool3o`0000Cooooo0_l0000iooooo`?o0000>oooool2o`0003cooooo0ol0000ioooo
o`?o00001?ooool2o`0000Oooooo000Gooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000=oooool01Ol0003ooooooooooooooooo000003Wooooo00Co0000oooooooooooo0000>_oo
ool01Ol0003ooooooooooooooooo000003Wooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00006ooooo`003oooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000aooooo`Go00001Oooool00ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`00
03kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Kooooo000Gooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000>oooool0
0ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`0003kooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo000Gooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000=oooool4o`0003[ooooo00Co0000oooooooooooo
0000>_ooool4o`0003[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006oooo
o`005_ooool2o`0000Cooooo00Co0000oooooooooooo0000=oooool00ol0003oooooooooo`0koooo
o`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool0>_ooool2o`0000Cooooo00Co0000
oooooooooooo00001_ooool001Oooooo00?o0000ooooooooool00oooool2o`0003Sooooo1Ol0000j
ooooo`;o0000>oooool5o`0003Wooooo00?o0000ooooooooool00oooool2o`0000Oooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Boooooooo00003?l00003
ooooo`002_ooool2o`0000Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`01oooo
o`002Oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo007ooooo0009ooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo007ooooo0009ooooo`04o`000?ooooooooooo`0000Gooooo0_l00006oooo
o`07o`00ooooooooo`00ooooool00?ooooooool00004ooooo`0=ool00?oooooo003ooooooooo003o
ooooo`00ooooooooo`00ooooool00?ooooooool00003ooooo`06ool00?oooooo003oo`00oooooooo
o`000oooool01Ooo003oooooo`00ooooooooo`0000?ooooo00koo`00ooooool00?oo003ooooooooo
003oooooo`00ooooooooo`00ooooool00?ooooooool000?ooooo00Koo`00ooooool00?ooooooool0
0?ooool2o`00o`03oooooooo003ooooo00;ooooo00Woo`00ooooool00?ooooooool00?oooooo003o
oooooooo00001?ooool01Ooo003oooooo`00ooooooooo`0000?ooooo00Woo`00oooooooooooooooo
ool00?oooooo003ooooooooo00000_ooool00ol00?ooooooool00003ooooo`0:ool00?oooooooooo
oooooooo003oooooo`00ooooooooo`00ooooo`;o003o00[oooooool00?oooooo003ooooooooo003o
ooooo`00ooooooooo`000oooool01Ooo003oooooooooooooooooo`0000;ooooo013o003ooooooooo
003oooooo`00ooooooooo`00ooooool00?ooooooool00?oooooo003ooooooooo003ooooo0_l00?l0
4?ooooooo`00ooooool00?ooooooool00?oooooo003ooooooooo003oooooo`00ooooooooo`00oooo
ool00?l2ooooo`05ool00?oooooooooooooooooo00000oooool02_oo003oooooooooooooooooo`00
ooooool00?ooooooool00?ooool2o`00o`0@oooooooo003oooooo`00ooooooooo`00ooooool00?oo
ooooool00?oooooo003ooooooooo003oooooo`00o`;ooooo00Woo`00ooooooooooooooooool00?oo
oooo003ooooooooo00000oooool01Ooo003oooooo`00ooooooooo`0000;ooooo00?o003ooooooooo
00000oooool02Ooo003oooooo`00ooooooooo`00ooooool00?ooooooool00004ooooo`?o00000ooo
ool000Wooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`05ooooo`08o`00oooo
ooooo`00ooooool00?ooooooool00?ooool2o`00o`06oooooooo003oooooo`00ooooooooo`000_l0
0?l01oooooooo`00ooooool00?ooooooool00?ooool00_l00?l01_oo003oooooo`00ool00?oooooo
ool000;o003o00_oooooool00?oooooo003ooooooooo003oooooo`00ooooooooo`00ooooo`02o`00
o`03oooooooo003o003o00;ooooo00koo`00ooooool00?ooooooool00?oooooo003ooooooooo003o
ooooo`00ooooooooo`00ooooo`;o003o013oooooool00?oooooo003ooooooooo003oooooo`00oooo
ooooo`00ooooool00?ooooooool00?oooooo003o0_ooool04Ooo003oooooo`00ooooooooo`00oooo
ool00?ooooooool00?oooooo003ooooooooo003oooooo`00ooooooooo`0000;ooooo00?o003ooooo
oooo00000oooool02_oo003oooooo`00ooooooooo`00ooooool00?ooooooool00?ooool2o`00o`0>
oooooooo003oooooo`00ooooooooo`00ooooool00?ooooooool00?oooooo003ooooooooo0003oooo
o`0Dool00?ooooooooooo`00ooooooooo`00ooooool00?ooooooool00?oooooo003ooooooooo003o
ooooo`00ooooooooo`00ooooool00?l2ooooo`0?ool00?oooooo003ooooooooo003oooooo`00oooo
ooooo`00ooooool00?ooooooool00?oooooo003o00;ooooo00Goo`00o`00ool00?ooooooool00003
ooooo`05ool00?oooooo003ooooooooo00000_ooool00ol00?ooo`00ooooo`02o`00o`0?oooooooo
003oooooo`00ooooooooo`00ooooool00?ooooooool00?oooooo003ooooooooo003ooooo00;o003o
00koooooool00?l00?oo003ooooooooo003oooooo`00ooooooooo`00ooooool00?ooooooool000;o
oooo00Oo003oool00?ooooooooooo`00ooooooooo`0000;o003o00Koooooool00?oooooo003ooooo
oooo0002ooooo`03o`00oooo003ooooo00Gooooo00?o0000ooooooooool00Oooool000Wooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`07ooooo`06ool00?oooooo003oo`00oooo
003ooooo0_l00?l01_ooooooo`00o`00ool00?ooooooool000?ooooo00Koo`00ooooool00?oo003o
ool00?ooool2o`00o`03ool00?oooooooooo00;ooooo00[oo`00o`00ool00?ooooooool00?oooooo
003ooooooooo003ooooo0_l00?l00ooo003oooooo`00o`02ooooo`05ool00?l00?oo003ooooooooo
00000oooool02ooo003oooooo`00ool00?ooo`00ooooool00?ooooooool00?oooooo003o00;ooooo
00Goo`00ooooool00?ooooooool00003ooooo`06ool00?oooooo003ooooooooo003ooooo0_l00?l0
4_ooooooo`00ooooool00?ooooooool00?oooooo003ooooooooo003oooooo`00ooooooooo`00oooo
ool00?ooooooool000;ooooo00?o003ooooooooo00000oooool02Ooo003oooooo`00ooooooooo`00
ooooool00?ooooooool00004ooooo`0=ool00?l00?oooooooooooooo003oooooo`00ooooooooo`00
ooooool00?ooooooool00003ooooo`0Dool00?ooooooooooo`00ooooooooo`00ooooool00?oooooo
ool00?oooooo003ooooooooo003oooooo`00ooooooooo`00ooooool00?l2ooooo`0?ool00?l00?oo
oooooooooooo003oooooo`00ooooooooo`00ooooool00?ooooooool00?oooooo003o00;ooooo00Go
o`00o`00ool00?ooooooool00002o`00o`06oooooooo003oooooo`00ooooooooo`000_ooool00ol0
0?ooo`00ooooo`03ooooo`05ool00?l00?oo003ooooooooo00000oooool01ooo003oooooooooool0
0?ooo`00ooooool00?l00_ooool01Ooo003o003oo`00ooooooooo`0000?o003o00Goo`00ooooool0
0?oo003oool00002ooooo`03o`00oooo003ooooo00;o003o00Koooooool00?l00?oo003ooooooooo
0002o`00o`06oooooooo003oooooooooool00?ooo`001_ooool00ol0003oooooooooo`01ooooo`00
2_ooool2o`0000Kooooo00?o0000ooooooooool01?ooool01?l00?oooooooooooooo0002ooooo`08
o`00oooo003o003oooooool00?ooooooool00?l00?l2ooooo`0:ool00?oooooooooooooooooo003o
003oooooool00?ooo`00ooooo`;o003o00?oo`00ooooool00?l00_ooool01_oo003o003oo`00oooo
ooooo`00o`00o`;ooooo00Goo`00o`00ool00?oo003oool00002ooooo`03o`00ooooooooo`0000;o
003o00?oooooool00?ooool00_ooool01Ooo003oooooo`00ool00?ooo`0000;ooooo00?o003oool0
0?ooool00_l00?l01_ooooooo`00o`00ool00?ooooooool000?ooooo00Koo`00ooooool00?oooooo
ool00?ooool2o`00o`03oooooooo003ooooo00;ooooo00Woo`00ooooool00?ooooooool00?oooooo
003ooooooooo00000oooool01_oo003oooooooooool00?ooooooool000?ooooo00Goo`00ooooool0
0?ooooooool00003ooooo`0Bool00?ooooooooooo`00ooooooooo`00ooooool00?ooooooool00?oo
oooo003ooooooooo003oooooo`00ooooooooo`000oooool04ooo003oooooooooool00?ooooooool0
0?oooooo003ooooooooo003oooooo`00ooooooooo`00ooooool00?ooooooool00?ooool00_l00?l0
1oooooooo`00ooooool00?ooooooool00?l00?l00_ooool01_oo003oooooo`00ooooooooo`00oooo
o`;o003o00Koooooool00?l00?oo003ooooooooo0002o`00o`0:oooooooo003oooooo`00oooooooo
o`00ooooool00?ooooooool000;ooooo00?o003ooooooooo00000_l00?l00oooooooo`00ooooo`02
ooooo`05ool00?l00?oooooooooooooo00000_ooool02?l00?ooooooool00?l00?ooooooo`00oooo
003o003o0_ooool01Ooo003oooooo`00ool00?ooo`0000;o003o00?oooooool00?ooool00_l00?l0
2oooooooo`00o`00oooooooo003oool00?l00?ooooooo`00oooo003o003o00;ooooo00?oo`00oooo
ooooool01?ooool00ol0003oooooooooo`01ooooo`004_ooool00ol0003oooooooooo`03ooooo`;o
003o00Goooooool00?oo003oo`00ooooo`03ool000?ooooo00Woo`00ooooooooooooooooool00?l0
0?ooooooo`00oooo00000_ooool01ol00?ooo`00o`00oooooooo003oool00?l00?l00_ooool02_l0
0?ooo`00o`00oooooooo003oool00?l00?ooooooo`00oooo0002ooooo`0@o`00oooo003o003ooooo
ool00?ooooooool00?l00?ooooooo`00oooo003o003oooooool00?ooo`00o`00o`;ooooo00Goo`00
oooooooooooo003oool00002ooooo`03o`00ooooooooo`0000;o003o00Ooooooool00?l00?oooooo
o`00oooo003ooooo00;o003o00Koo`00oooooooooooo003ooooooooo0002o`00o`0;oooooooo003o
ooooo`00ooooooooo`00ooooool00?ooooooool00?ooool00_l00?l01_oo003oooooooooool00?oo
ooooool000?ooooo00Koo`00ooooool00?ooooooool00?ooool2o`00o`03ool00?oooooo003o00?o
o`0000coooooo`00ooooooooo`00ooooool00?ooooooool00?oooooo003ooooooooo0003ooooo`0?
ool00?ooooooooooo`00ooooooooo`00ooooool00?ooooooool00?oooooo003ooooooooo003ooooo
00;o003o00_oo`00oooooooooooo003ooooooooo003oooooo`00ooooooooo`00o`00o`02ooooo`05
ool00?oooooo003oo`00oooo00000_ooool00ol00?ooooooool00002o`00o`0Loooooooo003o003o
ooooool00?ooo`00o`00oooooooo003oool00?oooooo003ooooooooo003oooooo`00oooooooo003o
ool00?l00?ooooooo`00oooo003o003oooooool00?ooo`00o`00o`;ooooo00?oo`00ooooooooool0
0_l00?l01_oo003o003oooooool00?ooo`00o`00o`;ooooo00[oo`00o`00ooooooooooooool00?l0
0?ooooooo`00oooo003o003o0oooool00ooo003o003oool00002ool00003o`00ooooooooo`0000;o
o`0000Coooooool00?oo003oo`001Oooool00ol0003oooooooooo`01ooooo`004_ooool2o`0000Co
oooo00?o003oooooooooool00ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Coooooool0
0?oo003oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo00001Oooooooo`00ool0
0?oo003ooooo00?oo`0000?o003ooooooooo00000_oo0002ooooo`0>ool00?l00?ooooooooooool0
0?ooo`00o`00oooooooo003oool00?l00?ooooooo`00oooo0003ooooo`05ool00?l00?ooooooo`00
oooo00000_ooool00ol00?ooooooool00003ooooo`09ool00?l00?ooooooo`00oooo003o003ooooo
ool00?ooo`0000Cooooo00Goo`00o`00ool00?ooooooool00003ooooo`06ool00?oooooooooooooo
oooo003ooooo0_l00?l01_oo003oooooo`00ool00?ooooooool000?ooooo00Koo`00ooooool00?oo
ooooool00?ooool2o`00o`03ool00?oooooo003o00?oo`0000Goooooo`00ooooooooo`00o`00o`02
ooooo`05ool00?oooooooooooooooooo00000oooool03ooo003oooooooooool00?ooooooool00?oo
oooo003ooooooooo003oooooo`00ooooooooo`00ooooo`02o`00o`06ool00?oooooo003oo`00oooo
ooooo`000_l00?l02oooooooo`00o`00oooooooo003oool00?l00?ooooooo`00oooo003ooooo00;o
003o00?oooooool00?ooool00_ooool01Ooo003o003oooooooooooooo`0000?ooooo00Koo`00o`00
oooooooo003oool00?l00?l2ooooo`03o`00oooo003o003o00;ooooo00?oo`00o`00ooooool00ooo
00001Oooooooo`00ool00?oo003ooooo00?oo`0000Coooooool00?oo003oo`000_ooool3ool00005
oooooooo003oo`00ool00?ooool00ooo00001Oooooooo`00ool00?oo003ooooo00?oo`000_ooool3
ool00004oooooooo003oo`00ool000Cooooo0_l00003ooooo`004_ooool00ol0003oooooooooo`06
ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool00004oooooooo003oo`00ool000;ooooo
0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Goooooool00?oo003oo`00ooooo`03ool0
00;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Koooooool00?oo003oo`00o`00
ooooool3ool0000<ooooool00?ooo`00o`00oooooooo003oool00?oooooo003oooooool00?ooo`00
0_ooool03?l00?ooo`00o`00oooooooo003oool00?l00?ooooooo`00oooo003oooooo`00o`;ooooo
00Woo`00o`00ool00?ooooooool00?oooooo003ooooooooo00000oooool01_oo003oooooo`00ool0
0?ooo`00ooooo`;o003o00?oooooool00?ooool00_ooool01_oo003oooooooooooooooooo`00oooo
o`;o003o00?oo`00o`00ooooool00ooo0002ooooo`06o`00oooo003oooooo`00ooooooooo`000ooo
ool01ooo003oooooooooooooooooo`00ooooool00?l00_ooool03ooo003oooooo`00ooooooooo`00
ooooool00?ooooooool00?oooooo003ooooooooo003oooooo`00o`02ooooo`0>ool00?l00?oo003o
oooooooo003o003oooooool00?ooo`00o`00oooooooo003oool00?l00?l3ooooo`05ool00?oooooo
ooooo`00oooo00000oooool00ooo003o003oooooo`03ool00005oooooooo003oo`00ool00?ooool0
0ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool0
0004oooooooo003oo`00ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Go
ooooool00?oo003oo`00ooooo`03ool000;ooooo0ooo00001?ooooooo`00ool00?oo0005ooooo`03
o`000?oooooooooo007ooooo000Booooo`03o`000?oooooooooo00kooooo0ooo00001?ooooooo`00
ool00?oo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool00005oooooooo003oo`00
ool00?ooool00ooo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool00004oooooooo
003oo`00ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`000oooool01Ooo003o
003oooooool00?ooo`0000;ooooo00Oo003oool00?ooooooooooo`00oooo003ooooo00;o003o00?o
ooooool00?l00?l00_ooool01_oo003o003oo`00ooooooooo`00ooooo`;o003o00Goo`00oooooooo
oooo003oool00002ooooo`03o`00ooooooooo`0000?ooooo00Koo`00ooooool00?ooooooool00?oo
ool2o`00o`03ool00?l00?oooooo00;ooooo00go0000ooooooooooooooooool00?oooooo003ooooo
oooo003oooooo`00ooooooooo`0000?ooooo00?oo`00ooooool00?l00_ooool01Ooo003oooooo`00
ooooooooo`0000;ooooo00?o003oool00?ooool00_l00?l00ooo003oooooo`00o`02ooooo`05ool0
0?l00?oooooooooooooo00000_ooool01ol00?ooo`00oooooooooooo003oool00?l00?l00oooool0
0ooo003oooooool00002ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Go
ooooool00?oo003oo`00ooooo`03ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?o
o`0000Coooooool00?oo003oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo0000
1?ooooooo`00ool00?oo000Booooo`03o`000?oooooooooo007ooooo000Booooo`03o`000?oooooo
oooo033ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`000_ooool3ool00005oooooooo
003oo`00ool00?ooool00ooo00001?ooooooo`00ool00?oo0002ooooo`03o`00oooo003ooooo00;o
oooo00[oo`00o`00ooooooooooooool00?l00?ooooooo`00ooooooooo`000oooool01_oo003o003o
ooooool00?ooo`00ooooo`;o003o00Koo`00ooooooooooooooooool00?ooool2o`00o`03oooooooo
003ooooo00;ooooo00Goo`00ooooool00?ooooooool00003ooooo`03ool00?oooooooooo00;ooooo
00go0000oooooooooooo003oool00?l00?ooooooo`00oooo003oooooo`00ooooooooo`0000?ooooo
00Ooo`00ooooool00?oo003ooooooooo003o003o00;ooooo00Goo`00o`00oooooooo003oool00002
ooooo`03o`00oooo003ooooo00;o003o00Ooooooool00?ooooooooooo`00oooo003o003o00;ooooo
00Ooo`00ooooooooooooooooool00?l00?oooooo00?oo`0000Coooooool00?oo003oo`000_ooool3
ool00005oooooooo003oo`00ool00?ooool00ooo00001Oooooooo`00ool00?oo003ooooo00?oo`00
=?ooool00ol0003oooooooooo`01ooooo`004_ooool00ol0003oooooooooo`11ooooo`?oo`0000Go
ooooool00?oo003oo`00ooooo`03ool00004oooooooo003oo`00ool000?ooooo00Koo`00o`00oooo
ooooooooool00?l00?l2ooooo`0Do`00oooo003o003oooooool00?ooo`00o`00oooooooo003oool0
0?l00?ooooooo`00oooo003oooooo`00ooooooooo`00ooooool00?l2ooooo`09ool00?oooooooooo
oooooooo003oooooo`00ooooooooo`0000?ooooo00?oo`00o`00ooooool00_ooool01_l0003ooooo
ooooool00?ooo`00o`00o`;ooooo00Goo`00ooooool00?ooooooool00003ooooo`07ool00?oooooo
ooooo`00ooooooooo`00o`00o`02ooooo`09ool00?l00?oooooooooooooo003o003oooooool00?oo
o`0000;ooooo00?o003ooooooooo00000_ooool00ol00?ooo`00o`00o`02ooooo`03ool00?l00?oo
oooo00?oo`0000Goooooool00?oo003oo`00ooooo`03ool000;ooooo0ooo0014ooooo`03o`000?oo
oooooooo007ooooo000Booooo`;o0000B_ooool3ool00004oooooooo003oo`00ool000;ooooo0ooo
0002ooooo`0;ool00?ooooooooooooooool00?ooo`00o`00oooooooo003oool00?l00?l00_ooool0
1_oo003oooooooooool00?ooo`00ooooo`;o003o00?oo`00ooooool00?l00_ooool02ooo003ooooo
ooooooooooooo`00ooooool00?ooooooool00?l00?oooooo00?oo`000oooool00ol0003oooooool0
0002ool00004o`00ooooooooooooool000?ooooo00Goo`00ooooooooooooooooool00002ooooo`03
o`00ooooooooo`0000;o003o00[oooooool00?l00?ooooooo`00oooo003o003oooooool00?ooo`00
0oooool01_l00?ooo`00oooooooooooo003oool000;ooooo0ooo00001Oooooooo`00ool00?oo003o
oooo00?oo`00C?ooool2o`0000?ooooo000Booooo`03o`000?oooooooooo04gooooo0ooo0002oooo
o`?oo`0000Coooooool00?oo003oo`000_ooool01_l00?ooo`00o`00oooooooo003oool000?ooooo
00Koo`00o`00ooooooooooooool00?ooool2o`00o`06ool00?oooooo003oo`00ooooooooo`000ooo
ool01ooo003oooooooooooooooooo`00o`00ooooool00ooo0003ooooo`03o`000?ooooooo`0000;o
o`000_ooool00ol00?ooo`00ooooo`02ooooo`06ool00?oooooooooooooooooo003ooooo0_l00?l0
2oooooooo`00o`00ool00?ooooooool00?l00?ooooooo`00oooo003o003o00;ooooo00?oo`00o`00
ooooool00_ooool00ooo003oooooool00002ool000;ooooo0ooo00001?ooooooo`00ool00?oo001A
ooooo`03o`000?oooooooooo007ooooo000Booooo`03o`000?oooooooooo05;ooooo0ooo00001Ooo
ooooo`00ool00?oo003ooooo00?oo`000_ooool01_l00?ooo`00o`00oooooooo003oool000;ooooo
00?o003oool00?ooool00_l00?l01_oo003oooooooooool00?ooooooool000?ooooo00Ooo`00oooo
ool00?ooooooool00?l00?oooooo00?oo`000oooool00ol0003oooooool00002ool000;ooooo00?o
003oool00?ooool00_l00?l01ooo003oooooooooooooooooo`00ooooool00?l00_ooool01Ooo003o
ooooo`00ooooooooo`0000;ooooo00?o003oool00?l00?l00_ooool00ooo003o003oooooo`03ool0
0004oooooooo003oo`00ool000;ooooo0ooo001Eooooo`03o`000?oooooooooo007ooooo000Boooo
o`03o`000?oooooooooo05Kooooo0ooo00001?ooooooo`00ool00?oo0003ooooo`09ool00?l00?oo
ooooo`00oooo003o003oooooool00?ooo`0000?ooooo00Koo`00oooooooooooo003ooooooooo0003
ooooo`06ool00?oooooo003oo`00oooo003o003o1oooool00ol0003oooooooooo`04ooooo`03o`00
oooo003ooooo00;o003o00Koo`00ooooooooooooooooool00?ooool2o`00o`0:oooooooo003ooooo
o`00ooooooooo`00o`00oooooooo003oool000?ooooo00?oo`00o`00ooooool00ooo00001?oooooo
o`00ool00?oo001Jooooo`03o`000?oooooooooo007ooooo000Booooo`03o`000?oooooooooo05[o
oooo0ooo0002ooooo`0@o`00oooo003oooooooooool00?ooo`00o`00oooooooo003oool00?oooooo
003ooooooooo003oooooo`00o`;ooooo00Koo`00ooooooooooooooooool00?ooool2o`00o`03ool0
0?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol00?ooo`00ooooo`02o`00o`06ool0
0?oooooooooooooooooo003ooooo0_l00?l00oooooooo`00o`00o`02ooooo`05ool00?l00?oooooo
oooooooo00000oooool00ooo003oooooooooo`03ool005kooooo00?o0000ooooooooool00Oooool0
01;ooooo0_l0001Oooooo`?oo`000oooool01_oo003o003oooooool00?ooo`00ooooo`;o003o00?o
o`00ooooool00?l00_ooool01_oo003oooooooooooooooooo`00ooooo`;o003o00?oo`00o`00oooo
ool01_ooool00ol0003oooooooooo`05ooooo`05ool00?oooooo003oo`00oooo00000oooool02ooo
003oooooooooool00?ooooooool00?l00?ooooooo`00oooo003o003o00;ooooo00?oo`00o`00oooo
ool00ooo001Qooooo`;o00000oooool001;ooooo00?o0000ooooooooool0G_ooool3ool000?ooooo
00Koo`00o`00ooooooooooooool00?ooool2o`00o`06ool00?oooooo003oo`00ooooooooo`000ooo
ool01_oo003oooooooooooooooooo`00o`00o`Oooooo00?o0000ooooooooool01?ooool00ol00?oo
o`00ooooo`02ooooo`06ool00?oooooooooooooooooo003ooooo0_l00?l03?ooooooo`00o`00oooo
oooo003oool00?l00?ooooooo`00oooo003o003oooooo`?oo`00H_ooool00ol0003oooooooooo`01
ooooo`004_ooool00ol0003oooooooooo`1Nooooo`?oo`000_ooool02_l00?ooo`00oooooooooooo
003oool00?l00?ooooooo`00oooo0002ooooo`03o`00ooooooooo`0000?ooooo00Koo`00ooooool0
0?ooooooool00?l00?l7ooooo`03o`000?oooooooooo00Cooooo00Ko003oool00?l00?ooooooo`00
oooo0003ooooo`03ool00?oooooo003o00;ooooo00Goo`00oooooooooooo003oool00002ooooo`04
o`00oooo003o003oooooo`?oo`00H_ooool00ol0003oooooooooo`01ooooo`004_ooool00ol0003o
ooooooooo`1Sooooo`?oo`0000?oooooo`00oooo00000_ooool01ol00?ooo`00oooooooooooo003o
oooooooo00000oooool01_oo003oooooo`00ool00?ooo`00o`00o`Oooooo00?o0000ooooooooool0
1?ooool01_l00?ooo`00o`00oooooooo003oool000?ooooo00?oo`00ooooool00?l00_ooool01Ooo
003oooooooooool00?ooo`0000;ooooo0ooo001Vooooo`03o`000?oooooooooo007ooooo000Boooo
o`03o`000?oooooooooo06?ooooo0ooo00000ooooooo003oool00003ooooo`06ool00?oooooo003o
o`00ooooooooo`000oooool01Ooo003o003oooooool00?ooo`0000Sooooo00?o0000ooooooooool0
1?ooool01_l00?ooo`00o`00oooooooo003oool000?ooooo00Ooo`00ooooool00?oo003ooooooooo
003o003o00;ooooo00?oo`00o`00ooooool00ooo001Vooooo`03o`000?oooooooooo007ooooo000B
ooooo`03o`000?oooooooooo06?ooooo0ooo00002Ooooooo003oool00?l00?ooooooo`00oooo003o
ooooo`00o`02ooooo`09ool00?oooooooooooooooooo003o003oooooool00?ooo`0000Sooooo00?o
0000ooooooooool01Oooool01Ooo003o003oooooool00?ooo`0000?ooooo00Ooo`00oooooooooooo
003ooooooooo003o003o00;ooooo00?oo`00o`00ooooool00ooo001Vooooo`03o`000?oooooooooo
007ooooo000Booooo`;o0000JOooool01_oo003o003oooooool00?ooo`00ooooo`;o003o00?ooooo
ool00?ooool00_ooool01_oo003oooooooooool00?ooo`00o`00o`Oooooo00?o0000ooooooooool0
1Oooool01Ooo003oooooooooooooooooo`0000?ooooo00[oo`00oooooooooooo003ooooooooo003o
003oooooool00?ooo`00J_ooool2o`0000?ooooo000Booooo`03o`000?oooooooooo06Sooooo00Ko
o`00o`00oooooooo003oool00?ooool2o`00o`03oooooooo003ooooo00;ooooo00Koo`00oooooooo
ooooooooool00?l00?l7ooooo`03o`000?oooooooooo00Gooooo00Goo`00o`00ooooooooooooool0
0003ooooo`03ool00?oooooo003o00;ooooo00Goo`00o`00oooooooo003oool0001[ooooo`03o`00
0?oooooooooo007ooooo0009ooooo`?o00001_ooool00ol0003oooooooooo`1Xooooo`05ool00?oo
ooooooooo`00oooo00000_ooool00ol00?ooooooool00003ooooo`05ool00?l00?ooooooo`00oooo
00002?ooool00ol0003oooooooooo`05ooooo`05ool00?l00?ooooooo`00oooo00000oooool00ooo
003oooooo`00o`02ooooo`05ool00?ooooooooooo`00oooo0000Joooool00ol0003oooooooooo`01
ooooo`002?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0Ioooool3
ool000;ooooo00Koo`00ooooool00?oo003ooooooooo0003ooooo`03ool00?l00?oooooo00?oo`00
1oooool00ol0003oooooooooo`04ooooo`?oo`0000?oooooo`00oooo00000oooool02?oo003ooooo
o`00ool00?ooooooool00?l00?oooooo0ooo001Zooooo`03o`000?oooooooooo007ooooo000<oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Ioooool3ool000;ooooo00?oo`00oooo
ool00?l00_ooool01ooo003oooooooooooooooooo`00o`00ooooool00ooo0007ooooo`03o`000?oo
oooooooo00Cooooo0ooo00000ooooooo003oool00003ooooo`08ool00?ooooooooooo`00oooooooo
o`00o`00ooooool3ool006[ooooo00?o0000ooooooooool00Oooool000cooooo00?o0000oooooooo
ool00oooool2o`0006Sooooo0ooo00001Ooooooo003oool00?oooooo003o00;ooooo00Goo`00oooo
ooooooooooooool00002ooooo`?oo`001oooool00ol0003oooooooooo`04ooooo`?oo`000_ooool0
1Ooo003oooooooooooooooooo`0000;ooooo00Go003ooooooooo003o003oooooo`03ool006Sooooo
0ol00003ooooo`002?ooool4o`0000Kooooo00?o0000ooooooooool0Joooool00ol00?ooo`00oooo
o`02o`00o`03oooooooo003ooooo00;ooooo00?oo`00ooooooooool02_ooool00ol0003ooooooooo
o`09ooooo`06ool00?oooooooooooooooooo003ooooo0_l00?l00oooooooo`00o`00o`1^ooooo`03
o`000?oooooooooo007ooooo0008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
K?ooool01_oo003oooooooooool00?ooooooool000?ooooo00?oo`00o`00ooooool02_ooool00ol0
003oooooooooo`08ooooo`03o`00oooo003ooooo00;ooooo00?oo`00ooooool00?l00_ooool00ooo
003oooooooooo`1]ooooo`03o`000?oooooooooo007ooooo0008ooooo`Go00001Oooool00ol0003o
ooooooooo`1/ooooo`06ool00?oooooo003oo`00ooooooooo`000oooool00ooo003o003oooooo`0:
ooooo`03o`000?oooooooooo00Sooooo00?o003oool00?ooool00_ooool01_oo003oooooo`00oooo
oooo003oool006oooooo00?o0000ooooooooool00Oooool001;ooooo00?o0000ooooooooool0K?oo
ool00ooo003oooooo`00o`02ooooo`06ool00?oooooooooooooooooo003o003o2oooool00ol0003o
ooooooooo`08ooooo`03o`00oooo003ooooo00;ooooo00Koo`00ooooool00?ooooooo`00oooo001_
ooooo`03o`000?oooooooooo007ooooo000Booooo`;o0000KOooool00ooo003oooooo`00o`02oooo
o`06ool00?oooooooooooooooooo003o003o2oooool00ol0003oooooooooo`08ooooo`03o`00oooo
003ooooo00;ooooo00Koo`00ooooooooooooooooo`00oooo001^ooooo`;o00000oooool001;ooooo
00?o0000ooooooooool0K?ooool01_oo003oooooo`00ool00?ooooooool000?ooooo00?oo`00oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`0:ool00?oooooooooooooooooo003oooooo`00
oooooooo003oool006oooooo00?o0000ooooooooool00Oooool001;ooooo00?o0000ooooooooool0
K?ooool01_oo003oooooooooool00?ooooooool000?ooooo00?oo`00o`00ooooool02_ooool00ol0
003oooooooooo`08ooooo`03o`00oooo003ooooo00;ooooo00?oo`00ooooool00?l00_ooool00ooo
003oooooooooo`1]ooooo`03o`000?oooooooooo007ooooo000Booooo`03o`000?oooooooooo06co
oooo00Koo`00oooooooooooo003ooooooooo0003ooooo`03ool00?l00?oooooo00[ooooo00?o0000
ooooooooool02?ooool00ol00?ooo`00ooooo`02ooooo`03ool00?oooooo003o00;ooooo00?oo`00
ooooooooool0KOooool00ol0003oooooooooo`01ooooo`004_ooool00ol0003oooooooooo`1/oooo
o`06ool00?l00?ooooooo`00ooooooooo`000oooool00ooo003o003oooooo`0:ooooo`03o`000?oo
oooooooo00Sooooo00?o003oool00?ooool00_ooool01_oo003oooooo`00oooooooo003oool006oo
oooo00?o0000ooooooooool00Oooool001;ooooo0_l0001]ooooo`03ool00?l00?oooooo00;ooooo
00Koo`00ooooooooooooooooool00?l00?l;ooooo`03o`000?oooooooooo00Sooooo00?o003oool0
0?ooool00_ooool01_oo003ooooooooooooooooo003oool006kooooo0_l00003ooooo`004_ooool0
0ol0003oooooooooo`1/ooooo`06ool00?l00?ooooooo`00ooooooooo`000oooool00ooo003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00Goo`00ooooooooooooooooool00003ooooo`03
o`00oooo003ooooo06kooooo00?o0000ooooooooool00Oooool001;ooooo00?o0000ooooooooool0
Joooool3ool00004ooooool00?ooooooool000?ooooo00?oo`00o`00ooooool02_ooool00ol0003o
ooooooooo`09ooooo`07ool00?oooooooooooooooooo003oooooo`00o`03ool006oooooo00?o0000
ooooooooool00Oooool001;ooooo00?o0000ooooooooool0Joooool3ool00004ooooool00?oooooo
ool000?ooooo00?oo`00o`00ooooool02_ooool00ol0003oooooooooo`08ooooo`03o`00oooo003o
oooo00;ooooo00?oo`00ooooool00?l00ooo001_ooooo`03o`000?oooooooooo007ooooo000Boooo
o`03o`000?oooooooooo06_ooooo0ooo00001?oooooo003ooooooooo0003ooooo`03ool00?l00?oo
oooo00[ooooo00?o0000ooooooooool02?ooool00ol00?ooo`00ooooo`02ooooo`03ool00?oooooo
003o00?oo`00Koooool00ol0003oooooooooo`01ooooo`004_ooool2o`0007;ooooo00Koo`00oooo
ooooooooooooool00?l00?l;ooooo`03o`000?oooooooooo00Sooooo00?o003oool00?ooool00_oo
ool00ooo003oooooooooo`1aooooo`;o00000oooool001;ooooo00?o0000ooooooooool0LOooool0
1Ooo003oooooooooooooooooo`0000cooooo00?o0000ooooooooool02Oooool01Ooo003ooooooooo
ooooooooo`0007Cooooo00?o0000ooooooooool00Oooool001;ooooo00?o0000ooooooooool0Kooo
ool00ol00?ooooooool00003ooooo`03ool00?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool01ooo003oooooooooooooooooo`00ooooool00?l0L_ooool00ol0003oooooooooo`01ooooo`00
4_ooool00ol0003oooooooooo`1_ooooo`03o`00ooooooooo`0000?ooooo00?oo`00o`00ooooool0
2_ooool00ol0003oooooooooo`08ooooo`03o`00oooo003ooooo00;ooooo00?oo`00ooooool00?l0
L_ooool00ol0003oooooooooo`01ooooo`004_ooool00ol0003oooooooooo`1`ooooo`03o`00oooo
003ooooo00;ooooo00?oo`00o`00ooooool02_ooool00ol0003oooooooooo`08ooooo`03o`00oooo
003ooooo00;ooooo00?oo`00ooooool00?l0L_ooool00ol0003oooooooooo`01ooooo`004_ooool0
0ol0003oooooooooo`1aooooo`06ool00?oooooooooooooooooo003o003o2oooool00ol0003ooooo
ooooo`08ooooo`03o`00oooo003ooooo00;ooooo00?oo`00ooooool00?l0L_ooool00ol0003ooooo
ooooo`01ooooo`004_ooool2o`0007;ooooo00Goo`00ooooooooooooooooool0000<ooooo`03o`00
0?oooooooooo00Sooooo00?o003oool00?ooool00_ooool00ooo003oooooooooo`1aooooo`;o0000
0oooool001;ooooo00?o0000ooooooooool0L?ooool00ol00?ooo`00ooooo`02ooooo`03ool00?oo
oooooooo00[ooooo00?o0000ooooooooool02Oooool01ooo003oooooooooooooooooo`00ooooool0
0?l0L_ooool00ol0003oooooooooo`01ooooo`000oooool3o`0000Cooooo0_l00006ooooo`03o`00
0?oooooooooo073ooooo00?o003oool00?ooool00_ooool00ooo003o003oooooo`0:ooooo`03o`00
0?oooooooooo00Sooooo00?o003oool00?ooool00_ooool00ooo003oooooo`00o`1booooo`03o`00
0?oooooooooo007ooooo0004ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
1Oooool00ol0003oooooooooo`1`ooooo`03o`00oooo003ooooo00;ooooo00?oo`00o`00ooooool0
2_ooool00ol0003oooooooooo`08ooooo`03o`00oooo003ooooo00;ooooo00?oo`00ooooool00?l0
L_ooool00ol0003oooooooooo`01ooooo`001?ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool0L?ooool00ol00?ooo`00ooooo`02ooooo`03ool0
0?l00?oooooo00[ooooo00?o0000ooooooooool02?ooool00ol00?ooo`00ooooo`02ooooo`03ool0
0?oooooo003o07;ooooo00?o0000ooooooooool00Oooool000Cooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00005ooooo`;o0000L_ooool01_oo003oooooooooooooooooo`00o`00
o`_ooooo00?o0000ooooooooool02?ooool00ol00?ooo`00ooooo`02ooooo`03ool00?oooooooooo
073ooooo0ol00003ooooo`001?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00Gooooo00?o0000ooooooooool0L?ooool00ol00?ooo`00ooooo`02ooooo`03ool00?oooooooooo
00[ooooo00?o0000ooooooooool02Oooool01Ooo003oooooooooooooooooo`0007Cooooo00?o0000
ooooooooool00Oooool000?ooooo0_l00004ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000
ooooooooool0L?ooool00ol00?ooo`00ooooo`02ooooo`03ool00?l00?oooooo00[ooooo00?o0000
ooooooooool02Oooool01_oo003oooooooooooooooooo`00o`00og?ooooo00?o0000ooooooooool0
0Oooool000Cooooo00?o0000ooooooooool00oooool2o`0000Kooooo00?o0000ooooooooool0L?oo
ool00ol00?ooo`00ooooo`02ooooo`03ool00?l00?oooooo00[ooooo00?o0000ooooooooool02?oo
ool00ol00?ooo`00ooooo`02ooooo`03ool00?l00?oooooo07;ooooo00?o0000ooooooooool00Ooo
ool001;ooooo00?o0000ooooooooool0L?ooool00ol00?ooo`00ooooo`02ooooo`03ool00?l00?oo
oooo00[ooooo00?o0000ooooooooool02?ooool00ol00?ooo`00ooooo`02ooooo`03ool00?l00?oo
oooo07;ooooo00?o0000ooooooooool00Oooool001;ooooo0_l0001booooo`06ool00?oooooooooo
oooooooo003o003o2oooool00ol0003oooooooooo`09ooooo`05ool00?oooooooooooooooooo0000
Loooool2o`0000?ooooo000Booooo`03o`000?oooooooooo077ooooo00Goo`00oooooooooooooooo
ool0000<ooooo`03o`000?oooooooooo00Wooooo00Goo`00ooooooooooooooooool0001dooooo`03
o`000?oooooooooo007ooooo000Booooo`03o`000?oooooooooo073ooooo00?o003oool00?ooool0
0_ooool00ooo003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00Koo`00oooooooooooo
ooooool00?l00?mcooooo`03o`000?oooooooooo007ooooo000Booooo`03o`000?oooooooooo073o
oooo00?o003oool00?ooool00_ooool00ooo003o003oooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00Koo`00ooooooooooooooooool00?l00?mcooooo`03o`000?oooooooooo007ooooo000Boooo
o`03o`000?oooooooooo073ooooo00?o003oool00?ooool00_ooool00ooo003o003oooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00Koo`00ooooooooooooooooool00?l00?mcooooo`03o`000?oo
oooooooo007ooooo000Booooo`;o0000L_ooool01Ooo003oooooooooooooooooo`0000cooooo00?o
0000ooooooooool02Oooool01_oo003oooooooooooooooooo`00o`00og;ooooo0_l00003ooooo`00
4_ooool00ol0003oooooooooo`1aooooo`05ool00?oooooooooooooooooo00003?ooool00ol0003o
ooooooooo`09ooooo`05ool00?oooooooooooooooooo0000M?ooool00ol0003oooooooooo`01oooo
o`004_ooool00ol0003oooooooooo`1`ooooo`03o`00oooo003ooooo00;ooooo00?oo`00oooooooo
ool02_ooool00ol0003oooooooooo`09ooooo`06ool00?oooooooooooooooooo003o003oLoooool0
0ol0003oooooooooo`01ooooo`004_ooool00ol0003oooooooooo`1`ooooo`03o`00oooo003ooooo
00;ooooo00?oo`00ooooooooool02_ooool00ol0003oooooooooo`09ooooo`06ool00?oooooooooo
oooooooo003o003oLoooool00ol0003oooooooooo`01ooooo`004_ooool00ol0003oooooooooo`1`
ooooo`03o`00oooo003ooooo00;ooooo00?oo`00ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`06ool00?oooooooooooooooooo003o003oLoooool00ol0003oooooooooo`01ooooo`004_oo
ool2o`00077ooooo00?o003oool00?ooool00_ooool00ooo003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo00Koo`00ooooooooooooooooool00?l00?mbooooo`;o00000oooool001;ooooo
00?o0000ooooooooool0LOooool01Ooo003oooooooooooooooooo`0000cooooo00?o0000oooooooo
ool02Oooool01Ooo003oooooooooooooooooo`0007Cooooo00?o0000ooooooooool00Oooool001;o
oooo00?o0000ooooooooool0L?ooool00ol00?ooo`00ooooo`02ooooo`03ool00?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool01_oo003oooooooooooooooooo`00o`00og?ooooo00?o0000
ooooooooool00Oooool001;ooooo00?o0000ooooooooool0L?ooool00ol00?ooo`00ooooo`02oooo
o`03ool00?oooooooooo00[ooooo00?o0000ooooooooool02Oooool01_oo003ooooooooooooooooo
o`00o`00og?ooooo00?o0000ooooooooool00Oooool001;ooooo00?o0000ooooooooool0L?ooool0
0ol00?ooo`00ooooo`02ooooo`03ool00?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
1_oo003oooooooooooooooooo`00o`00og?ooooo00?o0000ooooooooool00Oooool001;ooooo00?o
0000ooooooooool0L?ooool00ol00?ooo`00ooooo`02ooooo`03ool00?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool01_oo003oooooooooooooooooo`00o`00og?ooooo00?o0000oooooooo
ool00Oooool001;ooooo0_l0001booooo`05ool00?oooooooooooooooooo00003?ooool00ol0003o
ooooooooo`09ooooo`05ool00?oooooooooooooooooo0000Loooool2o`0000?ooooo000Booooo`03
o`000?oooooooooo077ooooo00Goo`00ooooooooooooooooool0000<ooooo`03o`000?oooooooooo
00Wooooo00Goo`00ooooooooooooooooool0001dooooo`03o`000?oooooooooo007ooooo0003oooo
o`?o00000oooool3o`0000Kooooo00?o0000ooooooooool0L?ooool00ol00?ooo`00ooooo`02oooo
o`03ool00?oooooooooo00[ooooo00?o0000ooooooooool02Oooool01_oo003ooooooooooooooooo
o`00o`00og?ooooo00?o0000ooooooooool00Oooool000Cooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L?ooool00ol00?ooo`00oooo
o`02ooooo`03ool00?oooooooooo00[ooooo00?o0000ooooooooool02Oooool01_oo003ooooooooo
ooooooooo`00o`00og?ooooo00?o0000ooooooooool00Oooool000Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo073ooooo00?o003oool00?ooool0
0_ooool00ooo003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00Koo`00oooooooooooo
ooooool00?l00?mcooooo`03o`000?oooooooooo007ooooo0004ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool2o`0007;ooooo00Goo`00ooooooooooooooooool0000<oooo
o`03o`000?oooooooooo00Wooooo00Goo`00ooooooooooooooooool0001booooo`?o00000oooool0
00Cooooo00Co0000oooooooooooooooo1?l00006ooooo`03o`000?oooooooooo077ooooo00Goo`00
ooooooooooooooooool0000<ooooo`03o`000?oooooooooo00Wooooo00Goo`00oooooooooooooooo
ool0001dooooo`03o`000?oooooooooo007ooooo0003ooooo`;o00000oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo073ooooo00?o003oool00?ooool00_ooool00ooo003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00Koo`00ooooooooooooooooool00?l00?mcooooo`03
o`000?oooooooooo007ooooo0004ooooo`04o`000?ooooooooooooooo`Go00001Oooool00ol0003o
ooooooooo`1`ooooo`03o`00oooo003ooooo00;ooooo00?oo`00ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`06ool00?oooooooooooooooooo003o003oLoooool00ol0003oooooooooo`01
ooooo`004_ooool00ol0003oooooooooo`1`ooooo`03o`00oooo003ooooo00;ooooo00?oo`00oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`06ool00?oooooooooooooooooo003o003oLooo
ool00ol0003oooooooooo`01ooooo`004_ooool2o`0007;ooooo00Goo`00ooooooooooooooooool0
000<ooooo`03o`000?oooooooooo00Wooooo00Koo`00ooooooooooooooooool00?l00?mbooooo`;o
00000oooool001;ooooo00?o0000ooooooooool0LOooool01Ooo003oooooooooooooooooo`0000co
oooo00?o0000ooooooooool02Oooool01Ooo003oooooooooooooooooo`0007Cooooo00?o0000oooo
ooooool00Oooool001;ooooo00?o0000ooooooooool0L?ooool00ol00?ooo`00ooooo`02ooooo`03
ool00?oooooooooo00[ooooo00?o0000ooooooooool02Oooool01_oo003oooooooooooooooooo`00
o`00og?ooooo00?o0000ooooooooool00Oooool001;ooooo00?o0000ooooooooool0L?ooool00ol0
0?ooo`00ooooo`02ooooo`03ool00?oooooooooo00[ooooo00?o0000ooooooooool02Oooool01_oo
003oooooooooooooooooo`00o`00og?ooooo00?o0000ooooooooool00Oooool001;ooooo00?o0000
ooooooooool0L?ooool00ol00?ooo`00ooooo`02ooooo`03ool00?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool01_oo003oooooooooooooooooo`00o`00og?ooooo00?o0000ooooooooool0
0Oooool001;ooooo0_l0001aooooo`03o`00oooo003ooooo00;ooooo00?oo`00ooooooooool02_oo
ool00ol0003oooooooooo`09ooooo`06ool00?oooooooooooooooooo003o003oL_ooool2o`0000?o
oooo000Booooo`03o`000?oooooooooo077ooooo00Goo`00ooooooooooooooooool0000<ooooo`03
o`000?oooooooooo00Wooooo00Goo`00ooooooooooooooooool0001dooooo`03o`000?oooooooooo
007ooooo000Booooo`03o`000?oooooooooo073ooooo00?o003oool00?ooool00_ooool00ooo003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00Goo`00ooooooooooooooooool0001doooo
o`03o`000?oooooooooo007ooooo000Booooo`03o`000?oooooooooo073ooooo00?o003oool00?oo
ool00ooo000<ooooo`03o`000?oooooooooo00Sooooo0ooo0002ooooo`03ool00?l00?oooooo07;o
oooo00?o0000ooooooooool00Oooool001;ooooo00?o0000ooooooooool0L?ooool00ol00?ooo`00
ooooo`03ool000cooooo00?o0000ooooooooool02?ooool3ool000;ooooo00?oo`00o`00ooooool0
L_ooool00ol0003oooooooooo`01ooooo`004_ooool00ol0003oooooooooo`1`ooooo`03o`00oooo
003ooooo00?oo`003?ooool00ol0003oooooooooo`08ooooo`?oo`000_ooool00ooo003o003ooooo
o`1booooo`03o`000?oooooooooo007ooooo000Booooo`;o0000L_ooool01Ooo003ooooooooooooo
oooo003o00cooooo00?o0000ooooooooool02Oooool01Ol00?ooooooooooooooooooo`0007?ooooo
0_l00003ooooo`004_ooool00ol0003oooooooooo`1aooooo`03ool00?oooooooooo00kooooo00?o
0000ooooooooool02Oooool01Ol00?ooooooooooooooooooo`0007Cooooo00?o0000ooooooooool0
0Oooool001;ooooo00?o0000ooooooooool0LOooool00ooo003oooooooooo`0>ooooo`03o`000?oo
oooooooo00gooooo00?oo`00o`00ooooool0L_ooool00ol0003oooooooooo`01ooooo`004_ooool0
0ol0003oooooooooo`1aooooo`05ool00?ooooooooooooooool00?l03?ooool00ol0003ooooooooo
o`09ooooo`06o`00oooooooooooooooooooo003o003oLoooool00ol0003oooooooooo`01ooooo`00
4_ooool00ol0003oooooooooo`1aooooo`05ool00?ooooooooooooooool00?l03?ooool00ol0003o
ooooooooo`09ooooo`06o`00oooooooooooooooooooo003o003oLoooool00ol0003oooooooooo`01
ooooo`004_ooool2o`0007;ooooo00Goo`00ooooooooooooooooo`00o`0<ooooo`03o`000?oooooo
oooo00Wooooo00Ko003oooooooooooooooooool00?l00?mbooooo`;o00000oooool001;ooooo00?o
0000ooooooooool0LOooool01Ooo003ooooooooooooooooo003o00cooooo00?o0000ooooooooool0
2Oooool01Ol00?ooooooooooooooooooo`0007Cooooo00?o0000ooooooooool00Oooool000;ooooo
1Ol00003ooooo`;o00001_ooool00ol0003oooooooooo`1aooooo`03ool00?oooooooooo00kooooo
00?o0000ooooooooool03Oooool00ooo003o003oooooo`1booooo`03o`000?oooooooooo007ooooo
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003o
ooooooooo`1aooooo`05ool00?ooooooooooooooool00?l03?ooool00ol0003oooooooooo`0=oooo
o`03ool00?l00?oooooo07;ooooo00?o0000ooooooooool00Oooool000Cooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo077ooooo00Goo`00oooo
ooooooooooooo`00o`0<ooooo`03o`000?oooooooooo00Wooooo00Go003oooooooooooooooooool0
001dooooo`03o`000?oooooooooo007ooooo0005ooooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooooooo`03ooooo`;o0000L_ooool01Ooo003ooooooooooooooooo003o00cooooo
00?o0000ooooooooool02Oooool01Ol00?ooooooooooooooooooo`0007;ooooo0ol00003ooooo`00
0_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001Oooool00ol0
003oooooooooo`1_ooooo`?oo`000oooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o003ooooooooo00000_oo001cooooo`03o`000?oooooooooo007ooooo0002ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo
oooo06oooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo001cooooo`03o`000?oooooo
oooo007ooooo0003ooooo`?o00001?ooool2o`0000Kooooo00?o0000ooooooooool0Koooool3ool0
013ooooo00?o0000ooooooooool03?ooool3ool007?ooooo00?o0000ooooooooool00Oooool001;o
oooo00?o0000ooooooooool0LOooool01Ol00?oooooooooooooooooo003o00cooooo00?o0000oooo
ooooool02_ooool01?l00?ooooooooooool00?mdooooo`03o`000?oooooooooo007ooooo000Boooo
o`;o0000L_ooool01Ol00?oooooooooooooooooo003o00cooooo00?o0000ooooooooool02_ooool0
1?l00?ooooooooooool00?mcooooo`;o00000oooool001;ooooo00?o0000ooooooooool0M?ooool0
0ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o003oooooooooool0MOooool0
0ol0003oooooooooo`01ooooo`004_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo
00[ooooo00?o003oooooooooool0MOooool00ol0003oooooooooo`01ooooo`004_ooool00ol0003o
ooooooooo`1aooooo`03o`00oooooooooooo00kooooo00?o0000ooooooooool03Oooool00ol00?oo
ooooooooo`1booooo`03o`000?oooooooooo007ooooo000Booooo`03o`000?oooooooooo077ooooo
00Co003ooooooooooooo003o3Oooool00ol0003oooooooooo`0:ooooo`04o`00ooooooooooooo`00
ogCooooo00?o0000ooooooooool00Oooool001;ooooo0_l0001booooo`04o`00ooooooooooooo`00
o`gooooo00?o0000ooooooooool02_ooool01?l00?ooooooooooool00?mcooooo`;o00000oooool0
01;ooooo00?o0000ooooooooool0M?ooool00ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo
00[ooooo00Co003ooooooooooooo003oM?ooool00ol0003oooooooooo`01ooooo`004_ooool00ol0
003oooooooooo`1dooooo`03o`00oooooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0
0?ooooooooooo`1eooooo`03o`000?oooooooooo007ooooo000Booooo`03o`000?oooooooooo077o
oooo00?o003oooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`00oooooooooooo07;o
oooo00?o0000ooooooooool00Oooool001;ooooo00?o0000ooooooooool0LOooool01?l00?oooooo
ooooool00?l=ooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool0L_ooool00ol0003o
ooooooooo`01ooooo`004_ooool00ol0003oooooooooo`1aooooo`04o`00ooooooooooooo`00o`go
oooo00?o0000ooooooooool02_ooool01?l00?ooooooooooool00?mdooooo`03o`000?oooooooooo
007ooooo000Booooo`;o0000L_ooool01?l00?ooooooooooool00?l=ooooo`03o`000?oooooooooo
00[ooooo00Co003ooooooooooooo003oLoooool2o`0000?ooooo000Booooo`03o`000?oooooooooo
07Cooooo00?o003oooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo
07Gooooo00?o0000ooooooooool00Oooool001;ooooo00?o0000ooooooooool0LOooool00ol00?oo
ooooooooo`0>ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool00Oooool001;ooooo
00?o0000ooooooooool0LOooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo00gooooo
00?o003oooooooooool0L_ooool00ol0003oooooooooo`01ooooo`004_ooool00ol0003ooooooooo
o`1aooooo`04o`00ooooooooooooo`00o`gooooo00?o0000ooooooooool02_ooool01?l00?oooooo
ooooool00?mdooooo`03o`000?oooooooooo007ooooo000Booooo`;o0000L_ooool01?l00?oooooo
ooooool00?l=ooooo`03o`000?oooooooooo00[ooooo00Co003ooooooooooooo003oLoooool2o`00
00?ooooo000Booooo`03o`000?oooooooooo07Cooooo00?o003oooooooooool02oooool00ol0003o
ooooooooo`0:ooooo`03o`00oooooooooooo07Gooooo00?o0000ooooooooool00Oooool000;ooooo
1Ol00002ooooo`?o00001_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo00[ooooo
00?o003oooooooooool0MOooool00ol0003oooooooooo`01ooooo`000oooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1aooooo`03
o`00oooooooooooo00kooooo00?o0000ooooooooool03Oooool00ol00?ooooooooooo`1booooo`03
o`000?oooooooooo007ooooo0004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1aooooo`04o`00ooooooooooooo`00o`gooooo00?o0000oooooooo
ool02_ooool01?l00?ooooooooooool00?mdooooo`03o`000?oooooooooo007ooooo0005ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool2o`0007;ooooo00Co003ooooooooo
oooo003o3Oooool00ol0003oooooooooo`0:ooooo`04o`00ooooooooooooo`00og;ooooo0ol00003
ooooo`000_ooool01_l0003ooooooooooooooooo0000ooooo`Co00001_ooool00ol0003ooooooooo
o`1dooooo`03o`00oooooooooooo00_ooooo00?o0000ooooooooool02_ooool01?l00?oooooooooo
ool00?mdooooo`03o`000?oooooooooo007ooooo0002ooooo`07o`000?ooooooooooooooool0003o
ooooo`000009ooooo`03o`000?oooooooooo07Cooooo00?o003oooooooooool02oooool00ol0003o
ooooooooo`0:ooooo`03o`00oooooooooooo07Gooooo00?o0000ooooooooool00Oooool000?ooooo
0ol00002ooooo`Go00001Oooool00ol0003oooooooooo`1aooooo`03o`00oooooooooooo00kooooo
00?o0000ooooooooool03Oooool00ol00?ooooooooooo`1booooo`03o`000?oooooooooo007ooooo
000Booooo`03o`000?oooooooooo077ooooo00Co003ooooooooooooo003o3Oooool00ol0003ooooo
ooooo`0=ooooo`03o`00oooooooooooo07;ooooo00?o0000ooooooooool00Oooool001;ooooo0_l0
001booooo`04o`00ooooooooooooo`00o`gooooo00?o0000ooooooooool02_ooool01?l00?oooooo
ooooool00?mcooooo`;o00000oooool001;ooooo00?o0000ooooooooool0LOooool01?l00?oooooo
ooooool00?l=ooooo`03o`000?oooooooooo00[ooooo00Co003ooooooooooooo003oM?ooool00ol0
003oooooooooo`01ooooo`004_ooool00ol0003oooooooooo`1dooooo`03o`00oooooooooooo00_o
oooo00?o0000ooooooooool02_ooool00ol00?ooooooooooo`1eooooo`03o`000?oooooooooo007o
oooo000Booooo`03o`000?oooooooooo07;ooooo00?o003oooooooooool03Oooool00ol0003ooooo
ooooo`22ooooo`03o`000?oooooooooo007ooooo000Booooo`03o`000?oooooooooo07;ooooo00?o
003oooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00oooooooooooo07;ooooo00?o
0000ooooooooool00Oooool001;ooooo0_l0001cooooo`03o`00oooooooo003o00gooooo00?o0000
ooooooooool02_ooool01?l00?ooooooooooool00?mcooooo`;o00000oooool001;ooooo00?o0000
ooooooooool0L_ooool00ol00?ooooooo`00o`0=ooooo`03o`000?oooooooooo00[ooooo00Co003o
oooooooooooo003oM?ooool00ol0003oooooooooo`01ooooo`004_ooool00ol0003oooooooooo`1d
ooooo`03o`00oooooooooooo00_ooooo00?o0000ooooooooool02oooool00ol00?ooooooooooo`1d
ooooo`03o`000?oooooooooo007ooooo000Booooo`03o`000?oooooooooo08;ooooo00?o0000oooo
ooooool0P_ooool00ol0003oooooooooo`01ooooo`004_ooool00ol0003oooooooooo`1booooo`03
o`00oooooooooooo00gooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`1cooooo`03
o`000?oooooooooo007ooooo000Booooo`03o`000?oooooooooo07;ooooo00?o003oooooool00?l0
3Oooool00ol0003oooooooooo`0;ooooo`;o003oMOooool00ol0003oooooooooo`01ooooo`004_oo
ool2o`0007?ooooo00?o003oooooool00?l03Oooool00ol0003oooooooooo`0;ooooo`;o003oM?oo
ool2o`0000?ooooo000Booooo`03o`000?oooooooooo07?ooooo00?o003oooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`;o003oMOooool00ol0003oooooooooo`01ooooo`004_ooool00ol0
003oooooooooo`1cooooo`03o`00oooooooooooo00cooooo00?o0000ooooooooool02oooool00ol0
0?ooooooooooo`1dooooo`03o`000?oooooooooo007ooooo000Booooo`03o`000?oooooooooo07;o
oooo00?o003oooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo07?o
oooo00?o0000ooooooooool00Oooool001;ooooo00?o0000ooooooooool0L_ooool2o`00o`kooooo
00?o0000ooooooooool02oooool2o`00ogGooooo00?o0000ooooooooool00Oooool001;ooooo0_l0
001cooooo`;o003o3_ooool00ol0003oooooooooo`0;ooooo`;o003oM?ooool2o`0000?ooooo000B
ooooo`03o`000?oooooooooo07;ooooo0_l00?l>ooooo`03o`000?oooooooooo00_ooooo0_l00?me
ooooo`03o`000?oooooooooo007ooooo0003ooooo`?o00001?ooool2o`0000Kooooo00?o0000oooo
ooooool0Loooool00ol00?ooooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o003ooooo
ooooool0M?ooool00ol0003oooooooooo`01ooooo`000_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`1booooo`03o`00oooooooo
oooo00gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`01ooooo`001_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool0
0ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o003oooooooooool0Loooool0
0ol0003oooooooooo`01ooooo`001?ooool2o`0000?ooooo00Co0000oooooooooooo00001Oooool2
o`0007?ooooo0_l00?l>ooooo`03o`000?oooooooooo00_ooooo0_l00?mcooooo`?o00000oooool0
00Kooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`01ooooo`000_ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001Oooool00ol0003ooooooooo
o`22ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool00Oooool000?ooooo0ol00004
ooooo`;o00001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo007ooooo000Boooo
oooo00003?l00003ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-11.9245, -3.11973, \
0.0789178, 0.192069}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g7 = 
        DiscreteListPlot[
          FourierRearrange[Arg[\(\((Last[#] +  .0000001)\) &\)\  /@ \ fft], 
            fs], Red, PlotRange \[Rule] All, ImageSize \[Rule] 504, \ 
          Frame \[Rule] True, \ Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g8 = \ Show[g2, g7];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.307985 0.0969315 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01719 -12 -4.5 ]
[-0.0125 .01719 0 4.5 ]
[-0.0125 .11412 -12 -4.5 ]
[-0.0125 .11412 0 4.5 ]
[-0.0125 .21105 -12 -4.5 ]
[-0.0125 .21105 0 4.5 ]
[-0.0125 .30798 -6 -4.5 ]
[-0.0125 .30798 0 4.5 ]
[-0.0125 .40492 -6 -4.5 ]
[-0.0125 .40492 0 4.5 ]
[-0.0125 .50185 -6 -4.5 ]
[-0.0125 .50185 0 4.5 ]
[-0.0125 .59878 -6 -4.5 ]
[-0.0125 .59878 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01719 m
.00625 .01719 L
s
[(-3)] -0.0125 .01719 1 0 Mshowa
0 .11412 m
.00625 .11412 L
s
[(-2)] -0.0125 .11412 1 0 Mshowa
0 .21105 m
.00625 .21105 L
s
[(-1)] -0.0125 .21105 1 0 Mshowa
0 .30798 m
.00625 .30798 L
s
[(0)] -0.0125 .30798 1 0 Mshowa
0 .40492 m
.00625 .40492 L
s
[(1)] -0.0125 .40492 1 0 Mshowa
0 .50185 m
.00625 .50185 L
s
[(2)] -0.0125 .50185 1 0 Mshowa
0 .59878 m
.00625 .59878 L
s
[(3)] -0.0125 .59878 1 0 Mshowa
.125 Mabswid
0 .03658 m
.00375 .03658 L
s
0 .05596 m
.00375 .05596 L
s
0 .07535 m
.00375 .07535 L
s
0 .09474 m
.00375 .09474 L
s
0 .13351 m
.00375 .13351 L
s
0 .15289 m
.00375 .15289 L
s
0 .17228 m
.00375 .17228 L
s
0 .19167 m
.00375 .19167 L
s
0 .23044 m
.00375 .23044 L
s
0 .24983 m
.00375 .24983 L
s
0 .26921 m
.00375 .26921 L
s
0 .2886 m
.00375 .2886 L
s
0 .32737 m
.00375 .32737 L
s
0 .34676 m
.00375 .34676 L
s
0 .36614 m
.00375 .36614 L
s
0 .38553 m
.00375 .38553 L
s
0 .4243 m
.00375 .4243 L
s
0 .44369 m
.00375 .44369 L
s
0 .46308 m
.00375 .46308 L
s
0 .48246 m
.00375 .48246 L
s
0 .52123 m
.00375 .52123 L
s
0 .54062 m
.00375 .54062 L
s
0 .56001 m
.00375 .56001 L
s
0 .57939 m
.00375 .57939 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01719 m
1 .01719 L
s
.99375 .11412 m
1 .11412 L
s
.99375 .21105 m
1 .21105 L
s
.99375 .30798 m
1 .30798 L
s
.99375 .40492 m
1 .40492 L
s
.99375 .50185 m
1 .50185 L
s
.99375 .59878 m
1 .59878 L
s
.125 Mabswid
.99625 .03658 m
1 .03658 L
s
.99625 .05596 m
1 .05596 L
s
.99625 .07535 m
1 .07535 L
s
.99625 .09474 m
1 .09474 L
s
.99625 .13351 m
1 .13351 L
s
.99625 .15289 m
1 .15289 L
s
.99625 .17228 m
1 .17228 L
s
.99625 .19167 m
1 .19167 L
s
.99625 .23044 m
1 .23044 L
s
.99625 .24983 m
1 .24983 L
s
.99625 .26921 m
1 .26921 L
s
.99625 .2886 m
1 .2886 L
s
.99625 .32737 m
1 .32737 L
s
.99625 .34676 m
1 .34676 L
s
.99625 .36614 m
1 .36614 L
s
.99625 .38553 m
1 .38553 L
s
.99625 .4243 m
1 .4243 L
s
.99625 .44369 m
1 .44369 L
s
.99625 .46308 m
1 .46308 L
s
.99625 .48246 m
1 .48246 L
s
.99625 .52123 m
1 .52123 L
s
.99625 .54062 m
1 .54062 L
s
.99625 .56001 m
1 .56001 L
s
.99625 .57939 m
1 .57939 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30798 m
1 .30798 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .30798 m
.02608 .26522 L
.02847 .22013 L
.02964 .19804 L
.03089 .17441 L
.03126 .16743 L
.03145 .164 L
.03153 .16249 L
.03161 .16083 L
.03177 .46248 L
.03185 .4609 L
.03193 .45943 L
.03227 .453 L
.03355 .42884 L
.03823 .34068 L
.0406 .29587 L
.0432 .24695 L
.0444 .22428 L
.04568 .20012 L
.0463 .18838 L
.04689 .17733 L
.04715 .1725 L
.04742 .1674 L
.04756 .16473 L
.04771 .46632 L
.04786 .46366 L
.04799 .46117 L
.05268 .3727 L
.05767 .27865 L
.06016 .23159 L
.06126 .2109 L
.06185 .1999 L
.06247 .18805 L
.06277 .18251 L
.06308 .17668 L
.06334 .1717 L
.06349 .16888 L
.06363 .47078 L
.06377 .46811 L
.0639 .46559 L
.06415 .46088 L
.06472 .45031 L
.0671 .40542 L
.07174 .31795 L
.07409 .27365 L
.07667 .22491 L
.07785 .2026 L
.07851 .1903 L
.07883 .18424 L
.07898 .18129 L
Mistroke
.07913 .17862 L
.07927 .17592 L
.0794 .4779 L
.07955 .47521 L
.0797 .47231 L
.08033 .46051 L
.08142 .43984 L
.08637 .34648 L
.08884 .29996 L
.09114 .25658 L
.09336 .21482 L
.09399 .2028 L
.0946 .19143 L
.09486 .18647 L
.095 .18376 L
.09514 .18121 L
.09529 .48299 L
.09536 .48154 L
.09545 .47997 L
.09573 .47464 L
.1007 .38098 L
.10548 .29076 L
.10789 .24528 L
.10895 .22546 L
.11008 .204 L
.11039 .19818 L
.11072 .19203 L
.11085 .18949 L
.111 .18677 L
.11116 .48831 L
.1113 .48552 L
.11245 .46384 L
.11498 .41617 L
.11997 .3222 L
.12246 .2752 L
.12356 .25452 L
.12477 .23168 L
.12532 .22121 L
.12592 .20992 L
.1262 .20473 L
.12649 .19926 L
.12674 .19459 L
.12688 .19194 L
.12701 .494 L
.12715 .4912 L
.12732 .48816 L
.12761 .48264 L
.12816 .47231 L
.12939 .44912 L
.13432 .35616 L
Mistroke
.13677 .30993 L
.13907 .26665 L
.14127 .22517 L
.1419 .21323 L
.14221 .20734 L
.1425 .20188 L
.14264 .19934 L
.14276 .19695 L
.14291 .49871 L
.14304 .49621 L
.14363 .4851 L
.14828 .3974 L
.15323 .30413 L
.1557 .25767 L
.1569 .23498 L
.158 .21431 L
.15826 .20933 L
.15854 .20405 L
.15869 .20129 L
.15877 .50424 L
.15885 .50277 L
.15913 .49741 L
.16021 .47713 L
.16258 .43245 L
.16725 .34445 L
.16962 .29975 L
.17087 .27611 L
.17221 .25088 L
.17288 .23828 L
.17351 .2264 L
.17407 .21573 L
.17423 .21281 L
.17439 .20972 L
.17453 .20708 L
.17469 .50869 L
.17484 .50579 L
.17499 .50304 L
.17526 .49787 L
.17588 .48625 L
.17699 .46527 L
.18161 .37827 L
.18418 .32968 L
.18652 .28571 L
.18769 .26362 L
.18895 .23978 L
.18953 .22882 L
.18985 .22284 L
.19015 .21726 L
.19028 .21481 L
.1904 .2125 L
Mistroke
.19054 .51435 L
.19067 .51192 L
.19124 .50111 L
.19588 .41381 L
.2008 .32093 L
.20325 .27477 L
.20445 .25218 L
.20555 .23151 L
.20581 .2266 L
.20609 .22136 L
.20617 .21981 L
.20624 .21835 L
.20639 .52013 L
.20653 .51757 L
.20667 .5148 L
.20774 .49461 L
.21011 .45005 L
.21505 .35687 L
.21751 .31047 L
.21981 .26714 L
.22095 .24576 L
.22151 .23524 L
.22175 .23061 L
.22202 .2255 L
.22217 .2227 L
.22231 .5246 L
.22246 .52183 L
.22262 .51884 L
.22326 .50667 L
.22439 .48537 L
.22935 .39189 L
.23183 .34525 L
.23413 .30185 L
.23635 .25999 L
.23699 .24794 L
.2373 .24202 L
.23759 .23656 L
.23786 .2316 L
.23799 .2291 L
.23813 .53086 L
.23828 .5281 L
.23844 .52514 L
.23872 .51978 L
.2437 .42599 L
.24849 .33565 L
.25091 .29006 L
.25197 .27021 L
.2531 .24876 L
.25341 .24291 L
.25358 .23972 L
Mistroke
.25374 .23674 L
.25388 .2342 L
.25402 .53599 L
.2541 .53444 L
.25418 .53297 L
.25433 .53021 L
.25548 .5085 L
.25801 .46082 L
.26264 .37362 L
.26498 .3295 L
.26622 .30608 L
.26756 .28086 L
.26818 .26913 L
.26884 .2568 L
.2694 .24627 L
.26955 .24339 L
.26963 .2418 L
.26971 .24031 L
.26987 .54192 L
.27001 .53928 L
.2723 .49606 L
.27695 .40856 L
.2793 .36422 L
.28189 .31549 L
.28307 .29315 L
.28434 .26917 L
.28496 .25755 L
.28526 .25183 L
.2854 .24932 L
.28555 .24654 L
.28568 .24407 L
.2858 .54626 L
.28593 .54381 L
.28607 .54117 L
.28664 .5304 L
.2916 .43703 L
.29637 .34711 L
.29878 .30183 L
.29982 .28208 L
.30038 .27167 L
.30096 .26064 L
.30126 .25498 L
.30135 .25343 L
.30143 .25177 L
.30152 .25019 L
.30159 .55327 L
.30174 .55058 L
.30189 .54765 L
.30218 .5423 L
.30332 .52069 L
Mistroke
.30585 .47313 L
.31075 .38079 L
.31302 .33808 L
.31547 .2919 L
.31613 .27958 L
.31682 .26656 L
.3171 .2612 L
.31726 .25825 L
.31741 .25545 L
.31749 .55839 L
.31758 .55667 L
.31774 .55366 L
.31806 .54778 L
.32049 .50197 L
.32541 .40934 L
.32785 .36334 L
.33014 .32016 L
.33121 .30006 L
.33234 .27891 L
.33292 .26782 L
.33309 .26479 L
.33317 .26312 L
.33326 .26155 L
.33334 .5646 L
.33342 .563 L
.33357 .56022 L
.3347 .53896 L
.33963 .44605 L
.34439 .35659 L
.34677 .31165 L
.34782 .292 L
.34837 .28163 L
.34867 .27594 L
.34896 .27059 L
.34911 .26762 L
.3492 .26595 L
.34928 .56894 L
.34943 .56622 L
.34958 .56336 L
.35016 .55246 L
.3513 .53096 L
.35382 .48355 L
.35841 .39726 L
.36097 .34919 L
.36329 .30543 L
.36385 .29486 L
.36445 .28365 L
.36476 .27781 L
.36485 .2762 L
.36494 .27448 L
Mistroke
.36502 .27285 L
.3651 .57588 L
.36525 .5731 L
.36541 .57006 L
.36571 .56452 L
.36799 .52157 L
.37289 .42946 L
.37761 .34081 L
.37885 .31753 L
.3795 .30527 L
.38019 .29232 L
.38048 .28685 L
.38064 .28384 L
.38079 .28098 L
.38088 .27937 L
.38097 .58214 L
.38105 .58054 L
.38113 .57906 L
.38145 .57305 L
.38262 .55115 L
.38735 .46224 L
.3919 .3768 L
.39443 .32936 L
.39554 .30858 L
.39612 .29759 L
.39644 .29155 L
.3966 .28858 L
.39675 .28584 L
.39689 .58767 L
.39704 .58481 L
.39736 .5788 L
.39792 .56829 L
.39902 .54775 L
.40141 .50287 L
.40598 .41723 L
.40852 .36962 L
.41084 .32611 L
.41199 .3046 L
.4123 .29871 L
.41247 .29548 L
.41256 .2939 L
.41264 .29244 L
.41279 .59411 L
.41287 .59262 L
.41295 .59104 L
.41324 .58567 L
.41552 .54299 L
.4201 .45722 L
.42265 .40948 L
.42498 .36601 L
Mistroke
.42613 .34442 L
.42674 .33304 L
.42739 .32095 L
.42796 .31042 L
.42811 .30753 L
.42828 .30442 L
.42843 .30149 L
.42858 .60332 L
.42871 .60085 L
.42883 .59855 L
.42911 .59334 L
.42967 .58284 L
.43439 .49497 L
.4394 .40175 L
.44422 .31214 L
.44886 .22616 L
.4538 .13503 L
.45626 .08984 L
.45746 .0678 L
.45856 .04771 L
.4591 .0378 L
.45969 .02701 L
.45996 .02207 L
.46011 .01937 L
.46025 .01683 L
.46038 .31897 L
.46052 .3164 L
.46076 .31192 L
.46313 .26881 L
.46808 .17924 L
.47055 .13503 L
.47286 .09418 L
.474 .07409 L
.47507 .05521 L
.47567 .04482 L
.47583 .04198 L
.476 .03897 L
.47615 .0364 L
.47624 .33946 L
.47632 .3381 L
.47745 .31856 L
.48212 .23957 L
.48709 .16049 L
.48957 .12393 L
.49078 .10709 L
.49135 .09938 L
.49161 .09605 L
.49175 .09418 L
.49188 .09244 L
.49201 .09075 L
Mistroke
.49215 .39347 L
.4923 .39156 L
.49243 .38983 L
.49303 .38232 L
.49411 .36921 L
.49649 .34273 L
.50129 .29559 L
.50349 .27352 L
.50474 .25999 L
.50591 .2465 L
.50706 .23255 L
.50737 .2286 L
.50755 .22642 L
.50771 .22438 L
.50784 .22262 L
.50799 .52525 L
.50807 .52416 L
.50815 .52313 L
.5083 .5212 L
.51083 .48624 L
.51547 .41554 L
.51782 .37739 L
.5204 .33416 L
.52159 .31402 L
.52224 .30284 L
.52286 .29217 L
.52343 .28225 L
.52359 .27952 L
.52368 .27802 L
.52376 .27661 L
.52392 .57839 L
.52406 .5759 L
.52516 .55676 L
.52981 .47443 L
.53476 .38542 L
.53723 .34066 L
.53843 .31874 L
.539 .30834 L
.53925 .30377 L
.5394 .30117 L
.53953 .29873 L
.53966 .29641 L
.53979 .59842 L
.53994 .59574 L
.54007 .59329 L
.54067 .58246 L
.54174 .56276 L
.54411 .51927 L
.5489 .43116 L
.5535 .34607 L
Mistroke
.5584 .25523 L
.56311 .16755 L
.56552 .12275 L
.56812 .0742 L
.56934 .05141 L
.57001 .03896 L
.57064 .02731 L
.57091 .02222 L
.57117 .01738 L
.57131 .01472 L
.57147 .31633 L
.57161 .31369 L
.57174 .31125 L
.57295 .28862 L
.57768 .20021 L
.58223 .11513 L
.58476 .06785 L
.58586 .04713 L
.58645 .03616 L
.58677 .03013 L
.58693 .02717 L
.58707 .02444 L
.58722 .02175 L
.58737 .32343 L
.58752 .32057 L
.58769 .31743 L
.58825 .30694 L
.58934 .28644 L
.59174 .24162 L
.5966 .15049 L
.59883 .10853 L
.60127 .06274 L
.60191 .05072 L
.60227 .04413 L
.6026 .03792 L
.60291 .03211 L
.60299 .03052 L
.60308 .02884 L
.60316 .0274 L
.60324 .33035 L
.60339 .32762 L
.60354 .32468 L
.60382 .3194 L
.60625 .27391 L
.61124 .18021 L
.61374 .1333 L
.61605 .08991 L
.6172 .06818 L
.61829 .04778 L
.61855 .04279 L
Mistroke
.61883 .03754 L
.61898 .03478 L
.61906 .33775 L
.61914 .3363 L
.61942 .33102 L
.62067 .30754 L
.62538 .219 L
.62778 .17383 L
.63039 .12488 L
.63161 .10195 L
.6329 .07768 L
.634 .05696 L
.6343 .05128 L
.63447 .04815 L
.63463 .04518 L
.63477 .04243 L
.63486 .04087 L
.63493 .34395 L
.63507 .3414 L
.63521 .33869 L
.64023 .24421 L
.64507 .15316 L
.6473 .11135 L
.64856 .08763 L
.64917 .07606 L
.64973 .06553 L
.65002 .06013 L
.65033 .05427 L
.65047 .05158 L
.65062 .04873 L
.65075 .0463 L
.6509 .34814 L
.65098 .34658 L
.65106 .34509 L
.65121 .34231 L
.65154 .33603 L
.65214 .32469 L
.65469 .27684 L
.65929 .19019 L
.66186 .14183 L
.66419 .09796 L
.66536 .07601 L
.66597 .06446 L
.6663 .05814 L
.66647 .05506 L
.66662 .05225 L
.66676 .35412 L
.66689 .35161 L
.66719 .34607 L
.66781 .33433 L
Mistroke
.66891 .31368 L
.67353 .22669 L
.67586 .1827 L
.67844 .13412 L
.67962 .11201 L
.68088 .08816 L
.68147 .07719 L
.68178 .07121 L
.68208 .06564 L
.68233 .06088 L
.68248 .05821 L
.6826 .3603 L
.68275 .35764 L
.6829 .35475 L
.68318 .34951 L
.68811 .25661 L
.69286 .16715 L
.69525 .12221 L
.69629 .10256 L
.69743 .08113 L
.69773 .07544 L
.69805 .06938 L
.69821 .06644 L
.69835 .06367 L
.69849 .3657 L
.69863 .36301 L
.69977 .3415 L
.70229 .29405 L
.70724 .20082 L
.70971 .15436 L
.71201 .11103 L
.71314 .08961 L
.7137 .07907 L
.71395 .07444 L
.71408 .07198 L
.71422 .06933 L
.71437 .37105 L
.71451 .36842 L
.71481 .36265 L
.71546 .35048 L
.71659 .32919 L
.72156 .23564 L
.72403 .18894 L
.72634 .14552 L
.72856 .1036 L
.7292 .09153 L
.72952 .0856 L
.72981 .08014 L
.72995 .07757 L
.73007 .07517 L
Mistroke
.73021 .37719 L
.73035 .37444 L
.73094 .36337 L
.73563 .27506 L
.74061 .18118 L
.7431 .13423 L
.7442 .11357 L
.74478 .10259 L
.74541 .09074 L
.7457 .08522 L
.74586 .08221 L
.74601 .07941 L
.74614 .38153 L
.74627 .37896 L
.74656 .37353 L
.74764 .3531 L
.75002 .30826 L
.75502 .21406 L
.75753 .16686 L
.75863 .14613 L
.75984 .1233 L
.7604 .11275 L
.761 .10141 L
.76129 .09592 L
.76157 .0907 L
.76169 .08844 L
.76182 .08602 L
.76196 .38789 L
.76209 .38543 L
.76447 .3405 L
.76949 .24598 L
.772 .19854 L
.77432 .1549 L
.77658 .11228 L
.77713 .10193 L
.77743 .09622 L
.77758 .09342 L
.77772 .09082 L
.7778 .39386 L
.77788 .39229 L
.77806 .38897 L
.77837 .38316 L
.77897 .37178 L
.78352 .28597 L
.78837 .19457 L
.7906 .15257 L
.79186 .12876 L
.79248 .11716 L
.79304 .10662 L
.79333 .10118 L
Mistroke
.79348 .09832 L
.79356 .09675 L
.79364 .09529 L
.79378 .39716 L
.79393 .39424 L
.79421 .38911 L
.79546 .36558 L
.798 .31761 L
.80268 .22935 L
.80506 .18445 L
.80632 .16074 L
.80766 .13551 L
.80833 .12282 L
.80866 .1166 L
.80897 .11089 L
.80924 .10567 L
.80938 .10305 L
.80954 .40469 L
.80969 .4018 L
.80985 .3987 L
.81015 .39312 L
.81246 .34963 L
.81745 .25547 L
.81995 .20833 L
.82226 .16476 L
.82342 .14291 L
.82451 .12242 L
.82506 .11213 L
.82521 .10931 L
.82536 .10635 L
.8255 .40834 L
.82564 .40557 L
.82689 .38202 L
.83179 .28968 L
.83651 .20078 L
.83775 .17743 L
.83909 .15215 L
.8397 .14055 L
.84035 .12829 L
.84091 .11781 L
.84106 .11494 L
.84114 .11336 L
.84122 .11187 L
.84138 .41348 L
.84152 .41083 L
.84614 .32375 L
.85105 .2311 L
.85349 .1851 L
.85469 .16257 L
.85578 .14189 L
Mistroke
.85634 .13148 L
.85685 .1218 L
.85698 .11929 L
.85711 .11691 L
.85725 .4187 L
.85739 .41621 L
.85797 .40515 L
.86033 .36064 L
.86497 .27325 L
.86732 .229 L
.8699 .18028 L
.87108 .158 L
.87173 .14572 L
.87235 .13405 L
.87263 .12881 L
.87278 .12594 L
.87293 .12323 L
.87301 .12169 L
.8731 .42454 L
.87325 .42163 L
.87355 .41595 L
.87465 .39528 L
.8796 .302 L
.88206 .25552 L
.88436 .21216 L
.88657 .17046 L
.88721 .15845 L
.88781 .14708 L
.88836 .13687 L
.8885 .13407 L
.88866 .1311 L
.8888 .12857 L
.88894 .43029 L
.88909 .42752 L
.88923 .42494 L
.88954 .4191 L
.89016 .40732 L
.89128 .38626 L
.8938 .33883 L
.89851 .25 L
.90091 .20468 L
.90218 .18083 L
.90352 .15559 L
.90409 .14472 L
.90441 .13873 L
.90457 .13577 L
.90471 .13304 L
.90479 .43601 L
.90488 .43436 L
.90507 .43086 L
Mistroke
.90539 .42475 L
.90603 .41277 L
.90834 .36915 L
.91336 .27443 L
.91589 .22685 L
.91821 .18315 L
.91938 .16103 L
.91995 .15023 L
.9202 .14552 L
.92047 .14041 L
.92062 .13763 L
.92076 .43958 L
.92089 .43713 L
.92102 .43453 L
.92161 .42341 L
.92286 .39985 L
.92743 .31384 L
.92996 .26602 L
.93228 .22225 L
.93343 .20065 L
.93468 .17707 L
.93525 .16629 L
.93586 .1548 L
.93616 .14921 L
.9363 .14647 L
.93644 .14395 L
.93656 .44617 L
.93669 .44375 L
.93696 .43863 L
.94154 .35231 L
.94641 .26042 L
.94866 .21806 L
.94984 .19571 L
.9511 .17197 L
.95173 .16005 L
.95191 .15678 L
.95209 .15326 L
.95218 .15164 L
.95227 .14994 L
.95235 .14848 L
.95243 .45141 L
.95251 .44985 L
.95259 .44837 L
.95274 .4456 L
.95307 .43939 L
.95366 .42821 L
.95609 .38246 L
.96073 .29501 L
.96308 .25072 L
.96566 .20199 L
Mistroke
.96684 .17969 L
.9675 .16739 L
.96782 .16134 L
.96797 .15839 L
.96812 .15572 L
.96826 .45754 L
.96839 .455 L
.96869 .44942 L
.96932 .43761 L
.97041 .41694 L
.97507 .32918 L
.97619 .30799 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.03968 .30798 m
.03968 .31323 L
s
.05556 .30798 m
.05556 .31849 L
s
.07143 .30798 m
.07143 .32374 L
s
.0873 .30798 m
.0873 .32899 L
s
.10317 .30798 m
.10317 .33425 L
s
.11905 .30798 m
.11905 .33952 L
s
.13492 .30798 m
.13492 .34479 L
s
.15079 .30798 m
.15079 .35007 L
s
.16667 .30798 m
.16667 .35536 L
s
.18254 .30798 m
.18254 .36066 L
s
.19841 .30798 m
.19841 .36598 L
s
.21429 .30798 m
.21429 .37131 L
s
.23016 .30798 m
.23016 .37666 L
s
.24603 .30798 m
.24603 .38204 L
s
.2619 .30798 m
.2619 .38744 L
s
.27778 .30798 m
.27778 .39289 L
s
.29365 .30798 m
.29365 .39837 L
s
.30952 .30798 m
.30952 .40392 L
s
.3254 .30798 m
.3254 .40954 L
s
.34127 .30798 m
.34127 .41525 L
s
.35714 .30798 m
.35714 .42109 L
s
.37302 .30798 m
.37302 .42711 L
s
.38889 .30798 m
.38889 .43337 L
s
.40476 .30798 m
.40476 .44 L
s
.42063 .30798 m
.42063 .44723 L
s
.43651 .30798 m
.43651 .45547 L
s
.45238 .30798 m
.45238 .1612 L
s
.46825 .30798 m
.46825 .17619 L
s
.48413 .30798 m
.48413 .20689 L
s
.5 .30798 m
.5 .30798 L
s
.51587 .30798 m
.51587 .40908 L
s
.53175 .30798 m
.53175 .43978 L
s
.54762 .30798 m
.54762 .45477 L
s
.56349 .30798 m
.56349 .1605 L
s
.57937 .30798 m
.57937 .16874 L
s
.59524 .30798 m
.59524 .17597 L
s
.61111 .30798 m
.61111 .1826 L
s
.62698 .30798 m
.62698 .18886 L
s
.64286 .30798 m
.64286 .19488 L
s
.65873 .30798 m
.65873 .20072 L
s
.6746 .30798 m
.6746 .20643 L
s
.69048 .30798 m
.69048 .21205 L
s
.70635 .30798 m
.70635 .2176 L
s
.72222 .30798 m
.72222 .22308 L
s
.7381 .30798 m
.7381 .22853 L
s
.75397 .30798 m
.75397 .23393 L
s
.76984 .30798 m
.76984 .23931 L
s
.78571 .30798 m
.78571 .24466 L
s
.80159 .30798 m
.80159 .24999 L
s
.81746 .30798 m
.81746 .25531 L
s
.83333 .30798 m
.83333 .26061 L
s
.84921 .30798 m
.84921 .2659 L
s
.86508 .30798 m
.86508 .27118 L
s
.88095 .30798 m
.88095 .27645 L
s
.89683 .30798 m
.89683 .28172 L
s
.9127 .30798 m
.9127 .28698 L
s
.92857 .30798 m
.92857 .29223 L
s
.94444 .30798 m
.94444 .29748 L
s
.96032 .30798 m
.96032 .30274 L
s
.97619 .30798 m
.97619 .30798 L
s
.015 w
.03968 .31323 Mdot
.05556 .31849 Mdot
.07143 .32374 Mdot
.0873 .32899 Mdot
.10317 .33425 Mdot
.11905 .33952 Mdot
.13492 .34479 Mdot
.15079 .35007 Mdot
.16667 .35536 Mdot
.18254 .36066 Mdot
.19841 .36598 Mdot
.21429 .37131 Mdot
.23016 .37666 Mdot
.24603 .38204 Mdot
.2619 .38744 Mdot
.27778 .39289 Mdot
.29365 .39837 Mdot
.30952 .40392 Mdot
.3254 .40954 Mdot
.34127 .41525 Mdot
.35714 .42109 Mdot
.37302 .42711 Mdot
.38889 .43337 Mdot
.40476 .44 Mdot
.42063 .44723 Mdot
.43651 .45547 Mdot
.45238 .1612 Mdot
.46825 .17619 Mdot
.48413 .20689 Mdot
.5 .30798 Mdot
.51587 .40908 Mdot
.53175 .43978 Mdot
.54762 .45477 Mdot
.56349 .1605 Mdot
.57937 .16874 Mdot
.59524 .17597 Mdot
.61111 .1826 Mdot
.62698 .18886 Mdot
.64286 .19488 Mdot
.65873 .20072 Mdot
.6746 .20643 Mdot
.69048 .21205 Mdot
.70635 .2176 Mdot
.72222 .22308 Mdot
.7381 .22853 Mdot
.75397 .23393 Mdot
.76984 .23931 Mdot
.78571 .24466 Mdot
.80159 .24999 Mdot
.81746 .25531 Mdot
.83333 .26061 Mdot
.84921 .2659 Mdot
.86508 .27118 Mdot
.88095 .27645 Mdot
.89683 .28172 Mdot
.9127 .28698 Mdot
.92857 .29223 Mdot
.94444 .29748 Mdot
.96032 .30274 Mdot
.97619 .30798 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005_ooool3o`0000Cooooo0_l0000iooooo`?o0000>oooool2o`0003cooooo0ol0000ioooo
o`?o00001?ooool2o`0000Oooooo000Gooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000=oooool01Ol0003ooooooooooooooooo000003Wooooo00Co0000oooooooooooo0000>_oo
ool01Ol0003ooooooooooooooooo000003Wooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00006ooooo`003oooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000aooooo`Go00001Oooool00ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`00
03kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Kooooo000Gooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000>oooool0
0ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`0003kooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo000Gooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000=oooool4o`0003[ooooo00Co0000oooooooooooo
0000>_ooool4o`0003[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006oooo
o`005_ooool2o`0000Cooooo00Co0000oooooooooooo0000=oooool00ol0003oooooooooo`0koooo
o`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool0>_ooool2o`0000Cooooo00Co0000
oooooooooooo00001_ooool001Oooooo00?o0000ooooooooool00oooool2o`0003Sooooo1Ol0000j
ooooo`;o0000>oooool5o`0003Wooooo00?o0000ooooooooool00oooool2o`0000Oooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Aoooooooo00003Ol00003
ooooo`004Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo007ooooo0009ooooo`?o
00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool0?Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`01ooooo`002?ooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo007o
oooo0002ooooo`Go00001Oooool00ol0003oooooooooo`02ooooo`?o0000N?ooool00ol00?oooooo
ooooo`08ooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool0KOooool3o`0000?ooooo
000:ooooo`;o00001Oooool00ol0003oooooooooo`1hooooo`03o`00oooooooooooo00Sooooo00?o
0000ooooooooool04?ooool00ol00?ooooooooooo`1_ooooo`03o`000?oooooooooo007ooooo000<
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0N?ooool00ol00?ooooooooooo`08
ooooo`03o`000?oooooooooo00oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1[
ooooo`03o`000?oooooooooo007ooooo0008ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`23ooooo`03o`000?oooooooooo013ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo06Oooooo00?o0000ooooooooool00Oooool000Wooooo0ol00005
ooooo`03o`000?oooooooooo07Sooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0?
ooooo`;o003o1oooool00ol00?ooooooooooo`1Wooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo07Sooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0?oooo
o`;o003o0oooool01Ol00?oooooooooooooooooo003o06Wooooo00?o0000ooooooooool00Oooool0
017ooooo0_l0001iooooo`05o`00ooooooooooooooooool00?l01_ooool00ol0003oooooooooo`0?
ooooo`;o003o0oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo06;ooooo0_l00003
ooooo`004Oooool00ol0003oooooooooo`1hooooo`05o`00ooooooooooooooooool00?l01_ooool0
0ol0003oooooooooo`0?ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo06?ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool0O?ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo01?ooooo0_l00?l3
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`1Oooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo07cooooo00?o003oooooooooool01?ooool0
0ol0003oooooooooo`0@ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo0_l00?l3ooooo`03o`00oooooooooooo05[ooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool0Moooool2o`00o`?ooooo00?o003oooooooooool01?oo
ool00ol0003oooooooooo`0?ooooo`;o003o1oooool01Ol00?oooooooooooooooooo003o00?ooooo
0_l00?l3ooooo`05o`00ooooooooooooooooool00?l0F?ooool00ol0003oooooooooo`01ooooo`00
4Oooool2o`0007Sooooo0_l00?l3ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool0
3oooool2o`00o`;ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool0EOooool2o`0000?ooooo000Aooooo`03
o`000?oooooooooo07Oooooo0_l00?l3ooooo`03o`00oooooooooooo00Cooooo00?o0000oooooooo
ool03oooool01?l00?ooooooooooooooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`08
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`1Booooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo07cooooo00?o003oooooooooool01?ooool0
0ol0003oooooooooo`0Cooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`1@ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07cooooo
00?o003oooooooooool01?ooool00ol0003oooooooooo`0@ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l7ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`1>ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo07Oooooo0_l00?l3ooooo`03o`00oooooooooooo00Cooooo00?o0000oooo
ooooool03oooool2o`00o`Kooooo0_l00?l3ooooo`04o`00ooooooooooooooooo`;o003o0_ooool2
o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool0BOooool00ol0003oooooooooo`01ooooo`004Oooool2o`0007Sooooo0_l00?l3
ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool03oooool2o`00o`;ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l2ooooo`;o003o0ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o04Kooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1gooooo`;o003o
0oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00oooooo0_l00?l2ooooo`;o003o
0_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00;o003o0oooool00ol00?oooooo
ooooo`05ooooo`04o`00ooooooooooooooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o
04?ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Moooool2o`00o`;o
oooo00?o003oooooooooool01Oooool00ol0003oooooooooo`0?ooooo`04o`00oooooooooooooooo
o`;o003o0_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`11ooooo`03o`000?oooooooooo007o
oooo000Aooooo`03o`000?oooooooooo07_ooooo0_l00?l6ooooo`03o`000?oooooooooo013ooooo
00?o003oooooooooool00_l00?l2ooooo`;o003o0oooool01?l00?ooooooooooooooool2o`00o`Oo
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0?oooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`1gooooo`;o003o0oooool01Ol00?oooooooooooooo
oooo003o00;ooooo00?o0000ooooooooool03_ooool00ol00?ooooooo`00o`06ooooo`;o003o0ooo
ool01?l00?ooooooooooooooool2o`00o`;ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo03Sooooo00?o0000
ooooooooool00Oooool0017ooooo0_l0001hooooo`;o003o0oooool01Ol00?oooooooooooooooooo
003o00;ooooo00?o0000ooooooooool03_ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0_ooool2o`00o`;ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0gooooo`;o00000oooool0017ooooo00?o0000ooooooooool0Moooool2o`00o`;ooooo
00?o003oooooooooool00_ooool01?l00?ooooooooooool0000@ooooo`03o`00oooooooo003o00;o
oooo0_l00?l6ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00_l00?l2ooooo`03
o`00oooooooooooo00Kooooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0=?oo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1gooooo`;o003o0_ooool0
0ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00013ooooo00?o003oooooooooool00_oo
ool2o`00o`;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`;o003o0_oo
ool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0_ooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`?ooooo00Go003ooooooooo
ooooooooo`00o`0booooo`03o`000?oooooooooo007ooooo0008ooooo`Go00001?ooool00ol0003o
ooooooooo`1kooooo`;o003o0oooool01?l00?ooooooooooool0000Booooo`03o`00oooooooooooo
00;o003o0_ooool2o`00o`;ooooo0_l00?l3ooooo`03o`00oooooooooooo00Gooooo0_l00?l3oooo
o`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02o`00o`?ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o02kooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`1looooo`05o`00ooooooooooooooooool00?l00_ooool00ol0
003oooooooooo`0@ooooo`05o`00ooooooooooooooooool00?l00_ooool2o`00o`;ooooo0_l00?l3
ooooo`;o003o0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o0oooool0
1?l00?ooooooooooooooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00
ooooooooooooooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool0;?ooool00ol0003oooooooooo`01ooooo`000_ooool5o`0000?ooooo00?o0000oooooooo
ool01?ooool3o`0007Oooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol0
003oooooooooo`0>ooooo`03o`00oooooooo003o00Oooooo00?o003oooooooooool00_l00?l2oooo
o`03o`00oooooooo003o00;ooooo0_l00?l2ooooo`04o`00ooooooooooooooooo`;o003o0oooool0
1Ol00?oooooooooooooooooo003o00?ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l0
0oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l0:?ooool3o`0000?ooooo000;ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0Moooool2o`00o`;ooooo0_l00?l3ooooo`04o`00ooooooooooooo`00013ooooo00Oo003ooooo
ool00?ooooooo`00oooooooo003o00?ooooo00Co003ooooooooooooo003o1Oooool00ol00?oooooo
ooooo`02o`00o`;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l01?ooool00ol00?ooooooooooo`0Sooooo`03o`000?oooooooooo007ooooo0008
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1fooooo`03o`00oooo
oooo003o00;ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool0000@ooooo`07o`00
ooooooooooooooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool01Oooool2o`00o`;ooooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Co003ooooo
oooooooooooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l08Oooool00ol0003oooooooooo`01oooo
o`002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0Noooool2o`00
o`?ooooo00Co003ooooooooooooo00005?ooool00ol00?ooooooo`00o`02ooooo`;o003o0oooool0
1?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00o`?ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02o`00o`?ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`03o`00oooooooooooo00;o003o0oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o027ooooo00?o0000oooo
ooooool00Oooool000Wooooo0ol00005ooooo`03o`000?oooooooooo07_ooooo0_l00?l3ooooo`04
o`00ooooooooooooo`0001;ooooo00Go003oooooooooooooooooo`00o`02ooooo`;o003o0_ooool2
o`00o`;ooooo00?o003oooooool00?l01oooool00ol00?ooooooooooo`02o`00o`?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00;ooooo0_l00?l3ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_l00?l3ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`0Kooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000Moooool00ol00?oooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol0003oooooooooo`0>ooooo`03
o`00oooooooo003o00Oooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooo003o00;o
oooo0_l00?l3ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00o`?ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02o`00o`?ooooo00Co003ooooooooooooooooo0_l00?l3oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo0_l00003ooooo`004Ooo
ool00ol0003oooooooooo`1fooooo`03o`00oooooooo003o00;ooooo0_l00?l3ooooo`04o`00oooo
ooooooooo`00013ooooo00Go003oooooool00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00
o`Gooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_l00?l3ooooo`04o`00ooooooooooooooooo`;o003o0oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o01Wooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool0M_ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00;ooooo00Co003ooooo
oooooooo00004?ooool02Ol00?oooooooooooooooooo003oooooool00?ooooooo`00o`0:ooooo`05
o`00oooooooo003oooooool00?l00_ooool2o`00o`Oooooo00Co003ooooooooooooooooo0_l00?l2
ooooo`04o`00ooooooooooooooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooo
oooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0G
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07Kooooo00?o003ooooo
ool00?l00_ooool01?l00?ooooooooooooooool2o`00o`;ooooo00?o0000ooooooooool03_ooool0
2Ol00?oooooooooooooooooo003oooooool00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00
o`Gooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02o`00o`;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00o`?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo07_ooooo0_l00?l2ooooo`05o`00ooooooooooooooooool000004_oo
ool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`02ooooo`;o003o0_ooool00ol0
0?ooooooo`00o`07ooooo`03o`00oooooooooooo00;o003o0_ooool00ol00?ooooooooooo`03oooo
o`05o`00ooooooooooooooooool00?l00_ooool2o`00o`;ooooo0_l00?l4ooooo`03o`00oooooooo
oooo00;o003o0_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05
o`00ooooooooooooooooool00?l04?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`1fooooo`03o`00oooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool00ol0
003oooooooooo`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l00_ooool2o`00
o`;ooooo00Go003oooooool00?ooooooo`00o`05ooooo`03o`00oooooooooooo00;o003o0_ooool2
o`00o`;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`02o`00o`;ooooo00?o003o
ooooooooool00_ooool2o`00o`?ooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooo
oooooooo003o00Sooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooooooooooooooo
o`;o003o0oooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o
0000Moooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00;o003o0_ooool00ol0003o
ooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l01Oooool01?l00?ooooooooooool00?l3
ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooooooo00;ooooo0_l00?l3ooooo`04o`00
ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0_ooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`05ooooo`;o00000oooool0017ooooo00?o
0000ooooooooool0M?ooool3ool00004ooooool00?ooooooo`00o`Gooooo00Co003ooooooooooooo
00003_ooool3ool00008ooooool00?ooooooo`00oooooooo003oooooool00?l:ooooo`05o`00oooo
oooo003oooooool00?l00_ooool00ol00?ooooooooooo`06ooooo`06o`00ooooooooooooo`00oooo
oooo003o0_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00
ooooooooooooooooo`;o003o0_ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l02?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool01_ooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo
06_ooooo0ooo00001?oooooo003oooooool00?l4ooooo`;o003o0_ooool00ol0003oooooooooo`0<
ooooo`?oo`000oooool01Ol00?ooooooo`00oooooooo003o00Gooooo00Co003ooooooooooooo003o
1Oooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool00_ooool01_l00?oo
ooooooooool00?ooooooo`00o`;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_l00?l2ooooo`;o003o0oooool00ol00?oooooooooo
o`05ooooo`;o003o0_ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool01_ooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`06ooooo`05o`00ooooooooooooooooool0
0?l0JOooool3ool000?ooooo00?o003oooooool00?l00_ooool01Ol00?oooooooooooooooooo0000
00kooooo0ooo00003_ooooooo`00ool00?oo003oooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003o0_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo003o00;ooooo0_l00?l2
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00_l00?l2ooooo`04o`00oooooooo
ooooooooo`;o003o1?ooool00ol00?ooooooooooo`02o`00o`;ooooo0_l00?l2ooooo`;o003o0ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo0_l00?l7ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0:ooooo`05o`00oooooooooooooooo
ool00?l0Ioooool00ooo003oooooooooo`03ooooo`04o`00ooooooooooooo`00o`?ooooo00?o0000
ooooooooool03_ooool00ooo003oooooool00002ool000?ooooo00Oo003oooooool00?ooooooo`00
oooooooo003o00;ooooo00Go003oooooool00?ooooooo`00o`05ooooo`03o`00oooooooooooo00;o
003o0_ooool01ol00?oooooooooooooooooo003oooooool00?l00oooool00ol00?ooooooooooo`02
o`00o`;ooooo00Oo003oooooooooooooooooo`00oooooooo003o00?ooooo00Co003ooooooooooooo
003o0oooool2o`00o`?ooooo00?o003oooooooooool01_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`;o003o1oooool00ol00?ooooooooooo`06
ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00001oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo06Gooooo00?oo`00ooooool00?l00ooo00000ol00?ooooooooooo`02o`00
o`;ooooo00?o0000ooooooooool03Oooool00ol00?ooo`00ooooo`03ool000;ooooo0ooo00001Ol0
0?ooooooo`00oooooooo003o00;ooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool0
0?l01?ooool2o`00o`;ooooo0_l00?l2ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`03
ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooool00?l00oooool00ol00?oooooooooo
o`02o`00o`;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l2ooooo`;o
003o0oooool01Ol00?oooooooooooooooooo003o00Oooooo0_l00003ooooo`004Oooool00ol0003o
ooooooooo`06ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol00?ooooooooooo`1Poooo
o`03ool00?oooooo003o00?oo`0000Go003oooooooooooooooooo`00o`02ooooo`03o`000?oooooo
oooo00gooooo00So003oool00?oooooo003ooooooooo003oooooo`00o`?oo`0000?o003oooooool0
0?l01_ooool01ol00?ooooooo`00oooooooo003oooooool00?l01Oooool00ol00?ooooooooooo`02
o`00o`;ooooo00Go003oooooool00?ooooooo`00o`05ooooo`03o`00oooooooooooo00;o003o0_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`04o`00ooooooooooooooooo`;o003o0_ooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l01oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`08
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Kooooo00Go003ooooo
ooooooooooooo`00o`07ooooo`;o003o0oooool00ol00?ooooooooooo`1Looooo`03ool00?oooooo
003o00?oo`001?ooool01?l00?ooooooooooool0000?ooooo`03o`00oooo003ooooo00;ooooo00?o
o`00ooooool00?l00ooo00001Oooooooo`00ool00?oo003o003o00Kooooo00Wo003oooooool00?oo
ooooo`00oooooooo003oooooool00?l01Oooool02?l00?ooooooooooool00?ooooooo`00oooooooo
003o1?ooool00ol00?ooooooooooo`02ooooo`06o`00ooooooooooooo`00oooooooo003o0_ooool0
1?l00?ooooooooooooooool2o`00o`?ooooo00Co003ooooooooooooo003o1?ooool2o`00o`;ooooo
0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo00Gooooo0_l00?l3ooooo`05o`00oooooooooooooooo
ool00?l02?ooool00ol00?ooooooooooo`1Looooo`07ool00?oooooooooooooooooo003oooooo`00
o`02ooooo`;o003o0_ooool00ol0003oooooooooo`0>ooooo`0;ool00?ooooooooooo`00oooo003o
ooooo`00ooooooooo`00ooooool00?l00ooo00000ol00?ooooooo`00o`06ooooo`09o`00oooooooo
003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool00oooool01Ol00?oo
ooooo`00oooooooo003o00;ooooo00Co003ooooooooooooooooo0_l00?l4ooooo`03o`00oooooooo
oooo00;o003o0_ooool2o`00o`;ooooo0_l00?l3ooooo`04o`00ooooooooooooooooo`;o003o0_oo
ool2o`00o`;ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooooooool2o`00o`Oooooo
00Go003oooooooooooooooooo`00o`08ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo00Gooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o05[ooooo00Ooo`00oooo
ooooooooooooool00?oooooo003o00;ooooo00Go003oooooooooooooooooo`00000@ooooo`0;ool0
0?oooooo003ooooooooo003oooooo`00ooooooooo`00ooooool00?l00ooo00002?l00?ooo`00ool0
0?oo003oooooo`00oooooooo003o1Oooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003o
ooooooooool00oooool01Ol00?oooooooooooooooooo003o00;ooooo0_l00?l2ooooo`;o003o0_oo
ool00ol00?ooooooo`00o`02ooooo`;o003o0_ooool01?l00?ooooooooooooooool2o`00o`;ooooo
0_l00?l8ooooo`03o`00oooooooooooo00;o003o0oooool01?l00?ooooooooooooooool2o`00o`;o
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo007o
oooo000Aooooo`;o00002oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l7ooooo`05
o`00ooooooooooooooooool00?l0EOooool02?l00?ooo`00ooooool00?ooooooool00?oooooo003o
0_ooool2o`00o`;ooooo00?o0000ooooooooool03Oooool01_l00?ooo`00ooooool00?ooooooool0
00?ooooo00Ooo`00ooooool00?ooooooool00?oooooo003o00?oo`0000Koooooool00?oo003oo`00
ooooool00?l3ooooo`05o`00oooooooo003oooooool00?l00_ooool2o`00o`;ooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`02o`00o`;ooooo00Oo003oooooooooooooooooo`00oooo
oooo003o00?ooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooooooool2o`00o`?o
oooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool2
o`00o`;ooooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool2
o`0000?ooooo000Aooooo`03o`000?oooooooooo00Gooooo0_l00?l7ooooo`04o`00oooooooooooo
ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0Dooo
ool02?l00?ooo`00ooooool00?ooooooool00?oooooo003o0oooool01?l00?ooooooooooool0000?
ooooo`03o`00oooo003ooooo00;o003o00Woo`00ooooool00?ooooooool00?oooooo003ooooooooo
00000_ooool3ool00008oooooooo003oo`00ool00?oooooo003oooooool00?l5ooooo`03o`00oooo
oooooooo00;o003o0_ooool01ol00?oooooooooooooooooo003oooooool00?l00oooool00ol00?oo
ooooooooo`02o`00o`;ooooo00Go003oooooooooooooooooo`00o`05ooooo`04o`00oooooooooooo
o`00o`?ooooo0_l00?l3ooooo`;o003o0_ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l01oooool2o`00o`;ooooo0_l00?l3ooooo`03o`00oooooooooooo00Kooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01Oooool2o`00o`?ooooo00?o003o
ooooooooool01Oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l0DOooool01_l00?ooo`00ooooool00?ooooooool000Gooooo00Co003ooooo
oooooooo00003oooool02_l00?ooo`00oooooooooooo003oool00?oooooo003ooooooooo0003oooo
o`05ool00?oooooooooooooooooo00000_ooool3ool00006oooooooo003oo`00ool00?oooooo003o
1oooool02?l00?ooooooooooool00?ooooooo`00oooooooo003o0oooool00ol00?ooooooo`00o`03
ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool00oooool01Ol00?oooooooooo
oooooooo003o00;ooooo00Oo003oooooooooooooooooo`00oooooooo003o00;ooooo0_l00?l2oooo
o`;o003o0oooool00ol00?ooooooooooo`05ooooo`;o003o0_ooool2o`00o`?ooooo00?o003ooooo
ooooool01_ooool00ol0003oooooooooo`01ooooo`002Oooool3o`0000Gooooo00?o0000oooooooo
ool01Oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`07ooooo`;o003o0oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1:
ooooo`06o`00oooo003oooooo`00ooooooooo`000_ooool3ool00004o`00ooooooooooooo`0000oo
oooo00[o003oool00?ooooooooooo`00oooo003oooooo`00ooooooooo`000oooool01Ooo003ooooo
o`00ooooooooo`0000Cooooo00?oo`00oooooooo00000_oo00000ooooooo003oool00002ool000Co
oooo00?o003oooooooooool00_ooool01ol00?ooooooo`00oooooooo003oooooool00?l01Oooool0
0ol00?ooooooooooo`02ooooo`05o`00oooooooo003oooooool00?l00_ooool2o`00o`;ooooo0_l0
0?l3ooooo`06o`00ooooooooooooo`00oooooooo003o0_ooool2o`00o`;ooooo00Co003ooooooooo
oooooooo0_l00?l3ooooo`;o003o1_ooool2o`00o`?ooooo00?o003oooooooooool01_ooool00ol0
003oooooooooo`01ooooo`002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00Co003ooooooooooooooooo0_l00?l3ooooo`03o`00oooooooooooo00Gooooo0_l00?l3oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo04_ooooo00Ooo`00ooooooooooooooooool00?oooooo003o00?oo`000oooool00ol0003ooooo
ooooo`0>ooooo`06ool00?oooooo003oo`00oooo003ooooo0_l00?l02Ooo003oooooo`00oooooooo
o`00ooooool00?ooooooool00002ooooo`04o`00ooooooooo`00ooooo`?oo`0000?oooooo`00oooo
00000_oo00000ol00?ooooooo`00o`06ooooo`09o`00ooooooooooooooooool00?ooooooo`00oooo
oooo003o00;ooooo0_l00?l4ooooo`05o`00oooooooo003oooooool00?l00_ooool01?l00?oooooo
ooooooooool2o`00o`?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00;ooooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo0_l00?l2ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`01ooooo`000_ooool5o`0000?o
oooo00?o0000ooooooooool01?ooool3o`0000Wooooo00?o003oooooooooool00_ooool01?l00?oo
ooooooooooooool2o`00o`Oooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo04;ooooo00So
003oool00?oooooo003ooooooooo003oooooo`00o`?oo`000oooool00ol0003oooooooooo`0=oooo
o`06o`00oooo003oooooo`00ooooooooo`000_ooool02_l00?ooo`00ooooool00?ooooooool00?oo
oooo003ooooooooo0002ooooo`;o003o00Ooo`00ooooooooooooooooool00?oooooo003o00?oo`00
00Go003oool00?oo003oo`00o`00o`02ooooo`03o`00oooooooooooo00?ooooo00Go003oooooool0
0?ooooooo`00o`02ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`03ooooo`03o`00oooo
oooo003o00Cooooo00Co003ooooooooooooooooo0_l00?l8ooooo`03o`00oooooooooooo00;o003o
0_ooool00ol00?ooooooooooo`02ooooo`;o003o0_ooool2o`00o`;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`04ooooo`?o00000oooool000[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooooooo
0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
04;ooooo00co003oool00?oooooo003ooooooooo003oooooo`00ooooooooo`00ooooool00?l2oooo
o`03o`000?oooooooooo00gooooo00?o003oool00?ooool00_l00?l02Ooo003ooooooooooooooooo
o`00ooooool00?ooooooool00003ooooo`03ool00?oooooooooo00;o003o00Goo`00ooooool00?oo
ooooool00003ooooo`03ool00?oooooo003o00?oo`0000Co003oool00?oo003oo`000oooool00ol0
0?ooooooo`00o`03ooooo`04o`00oooooooo003oo`00o`?ooooo00Oo003oooooooooooooooooo`00
oooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool2o`00o`;ooooo00?o003oooooool0
0?l00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o0oooool01?l00?oo
ooooooooooooool2o`00o`;ooooo0_l00?l3ooooo`03o`00oooooooooooo00Kooooo00?o0000oooo
ooooool00Oooool000[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`;o
003o0oooool00ol00?ooooooooooo`05ooooo`;o003o0_ooool2o`00o`?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool0?_ooool01_l00?ooo`00ooooool00?ooooooool000?o
oooo00?oo`00ooooool00?l00_ooool00ol0003oooooooooo`0=ooooo`03o`00oooo003ooooo00;o
003o00Goo`00ooooool00?oo003oool00003ooooo`05ool00?oooooooooooooooooo00000_ooool2
o`00o`05ool00?oooooo003ooooooooo00000oooool00ooo003oooooooooo`03ool00008o`00oooo
003oo`00ool00?oooooo003oooooool00?l5ooooo`05o`00ooooooooooooooooool00?l00_ooool0
1Ol00?oooooooooooooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`02ooooo`07o`00
ooooooooooooooooool00?ooooooo`00o`02ooooo`04o`00ooooooooooooooooo`;o003o0oooool0
0ol00?ooooooooooo`05ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l8ooooo`03o`000?oooooo
oooo007ooooo0009ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`;o003o0_ooool2o`00
o`?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02o`00o`?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Kooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0>Oooool01_l00?ooo`00oooo
ool00?ooooooool000?ooooo00?oo`00ooooool00?l00_ooool00ol0003oooooo`00o`0=ooooo`07
o`00oooo003oooooooooool00?ooo`00ooooo`02o`00o`09ool00?oooooooooooooooooo003ooooo
o`00ooooooooo`0000Cooooo00Woo`00ooooool00?ooooooool00?oooooo003ooooooooo00000ooo
ool00ooo003oooooo`00o`03ool00004oooooooo003oo`00ool000?ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`02ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo
003o00?ooooo00?o003oooooooooool01?ooool01ol00?ooooooo`00oooooooo003oooooool00?l0
0_ooool01?l00?ooooooooooooooool2o`00o`;ooooo00?o003oooooool00?l00oooool00ol00?oo
ooooooooo`02o`00o`;ooooo00?o003oooooooooool01oooool00ol0003oooooooooo`01ooooo`00
2_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo0_l00?l2ooooo`;o003o
0oooool00ol00?ooooooooooo`05ooooo`;o003o0_ooool2o`00o`?ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00Cooooo00?o003oooooooooool0>_ooool02Ooo003oooooooooool00?ooo`00ooooool00?oo
ooooool00004ooooo`03o`000?oooooo003o00kooooo00Koo`00ooooool00?oo003oool00?ooool2
o`00o`09ool00?oooooo003ooooooooo003oooooo`00ooooooooo`0000Cooooo00goo`00oooooooo
ooooooooool00?oooooo003ooooooooo003oooooo`00ooooooooo`0000Cooooo00?oo`00oooooooo
00000_oo00000ooooooo003oool00002ool000;ooooo00?o003oooooool00?l01?ooool02Ol00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00o`02ooooo`;o003o0oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooool00?l01oooool00ol00?ooooooooooo`02o`00o`Sooooo00?o0000oooooooo
ool00Oooool0017ooooo0_l0000:ooooo`;o003o0oooool01?l00?ooooooooooooooool2o`00o`Ko
oooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`?ooooo00Go003ooooo
ooooooooooooo`00o`07ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0=_ooool0
2Ooo003oooooooooooooooooo`00ooooool00?ooooooool00004ooooo`03o`000?oooooo003o00ko
oooo00Goo`00ooooool00?ooooooool00002ooooo`0:o`00oooo003oooooo`00ooooooooo`00oooo
ool00?ooooooool000;ooooo0_l00?l03Ooo003oooooooooooooooooo`00ooooool00?ooooooool0
0?oooooo003ooooooooo00000oooool00ol00?ooo`00ooooo`03ool00003ooooool00?ooo`0000;o
o`0000?o003oooooool00?l01?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooo003o00Co
oooo0_l00?l2ooooo`;o003o2?ooool00ol00?ooooooooooo`02o`00o`;ooooo00Oo003ooooooooo
ooooooooo`00oooooooo003o00;ooooo0_l00?l6ooooo`;o003o1oooool2o`0000?ooooo000Aoooo
o`03o`000?oooooooooo00Kooooo00?o003oooooooooool01?ooool2o`00o`?ooooo0_l00?l7oooo
o`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00o`?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Kooooo00Go003ooooooooooooo
ooooo`00o`0cooooo`0<o`00oooo003oooooo`00ooooooooo`00ooooool00?ooooooool00?oooooo
003o0_ooool00ol0003o003oo`00o`0<ooooo`07o`00ooooooooo`00ooooool00?ooooooool00003
ooooo`09ool00?oooooo003oo`00oooo003oooooo`00ooooooooo`0000;ooooo0_l00?l01Ooo003o
ooooo`00ool00?ooo`0000?ooooo00[oo`00ooooool00?ooooooool00?oooooo003oooooool00?oo
o`000oooool00ooo003oooooo`00o`03ool00004o`00oooo003oo`00ool000?ooooo00?o003ooooo
ool00?l00oooool01ol00?ooooooo`00oooooooo003oooooool00?l01?ooool2o`00o`;ooooo00Go
003oooooooooooooooooo`00o`05ooooo`03o`00oooooooooooo00;o003o0_ooool00ol00?oooooo
o`00o`02ooooo`;o003o0_ooool2o`00o`?ooooo00?o003oooooooooool01_ooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`05ooooo`;o003o0oooool00ol00?oooooooooo
o`05ooooo`;o003o0_ooool2o`00o`Oooooo00?o003oooooooooool01Oooool01?l00?oooooooooo
ooooool2o`00o`Oooooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00oooooooooooooooo
ool00?l0<oooool00ol00?ooo`00ooooo`02o`00o`07ool00?oooooo003ooooooooo003oooooo`00
o`02ooooo`03o`000?oooooo003o00cooooo00Co003ooooooooo003ooooo0_l00?l01_oo003ooooo
o`00ooooooooo`00ooooo`;o003o00Goo`00ooooooooooooooooool00002ooooo`;o003o00Goo`00
ooooool00?oo003oool00003ooooo`0>ool00?oooooo003ooooooooo003oooooo`00oooooooo003o
ool00?oooooo003ooooooooo0003ooooo`03ool00?oooooo003o00?oo`0000Co003oool00?oo003o
o`000oooool00ol00?ooooooooooo`03ooooo`05o`00ooooooooooooooooool00?l00_ooool02Ol0
0?oooooooooooooooooo003oooooool00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool0
0?l01_ooool00ol00?ooooooo`00o`02ooooo`;o003o0oooool00ol00?ooooooooooo`06ooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Gooooo0_l00?l2ooooo`;o003o
1oooool2o`00o`;ooooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o0oooool01Ol00?oooooooooooooooooo
003o00?ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`0]ooooo`03o`00oooo003ooooo00;o003o00Ooo`00ooooooooooooooooool00?oooooo003o00;o
oooo00?o0000ooooool00?l03?ooool00ol00?ooooooool00002ooooo`03o`00oooo003ooooo00;o
003o00Woo`00ooooooooooooooooool00?oooooo003ooooooooo00000oooool00ol00?ooo`00oooo
o`02o`00o`05ool00?oooooo003ooooooooo00000oooool02_oo003oooooo`00oooooooo003oool0
0?oooooo003ooooooooo0003ooooo`03ool00?oooooooooo00?oo`0000Go003oool00?oo003oo`00
ooooo`03ool000?ooooo00?o003oooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`07
o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`04o`00ooooooooooooooooo`;o003o1?oo
ool01Ol00?oooooooooooooooooo003o00;ooooo0_l00?l2ooooo`03o`00oooooooooooo00Oooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01Oooool2o`00o`;ooooo0_l0
0?l2ooooo`;o003o1oooool2o`00o`;ooooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool0
0?l00oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool0:Oooool02ooo003oooooooooool00?ooo`00ooooool00?oooooo
ool00?oooooo003o00;ooooo00?o0000o`00ooooool03_ooool01_oo003oooooooooool00?ooo`00
ooooo`;o003o00Woo`00ooooool00?oo003oool00?oooooo003ooooooooo00001?ooool03Ooo003o
ooooo`00ool00?ooo`00ooooool00?ooooooool00?oooooo003ooooooooo00001?ooool02Ooo003o
ooooo`00ool00?ooo`00ooooool00?ooooooool00003ooooo`03ool00?oooooo003o00?oo`0000ko
ooooool00?oo003oo`00ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`?ooooo
00[o003ooooooooooooo003oooooool00?ooooooo`00oooooooo003o0_ooool01?l00?oooooooooo
ooooool2o`00o`;ooooo00?o003oooooool00?l01oooool01?l00?ooooooooooool00?l9ooooo`03
o`000?oooooooooo007ooooo000Aooooo`;o00001_ooool01?l00?ooooooooooooooool2o`00o`;o
oooo0_l00?l2ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00_l00?l2ooooo`03
o`00oooooooooooo00;ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00oooooooooooo
ooooool00?l01oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooo
ooooooooooooo`;o003o:oooool02Ooo003oooooooooool00?ooo`00ooooool00?ooooooool00004
ooooo`03o`000?l00?oooooo00kooooo00Koo`00ooooool00?ooooooool00?ooool2o`00o`09ool0
0?oooooo003oo`00oooo003oooooo`00ooooooooo`0000;ooooo0_l00?l01_oo003ooooooooooooo
ooooo`00ooooo`;o003o00Goo`00ooooool00?ooooooool00004ooooo`0Aool00?oooooo003ooooo
oooo003oooooo`00ooooooooo`00ooooool00?ooooooool00?oooooo003ooooooooo00000_ooool3
ool00004oooooooo003oo`00ool000?ooooo00?o003oooooool00?l00_ooool2o`00o`Sooooo00Go
003oooooool00?ooooooo`00o`02ooooo`09o`00ooooooooooooooooool00?ooooooo`00oooooooo
003o00Sooooo0_l00?l7ooooo`;o00000oooool0017ooooo00?o0000ooooooooool02Oooool01?l0
0?ooooooooooooooool2o`00o`;ooooo00?o003oooooool00?l01oooool00ol00?ooooooooooo`02
o`00o`?ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`05ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Tooooo`0<o`00oooo003oooooo`00
ooooooooo`00ooooool00?ooooooool00?oooooo003o0_ooool00ol0003o003oo`00o`0<ooooo`07
o`00ooooooooo`00ooooool00?ooooooool00003ooooo`06ool00?oooooo003oo`00oooo003ooooo
0_l00?l00ooo003oooooooooo`02o`00o`06ool00?oooooo003oo`00oooo003ooooo0_l00?l02_oo
003oooooo`00ooooooooo`00ooooool00?ooooooo`00oooo0003ooooo`09ool00?oooooo003ooooo
oooo003oooooo`00ooooooooo`0000?ooooo00Ooo`00oooooooooooo003ooooooooo003ooooo00?o
o`000_ooool3ool000?ooooo0_l00?l2ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`03
ooooo`03o`00oooooooooooo00;o003o0_ooool01ol00?ooooooo`00oooooooo003oooooool00?l0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool01?ooool00ol00?ooooooo`00o`06ooooo`07o`00oooo
ooooooooooooool00?ooooooo`00o`02ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`;o003o0oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o02Kooooo00?o003oool00?ooool00_l00?l01ooo
003oooooo`00ooooooooo`00ooooool00?l00_ooool00ol0003o003oo`00o`0<ooooo`0<o`00oooo
ooooo`00ooooool00?ooooooool00?oooooo003ooooooooo003ooooo0_l00?l01Ooo003ooooooooo
ooooooooo`0000;ooooo0_l00?l01Ooo003oooooo`00ool00?ooo`0000?ooooo00[oo`00ooooool0
0?ooooooool00?oooooo003oooooool00?ooo`000_ooool03_l00?ooo`00ooooool00?ooooooool0
0?oooooo003ooooooooo003oooooo`00ooooooooo`000oooool00ol00?ooo`00ooooo`03ool00003
ooooool00?ooo`0000;oo`000_ooool00ol00?ooooooo`00o`02ooooo`05o`00oooooooo003ooooo
ool00?l01Oooool01Ol00?oooooooooooooooooo003o00Kooooo00?o003oooooool00?l00_ooool2
o`00o`?ooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`04ooooo`03o`00oooooooo003o00;ooooo0_l00?l6ooooo`03o`00oooooooo003o
00;ooooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`04o`00ooooooooooooooooo`;o003o0_ooool00ol00?ooooooooooo`02ooooo`04o`00oooo
ooooooooooooo`;o003o2oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool07oooool01?l00?ooooooool00?ooool2o`00o`07ool00?oooooooooooooo
oooo003oooooo`00o`02ooooo`03o`000?oooooo003o00cooooo00So003ooooooooo003oooooo`00
ooooooooo`00ooooo`;o003o00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo
00;o003o00Koo`00ooooool00?oo003oool00?ooool2o`00o`0;ool00?oooooooooooooooooo003o
ooooo`00oooooooo003oool00?ooool00_l00?l03Ooo003oooooooooooooooooo`00ooooool00?oo
ooooool00?oooooo003ooooooooo00000oooool00ol00?ooo`00ooooo`02ooooo`03ool00?oooooo
003o00?oo`0000Co003oool00?oo003oo`000oooool02ol00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003o00?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`02
o`00o`;ooooo00?o003oooooooooool01oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`04ooooo`03o`00oooooooo003o00;ooooo0_l00?l2ooooo`;o003o1oooool2o`00
o`;ooooo0_l00?l2ooooo`04o`00ooooooooooooooooo`;o003o1?ooool01?l00?ooooooooooool0
0?l3ooooo`;o003o0oooool01?l00?ooooooooooooooool2o`00o`;ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l3ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`0Kooooo`04o`00ooooooooo`00ooooo`;o003o00Ooo`00
oooooooooooo003oool00?oooooo003o00;ooooo00?o0000o`00ooooool03?ooool02?l00?oooooo
ool00?oooooo003ooooooooo003ooooo0_l00?l01_oo003oooooooooooooooooo`00ooooo`;o003o
00?oo`00ooooooooool00_ooool01_oo003oooooo`00ool00?ooo`00ooooo`;o003o00Ooo`00oooo
ool00?ooooooool00?oooooo003o00;ooooo00Woo`00ooooool00?oo003oool00?oooooo003ooooo
oooo00000oooool01Ooo003oooooo`00ooooooooo`0000;ooooo0_l00?l02ooo003oooooo`00oooo
ooooo`00ooooool00?ooooooool00?oooooo003o00?oo`0000co003oool00?oo003oo`00ooooool0
0?ooooooo`00oooooooo003oooooool00?l4ooooo`;o003o0_ooool00ol00?ooooooo`00o`05oooo
o`03o`00oooooooo003o00;ooooo00?o003oooooooooool01oooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00;ooooo0_l00?l2ooooo`;o
003o1oooool2o`00o`;ooooo0_l00?l2ooooo`04o`00ooooooooooooooooo`;o003o0oooool2o`00
o`;ooooo00Co003ooooooooooooooooo0_l00?l7ooooo`;o003o0_ooool2o`00o`?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`;o003o0_ooool2o`00o`?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo01Wooooo00Koo`00oooooooooooo003oool00?ooool2o`00
o`03ool00?oooooooooo00;ooooo00?o0000o`00ooooool03_ooool01_oo003oooooo`00oooooooo
o`00ooooo`;o003o00Koo`00ooooool00?oo003oool00?ooool2o`00o`06ool00?ooooooooooo`00
ooooooooo`000oooool02Ooo003oooooo`00ool00?ooo`00ooooool00?ooooooool00004ooooo`06
ool00?oooooo003ooooooooo003ooooo0_l00?l02Ooo003oooooo`00ooooooooo`00ooooool00?oo
ooooool00002ooooo`;o003o00Goo`00ooooool00?ooooooool00003ooooo`03ool00?oooooo003o
00?oo`0000Ko003oool00?oo003oo`00ooooool00?l3ooooo`05o`00oooooooo003oooooool00?l0
0_ooool02Ol00?oooooooooooooooooo003oooooool00?ooooooo`00o`08ooooo`;o003o2?ooool0
0ol0003oooooooooo`01ooooo`004Oooool2o`0000[ooooo00Co003ooooooooooooooooo0_l00?l2
ooooo`03o`00oooooooo003o00Kooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l3
ooooo`03o`00oooooooooooo00;o003o0oooool00ol00?ooooooooooo`05ooooo`;o003o0oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Gooooo`08o`00ooooooooo`00oooo
ool00?ooooooool00?ooool2o`00o`03ool00?oooooooooo00;ooooo00?o0000o`00ool00?l03?oo
ool01ol00?ooooooool00?oooooo003ooooooooo00000_ooool00ol00?ooo`00ooooo`02o`00o`05
ool00?oooooo003oo`00oooo00000_ooool2o`00o`06ool00?oooooooooooooooooo003ooooo0_l0
0?l02_oo003oooooo`00ooooooooo`00ooooool00?ooooooo`00oooo0003ooooo`09ool00?oooooo
003oo`00oooo003oooooo`00ooooooooo`0000?ooooo00[oo`00oooooooooooo003ooooooooo003o
ooooo`00ooooooooo`000oooool01ooo003oooooooooooooooooo`00ooooool00?l00ooo00003?oo
ooooo`00ool00?oo003oooooo`00oooooooo003oooooool00?ooooooo`00o`Cooooo00Wo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?l01Oooool00ol00?ooooooooooo`05ooooo`;o0000
0oooool0017ooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`04ooooo`;o003o0_oo
ool01Ol00?ooooooo`00oooooooo003o00Gooooo00?o003oooooooooool00_l00?l2ooooo`03o`00
oooooooooooo00;ooooo0_l00?l2ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00So
oooo00?o003oooooooooool00_l00?l3ooooo`03o`00oooooooooooo00Gooooo0_l00?l7ooooo`05
o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`0Booooo`08o`00ooooooooo`00
ooooool00?ooooooool00?ooool2o`00o`03ool00?oooooo003o00;ooooo0ol00?l<ooooo`07o`00
ooooooooo`00ooooool00?ooooooool00003ooooo`05ool00?oooooo003oo`00oooo00000_ooool0
1?l00?ooo`00ooooooooool2o`00o`05ool00?oooooo003oo`00oooo00000oooool02_oo003ooooo
o`00ool00?ooo`00ooooool00?ooooooo`00oooo0002ooooo`0:o`00oooo003oooooo`00oooooooo
o`00ooooool00?ooooooool000?ooooo00koo`00ooooooooooooooooo`00oooo003oooooo`00oooo
ooooo`00ooooool00?ooooooool000?ooooo00Ooo`00ooooool00?ooooooo`00oooo003ooooo00?o
o`000_ooool3ool00005o`00ooooooooooooooooool00?l00_ooool02ol00?oooooooooooooooooo
003oooooool00?ooooooo`00oooooooo003o00?ooooo00?o003oooooooooool01_ooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooo003o00?ooooo
00?o003oooooooooool01?ooool01ol00?ooooooo`00oooooooo003oooooool00?l00_ooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oooooooooooooo
ool2o`00o`;ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooooooool2o`00o`_ooooo
00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l04?ooool0
1?l00?ooooooool00?ooool2o`00o`07ool00?oooooooooooooooooo003oooooo`00o`02ooooo`03
o`000?oooooo003o00?ooooo00?o003oooooooooool01_ooool02ol00?ooooooool00?oooooo003o
oooooooo003oooooo`00ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002ooooo`04
o`00ooooooooo`00ooooo`;o003o00Goo`00ooooooooooooooooool00003ooooo`07ool00?oooooo
003oooooool00?ooo`00ooooo`02o`00o`0=ool00?oooooooooooooooooo003oooooo`00oooooooo
o`00ooooool00?ooooooool00003ooooo`03o`00oooo003ooooo00;ooooo00Woo`00ooooool00?oo
ooooool00?oooooo003ooooooooo00000oooool00ol00?ooo`00ooooo`03ool000;ooooo0ooo0000
1Ol00?ooo`00ool00?oo003o003o00Kooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;o
oooo0_l00?l8ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo
00Oo003oooooool00?ooooooo`00oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?ooooooo`00oooooooo003o00;ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`03o`00oooo
oooooooo00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0oooool2o`00o`;ooooo
00?o003oooooooooool01_ooool01?l00?ooooooooooooooool2o`00o`?ooooo00Go003ooooooooo
ooooooooo`00o`07ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0@
ooooo`04o`00ooooooooo`00ooooo`;o003o00Ooo`00oooooooooooo003oool00?oooooo003o00;o
oooo00?o0000ooooool00?l00oooool00ol00?ooooooooooo`06ooooo`0;o`00ooooooooo`00oooo
ool00?ooooooool00?oooooo003ooooooooo00000oooool01Ooo003oooooo`00ool00?ooo`0000Co
oooo00Koo`00ooooool00?oo003oool00?ooool2o`00o`0;ool00?oooooooooooooooooo003ooooo
o`00oooooooo003oool00?ooool00_l00?l01Ooo003oooooooooool00?ooo`0000?ooooo00Goo`00
ooooool00?ooooooool00002ooooo`;o003o00goo`00ooooool00?oo003oool00?oooooo003ooooo
oooo003oooooo`00ooooooooo`0000?ooooo00So003oool00?oooooo003ooooooooo003oooooo`00
o`?oo`0000Goooooool00?oo003oo`00o`00o`02ooooo`03o`00oooooooo003o00?ooooo00Go003o
ooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool01?ooool01ol00?ooooooo`00oooooooo003oooooool00?l0
0_ooool2o`00o`Kooooo00?o003oooooool00?l00_ooool2o`00o`;ooooo00Co003ooooooooooooo
oooo0_l00?l4ooooo`04o`00ooooooooooooo`00o`?ooooo0_l00?l2ooooo`03o`00oooooooooooo
00;ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo00Co003ooooooooooooooooo0_l00?l2
ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool03?ooool01_oo003ooooo
o`00ooooooooo`00ooooo`;o003o00?oo`00ooooooooool00_ooool00ol00?ooooooooooo`0>oooo
o`0:ool00?oooooo003ooooooooo003oooooo`00ooooooooo`00ooooo`;o003o00Goo`00ooooool0
0?oo003oool00004ooooo`06ool00?oooooooooooooooooo003ooooo0_l00?l01Ooo003oooooo`00
ool00?ooo`0000Cooooo00Koo`00ooooool00?oo003oool00?ooool2o`00o`09ool00?oooooooooo
oooooooo003oooooo`00ooooooooo`0000;ooooo0_l00?l03ooo003oooooo`00ool00?ooo`00oooo
ool00?ooooooool00?oooooo003ooooooooo003oooooo`00o`02ooooo`09ool00?oooooo003ooooo
oooo003oooooo`00ooooooooo`0000;ooooo0ooo00002?ooooooo`00ool00?oo003oooooo`00oooo
oooo003o1Oooool01Ol00?ooooooo`00oooooooo003o00Sooooo00?o0000ooooooooool00Oooool0
017ooooo0_l00009ooooo`03o`00oooooooo003o00;ooooo0_l00?l2ooooo`03o`00oooooooo003o
00Kooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo00?o003oooooool00?l00oooool00ol0
0?ooooooooooo`02o`00o`Oooooo00Co003ooooooooooooooooo0_l00?l2ooooo`;o003o0oooool0
1Ol00?oooooooooooooooooo003o00?ooooo0_l00?l2ooooo`;o003o0oooool01Ol00?oooooooooo
oooooooo003o00?ooooo0_l00?l7ooooo`03o`00oooooooooooo00cooooo00Koo`00oooooooooooo
ooooool00?ooool2o`00o`03ool00?oooooooooo00;ooooo00?o003oooooool00?l00oooool00ol0
0?ooooooooooo`08ooooo`0:ool00?oooooo003ooooooooo003oooooo`00ooooooooo`00ooooo`;o
003o00Goo`00ooooool00?oo003oool00002ooooo`03o`00ooooooooo`0000?ooooo00Koo`00oooo
ool00?oo003oool00?ooool2o`00o`0;ool00?ooooooooooo`00ooooooooo`00ooooool00?oooooo
ool00?ooool00_l00?l01Ooo003oooooo`00ooooooooo`0000?ooooo00Ooo`00oooooooooooo003o
oooooooo003ooooo00;o003o00_oo`00ooooooooooooooooool00?oooooo003ooooooooo003ooooo
o`00o`02ooooo`0=ool00?oooooooooooooooooo003oooooo`00ooooooooo`00ooooool00?oooooo
ool00002ooooo`?oo`0000Koooooool00?oo003oo`00ooooool00?l5ooooo`03o`00oooooooo003o
00Oooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00Co
oooo0_l00?l2ooooo`03o`00oooooooo003o00Oooooo00?o003oooooooooool00_l00?l2ooooo`07
o`00ooooooooooooooooool00?ooooooo`00o`02ooooo`;o003o0oooool00ol00?ooooooooooo`02
o`00o`Oooooo0_l00?l2ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l0
0?l2ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool01_ooool02?l00?oo
ooooool00?oooooo003ooooooooo003ooooo0_l00?l00ooo003oooooo`00o`02ooooo`03o`00oooo
oooo003o00?ooooo00?o003oooooooooool01_ooool01ol00?ooooooool00?oooooo003ooooooooo
00000oooool01_oo003oooooo`00ool00?ooo`00ooooo`;o003o00Ooo`00oooooooooooo003ooooo
oooo003ooooo00;o003o00Koo`00ooooooooooooooooool00?ooool2o`00o`06ool00?oooooo003o
o`00ooooooooo`000_ooool01ol00?ooo`00ooooool00?ooooooool00?ooool00_l00?l01Ooo003o
ooooooooooooooooo`0000;ooooo00_o003ooooooooo003oooooo`00ooooooooo`00ooooool00?oo
ooooool00003ooooo`06ool00?oooooo003oooooool00?ooo`000_ooool00ol00?ooo`00ooooo`02
ooooo`07ool00?oooooo003ooooooooo003oooooo`00o`03ool0000:oooooooo003oo`00ool00?oo
oooo003oooooool00?ooooooo`00o`?ooooo00?o003oooooooooool01_ooool00ol0003ooooooooo
o`01ooooo`002_ooool2o`0000Gooooo00?o0000ooooooooool01?ooool00ol00?ooooooo`00o`03
ooooo`03o`00oooooooooooo00Cooooo00Oo003oooooool00?ooooooo`00oooooooo003o00Oooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`;o003o1_ooool2o`00o`;ooooo
00?o003oooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`;o003o1?ooool01?l00?oo
ooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Sooooo
00go003ooooooooo003oooooo`00ooooooooo`00ooooool00?ooooooool00?oooooo003o00;ooooo
00?o0000ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00co003ooooooooo
003oooooo`00ooooooooo`00ooooool00?ooooooool00?ooool2o`00o`05ool00?oooooooooooooo
oooo00000_ooool01?l00?ooooooool00?ooool2o`00o`05ool00?oooooooooooooooooo00000_oo
ool00ol00?ooo`00ooooo`02o`00o`03oooooooo003ooooo00;o003o00Koo`00oooooooooooooooo
ool00?ooool2o`00o`05ool00?oooooo003ooooooooo00000oooool00ol00?ooo`00ooooo`02oooo
o`09ool00?oooooo003ooooooooo003oooooo`00ooooooooo`0000?ooooo00?o003oool00?ooool0
0_l00?l02ooo003oooooooooooooooooo`00ooooool00?ooooooool00?oooooo003o00;ooooo00?o
o`00oooooooo00000_oo00000ooooooo003oool00002ool00005o`00oooooooo003oooooool00?l0
2?ooool00ol0003oooooooooo`01ooooo`002Oooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00Cooooo00Oo003oooooool00?ooooooo`00oooooooo003o00Sooooo00Oo003ooooo
ool00?ooooooo`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`07ooooo`;o003o
0_ooool01?l00?ooooooooooooooool2o`00o`;ooooo00?o003oooooool00?l00_ooool00ol00?oo
ooooooooo`05ooooo`;o003o0oooool2o`00o`Kooooo0_l00?l7ooooo`04o`00oooooooooooooooo
o`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool01_ooool0
1ol00?ooooooool00?oooooo003ooooooooo00000oooool00ooo003oooooo`00o`02ooooo`03o`00
0?oooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`0<o`00ooooooooooooool0
0?oooooo003ooooooooo003oooooo`00ooooooooo`000oooool01Ooo003oooooo`00ooooooooo`00
00;ooooo00So003ooooooooo003oooooo`00ooooooooo`00ooooo`;o003o00Koo`00oooooooooooo
ooooool00?ooool2o`00o`03oooooooo003ooooo00;o003o00Goo`00oooooooooooo003oool00003
ooooo`05ool00?oooooo003ooooooooo00000_ooool2o`00o`0=ool00?ooooooooooo`00oooo003o
ooooo`00ooooooooo`00ooooool00?ooooooool00003ooooo`03o`00oooo003ooooo00;o003o00Go
o`00ooooool00?ooooooool00003ooooo`03ool00?oooooo003o00;ooooo00Ooo`00ooooool00?oo
ooooool00?oooooo003o00?oo`0000Co003oool00?oo003oo`002Oooool00ol0003oooooooooo`01
ooooo`002Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00_o003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`06ooooo`07o`00oooooooo003o
ooooool00?ooooooo`00o`02ooooo`04o`00ooooooooooooooooo`;o003o1?ooool00ol00?oooooo
o`00o`04ooooo`;o003o0_ooool01ol00?oooooooooooooooooo003oooooool00?l00_ooool2o`00
o`;ooooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo0_l00?l3ooooo`03o`00oooooooooooo
00;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`03ooooo`06ool00?oooooo003ooooooooo003ooooo0_l00?l00ooo003oooooo`00o`03ool000Go
oooo00Go003oooooooooooooooooo`00o`06ooooo`0>ool00?oooooo003ooooooooo003oooooo`00
ooooooooo`00ooooool00?ooooooool00?ooool2o`00o`03ool00?oooooooooo00;ooooo00Koo`00
ooooool00?ooooooool00?ooool2o`00o`05ool00?oooooo003oo`00oooo00001?ooool01_oo003o
ooooo`00ool00?ooo`00ooooo`;o003o00Woo`00oooooooooooo003oool00?oooooo003ooooooooo
00000_ooool2o`00o`06ool00?oooooo003oo`00oooo003ooooo0_l00?l04_oo003oooooo`00oooo
ooooo`00ooooool00?ooooooo`00oooo003oooooo`00ooooooooo`00ooooool00?ooooooool000?o
oooo00[oo`00ooooool00?ooooooo`00oooo003oooooo`00ooooooooo`000_ooool3ool00005o`00
oooo003oo`00ool00?ooool00ooo0005ooooo`03o`000?oooooooooo007ooooo0009ooooo`04o`00
0?ooooooooooo`0000Cooooo1ol000003_l00?oo0000o`000?l0003oo`00o`000?l00?oo0000ool0
0?l0003o003oo`000?oo003o003o0ol000002_oo003o0000o`00ool0003oo`00o`000?l00?oo0000
ool00?l00?l2o`000003ool00?l00?oo003o00;o000000Woo`00o`000?l00?oo0000ool00?l0003o
003oo`000?oo00000_l00?l00ol0003oo`00o`000003o`000005ool00?l0003o003oo`000?oo0000
0_l00?l01ol0003oo`00o`00ool00?oo0000ool00?l00?l00_l000000ooo003o0000o`00o`02o`00
0005ool00?l00?oo003oo`000?oo00000_l00?l02?l0003oo`00o`00ool00?oo0000ool00?l0003o
003o0_l000004_oo003o003oo`000?l0003oo`00o`000?l00?oo0000ool00?l0003o003oo`000?oo
003o0000o`00ool0003oo`00o`0000;o003o00?o0000ool00?l000000_l000001_oo003o0000o`00
ool0003oo`00o`0000;o003o00?oo`00o`000?l000000ooo0003o`000009ool00?l0003o0000o`00
0?oo003o0000o`00ool0003oo`0000Co000000koo`00o`000?l00?oo0000ool00?l0003o003oo`00
0?oo003o0000o`00ool0003oo`00o`0000;o003o00Koo`00o`000?l0003o003oo`000?oo0003o`00
0006ool00?l0003o003oo`00oooo003o00000_l00?l00ooo003o0000o`000002o`000006ool00?l0
003o003oo`000?oo003o00000_l00?l01_oo003o0000o`00ool00?ooo`00o`0000;o003o00Ooo`00
o`000?l0003o003oo`000?oo003o000000;o003o00_oo`00o`000?l0003o003oool00?l0003o003o
o`000?oo003o0000o`00o`02o`00000=ool00?l0003o0000o`000?oo003o0000o`00ool0003oo`00
o`000?l00?oo0000ool00003o`000006o`00oooo003o0000o`00ool0003oo`000ol000000ooo003o
0000o`000003ool00004o`00oooo003oo`00ool000Ko00000oooool000Wooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`07ooooo`?oo`000_ooool02_oo003oooooo`00oooooooo
o`00o`00oooooooo003ooooooooo0003ooooo`05ool00?oooooo003ooooooooo00000_l00?l00ooo
ooooo`00o`00o`03ooooo`0?ool00?oooooo003ooooooooo003oooooo`00ooooooooo`00ooooool0
0?ooooooool00?oooooo003o00;ooooo00Goo`00ooooooooooooooooool00002o`00o`0<oooooooo
003o003oo`00ooooooooo`00ooooool00?ooooooool00?oooooo003o0_ooool01_oo003o003oo`00
ooooooooo`00o`00o`;ooooo00Ooo`00o`00ool00?ooooooool00?oooooo003o00;ooooo00Koo`00
o`00ool00?ooooooool00?l00?l2ooooo`0:ool00?oooooo003ooooooooo003oooooo`00oooooooo
o`00ooooo`;o003o00Coooooool00?oooooo003o0oooool01?l00?ooooooooooooooool2o`00o`;o
oooo00So003oool00?oo003oo`00ooooool00?ooooooool000;o003o00Soooooool00?oooooo003o
oooooooo003oooooo`00o`Cooooo00?o003oooooooooool01Oooool01?l00?ooooooooooooooool2
o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0_ooool2o`00o`;ooooo0_l0
0?l7ooooo`;o003o0_ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o
0oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo003oooooool00?l00oooool01?l00?oo
ooooooooool00?l3ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`;o003o0_oo
ool00ol00?ooooooo`00o`05ooooo`04o`00oooo003oo`00ool000Gooooo00?o0000ooooooooool0
0Oooool000Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`06ooooo`05o`00
oooo003oo`00ool00?ooool00ooo0002ooooo`0Cool00?l00?ooooooo`00ooooooooo`00ooooool0
0?ooooooool00?oooooo003ooooooooo003oooooo`00ooooooooo`00o`00o`03ooooo`0=ool00?oo
oooo003ooooooooo003oooooo`00ooooooooo`00ooooool00?ooooooool00002o`00o`;ooooo00Wo
o`00ooooool00?ooooooool00?oooooo003ooooooooo00000_l00?l01_ooooooo`00ooooool00?oo
ooooool000;ooooo00Co003ooooooooo003o003o0_ooool01Ooo003oooooooooooooooooo`0000;o
003o00Coooooool00?oooooo003o0_ooool01Ooo003oooooo`00ooooooooo`0000;o003o00?ooooo
ool00?ooool00_ooool01_oo003oooooo`00ooooooooo`00ooooo`;o003o00Coooooool00?oooooo
003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00So003oooooool00?oo0000ooooool0
0?ooooooool000;o003o00Soooooool00?oooooo003ooooooooo003oooooo`00o`Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Kooooo00Go003ooooooooooooooooo
o`00o`07ooooo`;o003o0_ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o
003o0_ooool2o`00o`Cooooo00?o003oooooooooool01?ooool2o`00o`Cooooo00Go003oooooool0
0?ooooooo`00o`02ooooo`;o003o1_ooool01Ol00?oooooooooooooooooo003o00Gooooo00So003o
oooooooooooo003oooooool00?ooooooo`00o`?ooooo00?o003oooooooooool01_ooool00ol0003o
ooooooooo`01ooooo`002_ooool2o`0000Gooooo00?o0000ooooooooool01_ooool01Ol00?ooo`00
ool00?oo003o003o00?oo`000_ooool02_oo003o003oooooool00?ooooooool00?oooooo003ooooo
oooo0003ooooo`07ool00?oooooo003ooooooooo003oooooo`00o`02ooooo`0:ool00?oooooooooo
oooooooo003oooooo`00ooooooooo`00o`00o`;ooooo00?oo`00o`00ool00?l00_ooool01Ooo003o
ooooo`00ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002o`00o`07oooooooo003o
ooooooooool00?ooooooool00003ooooo`06ool00?oooooo003ooooooooo003o003o0_ooool00ooo
003oooooo`00o`02ooooo`05ool00?oooooo003ooooooooo00000_l00?l03?ooooooo`00ooooool0
0?ooooooool00?oooooo003ooooooooo003oooooo`00o`;ooooo00?oo`00ooooool00?l00oooool0
0ol00?ooooooooooo`05ooooo`08o`00ooooooooooooo`000?oooooo003ooooooooo0002o`00o`08
oooooooo003oooooo`00ooooooooo`00ooooool00?l8ooooo`03o`00oooooooooooo00[ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Gooooo0_l00?l3ooooo`03o`00
oooooooooooo00;ooooo00Co003ooooooooooooo003o0oooool2o`00o`Cooooo00Go003ooooooooo
ooooooooo`00o`02ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`03ooooo`03o`00oooo
oooooooo00;o003o0_ooool2o`00o`;ooooo00Go003oooooooooooooooooo`00o`08ooooo`07o`00
oooooooo003oooooool00?ooooooo`00o`03ooooo`03o`00oooooooooooo00Cooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool01_ooool01Ol00?ooooooo`00oooooooo003o
00?oo`0000Co003oool00?oo003oo`000oooool02Ooo003oooooo`00ooooooooo`00ooooool00?oo
ooooool00003ooooo`03ool00?l00?oo003o00;ooooo00Goo`00ooooool00?ooooooool00003oooo
o`05ool00?l00?oo003ooooooooo00000_l00?l2ooooo`05ool00?oooooo003ooooooooo00000ooo
ool01Ooo003oooooo`00ooooooooo`0000;o003o00_oooooool00?l00?ooooooo`00ooooooooo`00
ooooool00?ooooooool00002o`00o`08oooooooo003oooooo`00ooooooooo`00ooooool00?l2oooo
o`05ool00?l00?oooooooooooooo00000_l00?l02_ooooooo`00ooooool00?ooooooool00?oooooo
003ooooooooo0004ooooo`03ool00?oooooo003o00Oooooo00So003oooooooooooooooooo`00oooo
oooo003oo`0000?ooooo00_oo`00ooooool00?ooooooool00?oooooo003ooooooooo003oooooo`00
o`08ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooooooooooooooo
o`;o003o1_ooool00ol00?ooooooooooo`02ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2oooo
o`07o`00ooooooooooooooooool00?ooooooo`00o`02ooooo`;o003o0_ooool2o`00o`Cooooo00Go
003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00?ooooo00Go003oooooool00?oo
ooooo`00o`03ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00Oooool0017ooooo
0_l00009ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`03ool0000<oooooooo003oo`00
ool00?oooooo003ooooooooo003oooooo`00ooooooooo`000oooool00ooo003o003oo`00o`02oooo
o`05ool00?oooooo003ooooooooo00000oooool01Ooo003oooooo`00ooooooooo`0000Cooooo00Wo
o`00ooooool00?ooooooool00?oooooo003ooooooooo00000_l00?l00oooooooo`00o`00o`02oooo
o`06ool00?l00?ooooooo`00ooooooooo`000_l00?l01_ooooooo`00o`00ool00?ooooooool000;o
003o00Coooooool00?oooooo003o0_ooool02Ooo003o003oooooooooooooo`00ooooool00?oooooo
ool00002o`00o`07oooooooo003oooooo`00ooooooooo`00ooooo`02o`00o`03oooooooo003ooooo
00Sooooo00?o003oooooooooool00oooool00ol00?oo0000ooooo`02ooooo`09ool00?oooooooooo
oooooooo003oooooo`00ooooooooo`0000kooooo00Go003oooooooooooooooooo`00o`04ooooo`03
o`00oooooooooooo00Gooooo00Co003ooooooooooooooooo0_l00?l7ooooo`04o`00oooooooooooo
ooooo`;o003o0_ooool2o`00o`;ooooo00?o003oooooooooool00_ooool2o`00o`;ooooo0_l00?l3
ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool01_ooool2o`00o`;ooooo00?o
003oooooool00?l00oooool00ol00?ooooooooooo`02o`00o`Sooooo00Go003oooooool00?oooooo
o`00o`05ooooo`;o00000oooool0017ooooo00?o0000ooooooooool02?ooool01ol00?oooooooooo
oooooooo003oooooool00?l00ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000[oooooo`00
ooooooooo`00ooooool00?ooooooool00?oooooo003o0_ooool03ooo003oooooo`00ooooooooo`00
ooooool00?ooooooool00?oooooo003ooooooooo003oooooo`00o`02ooooo`09ool00?oooooooooo
oooooooo003oooooo`00ooooooooo`0000;o003o00Ooooooool00?oooooo003ooooooooo003o003o
00?ooooo00Koo`00o`00ool00?ooooooool00?l00?l2ooooo`07ool00?l00?oo003ooooooooo003o
ooooo`00o`02ooooo`06ool00?l00?oo003ooooooooo003o003o0_ooool02_oo003oooooo`00oooo
ooooo`00ooooool00?ooooooool00?ooool2o`00o`03oooooooo003o003o00Sooooo00?o003ooooo
ooooool00oooool01ol00?oo0000ooooool00?ooooooool00?l00?l00_ooool01ooo003oooooo`00
ooooooooo`00ooooool00?l03?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o0_ooool2o`00o`Oooooo0_l0
0?l2ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l3ooooo`05o`00
ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00
o`?ooooo00?o003oooooool00?l00oooool00ol00?ooooooooooo`02o`00o`;ooooo0_l00?l6oooo
o`03o`00oooooooooooo00Kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool01_ooool00ol00?ooooooooooo`03ooooo`05o`00oooooooo003oooooool00?l00_ooool3ool0
000<oooooooo003oo`00ool00?oooooo003ooooooooo003oooooo`00ooooooooo`001?ooool03Ooo
003oooooo`00ooooooooo`00ooooool00?ooooooool00?oooooo003ooooooooo00000_l00?l2oooo
o`09ool00?oooooooooooooooooo003oooooo`00ooooooooo`0000;o003o00Koooooool00?oooooo
003ooooooooo0002ooooo`07o`00ooooooooo`00ooooool00?ooooooool00003ooooo`05ool00?l0
0?oo003ooooooooo00000_l00?l2ooooo`06ool00?oooooo003ooooooooo003o003o0_ooool02_oo
003oooooo`00ooooooooo`00ooooool00?ooooooool00?ooool2o`00o`03oooooooo003o003o00So
oooo00co003oooooooooooooooooo`00oooooooo003oo`000?oooooo003ooooooooo0002o`00o`08
oooooooo003oooooo`00ooooooooo`00ooooool00?l@ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`07ooooo`;o003o0_ooool2o`00o`?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooo
oooooooooooo0_l00?l3ooooo`06o`00ooooooooooooo`00oooooooo003o0_ooool2o`00o`Kooooo
00Oo003oooooooooooooooooo`00oooooooo003o00?ooooo00?o003oooooooooool00_l00?l2oooo
o`05o`00ooooooooooooooooool00?l02?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`06ooooo`05o`00oooooooo003oooooool00?l01Oooool01ol00?ooooooooooool0
0?ooooooo`00ooooool00ooo0002ooooo`?oo`0000Go003ooooooooo003oooooo`00o`02ooooo`09
ool00?oooooooooooooooooo003oooooo`00ooooooooo`0000?ooooo00?oo`00o`00ool00?l00_oo
ool01Ooo003oooooo`00ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002o`00o`07
oooooooo003oooooooooool00?ooooooool00003ooooo`06ool00?oooooo003ooooooooo003o003o
0_ooool00ooo003o003oo`00o`02ooooo`05ool00?oooooo003ooooooooo00000_l00?l00ooooooo
o`00o`00o`02ooooo`07ool00?oooooo003ooooooooo003oooooo`00o`02ooooo`03ool00?l00?oo
oooo00_ooooo00So003ooooooooooooo0000ooooool00?ooooooool000;o003o00Soooooool00?oo
oooo003ooooooooo003oooooo`00oaGooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00Gooooo0_l00?l3ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo
oooo0_l00?l3ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooooooo0_l00?l4oooo
o`03o`00oooooooooooo00;o003o0oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool00_l00?l2ooooo`07o`00oooooooo003oooooool00?oooooo
o`00o`06ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Kooooo00Go
003oooooool00?ooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo0_l00?l2ooooo`03o`00
oooooooo003o00;ooooo0ooo00001Ol00?ooo`00ool00?oo003o003o00;ooooo00Goo`00oooooooo
ooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_l00?l2ooooo`05ool00?oooooo
003ooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;o003o00_oooooool00?l00?oo
ooooo`00ooooooooo`00ooooool00?ooooooool00002o`00o`03oooooooo003ooooo00;ooooo00?o
o`00o`00ooooool00_ooool01Ooo003o003oo`00ooooooooo`0000;o003o00[oooooool00?l00?oo
003ooooooooo003oooooo`00ooooooooo`001?ooool00ooo003o003oooooo`0;ooooo`08o`00oooo
oooo003oo`000?oooooo003ooooooooo0002o`00o`08oooooooo003oooooo`00ooooooooo`00oooo
ool00?lIooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`02ooooo`04o`00oooooooooooo
ooooo`;o003o0_ooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooooooo
0_l00?l2ooooo`;o003o0oooool01_l00?ooooooooooool00?ooooooo`00o`;ooooo00Co003ooooo
oooooooooooo0_l00?l2ooooo`03o`00oooooooo003o00?ooooo00?o003oooooooooool01?ooool0
0ol0003oooooooooo`01ooooo`004Oooool2o`0000Oooooo00Wo003oooooool00?ooooooo`00oooo
oooo003oooooool00?l01Oooool02?l00?ooooooooooool00?ooooooo`00oooooooo003o0ooo0000
1Oooooooo`00ool00?oo003o003o00;ooooo00Goo`00ooooool00?ooooooool00003ooooo`06ool0
0?oooooo003ooooooooo003o003o0oooool03_oo003oooooo`00ooooooooo`00ooooool00?oooooo
ool00?oooooo003ooooooooo003o003o0_ooool02_oo003o003oooooool00?ooooooool00?oooooo
003ooooooooo0002o`00o`06oooooooo003oooooo`00ooooooooo`000_l00?l2ooooo`09ool00?l0
0?oooooooooooooo003oooooo`00ooooooooo`0000;o003o00Ooooooool00?oooooo003ooooooooo
003ooooo00;o003o00?oooooool00?ooool03_ooool00ol00?oo0000ooooo`02ooooo`06ool00?oo
oooooooooooooooo003o003o0_ooool00ooo003oooooo`00o`0Mooooo`05o`00oooooooooooooooo
ool00?l02?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?oo
ool01?l00?ooooooooooooooool2o`00o`;ooooo0_l00?l2ooooo`05o`00ooooooooooooooooool0
0?l01?ooool01?l00?ooooooooooooooool2o`00o`?ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02o`00o`Kooooo00Oo003oooooool00?ooooooo`00oooooooo003o00Gooooo0_l0
0003ooooo`004Oooool00ol0003oooooooooo`07ooooo`0:o`00ooooooooooooo`00oooooooo003o
ooooool00?ooooooo`00o`;ooooo00?o003oooooooooool00oooool01ol00?ooooooo`00oooooooo
003oooooool00?l00ooo00004?l00?ooo`00ool00?oo003oooooo`00ooooooooo`00ooooool00?oo
ooooool00?oooooo003ooooooooo0004ooooo`0>ool00?oooooooooooooooooo003oooooo`00oooo
ooooo`00ooooool00?ooooooool00?l00?l2ooooo`03ool00?l00?oooooo00;ooooo00Goo`00oooo
ool00?ooooooool00002o`00o`08oooooooo003o003oo`00ooooooooo`00ooooool00?l2ooooo`05
ool00?l00?oo003ooooooooo00000oooool01_oo003o003oo`00ooooooooo`00o`00o`;ooooo00Ko
o`00ooooool00?oo003ooooooooo000>ooooo`08o`00oooooooo0000ooooool00?ooooooool00?l0
0?l2ooooo`07ool00?oooooo003ooooooooo003oooooo`00o`0Mooooo`05o`00oooooooooooooooo
ool00?l00oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02o`00o`;ooooo00?o003oooooooooool01_ooool2o`00o`;ooooo0_l00?l4ooooo`03o`00oooo
oooooooo00;o003o0_ooool2o`00o`Cooooo00Go003oooooool00?ooooooo`00o`06ooooo`03o`00
0?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool00ooo
ool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool01Oooool01ol00?oooooo
o`00oooooooo003oooooool00?l00_ooool3ool0000>oooooooo003oo`00ool00?oooooo003ooooo
oooo003oooooo`00ooooooooo`00ooooool00?l2ooooo`0Bool00?oooooooooooooooooo003ooooo
o`00ooooooooo`00ooooool00?ooooooool00?oooooo003ooooooooo003o003o0oooool01_oo003o
ooooo`00ooooooooo`00o`00o`;ooooo00Ooo`00o`00ool00?ooooooool00?oooooo003o00;ooooo
00Koo`00o`00ool00?ooooooool00?l00?l2ooooo`05ool00?oooooo003ooooooooo00000_l00?l0
0oooooooo`00ooooo`02o`00o`03oooooooo003o003o00cooooo0_l00?l01_oooooo0000ooooool0
0?ooooooool000;o003o00Koooooool00?l00?oo003ooooooooo000Sooooo`04o`00oooooooooooo
ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l3ooooo`05o`00oooo
ooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00o`?ooooo00?o003ooooooooo
ool00_l00?l3ooooo`;o003o1_ooool2o`00o`;ooooo00?o003oooooool00?l00_ooool2o`00o`;o
oooo0_l00?l2ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`06ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol0
0?ooooooooooo`02o`00o`;ooooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`02oooo
o`?oo`0000Koooooool00?oo003oo`00ooooool00?l3ool000;ooooo00?oo`00ooooool00?l00_oo
ool02Ooo003oooooo`00ooooooooo`00ooooool00?ooooooool00003ooooo`05ool00?l00?oo003o
oooooooo00000_ooool00ol00?ooooooool00003ooooo`06ool00?oooooo003ooooooooo003o003o
0_ooool00ooo003o003oo`00o`02ooooo`05ool00?oooooo003ooooooooo00000_l00?l00ooooooo
o`00o`00o`02ooooo`06ool00?oooooo003ooooooooo003ooooo0_l00?l00oooooooo`00o`00o`0<
ooooo`08o`00ooooooooooooo`000?oooooo003ooooooooo0002o`00o`08oooooooo003o003oo`00
ooooooooo`00ooooool00?lQooooo`04o`00ooooooooooooooooo`;o003o0oooool00ol00?oooooo
ooooo`05ooooo`04o`00ooooooooooooooooo`;o003o0oooool00ol00?ooooooooooo`05ooooo`04
o`00ooooooooooooooooo`;o003o0oooool01?l00?ooooooooooooooool2o`00o`?ooooo00Co003o
oooooooooooo003o0oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;o003o0_oo
ool2o`00o`;ooooo00?o003oooooool00?l01_ooool00ol0003oooooooooo`01ooooo`004Oooool0
0ol0003oooooooooo`06ooooo`;o003o0_ooool00ol00?ooooooooooo`06ooooo`;o003o0_ooool0
0ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l01?ooool3ool00003ooooool0
0?ooo`0000;oo`000_ooool00ooo003oooooo`00o`02ooooo`05ool00?oooooo003ooooooooo0000
0oooool01Ooo003oooooooooooooooooo`0000;o003o00Ooooooool00?l00?ooooooo`00oooooooo
o`0000?ooooo00Goo`00ooooool00?ooooooool00003ooooo`03ool00?l00?oooooo00;ooooo00Go
o`00ooooool00?ooooooool00002o`00o`03oooooooo003o003o00;ooooo00Goo`00o`00ool00?oo
ooooool00004ooooo`03ool00?l00?oooooo00_ooooo00So003ooooooooooooo0000ooooool00?oo
ooooool000;o003o00?oooooool00?l00?l00_ooool00ooo003oooooo`00o`0Uooooo`;o003o0ooo
ool01Ol00?oooooooooooooooooo003o00Oooooo0_l00?l3ooooo`05o`00ooooooooooooooooool0
0?l00oooool01?l00?ooooooooooooooool2o`00o`?ooooo00Co003ooooooooooooooooo0_l00?l2
ooooo`;o003o0oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooooooo`;o003o
0_ooool2o`00o`Cooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`004Ooo
ool2o`0000Oooooo0_l00?l2ooooo`05o`00oooooooo003oooooool00?l01Oooool02_l00?oooooo
ooooool00?ooooooo`00oooooooo003oooooool00?l5ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooool00?l00_ooool3ool00004o`00oooo003oo`00ool000?ooooo00goo`00ooooool00?oo
ooooool00?oooooo003ooooooooo003oooooo`00ooooooooo`0000?ooooo01?oo`00o`00oooooooo
003ooooooooo003oooooo`00ooooooooo`00ooooool00?ooooooool00?oooooo003ooooooooo003o
003o00?ooooo00Woo`00ooooooooooooooooool00?oooooo003ooooooooo00000_l00?l01ooooooo
o`00o`00ool00?ooooooool00?ooool00_l00?l00oooooooo`00ooooo`0<ooooo`;o003o00?ooooo
o`000?ooool00_ooool01_oo003oooooo`00ooooooooo`00o`00o`;ooooo00?oo`00ooooool00?l0
:_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l00oooool2o`00o`;ooooo00Co003ooooooooooooooooo0_l0
0?l3ooooo`04o`00ooooooooooooooooo`;o003o0oooool00ol00?ooooooooooo`02o`00o`?ooooo
00?o003oooooooooool01Oooool2o`00o`Cooooo00?o003oooooooooool00oooool2o`0000?ooooo
000Aooooo`03o`000?oooooooooo00Oooooo00[o003ooooooooooooo003oooooool00?ooooooo`00
oooooooo003o1_ooool2o`00o`;ooooo00?o003oooooool00?l00oooool01Ol00?ooooooo`00oooo
oooo003o00;ooooo00Wo003oooooooooooooooooo`00oooooooo003oooooool00?l00ooo00004?oo
ooooo`00ool00?oo003oooooo`00ooooooooo`00ooooool00?ooooooool00?oooooo003ooooooooo
0003ooooo`03ool00?l00?oooooo00;ooooo00Woo`00ooooool00?ooooooool00?oooooo003ooooo
oooo00000_l00?l01?ooooooo`00ooooool00?l2ooooo`09ool00?oooooooooooooooooo003ooooo
o`00ooooooooo`0000;o003o00?oooooool00?l00?l00_ooool01_oo003oooooo`00ool00?oooooo
ool000kooooo00?o003oooooool000000oooool02ooo003oooooooooooooooooo`00ooooool00?oo
ooooool00?oooooo003o02[ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooooooo
ooooooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0
0_l00?l2ooooo`03o`00oooooooooooo00Kooooo0_l00?l2ooooo`;o003o0oooool01?l00?oooooo
ooooooooool2o`00o`Oooooo00Ko003ooooooooooooo003oooooool00?l6ooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo00Oooooo00Go003oooooooooooooooooo`00o`02
ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool01Oooool01ol00?ooooooo`00oooo
oooo003oooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`05o`00oooooooooooooooo
ool00?l00ooo00001?l00?ooo`00ool00?oo0003ooooo`0>ool00?oooooo003ooooooooo003ooooo
o`00ooooooooo`00ooooool00?ooooooool00?l00?l3ooooo`05ool00?oooooo003ooooooooo0000
0oooool01ooo003o003oo`00ooooooooo`00ooooool00?l00_ooool01_oo003oooooo`00oooooooo
o`00o`00o`;ooooo00Goo`00ooooool00?ooooooool00002o`00o`08oooooooo003o003oooooool0
0?ooooooool00?l00?l<ooooo`;o003o00koooooo`000?oooooo003ooooooooo003oooooo`00oooo
ooooo`00ooooool00?ooooooool0033ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003ooooo
ooooool00_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`;ooooo0_l00?l3
ooooo`;o003o0_ooool2o`00o`Kooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02o`00o`;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooo003o00?ooooo00So003ooooooooooooo003oooooool00?ooooooo`00o`?o
oooo00Go003oooooool00?ooooooo`00o`03ool0000@oooooooo003oo`00ool00?oooooo003ooooo
oooo003oooooo`00ooooooooo`00ooooool00?ooooooool000;ooooo00?o003ooooooooo00000ooo
ool01Ooo003oooooooooooooooooo`0000;o003o00Coooooool00?l00?oo003o0_ooool01Ooo003o
ooooo`00ooooooooo`0000;o003o00?oooooool00?ooool00_ooool02ooo003oooooo`00oooooooo
o`00o`00oooooooo003ooooooooo003o003o00cooooo00co003ooooooooooooo0000ooooool00?oo
ooooool00?oooooo003ooooooooo0002o`00o`03oooooooo003ooooo02oooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o0oooool00ol00?ooooooooooo`05oooo
o`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooooooo`02o`00o`;ooooo00Go003o
ooooooooooooooooo`00o`08ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo00Kooooo0_l00?l2ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00_l00?l2
ooooo`;o003o1_ooool01ol00?oooooooooooooooooo003oooooool00?l01?ooool01Ol00?oooooo
o`00oooooooo003o00?ooooo00Go003oooooool00?ooooooo`00o`02ooooo`?oo`000_ooool3ool0
00;ooooo00Goo`00ooooool00?ooooooool00002ooooo`03o`00ooooooooo`0000?ooooo00Koo`00
ooooool00?ooooooool00?l00?l2ooooo`03ool00?l00?oooooo00;ooooo00[oo`00ooooool00?oo
ooooool00?oooooo003ooooooooo003o003o0_ooool01Ooo003oooooo`00ooooooooo`0000Cooooo
00?oo`00o`00ooooool02oooool03?l00?ooooooooooool0003oooooo`00ooooooooo`00ooooool0
0?ooooooool000;o003o00?oooooool00?l00?l0<oooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o0oooool0
1Ol00?oooooooooooooooooo003o00?ooooo0_l00?l2ooooo`05o`00ooooooooooooooooool00?l0
2?ooool2o`00o`;ooooo0_l00?l3ooooo`03o`00oooooooooooo00Gooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool01_ooool2o`00o`;ooooo0_l00?l2ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool00_l00?l2ooooo`;o003o1_ooool00ol00?oooooooooo
o`02ooooo`;o003o1?ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`02oooo
o`?oo`000_ooool3ool0000Io`00ooooooooo`00ooooool00?ooooooool00?l00?ooooooo`00oooo
ooooo`00ooooool00?ooooooool00?oooooo003ooooooooo003oooooo`00ooooooooo`00o`00o`03
ooooo`09ool00?oooooooooooooooooo003oooooo`00ooooooooo`0000;o003o00Koooooool00?l0
0?oo003ooooooooo0004ooooo`03ool00?l00?oooooo00_ooooo0_l00?l00ooooooo0000ooooo`02
ooooo`06ool00?oooooo003ooooooooo003o003o0_ooool00ooo003o003oooooo`0fooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool2o`00o`?ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`03o`00oooooooo
oooo00;o003o0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o0oooool0
0ol00?ooooooooooo`05ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00002?ooool00ol0
0?ooooooooooo`02o`00o`;ooooo0_l00?l4ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00
o`Cooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooool00?l01Oooool02?l00?ooooooooooool00?ooooooo`00oooooooo003o0ooo00001?l00?oo
o`00ool00?oo0002ooooo`0Dool00?l00?ooooooo`00ooooooooo`00ooooool00?ooooooool00?oo
oooo003ooooooooo003oooooo`00ooooooooo`00ooooool00?l2ooooo`09ool00?oooooooooooooo
oooo003oooooo`00ooooooooo`0000;o003o00?oooooool00?l00?l00_ooool01_oo003o003ooooo
ool00?ooooooool000kooooo00?o003oooooool000000oooool02_oo003oooooooooooooooooo`00
ooooool00?ooooooool00?l00?lgooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`06oooo
o`04o`00ooooooooooooooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00Sooooo00?o
003oooooooooool00_l00?l6ooooo`;o00000oooool0017ooooo00?o0000ooooooooool01oooool0
1Ol00?oooooooooooooooooo003o00;ooooo0_l00?l3ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_l00?l2ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Kooooo00Oo003o
ooooool00?ooooooo`00oooooooo003o00?oo`0000Co003oool00?oo003oo`000oooool01Ooo003o
ooooo`00ooooooooo`0000?ooooo00Ooo`00ooooool00?ooooooool00?oooooo003o00;ooooo00Go
o`00ooooool00?ooooooool00003ooooo`06ool00?oooooo003ooooooooo003o003o0_ooool01ooo
003o003oooooool00?ooooooool00?l00?l03Oooool01ol00?ooooooo`000?oooooo003ooooooooo
00000oooool01Ooo003oooooo`00ooooooooo`0003gooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`Ko
oooo00?o003oooooooooool01_ooool00ol0003oooooooooo`01ooooo`002Oooool3o`0000Gooooo
00?o0000ooooooooool01_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o
0oooool2o`00o`Kooooo0_l00?l2ooooo`03o`00oooooooo003o00?ooooo00?o003oooooooooool0
0_l00?l2ooooo`09o`00ooooooooooooooooool00?ooooooo`00oooooooo003o00Sooooo00Go003o
ooooool00?ooooooo`00o`03ool00005o`00oooo003oo`00ool00?ooool00ooo00001?oooooo003o
oooooooo0003ooooo`05ool00?oooooo003ooooooooo00000_l00?l2ooooo`05ool00?oooooo003o
oooooooo00000oooool03ooo003oooooo`00ooooooooo`00ooooool00?ooooooool00?l00?oooooo
o`00ooooooooo`00o`00o`0=ooooo`0;o`00oooooooo0000ooooool00?ooooooool00?oooooo003o
oooooooo00000_l00?l00oooooooo`00ooooo`10ooooo`05o`00ooooooooooooooooool00?l01?oo
ool00ol00?ooooooooooo`02o`00o`?ooooo00?o003oooooooooool01Oooool01?l00?oooooooooo
ooooool2o`00o`?ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`05o`00oooooooooooooooo
ool00?l02?ooool00ol0003oooooooooo`01ooooo`002_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Kooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooooooooooo
ooooo`;o003o0_ooool2o`00o`Kooooo00Oo003oooooool00?ooooooo`00oooooooo003o00?ooooo
00?o003oooooooooool00_l00?l4ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooo003o00?oo`0000Coooooool00?oo003oo`000oooool01Ooo
003oooooo`00ooooooooo`0000?ooooo00?oo`00o`00ool00?l00_ooool02_oo003oooooo`00oooo
ooooo`00ooooool00?ooooooool00?l00?l2ooooo`05ool00?oooooo003ooooooooo00001?ooool0
0ooo003oooooooooo`0>ooooo`09o`000?oooooo003ooooooooo003oooooo`00ooooooooo`0000;o
003o00?oooooool00?l00?l0A?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`;ooooo0_l00?l7ooooo`03o`00
0?oooooooooo007ooooo000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_oo
ool2o`00o`;ooooo00Go003oooooooooooooooooo`00o`04ooooo`;o003o0_ooool2o`00o`?ooooo
00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`03ooooo`05o`00oooooooooooooooo
ool00?l01?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo0_l00?l8ooooo`05o`00oooooooo
003oooooool00?l00_ooool3ool00008oooooooo003oo`00ool00?oooooo003ooooooooo0003oooo
o`03ool00?oooooooooo00;ooooo00Woo`00ooooool00?ooooooool00?oooooo003ooooooooo0000
0_l00?l01_ooooooo`00o`00ool00?ooooooool000Cooooo00?oo`00ooooooooool03_ooool02_l0
003oooooo`00ooooooooo`00ooooool00?ooooooool00?l00?l2ooooo`03ool00?l00?oooooo04?o
oooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o0oooool01Ol00?oooooooooooooo
oooo003o00?ooooo0_l00?l3ooooo`03o`00oooooooooooo00Gooooo00?o0000ooooooooool00Ooo
ool000[ooooo00?o0000ooooooooool01?ooool3o`0000Kooooo0_l00?l2ooooo`;o003o0_ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00o`?ooooo00Co003o
oooooooooooo003o1?ooool2o`00o`?ooooo00Ko003ooooooooooooo003oooooool00?l3ooooo`03
o`00oooooooooooo00;o003o0_ooool01ol00?ooooooo`00oooooooo003oooooool00?l00oooool0
0ol00?ooooooooooo`02o`00o`;ooooo0ooo00000ooooooo003oool00002ool00005o`00oooooooo
o`00ooooool00?l00_ooool03_oo003oooooooooooooooooo`00ooooool00?ooooooool00?oooooo
003ooooooooo003o003o0_ooool01_oo003o003oooooool00?ooooooool0013ooooo00?o0000oooo
oooo00000_oo0003ooooo`06ool00?l00?oooooooooooooo003o003oA?ooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Gooooo0_l00?l2oooo
o`;o003o1Oooool3o`0000?ooooo000:ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01oooool00ol00?ooooooooooo`02o`00o`;ooooo0_l00?l3ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_l00?l2ooooo`;o003o0_ooool00ol00?ooooooo`00o`02ooooo`04
o`00ooooooooooooooooo`;o003o0_ooool00ol00?ooooooooooo`03ooooo`05o`00oooooooooooo
ooooool00?l00_ooool01ol00?ooooooo`00oooooooo003oooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00;ooooo0ooo00000ooooooo003oool00002ool00005o`00ooooooooo`00oooo
ool00?l00_ooool01Ooo003oooooo`00ooooooooo`0000?ooooo00Koo`00ooooool00?ooooooool0
0?l00?l2ooooo`06ool00?l00?ooooooo`00ooooooooo`004?ooool00ol0003oooooool00002ool0
00?ooooo00Koo`00ooooool00?ooooooool00?l00?m8ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool01Oooool01?l00?ooooooooooooooool2o`00o`?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?l7ooooo`03
o`000?oooooooooo007ooooo0009ooooo`;o00001_ooool00ol0003oooooooooo`06ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_l00?l3ooooo`03o`00oooooooooooo00Gooooo
0_l00?l2ooooo`;o003o1?ooool00ol00?ooooooooooo`02o`00o`;ooooo00Wo003ooooooooooooo
ooooo`00oooooooo003oooooool00?l01Oooool00ol00?ooooooooooo`02o`00o`;ooooo00Oo003o
ooooooooooooooooo`00oooooooo003o00?ooooo00Ko003ooooooooooooo003oooooool00?l2oooo
o`?oo`0000Go003oool00?oo003oo`00o`00o`02ooooo`05ool00?oooooo003ooooooooo00000ooo
ool01Ooo003oooooo`00ooooooooo`0000;o003o00Ooooooool00?l00?ooooooo`00ooooooooo`00
013ooooo00?o0000oooooooo00000_oo00002?oooooo003ooooooooo003oooooo`00ooooooooo`00
C_ooool01Ol00?oooooooooooooooooo003o00Oooooo00Co003ooooooooooooooooo0_l00?l3oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Sooooo00?o
0000ooooooooool00Oooool000[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06
ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool01Oooool2o`00o`Cooooo00Go003oooooooooooooooooo`00o`02ooooo`;o
003o1?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo00Co003ooooooooooooooooo0_l00?l4
ooooo`03o`00oooooooo003o00Cooooo0_l00?l6ooooo`03o`00oooooooo003o00;ooooo0ooo0000
3?l00?ooo`00ool00?oo003oooooo`00ooooooooo`00ooooool00?ooooooool000?ooooo00[oo`00
ooooool00?ooooooool00?l00?ooooooo`00ooooooooo`004?ooool03_l0003oooooo`00oooooooo
003oooooool00?ooooooool00?oooooo003ooooooooo003o003oDOooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool2o`00o`;ooooo0_l00?l7ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo00Kooooo00Go003oooooooooooooooooo`00o`08ooooo`04o`00oooooooooooooooo
o`;o003o1_ooool01Ol00?oooooooooooooooooo003o00Gooooo00Go003oooooooooooooooooo`00
o`03ooooo`06o`00ooooooooooooo`00oooooooo003o0_ooool2o`00o`Sooooo00Go003oooooool0
0?ooooooo`00o`02ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01?ooool3ool0
000<oooooooo003oo`00ool00?oooooo003ooooooooo003oooooo`00ooooooooo`000oooool01Ooo
003oooooo`00ooooooooo`0000Cooooo00?oo`00ooooooooool03_ooool02Ol0003oooooo`00oooo
oooo003oooooool00?ooooooool00003ooooo`03ool00?l00?oooooo05Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`;o003o0oooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`;o00001oooool01?l00?ooooooooooooooool2o`00o`;ooooo00?o003oooooooooool00_ooool0
1?l00?ooooooooooooooool2o`00o`;ooooo0_l00?l6ooooo`03o`00oooooooooooo00;ooooo0_l0
0?l3ooooo`03o`00oooooooooooo00;o003o1?ooool00ol00?ooooooooooo`02o`00o`;ooooo0_l0
0?l2ooooo`03o`00oooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooo
o`00oooooooo003o00?ooooo00?o003oooooool00?l00_ooool3ool0000Eoooooooo003oo`00ool0
0?oooooo003ooooooooo003oooooo`00ooooooooo`00ooooool00?ooooooool00?l00?ooooooo`00
ooooooooo`00013ooooo00?o0000ooooooooool00oooool00ol00?ooooooool00003ooooo`03ool0
0?l00?oooooo05Cooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool2o`0000?o
oooo000Aooooo`03o`000?oooooooooo00Kooooo00Co003ooooooooooooooooo0_l00?l2ooooo`;o
003o1oooool2o`00o`;ooooo0_l00?l3ooooo`03o`00oooooooooooo00;o003o0oooool01?l00?oo
ooooooooooooool2o`00o`;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`02o`00
o`;ooooo0_l00?l2ooooo`03o`00oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`02
ooooo`;o003o0_ooool01Ol00?ooooooo`00oooooooo003o00?ooooo00?o003oooooool00?l00_oo
ool3ool00008ooooool00?ooooooool00?oooooo003ooooooooo0003ooooo`06ool00?l00?oooooo
o`00ooooooooo`004?ooool01?l0003oooooooooool00?l4ooooo`06ool00?oooooo003ooooooooo
003o003oFOooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01oooool0
1?l00?ooooooooooooooool2o`00o`Oooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool01_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o0oooool0
0ol00?ooooooooooo`05ooooo`;o003o0_ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00;o003o0_ooool01ol00?oooooooooooooooooo003oooooool00?l00oooool00ol0
0?ooooooooooo`02o`00o`Cooooo00?o003oooooool00?l00oooool00ol00?ooooooo`00o`02oooo
o`?oo`000_ooool3ool0000<o`00ooooooooo`00ooooool00?ooooooool00?l00?ooooooo`00oooo
ooooo`004?ooool01?l0003oooooo`00ool00?l2ooooo`07o`00ooooooooo`00ooooool00?oooooo
ool0001Nooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`07ooooo`03
o`00oooooooooooo00Kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
1_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`04o`00oooooooo
ooooooooo`;o003o0_ooool01?l00?ooooooooooooooool2o`00o`;ooooo00?o003oooooooooool0
0_ooool01?l00?ooooooooooooooool2o`00o`;ooooo00Go003oooooooooooooooooo`00o`04oooo
o`;o003o2?ooool01ol00?ooooooo`00oooooooo003oooooool00?l01?ooool01Ol00?ooooooo`00
oooooooo003o00?oo`000_ooool02_oo003oooooo`00ooooooooo`00o`00oooooooo003ooooooooo
000@ooooo`04o`000?oooooo003oo`00o`;ooooo00Oo003oool00?oo003oo`00o`00ooooooooo`00
05kooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`08ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo00Kooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`05ooooo`04o`00ooooooooooooooooo`;o003o1?ooool00ol00?oo
ooooooooo`02o`00o`?ooooo00Ko003ooooooooooooo003oooooool00?l2ooooo`03o`00oooooooo
oooo00Kooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`02ooooo`05o`00oooooooo003oooooool0
0?l00ooo00001oooooooo`00ool00?oo003o003ooooooooo00001?ooool00ooo003oooooooooo`0>
ooooo`04o`000?oooooo003oo`00o`;ooooo00So003oool00?oo003oo`00o`00ooooooooo`00o`00
ofKooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00Gooooo00?o0000
ooooooooool00Oooool0017ooooo0_l00007ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`Kooooo00?o
003oooooooooool00_ooool2o`00o`?ooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooo
oooo003o00;ooooo0_l00?l6ooooo`;o003o0_ooool00ol00?ooooooo`00o`02ooooo`04o`00oooo
ooooooooooooo`;o003o0_ooool01ol00?oooooooooooooooooo003oooooool00?l00oooool00ol0
0?ooooooooooo`04ooooo`05o`00oooooooo003oooooool00?l00ooo00001?l00?ooo`00ool00?oo
0003ooooo`03ool00?oooooooooo00kooooo00?o0000ooooooooool00oooool01?l00?ooo`00ool0
0?oo0002ooooo`03ool00?l00?oooooo06Gooooo00Go003oooooooooooooooooo`00o`04ooooo`03
o`00oooooooooooo00Cooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`06ooooo`05o`00
ooooooooooooooooool00?l00oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`;o003o0oooool00ol00?ooooooooooo`02o`00o`?ooooo00Co003ooooooooooooooooo0_l00?l2
ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`;o003o0_oo
ool2o`00o`Cooooo00?o003oooooooooool00_l00?l2ooooo`;o003o0_ooool01Ol00?ooooooo`00
oooooooo003o00?ooooo00?o003oooooool00?l01_ooool01Ol00?ooooooo`00oooooooo003o00?o
o`0000Soooooool00?oo003oo`00ooooool00?ooooooool0013ooooo00?o0000ooooooooool01ooo
ool00ol00?ooooooool0001[ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`06ooooo`05o`00ooooooooooooooooool00?l0
0oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0_ooool2o`00o`;o
oooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00Gooooo00?o003oooooooooool00_l00?l2ooooo`07o`00ooooooooooooooooool00?oooooo
o`00o`03ooooo`03o`00oooooooooooo00;o003o1?ooool00ol00?ooooooo`00o`03ooooo`03o`00
oooooooo003o00;ooooo0_l00?l6ooooo`03o`00oooooooo003o00;ooooo0ooo00001?oooooo003o
oooooooo000@ooooo`04o`000?oooooo003oo`00o`Kooooo00Co003oool00?oo003oo`00K_ooool0
0ol00?ooooooooooo`06ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
00Kooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0oooool00ol00?ooooooooooo`05
ooooo`;o003o0_ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooo
ooooooooooooo`;o003o0_ooool00ol00?ooooooooooo`06ooooo`;o003o0_ooool01Ol00?oooooo
oooooooooooo003o00Cooooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00So003ooooooooo
oooo003oooooool00?ooooooo`00o`Cooooo0_l00?l6ooooo`07o`00ooooooooooooooooool00?oo
ooooo`00o`02ooooo`?oo`004?ooool01?l0003oooooo`00ool00?l2ooooo`05o`00oooooooo003o
ooooool00?l00ooo001^ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool01_ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Gooooo0_l00?l2ooooo`;o003o0ooo
ool01?l00?ooooooooooooooool2o`00o`?ooooo00?o003oooooooooool00_l00?l3ooooo`03o`00
oooooooooooo00Kooooo00Co003ooooooooooooo003o1?ooool2o`00o`Kooooo0_l00?l4ooooo`03
o`00oooooooo003o00Cooooo0_l00?l2ooooo`03o`00oooooooo003o00Gooooo00?o003ooooooooo
ool00_ooool3ool0013ooooo00Co0000ooooool00?oo003o0_ooool01Ol00?ooooooo`00oooooooo
003o00?oo`00K_ooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`;o00001oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00;o
oooo0_l00?l3ooooo`;o003o1oooool00ol00?ooooooooooo`02o`00o`?ooooo00Co003ooooooooo
oooooooo0_l00?l2ooooo`03o`00oooooooooooo00?ooooo00Go003oooooooooooooooooo`00o`02
ooooo`;o003o0_ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`04ooooo`?o
o`004?ooool00ol0003oooooo`00o`03ooooo`03o`00oooooooo003o00?ooooo00?o003ooooooooo
ool0MOooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo00[ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
o`00o`?ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo00Co
003ooooooooooooooooo0_l00?l2ooooo`;o003o0_ooool02ol00?oooooooooooooooooo003ooooo
ool00?ooooooo`00oooooooo003o00Kooooo00Oo003oooooool00?ooooooo`00oooooooo003o00?o
oooo00Co003ooooooooooooo003o4_ooool00ol0003oooooooooo`05ooooo`05o`00oooooooooooo
ooooool00?l0N?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0>oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooooooo
ooooooooo`;o003o0_ooool2o`00o`?ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0_ooool2o`00o`?o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02o`00o`;ooooo0_l00?l2ooooo`07
o`00ooooooooooooooooool00?ooooooo`00o`02ooooo`;o003o0oooool01_l00?ooooooooooool0
0?ooooooo`00o`?ooooo00?o003oooooooooool00_l00?lAooooo`04o`000?oooooo003oo`00o`Ko
oooo00?o003oooooool00?l0N?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`0Cooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooooooo0_l00?l3ooooo`05
o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00o`;ooooo00?o003o
ooooooooool00_ooool01?l00?ooooooooooooooool2o`00o`;ooooo00Co003ooooooooooooooooo
0_l00?l4ooooo`03o`00oooooooooooo00;o003o0oooool00ol00?ooooooooooo`02o`00o`;ooooo
00?o003oooooooooool00_ooool2o`00o`Kooooo00Oo003oooooool00?ooooooo`00oooooooo003o
00;ooooo0_l00?lAooooo`04o`000?oooooo003oo`00o`;ooooo00Go003oooooool00?ooooooo`00
o`1jooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01?ooooo00Go003o
ooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?l3ooooo`04o`00
ooooooooooooooooo`;o003o0oooool01?l00?ooooooooooool00?l4ooooo`;o003o1_ooool2o`00
o`?ooooo00Co003ooooooooooooo003o1?ooool2o`00o`;ooooo0_l00?l6ooooo`03o`00oooooooo
003o00;ooooo0_l00?lAooooo`04o`000?oooooo003oo`00o`;ooooo00Oo003oooooool00?oooooo
o`00oooooooo003o07Sooooo00?o0000ooooooooool00Oooool0017ooooo0_l0000Hooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;o003o0oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00;o003o0oooool00ol00?ooooooooooo`02ooooo`04o`00oooooooo
ooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02o`00o`;ooooo0_l0
0?l4ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool03oooool01?l0003oooooo`00
ool00?l2ooooo`;o003o1?ooool00ol00?ooooooooooo`1eooooo`;o00000oooool0017ooooo00?o
0000ooooooooool05oooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l3ooooo`05o`00oooooooooooooooo
ool00?l00oooool01?l00?ooooooooooooooool2o`00o`?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`;o003o0_ooool01?l00?ooooooooooooooool2o`00o`Cooooo00?o003oooooooooool0
1?ooool2o`00o`;ooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003ooooo
ooooool04?ooool00ol0003oooooooooo`03ooooo`;o003o1?ooool00ol00?ooooooooooo`1foooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01_ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo
0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`;ooooo0_l00?l2ooooo`07
o`00ooooooooooooooooool00?ooooooo`00o`06ooooo`;o003o0_ooool2o`00o`Cooooo00Co003o
oooooooooooo003o4_ooool00ol0003oooooo`00o`07ooooo`03o`00oooooooo003o07Sooooo00?o
0000ooooooooool00Oooool000Sooooo1Ol00004ooooo`03o`000?oooooooooo01oooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`04
o`00ooooooooooooooooo`;o003o0oooool01?l00?ooooooooooooooool2o`00o`?ooooo00Co003o
oooooooooooo003o0oooool00ol00?ooooooo`00o`02ooooo`;o003o1_ooool2o`00o`;ooooo00?o
003oooooool00?l00_ooool2o`00oa7ooooo00?o0000ooooool00?l00oooool2o`00o`;ooooo00?o
003oooooooooool0N?ooool00ol0003oooooooooo`01ooooo`002Oooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo02Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`02o`00o`;ooooo00?o003oooooooooool00_ooool2o`00o`;ooooo0_l00?l6
ooooo`03o`00oooooooo003o00;ooooo0_l00?lAooooo`03o`000?oooooo003o00?ooooo0_l00?l2
ooooo`03o`00oooooooooooo07Sooooo00?o0000ooooooooool00Oooool000[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Sooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o0oooool00ol00?oooooooooo
o`06ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool01Oooool2o`00o`?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`;o003o0_ooool2o`00o`Kooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooo003o00?ooooo0_l00?l2ooooo`03
o`00oooooooo003o07Sooooo00?o0000ooooooooool00Oooool000_ooooo00?o0000ooooooooool0
0oooool3o`0002Sooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooooooooooooooo
o`;o003o0oooool00ol00?ooooooooooo`05ooooo`;o003o0_ooool2o`00o`?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o0oooool00ol00?oooooooooo
o`05ooooo`;o003o0_ooool2o`00o`;ooooo00?o003oooooooooool05Oooool00ol0003ooooooooo
o`03ooooo`;o003o1?ooool00ol00?ooooooooooo`1dooooo`?o00000oooool000Sooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo02cooooo00Go003ooooooooooooooooo
o`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o0_oo
ool01?l00?ooooooooooooooool2o`00o`Oooooo0_l00?l2ooooo`;o003o1?ooool01?l00?oooooo
ooooool00?lBooooo`03o`000?oooooooooo00Oooooo0_l00?miooooo`03o`000?oooooooooo007o
oooo0008ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0`ooooo`05
o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003o
oooooooooooooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?oooooo
ooooool00?l3ooooo`;o003o0oooool2o`00o`Kooooo0_l00?l4ooooo`03o`00oooooooooooo00;o
003o4Oooool00ol0003oooooo`00o`07ooooo`03o`00oooooooooooo07Sooooo00?o0000oooooooo
ool00Oooool000Wooooo0ol00005ooooo`03o`000?oooooooooo033ooooo00Go003ooooooooooooo
ooooo`00o`08ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02o`00o`;ooooo00?o003o
ooooooooool00_ooool2o`00o`Kooooo00Co003ooooooooooooooooo0_l00?l3ooooo`;o003o4Ooo
ool00ol0003oooooo`00o`03ooooo`;o003o0_ooool00ol00?ooooooooooo`1hooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo03Cooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`05ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oooooooooo
o`05ooooo`;o003o0oooool00ol00?ooooooooooo`05ooooo`04o`00ooooooooooooooooo`;o003o
1_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o0000ooooool00?l0
0oooool2o`00o`;ooooo0_l00?miooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000>_oo
ool00ol00?ooooooooooo`05ooooo`04o`00ooooooooooooooooo`;o003o0oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`;o003o0_ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00oooooo00?o0000ooooool00?l00oooool2o`00o`?ooooo00?o003o
ooooooooool0M_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo03Wooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`;ooooo0_l00?l7ooooo`;o003o
0_ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`0Booooo`03o`000?oooooooooo00So
oooo00?o003oooooooooool0Moooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`0mooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l3
ooooo`03o`00oooooooooooo00Gooooo0_l00?l3ooooo`04o`00ooooooooooooooooo`;o003o4Ooo
ool00ol0003oooooooooo`07ooooo`;o003oNOooool00ol0003oooooooooo`01ooooo`004Oooool0
0ol0003oooooooooo`11ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?l2ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool01Oooool2o`00o`;ooooo0_l00?l3ooooo`;o003o4Oooool00ol0003o
ooooooooo`03ooooo`;o003o0_ooool00ol00?ooooooooooo`1hooooo`03o`000?oooooooooo007o
oooo000Aooooo`03o`000?oooooooooo04Gooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooooooo`;o003o1_ooool2o`00o`?ooooo00?o003oooooooooool04?ooool0
0ol0003oooooooooo`03ooooo`;o003o0_ooool2o`00ogWooooo00?o0000ooooooooool00Oooool0
017ooooo0_l00016ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooo
ooooooooooooo`;o003o0oooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo013o
oooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo07Ko
oooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1:ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l7ooooo`04o`00oooooooooooo
ooooo`;o003o0_ooool2o`00o`?ooooo00?o003oooooooooool04?ooool00ol0003oooooooooo`03
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Moooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`1>ooooo`05o`00ooooooooooooooooool00?l00oooool0
1?l00?ooooooooooooooool2o`00o`Oooooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00
ooooooooooooooooool00?l04_ooool00ol0003oooooooooo`07ooooo`;o003oNOooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1>ooooo`05o`00ooooooooooooooooool0
0?l00oooool01?l00?ooooooooooooooool2o`00o`?ooooo00?o003oooooooooool01Oooool2o`00
o`;ooooo0_l00?l3ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool00oooool01Ol0
0?oooooooooooooooooo003o07[ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool0D_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00Oooooo0_l00?l3ooooo`03o`00oooooooooooo013ooooo00?o
0000ooooooooool00oooool01Ol00?oooooooooooooooooo003o07[ooooo00?o0000ooooooooool0
0Oooool0017ooooo0_l0001Cooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool04?ooool00ol0003oooooooooo`03ooooo`04o`00oooooooooooo
ooooo`;o003oN?ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo05Kooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`05ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`1gooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
05[ooooo0_l00?l7ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooo
oooo003o01;ooooo00?o0000ooooooooool01oooool2o`00ogWooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0Goooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`0Booooo`03o`000?oooooooooo00Oooooo00?o
003oooooooooool0N?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1O
ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooooooo0_l00?l3ooooo`03o`00oooo
oooooooo013ooooo00?o0000ooooooooool00oooool01Ol00?oooooooooooooooooo003o07[ooooo
00?o0000ooooooooool00Oooool0017ooooo0_l0001Tooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo00Go
003oooooooooooooooooo`00o`1iooooo`;o00000oooool0017ooooo00?o0000ooooooooool0Hooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool0N?ooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`1Wooooo`04o`00ooooooooooooooooo`;o003o
0oooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool0
N?ooool00ol0003oooooooooo`01ooooo`002Oooool3o`0000Gooooo00?o0000ooooooooool0Jooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool01ooo
ool00ol00?ooooooooooo`1hooooo`03o`000?oooooooooo007ooooo0008ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`1[ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo07Sooooo00?o
0000ooooooooool00Oooool000cooooo00?o0000ooooooooool00_ooool3o`00073ooooo00?o003o
ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo07Kooooo0ol00003
ooooo`002_ooool2o`0000Gooooo00?o0000ooooooooool0L?ooool00ol00?ooooooooooo`0@oooo
o`03o`000?oooooooooo08;ooooo00?o0000ooooooooool00Oooool000cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo08;ooooo00?o0000oooooooo
ool00Oooool000Sooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo08?o
oooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`01ooooo`002Oooool3o`0000Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooooooo`0000go00000ooo
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-11.9139, -3.65495, \
0.0788464, 0.0387345}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Show all", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{{g3, g4}, {g6, g8}}], \ 
        ImageSize \[Rule] 504];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 504 311.489 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.0147151 0.0195658 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11254 -6 -4.5 ]
[-0.0125 .11254 0 4.5 ]
[-0.0125 .21037 -12 -4.5 ]
[-0.0125 .21037 0 4.5 ]
[-0.0125 .3082 -12 -4.5 ]
[-0.0125 .3082 0 4.5 ]
[-0.0125 .40603 -12 -4.5 ]
[-0.0125 .40603 0 4.5 ]
[-0.0125 .50386 -12 -4.5 ]
[-0.0125 .50386 0 4.5 ]
[-0.0125 .60169 -12 -4.5 ]
[-0.0125 .60169 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11254 m
.00625 .11254 L
s
[(5)] -0.0125 .11254 1 0 Mshowa
0 .21037 m
.00625 .21037 L
s
[(10)] -0.0125 .21037 1 0 Mshowa
0 .3082 m
.00625 .3082 L
s
[(15)] -0.0125 .3082 1 0 Mshowa
0 .40603 m
.00625 .40603 L
s
[(20)] -0.0125 .40603 1 0 Mshowa
0 .50386 m
.00625 .50386 L
s
[(25)] -0.0125 .50386 1 0 Mshowa
0 .60169 m
.00625 .60169 L
s
[(30)] -0.0125 .60169 1 0 Mshowa
.125 Mabswid
0 .03428 m
.00375 .03428 L
s
0 .05385 m
.00375 .05385 L
s
0 .07341 m
.00375 .07341 L
s
0 .09298 m
.00375 .09298 L
s
0 .13211 m
.00375 .13211 L
s
0 .15168 m
.00375 .15168 L
s
0 .17124 m
.00375 .17124 L
s
0 .19081 m
.00375 .19081 L
s
0 .22994 m
.00375 .22994 L
s
0 .2495 m
.00375 .2495 L
s
0 .26907 m
.00375 .26907 L
s
0 .28864 m
.00375 .28864 L
s
0 .32777 m
.00375 .32777 L
s
0 .34733 m
.00375 .34733 L
s
0 .3669 m
.00375 .3669 L
s
0 .38647 m
.00375 .38647 L
s
0 .4256 m
.00375 .4256 L
s
0 .44516 m
.00375 .44516 L
s
0 .46473 m
.00375 .46473 L
s
0 .48429 m
.00375 .48429 L
s
0 .52343 m
.00375 .52343 L
s
0 .54299 m
.00375 .54299 L
s
0 .56256 m
.00375 .56256 L
s
0 .58212 m
.00375 .58212 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11254 m
1 .11254 L
s
.99375 .21037 m
1 .21037 L
s
.99375 .3082 m
1 .3082 L
s
.99375 .40603 m
1 .40603 L
s
.99375 .50386 m
1 .50386 L
s
.99375 .60169 m
1 .60169 L
s
.125 Mabswid
.99625 .03428 m
1 .03428 L
s
.99625 .05385 m
1 .05385 L
s
.99625 .07341 m
1 .07341 L
s
.99625 .09298 m
1 .09298 L
s
.99625 .13211 m
1 .13211 L
s
.99625 .15168 m
1 .15168 L
s
.99625 .17124 m
1 .17124 L
s
.99625 .19081 m
1 .19081 L
s
.99625 .22994 m
1 .22994 L
s
.99625 .2495 m
1 .2495 L
s
.99625 .26907 m
1 .26907 L
s
.99625 .28864 m
1 .28864 L
s
.99625 .32777 m
1 .32777 L
s
.99625 .34733 m
1 .34733 L
s
.99625 .3669 m
1 .3669 L
s
.99625 .38647 m
1 .38647 L
s
.99625 .4256 m
1 .4256 L
s
.99625 .44516 m
1 .44516 L
s
.99625 .46473 m
1 .46473 L
s
.99625 .48429 m
1 .48429 L
s
.99625 .52343 m
1 .52343 L
s
.99625 .54299 m
1 .54299 L
s
.99625 .56256 m
1 .56256 L
s
.99625 .58212 m
1 .58212 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .03428 m
.02395 .03427 L
.02408 .03425 L
.02423 .03421 L
.02437 .03416 L
.02462 .03403 L
.02489 .03383 L
.02519 .03355 L
.02551 .03319 L
.02608 .03234 L
.02722 .03 L
.02847 .02654 L
.02973 .02231 L
.03043 .01975 L
.03109 .01724 L
.03139 .01609 L
.03155 .01546 L
.03171 .01487 L
.03179 .0149 L
.03189 .01527 L
.03205 .01591 L
.03238 .01715 L
.03355 .02156 L
.03596 .02921 L
.03717 .03192 L
.03785 .03303 L
.03819 .03345 L
.0385 .03377 L
.03879 .034 L
.03894 .03409 L
.0391 .03418 L
.03918 .03421 L
.03926 .03424 L
.03941 .03428 L
.03949 .03429 L
.03958 .03431 L
.03967 .03431 L
.03976 .03431 L
.03991 .03429 L
.04006 .03426 L
.04019 .03421 L
.04033 .03415 L
.04065 .03395 L
.04095 .0337 L
.04147 .03311 L
.04204 .03223 L
.04319 .02979 L
.04573 .02188 L
.04631 .01973 L
.04694 .01736 L
Mistroke
.04724 .01619 L
.04739 .01562 L
.04752 .01509 L
.04765 .01482 L
.04778 .01533 L
.04805 .0164 L
.0492 .02077 L
.05046 .02517 L
.05165 .02878 L
.05274 .03139 L
.05332 .03249 L
.05388 .03331 L
.05417 .03365 L
.05447 .03394 L
.05463 .03406 L
.0548 .03417 L
.05495 .03425 L
.05511 .03432 L
.05525 .03436 L
.0554 .03439 L
.05553 .0344 L
.05566 .03439 L
.05581 .03437 L
.05595 .03434 L
.0561 .03429 L
.05625 .03422 L
.05652 .03405 L
.05676 .03384 L
.05732 .03322 L
.05789 .03235 L
.05849 .03118 L
.05959 .02847 L
.06208 .02016 L
.06267 .0179 L
.063 .01664 L
.0633 .01545 L
.06346 .01483 L
.06355 .01495 L
.06363 .01527 L
.064 .01669 L
.06464 .01916 L
.06589 .02377 L
.06706 .02756 L
.06826 .03074 L
.06878 .03185 L
.06934 .03286 L
.06967 .03333 L
.06996 .0337 L
.07027 .03401 L
.07055 .03423 L
Mistroke
.07071 .03433 L
.07085 .0344 L
.07101 .03447 L
.07109 .03449 L
.07118 .03451 L
.07126 .03453 L
.07134 .03454 L
.07149 .03454 L
.07159 .03453 L
.07167 .03452 L
.07175 .0345 L
.07184 .03448 L
.07199 .03443 L
.07213 .03436 L
.07243 .03416 L
.07272 .03391 L
.07299 .03362 L
.07359 .03278 L
.07425 .03157 L
.07557 .02829 L
.07679 .02443 L
.07787 .02052 L
.07844 .01834 L
.07904 .016 L
.07919 .01539 L
.07928 .01505 L
.07936 .01474 L
.07945 .01507 L
.07954 .01541 L
.07971 .01607 L
.08032 .01847 L
.08152 .02299 L
.0827 .02695 L
.08394 .03044 L
.085 .03268 L
.0856 .0336 L
.08588 .03394 L
.08617 .03423 L
.08633 .03437 L
.08648 .03447 L
.08663 .03456 L
.08677 .03463 L
.08693 .03469 L
.08702 .03471 L
.08711 .03473 L
.08726 .03475 L
.08734 .03475 L
.08742 .03475 L
.08758 .03472 L
.08772 .03469 L
Mistroke
.08786 .03464 L
.088 .03457 L
.08832 .03436 L
.08861 .0341 L
.08913 .03348 L
.0897 .03257 L
.09085 .03005 L
.09339 .02193 L
.09397 .01972 L
.09459 .01729 L
.09489 .01609 L
.09504 .0155 L
.09518 .01496 L
.0953 .01497 L
.09543 .01549 L
.09571 .01659 L
.09685 .02106 L
.0981 .02558 L
.0993 .02927 L
.10038 .03196 L
.10097 .03308 L
.10153 .03392 L
.10181 .03426 L
.10211 .03455 L
.10227 .03468 L
.10244 .0348 L
.10259 .03488 L
.10275 .03494 L
.10289 .03498 L
.10304 .03501 L
.10317 .03502 L
.1033 .03502 L
.10345 .035 L
.10358 .03496 L
.10374 .03491 L
.10389 .03483 L
.10416 .03466 L
.1044 .03445 L
.10496 .0338 L
.10552 .03291 L
.10613 .0317 L
.10722 .0289 L
.10971 .0203 L
.1103 .01797 L
.11063 .01667 L
.11093 .01544 L
.11102 .0151 L
.11111 .01473 L
.1112 .01509 L
.1113 .01546 L
Mistroke
.11162 .01679 L
.11226 .01935 L
.11343 .02382 L
.11469 .02808 L
.11593 .0315 L
.11652 .03278 L
.11706 .03374 L
.1176 .0345 L
.11789 .0348 L
.1182 .03505 L
.11832 .03514 L
.11846 .03521 L
.11858 .03526 L
.11871 .03531 L
.11885 .03534 L
.119 .03536 L
.11914 .03536 L
.11927 .03535 L
.11943 .03531 L
.1195 .03529 L
.11959 .03526 L
.11988 .0351 L
.12005 .03498 L
.12022 .03483 L
.12054 .0345 L
.12117 .03361 L
.12174 .03255 L
.12289 .02973 L
.12399 .02633 L
.12515 .02211 L
.12578 .01961 L
.12638 .01719 L
.12663 .01617 L
.12676 .01562 L
.12689 .0151 L
.12703 .01489 L
.12718 .01551 L
.12744 .01659 L
.1286 .0213 L
.13086 .02925 L
.13148 .031 L
.13213 .03259 L
.1327 .03372 L
.13331 .03467 L
.13364 .03507 L
.13394 .03536 L
.13408 .03547 L
.13424 .03557 L
.13439 .03565 L
.13453 .03571 L
Mistroke
.13462 .03573 L
.13471 .03576 L
.13479 .03577 L
.13487 .03578 L
.13495 .03578 L
.13504 .03578 L
.13514 .03577 L
.13523 .03575 L
.13531 .03573 L
.13539 .0357 L
.13554 .03564 L
.1357 .03555 L
.13588 .03543 L
.13617 .03518 L
.13649 .03482 L
.13714 .03384 L
.13774 .03265 L
.13831 .0313 L
.14074 .02335 L
.14182 .01905 L
.14211 .01787 L
.14241 .01658 L
.14255 .01599 L
.1427 .01536 L
.14283 .01482 L
.14297 .0152 L
.14313 .01586 L
.14329 .01655 L
.14359 .01781 L
.14416 .02014 L
.14526 .02449 L
.14655 .02902 L
.14775 .03241 L
.14839 .03382 L
.14898 .03484 L
.14929 .03528 L
.14962 .03566 L
.1498 .03584 L
.14997 .03597 L
.15014 .03608 L
.15031 .03617 L
.15046 .03622 L
.1506 .03626 L
.15074 .03628 L
.15087 .03628 L
.15102 .03627 L
.15117 .03624 L
.15132 .03618 L
.15149 .0361 L
.15179 .0359 L
Mistroke
.15208 .03563 L
.15273 .03478 L
.15333 .0337 L
.15398 .03222 L
.15517 .02878 L
.1574 .02037 L
.15804 .01767 L
.15836 .01632 L
.1585 .01573 L
.15865 .01507 L
.15878 .01495 L
.15891 .0155 L
.15919 .0167 L
.15978 .01921 L
.16107 .02453 L
.1623 .029 L
.16348 .0325 L
.1641 .03398 L
.16476 .03524 L
.16531 .03603 L
.16562 .03636 L
.16577 .03649 L
.16592 .0366 L
.16605 .03668 L
.16619 .03676 L
.16632 .03681 L
.16644 .03684 L
.16658 .03687 L
.16671 .03688 L
.16685 .03687 L
.16699 .03684 L
.16713 .0368 L
.16728 .03674 L
.16742 .03666 L
.16755 .03657 L
.16787 .0363 L
.16816 .03597 L
.16876 .03508 L
.1694 .0338 L
.17056 .03073 L
.17163 .02713 L
.17291 .02211 L
.17353 .01944 L
.17411 .01692 L
.17438 .01571 L
.17451 .01512 L
.17463 .01484 L
.17476 .01541 L
.1749 .01602 L
.17519 .01731 L
Mistroke
.17635 .02237 L
.17866 .03102 L
.17929 .03288 L
.17996 .03455 L
.18059 .0358 L
.18086 .03625 L
.18116 .03667 L
.18143 .03697 L
.18171 .03723 L
.18187 .03734 L
.18201 .03742 L
.18216 .03749 L
.18229 .03753 L
.18244 .03756 L
.1826 .03758 L
.18273 .03757 L
.18288 .03754 L
.18304 .03749 L
.18312 .03745 L
.18321 .03741 L
.18351 .0372 L
.18379 .03693 L
.18405 .03663 L
.18464 .03571 L
.18516 .03467 L
.18572 .03333 L
.18813 .02506 L
.1894 .01961 L
.19004 .01671 L
.19022 .01591 L
.19031 .01547 L
.1904 .01505 L
.19049 .01477 L
.19058 .0152 L
.19074 .01594 L
.19327 .02699 L
.19446 .03136 L
.19558 .03464 L
.19618 .036 L
.19672 .03699 L
.19701 .03741 L
.19733 .03779 L
.1975 .03796 L
.19766 .03809 L
.19782 .0382 L
.19798 .03828 L
.19813 .03834 L
.19822 .03837 L
.19831 .03838 L
.19846 .0384 L
Mistroke
.19854 .03839 L
.19862 .03839 L
.19877 .03836 L
.1989 .03831 L
.19906 .03824 L
.1992 .03815 L
.19953 .03788 L
.19983 .03755 L
.20051 .03649 L
.20107 .03532 L
.20167 .03378 L
.20276 .03031 L
.20395 .02569 L
.20525 .01993 L
.20585 .01709 L
.20603 .01626 L
.20619 .01547 L
.20634 .01477 L
.20642 .01506 L
.2065 .01543 L
.20766 .02094 L
.20898 .02679 L
.21021 .03157 L
.2113 .03501 L
.21186 .03643 L
.21247 .03767 L
.21282 .03823 L
.21314 .03865 L
.21344 .03896 L
.2136 .03908 L
.21377 .03919 L
.21385 .03924 L
.21394 .03927 L
.21409 .03932 L
.21424 .03935 L
.21439 .03936 L
.21454 .03934 L
.21469 .0393 L
.21483 .03925 L
.21496 .03918 L
.21524 .03898 L
.21554 .03868 L
.21586 .03827 L
.21616 .0378 L
.21726 .03536 L
.21789 .03351 L
.21847 .03156 L
.21977 .02638 L
.22088 .02132 L
.22148 .01837 L
Mistroke
.22178 .0169 L
.22206 .01554 L
.22222 .01475 L
.22229 .01508 L
.22238 .01551 L
.22274 .01727 L
.22335 .02031 L
.22455 .02601 L
.22576 .03111 L
.2269 .03512 L
.22754 .03691 L
.22822 .03848 L
.22853 .03903 L
.22885 .03952 L
.22912 .03986 L
.22928 .04003 L
.22943 .04016 L
.22958 .04027 L
.22971 .04035 L
.22986 .04041 L
.23001 .04046 L
.23015 .04048 L
.23029 .04048 L
.23043 .04047 L
.23055 .04043 L
.2307 .04038 L
.23083 .0403 L
.23114 .04007 L
.23145 .03975 L
.23177 .0393 L
.23236 .03823 L
.23292 .03691 L
.23397 .0337 L
.23522 .02882 L
.23639 .02341 L
.23744 .0181 L
.23773 .01661 L
.23789 .01579 L
.23804 .01502 L
.23816 .01507 L
.2383 .01577 L
.23858 .01726 L
.24096 .02901 L
.24227 .0344 L
.24349 .03824 L
.24408 .03965 L
.24471 .04078 L
.24504 .0412 L
.24535 .0415 L
.24552 .04163 L
Mistroke
.24569 .04172 L
.24577 .04175 L
.24586 .04178 L
.24596 .0418 L
.24605 .04181 L
.2462 .04181 L
.24629 .0418 L
.24637 .04178 L
.24651 .04173 L
.24666 .04166 L
.2468 .04157 L
.24693 .04146 L
.24722 .04117 L
.24754 .04075 L
.24783 .04027 L
.24848 .0389 L
.24967 .03535 L
.25077 .031 L
.25206 .02491 L
.25269 .02164 L
.25327 .01853 L
.25357 .01689 L
.25372 .01608 L
.25385 .01535 L
.25399 .01486 L
.25415 .01569 L
.25447 .01746 L
.25575 .02442 L
.258 .03495 L
.25858 .03713 L
.2592 .03913 L
.25973 .04057 L
.26031 .0418 L
.26063 .04235 L
.26092 .04274 L
.26106 .0429 L
.26122 .04305 L
.26136 .04316 L
.2615 .04325 L
.26158 .04329 L
.26167 .04333 L
.26183 .04338 L
.26192 .04339 L
.26201 .04339 L
.26209 .04339 L
.26218 .04337 L
.26234 .04333 L
.26243 .04329 L
.26251 .04325 L
.26267 .04314 L
Mistroke
.26281 .04302 L
.26309 .04273 L
.26339 .04231 L
.26401 .04115 L
.26454 .03982 L
.26511 .03808 L
.26642 .033 L
.26762 .0272 L
.26872 .0212 L
.26933 .01772 L
.26947 .01688 L
.26962 .01599 L
.26975 .01522 L
.2699 .01505 L
.26998 .01552 L
.27007 .01603 L
.27022 .01695 L
.27058 .01901 L
.27119 .02256 L
.27239 .02918 L
.27361 .03511 L
.27426 .03781 L
.27495 .04029 L
.27561 .04224 L
.2762 .04361 L
.27649 .04413 L
.2768 .04458 L
.27695 .04475 L
.2771 .04491 L
.27724 .04503 L
.27737 .04512 L
.27752 .0452 L
.2776 .04523 L
.27768 .04525 L
.27782 .04528 L
.27797 .04527 L
.2781 .04525 L
.27825 .0452 L
.27839 .04513 L
.27852 .04504 L
.2788 .04478 L
.27911 .04438 L
.27944 .04384 L
.27974 .04323 L
.28081 .04026 L
.28195 .03579 L
.28319 .0297 L
.28453 .02202 L
.28515 .01825 L
.28531 .01725 L
Mistroke
.28548 .01616 L
.28557 .01564 L
.28565 .01514 L
.2858 .01523 L
.28594 .0161 L
.28606 .0169 L
.28635 .01871 L
.28696 .0225 L
.28814 .02947 L
.2894 .03617 L
.29049 .04095 L
.29111 .04316 L
.29169 .04483 L
.29225 .04609 L
.29256 .04663 L
.29285 .04701 L
.29299 .04717 L
.29315 .04731 L
.29323 .04737 L
.29332 .04743 L
.29347 .0475 L
.29362 .04755 L
.29378 .04756 L
.29393 .04755 L
.29406 .04751 L
.2942 .04745 L
.29434 .04736 L
.2946 .04713 L
.2949 .04675 L
.29518 .0463 L
.29572 .04513 L
.29624 .0437 L
.29742 .03929 L
.29866 .03314 L
.29983 .02628 L
.30089 .0194 L
.30117 .01753 L
.30132 .01653 L
.30148 .01547 L
.30161 .01489 L
.30177 .01592 L
.30203 .01773 L
.30326 .0259 L
.30547 .03894 L
.30669 .04442 L
.30726 .04646 L
.3078 .048 L
.30839 .04925 L
.3087 .04972 L
.30887 .04993 L
Mistroke
.30903 .05009 L
.30919 .05022 L
.30928 .05027 L
.30938 .05031 L
.30953 .05036 L
.30962 .05037 L
.3097 .05037 L
.30986 .05035 L
.31 .05029 L
.31008 .05025 L
.31016 .0502 L
.31032 .05008 L
.31063 .04973 L
.31096 .0492 L
.31157 .04786 L
.31215 .04609 L
.3127 .04408 L
.31393 .03823 L
.31523 .03047 L
.31637 .02263 L
.31668 .02046 L
.317 .01807 L
.31715 .01697 L
.31731 .0158 L
.31745 .01479 L
.3176 .01575 L
.31876 .02426 L
.31981 .0317 L
.32095 .039 L
.32215 .04544 L
.32278 .04818 L
.32346 .05061 L
.32377 .05148 L
.32409 .05226 L
.32436 .05281 L
.32467 .05329 L
.32482 .05348 L
.32498 .05364 L
.32507 .05372 L
.32515 .05377 L
.32524 .05382 L
.32531 .05385 L
.32546 .05389 L
.32562 .0539 L
.32576 .05387 L
.32591 .05381 L
.32606 .0537 L
.32624 .05355 L
.32654 .05316 L
.32691 .0525 L
Mistroke
.32725 .05172 L
.32781 .05003 L
.32843 .04767 L
.32968 .04137 L
.33204 .02506 L
.33272 .01968 L
.33306 .01697 L
.3332 .01578 L
.33329 .0151 L
.33336 .01497 L
.3335 .01608 L
.33364 .01726 L
.33394 .01969 L
.33457 .02479 L
.33695 .04248 L
.33829 .05026 L
.33894 .05317 L
.33954 .05536 L
.34013 .05695 L
.34046 .05759 L
.34061 .05784 L
.34076 .05803 L
.34089 .05818 L
.34102 .05828 L
.34115 .05837 L
.3413 .05843 L
.34144 .05845 L
.34159 .05844 L
.34173 .05839 L
.34186 .05831 L
.342 .0582 L
.34216 .05804 L
.34243 .05764 L
.34276 .05701 L
.34306 .05626 L
.34368 .05425 L
.34433 .05147 L
.34549 .04503 L
.34672 .03628 L
.34787 .02674 L
.34838 .02227 L
.34893 .01723 L
.34908 .01586 L
.34917 .01508 L
.34924 .01505 L
.34939 .01643 L
.34953 .01773 L
.35017 .02359 L
.35151 .03558 L
.35269 .04515 L
Mistroke
.35394 .05371 L
.35459 .05729 L
.3552 .06006 L
.35574 .06201 L
.35603 .06281 L
.35634 .06351 L
.35648 .06377 L
.35663 .06401 L
.35676 .06418 L
.3569 .06433 L
.35698 .0644 L
.35706 .06445 L
.35721 .06452 L
.35735 .06455 L
.35749 .06453 L
.35762 .06449 L
.35775 .06441 L
.35788 .0643 L
.358 .06417 L
.35828 .06374 L
.35856 .06318 L
.35916 .06143 L
.35971 .05924 L
.36094 .05236 L
.36208 .04383 L
.36316 .03424 L
.36434 .02251 L
.36462 .01953 L
.36478 .01787 L
.36493 .0163 L
.36501 .0154 L
.36511 .015 L
.36519 .01589 L
.36527 .01671 L
.36558 .02006 L
.36781 .04309 L
.36889 .05294 L
.37006 .06181 L
.37073 .06589 L
.37134 .06888 L
.37193 .07104 L
.37222 .07185 L
.37239 .07222 L
.37254 .07251 L
.37269 .07274 L
.37285 .07293 L
.37293 .07301 L
.37301 .07307 L
.37309 .07312 L
.37318 .07315 L
Mistroke
.37326 .07317 L
.37334 .07317 L
.37349 .07313 L
.37364 .07304 L
.37378 .07291 L
.37393 .07272 L
.37407 .0725 L
.37433 .07196 L
.37461 .07122 L
.37491 .07021 L
.37555 .0674 L
.37622 .06346 L
.37743 .05412 L
.37867 .04197 L
.37983 .02861 L
.38034 .0224 L
.38062 .01892 L
.38076 .01721 L
.38088 .01563 L
.38102 .01552 L
.38116 .01738 L
.38147 .02134 L
.38202 .02833 L
.38438 .05676 L
.38568 .06972 L
.38632 .0749 L
.3869 .07886 L
.38743 .0818 L
.388 .0842 L
.38832 .08516 L
.38846 .08549 L
.38861 .0858 L
.38875 .08602 L
.38889 .08619 L
.38904 .08632 L
.38918 .08638 L
.38927 .08639 L
.38935 .08638 L
.38951 .08631 L
.38959 .08624 L
.38967 .08616 L
.38986 .0859 L
.39001 .0856 L
.39016 .08526 L
.39049 .08427 L
.39077 .0832 L
.39107 .08179 L
.39168 .07816 L
.39292 .0678 L
.39404 .0552 L
Mistroke
.39536 .03738 L
.39593 .02873 L
.39624 .02399 L
.39641 .02134 L
.39657 .0188 L
.39671 .0165 L
.39687 .01546 L
.39702 .01778 L
.39715 .01993 L
.39769 .02875 L
.39888 .04798 L
.40017 .06767 L
.40139 .08392 L
.40258 .09664 L
.40325 .10209 L
.40356 .1042 L
.40386 .10588 L
.40413 .10714 L
.40438 .10808 L
.40466 .10887 L
.40481 .10918 L
.40495 .10941 L
.40509 .10955 L
.40524 .10963 L
.40537 .10963 L
.40551 .10956 L
.40566 .10941 L
.40574 .10929 L
.40582 .10915 L
.40611 .10844 L
.40626 .10793 L
.40641 .10737 L
.40668 .1061 L
.40729 .10223 L
.40782 .09776 L
.40839 .09175 L
.40969 .07391 L
.41089 .05286 L
.41145 .04167 L
.41206 .02891 L
.41235 .02249 L
.41249 .01929 L
.41263 .01629 L
.41275 .01587 L
.41288 .01879 L
.41315 .02503 L
.41564 .08284 L
.41688 .10955 L
.41823 .13413 L
.41885 .14339 L
Mistroke
.4195 .15147 L
.42005 .15685 L
.42037 .15923 L
.42066 .16099 L
.42082 .16173 L
.42098 .16237 L
.42112 .16281 L
.42127 .16316 L
.42135 .16331 L
.42143 .1634 L
.42152 .16346 L
.42161 .16348 L
.42176 .16341 L
.42185 .16331 L
.42193 .16318 L
.42208 .16281 L
.42223 .16233 L
.42251 .16108 L
.4228 .15922 L
.42312 .15659 L
.42369 .15037 L
.42429 .14157 L
.42536 .1201 L
.4265 .08938 L
.42713 .06914 L
.42773 .0479 L
.42828 .02648 L
.42843 .02035 L
.42852 .01694 L
.4286 .01572 L
.42873 .02149 L
.42889 .02796 L
.42994 .07555 L
.4346 .31692 L
.43697 .43386 L
.43822 .48714 L
.43956 .53471 L
.44023 .55419 L
.44086 .56978 L
.44147 .58221 L
.44204 .59118 L
.44257 .59744 L
.44284 .59975 L
.44314 .60163 L
.4433 .60234 L
.44344 .60282 L
.44352 .60302 L
.4436 .60318 L
.44376 .60332 L
.4439 .60328 L
Mistroke
.44406 .60306 L
.44421 .60267 L
.44434 .60218 L
.44448 .60149 L
.44462 .60069 L
.44493 .59836 L
.44523 .59539 L
.44555 .59145 L
.44613 .58238 L
.44666 .572 L
.44795 .53889 L
.44917 .49834 L
.4538 .29287 L
.45614 .18062 L
.45738 .12491 L
.45872 .07031 L
.45934 .0473 L
.45968 .03546 L
.46 .02491 L
.46014 .02041 L
.46027 .01624 L
.46042 .01789 L
.46056 .02206 L
.46117 .03952 L
.46226 .06608 L
.46288 .07844 L
.46346 .0882 L
.46408 .09666 L
.46464 .10274 L
.46524 .10754 L
.46557 .10947 L
.46588 .11084 L
.46615 .11166 L
.4663 .11199 L
.46643 .1122 L
.46656 .11233 L
.4667 .11239 L
.46682 .11238 L
.46694 .11231 L
.46708 .11216 L
.46721 .11195 L
.46736 .11165 L
.46751 .11124 L
.46782 .11015 L
.4681 .10885 L
.46869 .10538 L
.46931 .1006 L
.47041 .08967 L
.47292 .05788 L
.47405 .0423 L
Mistroke
.47468 .03384 L
.47528 .02604 L
.47583 .01911 L
.47598 .01726 L
.47606 .01626 L
.47614 .01533 L
.47629 .01589 L
.47643 .0175 L
.47748 .02883 L
.47866 .0393 L
.4793 .04394 L
.4799 .04754 L
.48046 .05024 L
.48097 .05217 L
.48124 .05299 L
.48153 .05373 L
.48184 .05433 L
.48199 .05456 L
.48213 .05473 L
.48227 .05487 L
.48241 .05497 L
.48256 .05504 L
.48272 .05508 L
.48285 .05507 L
.483 .05503 L
.48314 .05496 L
.48327 .05486 L
.48343 .05471 L
.48357 .05453 L
.48391 .054 L
.4842 .05339 L
.48452 .05262 L
.48572 .04851 L
.48705 .04236 L
.48959 .02819 L
.4908 .02137 L
.49138 .0182 L
.49164 .01687 L
.49192 .01546 L
.49206 .01472 L
.4922 .0154 L
.49247 .0167 L
.49306 .01941 L
.49432 .02443 L
.4955 .0282 L
.49607 .0297 L
.4966 .03086 L
.49712 .03186 L
.4977 .03274 L
.49801 .03313 L
Mistroke
.4983 .03345 L
.49858 .0337 L
.49887 .03391 L
.49917 .03408 L
.4993 .03414 L
.49945 .03419 L
.49961 .03424 L
.4997 .03425 L
.49978 .03427 L
.49993 .03428 L
.50008 .03428 L
.50017 .03427 L
.50025 .03426 L
.50034 .03425 L
.50043 .03423 L
.50058 .03418 L
.50075 .03412 L
.50107 .03395 L
.50137 .03374 L
.50197 .03316 L
.50262 .03227 L
.50324 .03118 L
.50382 .02996 L
.5049 .02703 L
.50605 .02305 L
.50718 .01831 L
.50749 .01688 L
.50766 .01607 L
.50782 .01531 L
.50795 .01479 L
.50809 .01551 L
.5084 .01707 L
.5106 .02931 L
.513 .04262 L
.51426 .04846 L
.51496 .05103 L
.5156 .05293 L
.5159 .05362 L
.51618 .05415 L
.51633 .0544 L
.5165 .05462 L
.51665 .05479 L
.5168 .05491 L
.51688 .05497 L
.51697 .05501 L
.51713 .05507 L
.51721 .05508 L
.51731 .05507 L
.51739 .05506 L
.51748 .05503 L
Mistroke
.51763 .05494 L
.51772 .05487 L
.5178 .0548 L
.51795 .05463 L
.51811 .05441 L
.5184 .05387 L
.51868 .05323 L
.5193 .05123 L
.51983 .0489 L
.52042 .04568 L
.52164 .03688 L
.52276 .02642 L
.52306 .02318 L
.52339 .01955 L
.52355 .01774 L
.5237 .016 L
.52384 .01503 L
.52398 .01678 L
.5246 .02443 L
.52527 .03321 L
.52762 .06526 L
.52887 .08134 L
.53021 .09615 L
.53087 .10205 L
.53149 .10657 L
.53205 .10961 L
.53237 .11086 L
.53267 .1117 L
.53281 .112 L
.53297 .11223 L
.53311 .11235 L
.53325 .1124 L
.53337 .11237 L
.53351 .11227 L
.53365 .11209 L
.53378 .11184 L
.53393 .11145 L
.53408 .11099 L
.53435 .10988 L
.53464 .1083 L
.53496 .10614 L
.53555 .10088 L
.5361 .09442 L
.53735 .07397 L
.53865 .04425 L
.53896 .03589 L
.5393 .02645 L
.53946 .02167 L
.53961 .01705 L
.53974 .01662 L
Mistroke
.53989 .0213 L
.54106 .06196 L
.54233 .11274 L
.54456 .2138 L
.54692 .32784 L
.54951 .44634 L
.5507 .49355 L
.55197 .53655 L
.55317 .56836 L
.55369 .57917 L
.55427 .58888 L
.55485 .59619 L
.55517 .59913 L
.55531 .60022 L
.55546 .60119 L
.5556 .60189 L
.55574 .60249 L
.55587 .6029 L
.556 .60316 L
.55614 .60331 L
.55627 .60331 L
.55643 .60313 L
.55657 .6028 L
.55671 .6023 L
.55687 .60157 L
.55719 .59948 L
.55749 .59682 L
.55777 .59371 L
.5584 .58452 L
.55907 .57134 L
.56029 .53919 L
.56162 .49307 L
.56405 .38556 L
.56662 .25196 L
.56896 .12965 L
.57012 .07251 L
.57074 .04436 L
.57108 .02965 L
.57124 .02264 L
.57139 .01637 L
.57153 .0189 L
.57166 .02433 L
.57196 .03599 L
.57258 .05924 L
.57368 .09486 L
.57485 .12484 L
.57548 .13766 L
.57608 .14732 L
.57659 .15373 L
.57714 .1588 L
Mistroke
.57744 .16077 L
.5776 .16161 L
.57775 .16225 L
.57789 .16273 L
.57802 .16306 L
.57816 .16332 L
.57831 .16346 L
.57845 .16347 L
.57859 .16338 L
.57873 .16316 L
.57889 .16278 L
.57906 .16224 L
.57922 .16158 L
.57951 .16 L
.58004 .15601 L
.58062 .15011 L
.58193 .1316 L
.58313 .10919 L
.58431 .08405 L
.58557 .05487 L
.58615 .04123 L
.58677 .02695 L
.58702 .02114 L
.58716 .01796 L
.58729 .01499 L
.58744 .01794 L
.58759 .02109 L
.58786 .02716 L
.59007 .07001 L
.59118 .08653 L
.59182 .09414 L
.59241 .09981 L
.59301 .1043 L
.59334 .1062 L
.59365 .10761 L
.59379 .10812 L
.59394 .10858 L
.59407 .10892 L
.59421 .1092 L
.5943 .10934 L
.59438 .10945 L
.59453 .10959 L
.59467 .10964 L
.59482 .10961 L
.59496 .10951 L
.59508 .10936 L
.59523 .10911 L
.59537 .1088 L
.59561 .10809 L
.59588 .10708 L
Mistroke
.59648 .1039 L
.59704 .0999 L
.59821 .08869 L
.5993 .07515 L
.60051 .05759 L
.60178 .03737 L
.60234 .02821 L
.60265 .02318 L
.60294 .01845 L
.60302 .01715 L
.60311 .01578 L
.6032 .01515 L
.60329 .01653 L
.6036 .02151 L
.60421 .031 L
.60645 .06104 L
.60758 .07249 L
.60822 .07752 L
.60881 .08115 L
.60935 .08368 L
.60966 .08475 L
.6098 .08517 L
.60994 .0855 L
.61007 .08577 L
.61021 .08601 L
.61034 .08618 L
.61046 .08629 L
.61059 .08636 L
.61073 .08639 L
.61088 .08636 L
.61102 .08628 L
.61117 .08613 L
.61125 .08603 L
.61133 .0859 L
.61162 .0853 L
.61196 .08431 L
.61228 .08312 L
.61286 .0803 L
.61348 .07638 L
.61465 .06673 L
.61572 .05576 L
.61682 .04286 L
.618 .02806 L
.61835 .02359 L
.61868 .01937 L
.61883 .01753 L
.61898 .0156 L
.61906 .01484 L
.61915 .01595 L
.6193 .01789 L
Mistroke
.6205 .03259 L
.62171 .04591 L
.62285 .05658 L
.62348 .06146 L
.62417 .06588 L
.6248 .06902 L
.6251 .07023 L
.62537 .07116 L
.62564 .07188 L
.62593 .0725 L
.62608 .07274 L
.62622 .07291 L
.62637 .07305 L
.62653 .07314 L
.62667 .07317 L
.62683 .07315 L
.62697 .07308 L
.6271 .07298 L
.62722 .07285 L
.62736 .07268 L
.62762 .0722 L
.62795 .07141 L
.62824 .0705 L
.62891 .06777 L
.62952 .06447 L
.63011 .06069 L
.6325 .0401 L
.63356 .02916 L
.63412 .02321 L
.63443 .01994 L
.63472 .0169 L
.63487 .01527 L
.63495 .01507 L
.63503 .0159 L
.63538 .01957 L
.63599 .02589 L
.63719 .03753 L
.63828 .04677 L
.63944 .05477 L
.64001 .0579 L
.64064 .06068 L
.64091 .06167 L
.64121 .06258 L
.64148 .06327 L
.64174 .06378 L
.6419 .06403 L
.64205 .06422 L
.64221 .06438 L
.6423 .06444 L
.64238 .06449 L
Mistroke
.64246 .06452 L
.64255 .06454 L
.6427 .06454 L
.64279 .06452 L
.64287 .06449 L
.64295 .06444 L
.64305 .06438 L
.6432 .06423 L
.64337 .06401 L
.64367 .06349 L
.64397 .06281 L
.64425 .06204 L
.64486 .05982 L
.64553 .05671 L
.64673 .04938 L
.64898 .03134 L
.65013 .02088 L
.65044 .01797 L
.65061 .01636 L
.6507 .01558 L
.65078 .01485 L
.65093 .01598 L
.6511 .0175 L
.65139 .02014 L
.6527 .03158 L
.65393 .04109 L
.65511 .04859 L
.65619 .05375 L
.6568 .05587 L
.65708 .05664 L
.65739 .05731 L
.65755 .05762 L
.65771 .05786 L
.65786 .05806 L
.658 .0582 L
.65817 .05833 L
.65826 .05838 L
.65835 .05842 L
.6585 .05845 L
.65859 .05845 L
.65867 .05844 L
.65883 .05838 L
.6589 .05834 L
.65899 .05828 L
.65914 .05815 L
.65928 .05799 L
.65959 .05751 L
.65993 .0568 L
.66056 .05504 L
.66113 .0529 L
Mistroke
.66222 .04756 L
.66337 .04039 L
.66452 .03201 L
.66515 .02706 L
.66575 .02224 L
.6663 .01769 L
.66646 .01644 L
.66654 .01576 L
.66662 .01512 L
.66676 .01544 L
.66691 .01667 L
.66796 .02509 L
.6702 .04067 L
.67081 .04409 L
.67147 .04723 L
.67203 .04949 L
.67264 .05143 L
.673 .05232 L
.67333 .05296 L
.67365 .05342 L
.67381 .05359 L
.6739 .05367 L
.67398 .05374 L
.67414 .05383 L
.67429 .05388 L
.67444 .0539 L
.67453 .05389 L
.67461 .05388 L
.67475 .05383 L
.67489 .05374 L
.67505 .05362 L
.6752 .05346 L
.67549 .05306 L
.67581 .05249 L
.67636 .05112 L
.67696 .04916 L
.67762 .04649 L
.67999 .03303 L
.68131 .0238 L
.68188 .01957 L
.68221 .01714 L
.68237 .01596 L
.68252 .01488 L
.68267 .01565 L
.68281 .01669 L
.68312 .01897 L
.68376 .02354 L
.6851 .03252 L
.68627 .0393 L
.68692 .04244 L
Mistroke
.68753 .04496 L
.68812 .04698 L
.68867 .04844 L
.68896 .04905 L
.68927 .04958 L
.68959 .04999 L
.68976 .05014 L
.68985 .05021 L
.68993 .05026 L
.69006 .05032 L
.69021 .05036 L
.69035 .05037 L
.69049 .05036 L
.69061 .05032 L
.69073 .05026 L
.69086 .05018 L
.691 .05007 L
.69131 .04972 L
.6916 .04927 L
.69215 .04812 L
.69275 .0464 L
.6933 .04446 L
.69454 .03892 L
.69675 .02583 L
.69734 .02194 L
.69766 .01978 L
.69796 .01776 L
.69822 .01602 L
.69836 .01505 L
.69849 .01526 L
.69864 .01623 L
.69879 .01728 L
.69908 .01917 L
.70027 .02688 L
.70159 .03448 L
.70274 .03995 L
.70334 .0423 L
.70397 .04433 L
.7043 .04519 L
.70466 .04598 L
.70498 .04657 L
.70528 .04699 L
.70543 .04715 L
.70559 .0473 L
.70568 .04737 L
.70576 .04742 L
.70592 .0475 L
.70605 .04754 L
.7062 .04756 L
.70636 .04755 L
Mistroke
.70651 .04751 L
.70666 .04744 L
.70674 .04739 L
.70682 .04734 L
.70711 .04706 L
.70745 .04661 L
.70776 .04606 L
.70834 .04476 L
.70896 .04293 L
.71012 .03839 L
.71119 .03316 L
.71229 .027 L
.71347 .01984 L
.71381 .01767 L
.71399 .0166 L
.71414 .01561 L
.71429 .01472 L
.71444 .01567 L
.71476 .01766 L
.71596 .02494 L
.7171 .03121 L
.71832 .03696 L
.71891 .03927 L
.71947 .04115 L
.72001 .04266 L
.72052 .04377 L
.72081 .04427 L
.72113 .0447 L
.72127 .04485 L
.72141 .04499 L
.72155 .04509 L
.72168 .04516 L
.72182 .04523 L
.72198 .04527 L
.72213 .04528 L
.72226 .04527 L
.72234 .04525 L
.72242 .04522 L
.72257 .04515 L
.72273 .04505 L
.72291 .0449 L
.7232 .04458 L
.72346 .04421 L
.72405 .04307 L
.72458 .04175 L
.72513 .04005 L
.72751 .0297 L
.72857 .02393 L
.72913 .02073 L
.72972 .01728 L
Mistroke
.72987 .0164 L
.73003 .01545 L
.73013 .0149 L
.73021 .01503 L
.7303 .01553 L
.73038 .01601 L
.73099 .01953 L
.73219 .02617 L
.73336 .03201 L
.73443 .03646 L
.73558 .04016 L
.73622 .04163 L
.73651 .04215 L
.73682 .04261 L
.73708 .04292 L
.73722 .04305 L
.73737 .04317 L
.73751 .04326 L
.73764 .04332 L
.73776 .04336 L
.73788 .04338 L
.73802 .04339 L
.73817 .04337 L
.7383 .04334 L
.73844 .04328 L
.73859 .0432 L
.73875 .04308 L
.73904 .04279 L
.73933 .04241 L
.73964 .04191 L
.74019 .04074 L
.74086 .03896 L
.74146 .03699 L
.744 .02568 L
.74513 .01968 L
.7457 .01657 L
.74585 .01571 L
.74594 .01524 L
.74602 .01479 L
.74618 .01551 L
.74632 .0163 L
.74763 .02331 L
.74883 .02921 L
.74999 .0341 L
.75063 .03634 L
.75122 .03813 L
.75177 .03948 L
.75228 .04046 L
.75255 .04087 L
.75284 .04124 L
Mistroke
.75313 .04152 L
.7533 .04163 L
.75345 .04171 L
.7536 .04177 L
.75368 .04179 L
.75376 .04181 L
.75391 .04181 L
.75405 .0418 L
.75414 .04178 L
.75422 .04175 L
.75437 .04169 L
.75453 .04159 L
.75471 .04145 L
.75501 .04114 L
.75533 .04071 L
.75591 .03968 L
.75651 .03825 L
.75708 .0366 L
.75815 .03281 L
.76036 .02268 L
.76097 .01958 L
.76131 .01784 L
.76162 .01619 L
.76177 .01544 L
.76192 .01478 L
.762 .01519 L
.76208 .01565 L
.76224 .01645 L
.7628 .01934 L
.7652 .03058 L
.76651 .03529 L
.7671 .03696 L
.76774 .03844 L
.76804 .03899 L
.76836 .03949 L
.76863 .03984 L
.76893 .04013 L
.7691 .04026 L
.76926 .04036 L
.76942 .04042 L
.7695 .04045 L
.76958 .04047 L
.76973 .04048 L
.76989 .04048 L
.77004 .04045 L
.77018 .0404 L
.77031 .04033 L
.77046 .04024 L
.77072 .04002 L
.77104 .03967 L
Mistroke
.77132 .03928 L
.77188 .03827 L
.77241 .03706 L
.77359 .0335 L
.77483 .02868 L
.776 .02343 L
.77706 .01827 L
.77735 .01686 L
.7775 .01612 L
.77765 .01534 L
.77779 .01478 L
.77794 .01554 L
.77821 .01687 L
.77944 .0228 L
.78165 .03199 L
.78225 .03395 L
.78287 .03571 L
.78341 .03698 L
.78399 .03804 L
.78432 .0385 L
.78461 .03884 L
.78475 .03897 L
.78491 .03909 L
.78506 .03919 L
.78519 .03926 L
.78535 .03931 L
.78543 .03933 L
.78552 .03935 L
.78562 .03936 L
.78571 .03935 L
.78579 .03935 L
.78588 .03933 L
.78603 .03928 L
.78611 .03925 L
.7862 .03921 L
.78651 .039 L
.78679 .03873 L
.7871 .03835 L
.78772 .03732 L
.7883 .03606 L
.78884 .03464 L
.79135 .02539 L
.79262 .01963 L
.79292 .0182 L
.79324 .01668 L
.79351 .01537 L
.79367 .0148 L
.79381 .0155 L
.79489 .02055 L
.79606 .02571 L
Mistroke
.79731 .03056 L
.7985 .03425 L
.79902 .03552 L
.79957 .03663 L
.79989 .03715 L
.80017 .03755 L
.80046 .03787 L
.80073 .0381 L
.80088 .0382 L
.80101 .03827 L
.80116 .03833 L
.80132 .03838 L
.80148 .03839 L
.80156 .03839 L
.80164 .03839 L
.80179 .03836 L
.80194 .03831 L
.80208 .03826 L
.80222 .03817 L
.80247 .03798 L
.80278 .03767 L
.80306 .03732 L
.80364 .03636 L
.80428 .03498 L
.80557 .03126 L
.80689 .02637 L
.80813 .02105 L
.80868 .0186 L
.80925 .01597 L
.8094 .0153 L
.80955 .01484 L
.80964 .01525 L
.80972 .01563 L
.80988 .01636 L
.81046 .019 L
.81165 .02416 L
.81291 .02905 L
.81408 .03276 L
.81517 .03537 L
.81575 .03636 L
.81608 .03679 L
.81638 .0371 L
.81663 .03731 L
.81678 .0374 L
.81691 .03746 L
.81705 .03752 L
.8172 .03756 L
.81734 .03757 L
.81747 .03757 L
.81761 .03756 L
Mistroke
.81777 .03752 L
.81785 .03749 L
.81794 .03745 L
.81809 .03736 L
.81839 .03714 L
.81867 .03687 L
.81934 .03593 L
.81997 .0347 L
.82113 .03168 L
.82236 .02751 L
.82351 .02293 L
.82458 .01836 L
.82489 .01698 L
.82518 .01568 L
.82533 .01503 L
.82548 .0151 L
.82557 .0155 L
.82566 .01588 L
.82582 .01658 L
.82716 .02237 L
.82834 .02701 L
.82959 .03118 L
.83073 .03409 L
.83138 .03532 L
.83168 .03576 L
.83199 .03615 L
.83226 .03642 L
.8324 .03653 L
.83255 .03664 L
.83269 .03672 L
.83281 .03678 L
.83294 .03682 L
.83306 .03685 L
.8332 .03687 L
.83335 .03687 L
.83347 .03686 L
.83361 .03683 L
.83376 .03678 L
.83392 .0367 L
.83421 .03651 L
.83452 .03622 L
.83485 .03583 L
.83543 .03491 L
.83613 .03347 L
.83676 .03185 L
.83919 .02349 L
.84032 .01881 L
.84089 .01636 L
.84105 .01569 L
.84113 .01532 L
Mistroke
.84121 .01496 L
.84137 .01515 L
.84151 .01577 L
.84282 .02131 L
.84403 .026 L
.84519 .02993 L
.84583 .03174 L
.84643 .03319 L
.84698 .0343 L
.84749 .0351 L
.84776 .03545 L
.84805 .03576 L
.84834 .036 L
.8485 .0361 L
.84865 .03617 L
.84881 .03623 L
.84889 .03625 L
.84897 .03627 L
.84912 .03628 L
.84926 .03628 L
.84935 .03627 L
.84943 .03625 L
.84958 .03621 L
.84967 .03618 L
.84975 .03614 L
.84993 .03604 L
.8502 .03583 L
.85051 .03553 L
.85112 .03469 L
.85168 .03367 L
.85228 .03233 L
.85337 .02928 L
.85578 .0204 L
.85637 .01798 L
.85669 .01663 L
.85699 .01534 L
.85708 .01499 L
.85717 .01482 L
.85726 .01523 L
.85735 .01561 L
.85768 .01698 L
.85832 .01964 L
.85955 .02444 L
.86071 .02846 L
.86184 .03167 L
.86289 .03389 L
.86343 .03471 L
.86371 .03505 L
.86401 .03534 L
.86418 .03547 L
Mistroke
.86434 .03558 L
.86449 .03565 L
.86457 .03569 L
.86465 .03572 L
.86479 .03576 L
.86493 .03578 L
.86508 .03578 L
.86523 .03577 L
.86539 .03573 L
.86546 .03571 L
.86555 .03568 L
.86585 .03552 L
.86602 .03539 L
.8662 .03524 L
.86652 .03489 L
.86716 .03396 L
.86775 .03285 L
.86893 .02987 L
.87003 .02637 L
.87132 .02162 L
.87195 .0191 L
.87253 .01673 L
.87267 .01614 L
.87282 .0155 L
.87297 .0149 L
.8731 .01507 L
.87325 .01569 L
.87339 .01627 L
.87371 .01757 L
.875 .02266 L
.87724 .0301 L
.8784 .03283 L
.87905 .03395 L
.87935 .03437 L
.87963 .03469 L
.87989 .03494 L
.88018 .03514 L
.88033 .03522 L
.88047 .03528 L
.88062 .03533 L
.88078 .03536 L
.88091 .03536 L
.88106 .03536 L
.88121 .03533 L
.88134 .03529 L
.88146 .03525 L
.88159 .03519 L
.88185 .03502 L
.88215 .03476 L
.88248 .0344 L
Mistroke
.88307 .03353 L
.88365 .03243 L
.88419 .03121 L
.88671 .0233 L
.88732 .02099 L
.88798 .01838 L
.88828 .01716 L
.8886 .01587 L
.88874 .01533 L
.88888 .01476 L
.88903 .0153 L
.88918 .01589 L
.89142 .02453 L
.89265 .02853 L
.8933 .03032 L
.89398 .03194 L
.89458 .03309 L
.8949 .0336 L
.89524 .03406 L
.89556 .03441 L
.89584 .03466 L
.89612 .03484 L
.89626 .0349 L
.89641 .03496 L
.89657 .035 L
.89671 .03502 L
.89679 .03502 L
.89687 .03502 L
.89696 .03501 L
.89705 .035 L
.8972 .03496 L
.89733 .03491 L
.89749 .03483 L
.89765 .03474 L
.89793 .03452 L
.89818 .03427 L
.89877 .0335 L
.89941 .03237 L
.89999 .03111 L
.9013 .02752 L
.90362 .01923 L
.90426 .01672 L
.90458 .01545 L
.90467 .0151 L
.90476 .01472 L
.90485 .01506 L
.90493 .01539 L
.90613 .02011 L
.90735 .02456 L
.90863 .02865 L
Mistroke
.90973 .03143 L
.91036 .03267 L
.91094 .03358 L
.91151 .03421 L
.91179 .03444 L
.91196 .03455 L
.9121 .03462 L
.91224 .03467 L
.91237 .03471 L
.91251 .03474 L
.91266 .03475 L
.91279 .03475 L
.91292 .03473 L
.91304 .0347 L
.91317 .03466 L
.91333 .03458 L
.91348 .0345 L
.91377 .03429 L
.91407 .03399 L
.91441 .03359 L
.91501 .03266 L
.91557 .03157 L
.91685 .02832 L
.91805 .02448 L
.91912 .02059 L
.91969 .01842 L
.9203 .01605 L
.92046 .0154 L
.92062 .01478 L
.92076 .0152 L
.92091 .0158 L
.92148 .01803 L
.92273 .02272 L
.92496 .02971 L
.92609 .03223 L
.92674 .03328 L
.92703 .03365 L
.92735 .03398 L
.92752 .03412 L
.92768 .03424 L
.92784 .03434 L
.92799 .03442 L
.92813 .03447 L
.92827 .03451 L
.92841 .03453 L
.92857 .03454 L
.92873 .03453 L
.92882 .03452 L
.9289 .0345 L
.92907 .03444 L
Mistroke
.92925 .03435 L
.92958 .03413 L
.92988 .03386 L
.93046 .03315 L
.93108 .03212 L
.93219 .02965 L
.93338 .0262 L
.93469 .02168 L
.93528 .01946 L
.93591 .01706 L
.93616 .01606 L
.93631 .01551 L
.93644 .01498 L
.9366 .01507 L
.93674 .01563 L
.93702 .01672 L
.93954 .02584 L
.94071 .02928 L
.94135 .03084 L
.94195 .03206 L
.9425 .03298 L
.94301 .03362 L
.9433 .0339 L
.94357 .03411 L
.94371 .0342 L
.94386 .03427 L
.94395 .0343 L
.94402 .03433 L
.94418 .03437 L
.94432 .03439 L
.94446 .0344 L
.94461 .03438 L
.94477 .03435 L
.94485 .03433 L
.94493 .0343 L
.94509 .03423 L
.94539 .03405 L
.94567 .03381 L
.94597 .0335 L
.9465 .03277 L
.94712 .03169 L
.9477 .03044 L
.94901 .02686 L
.9502 .02292 L
.95145 .0183 L
.95197 .01631 L
.95212 .01574 L
.95226 .01519 L
.95238 .01473 L
.95252 .01526 L
Mistroke
.95312 .01759 L
.95369 .01973 L
.95604 .02771 L
.95669 .02947 L
.95738 .03109 L
.95803 .03234 L
.95863 .03323 L
.95892 .03357 L
.95924 .03387 L
.95956 .03409 L
.95974 .03418 L
.95982 .03422 L
.9599 .03425 L
.96005 .03428 L
.96021 .03431 L
.96035 .03431 L
.96049 .0343 L
.96065 .03427 L
.96079 .03422 L
.96096 .03415 L
.96111 .03406 L
.96139 .03387 L
.96168 .0336 L
.9622 .03295 L
.96277 .03205 L
.96338 .0308 L
.96573 .0241 L
.96703 .0194 L
.96767 .01698 L
.96795 .01591 L
.96809 .01534 L
.96825 .01475 L
.9684 .0153 L
.96855 .01586 L
.96884 .01696 L
.96947 .01936 L
.9708 .02415 L
.97197 .02783 L
.97322 .031 L
.97402 .03251 L
.97476 .0335 L
.97511 .03383 L
.9753 .03397 L
.97549 .03409 L
.97567 .03418 L
.97576 .03421 L
.97586 .03424 L
.97595 .03426 L
.97603 .03427 L
.97611 .03428 L
Mistroke
.97619 .03428 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.03968 .01472 m
.03968 .03431 L
s
.05556 .01472 m
.05556 .0344 L
s
.07143 .01472 m
.07143 .03454 L
s
.0873 .01472 m
.0873 .03475 L
s
.10317 .01472 m
.10317 .03502 L
s
.11905 .01472 m
.11905 .03536 L
s
.13492 .01472 m
.13492 .03578 L
s
.15079 .01472 m
.15079 .03628 L
s
.16667 .01472 m
.16667 .03688 L
s
.18254 .01472 m
.18254 .03757 L
s
.19841 .01472 m
.19841 .03839 L
s
.21429 .01472 m
.21429 .03935 L
s
.23016 .01472 m
.23016 .04048 L
s
.24603 .01472 m
.24603 .04181 L
s
.2619 .01472 m
.2619 .04339 L
s
.27778 .01472 m
.27778 .04527 L
s
.29365 .01472 m
.29365 .04755 L
s
.30952 .01472 m
.30952 .05036 L
s
.3254 .01472 m
.3254 .05388 L
s
.34127 .01472 m
.34127 .05842 L
s
.35714 .01472 m
.35714 .0645 L
s
.37302 .01472 m
.37302 .07308 L
s
.38889 .01472 m
.38889 .08619 L
s
.40476 .01472 m
.40476 .10909 L
s
.42063 .01472 m
.42063 .16084 L
s
.43651 .01472 m
.43651 .41241 L
s
.45238 .01472 m
.45238 .36124 L
s
.46825 .01472 m
.46825 .10807 L
s
.48413 .01472 m
.48413 .05356 L
s
.5 .01472 m
.5 .03428 L
s
.51587 .01472 m
.51587 .05356 L
s
.53175 .01472 m
.53175 .10807 L
s
.54762 .01472 m
.54762 .36124 L
s
.56349 .01472 m
.56349 .41241 L
s
.57937 .01472 m
.57937 .16084 L
s
.59524 .01472 m
.59524 .10909 L
s
.61111 .01472 m
.61111 .08619 L
s
.62698 .01472 m
.62698 .07308 L
s
.64286 .01472 m
.64286 .0645 L
s
.65873 .01472 m
.65873 .05842 L
s
.6746 .01472 m
.6746 .05388 L
s
.69048 .01472 m
.69048 .05036 L
s
.70635 .01472 m
.70635 .04755 L
s
.72222 .01472 m
.72222 .04527 L
s
.7381 .01472 m
.7381 .04339 L
s
.75397 .01472 m
.75397 .04181 L
s
.76984 .01472 m
.76984 .04048 L
s
.78571 .01472 m
.78571 .03935 L
s
.80159 .01472 m
.80159 .03839 L
s
.81746 .01472 m
.81746 .03757 L
s
.83333 .01472 m
.83333 .03688 L
s
.84921 .01472 m
.84921 .03628 L
s
.86508 .01472 m
.86508 .03578 L
s
.88095 .01472 m
.88095 .03536 L
s
.89683 .01472 m
.89683 .03502 L
s
.9127 .01472 m
.9127 .03475 L
s
.92857 .01472 m
.92857 .03454 L
s
.94444 .01472 m
.94444 .0344 L
s
.96032 .01472 m
.96032 .03431 L
s
.97619 .01472 m
.97619 .03428 L
s
.015 w
.03968 .03431 Mdot
.05556 .0344 Mdot
.07143 .03454 Mdot
.0873 .03475 Mdot
.10317 .03502 Mdot
.11905 .03536 Mdot
.13492 .03578 Mdot
.15079 .03628 Mdot
.16667 .03688 Mdot
.18254 .03757 Mdot
.19841 .03839 Mdot
.21429 .03935 Mdot
.23016 .04048 Mdot
.24603 .04181 Mdot
.2619 .04339 Mdot
.27778 .04527 Mdot
.29365 .04755 Mdot
.30952 .05036 Mdot
.3254 .05388 Mdot
.34127 .05842 Mdot
.35714 .0645 Mdot
.37302 .07308 Mdot
.38889 .08619 Mdot
.40476 .10909 Mdot
.42063 .16084 Mdot
.43651 .41241 Mdot
.45238 .36124 Mdot
.46825 .10807 Mdot
.48413 .05356 Mdot
.5 .03428 Mdot
.51587 .05356 Mdot
.53175 .10807 Mdot
.54762 .36124 Mdot
.56349 .41241 Mdot
.57937 .16084 Mdot
.59524 .10909 Mdot
.61111 .08619 Mdot
.62698 .07308 Mdot
.64286 .0645 Mdot
.65873 .05842 Mdot
.6746 .05388 Mdot
.69048 .05036 Mdot
.70635 .04755 Mdot
.72222 .04527 Mdot
.7381 .04339 Mdot
.75397 .04181 Mdot
.76984 .04048 Mdot
.78571 .03935 Mdot
.80159 .03839 Mdot
.81746 .03757 Mdot
.83333 .03688 Mdot
.84921 .03628 Mdot
.86508 .03578 Mdot
.88095 .03536 Mdot
.89683 .03502 Mdot
.9127 .03475 Mdot
.92857 .03454 Mdot
.94444 .0344 Mdot
.96032 .03431 Mdot
.97619 .03428 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.307985 0.0969315 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01719 -12 -4.5 ]
[-0.0125 .01719 0 4.5 ]
[-0.0125 .11412 -12 -4.5 ]
[-0.0125 .11412 0 4.5 ]
[-0.0125 .21105 -12 -4.5 ]
[-0.0125 .21105 0 4.5 ]
[-0.0125 .30798 -6 -4.5 ]
[-0.0125 .30798 0 4.5 ]
[-0.0125 .40492 -6 -4.5 ]
[-0.0125 .40492 0 4.5 ]
[-0.0125 .50185 -6 -4.5 ]
[-0.0125 .50185 0 4.5 ]
[-0.0125 .59878 -6 -4.5 ]
[-0.0125 .59878 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01719 m
.00625 .01719 L
s
[(-3)] -0.0125 .01719 1 0 Mshowa
0 .11412 m
.00625 .11412 L
s
[(-2)] -0.0125 .11412 1 0 Mshowa
0 .21105 m
.00625 .21105 L
s
[(-1)] -0.0125 .21105 1 0 Mshowa
0 .30798 m
.00625 .30798 L
s
[(0)] -0.0125 .30798 1 0 Mshowa
0 .40492 m
.00625 .40492 L
s
[(1)] -0.0125 .40492 1 0 Mshowa
0 .50185 m
.00625 .50185 L
s
[(2)] -0.0125 .50185 1 0 Mshowa
0 .59878 m
.00625 .59878 L
s
[(3)] -0.0125 .59878 1 0 Mshowa
.125 Mabswid
0 .03658 m
.00375 .03658 L
s
0 .05596 m
.00375 .05596 L
s
0 .07535 m
.00375 .07535 L
s
0 .09474 m
.00375 .09474 L
s
0 .13351 m
.00375 .13351 L
s
0 .15289 m
.00375 .15289 L
s
0 .17228 m
.00375 .17228 L
s
0 .19167 m
.00375 .19167 L
s
0 .23044 m
.00375 .23044 L
s
0 .24983 m
.00375 .24983 L
s
0 .26921 m
.00375 .26921 L
s
0 .2886 m
.00375 .2886 L
s
0 .32737 m
.00375 .32737 L
s
0 .34676 m
.00375 .34676 L
s
0 .36614 m
.00375 .36614 L
s
0 .38553 m
.00375 .38553 L
s
0 .4243 m
.00375 .4243 L
s
0 .44369 m
.00375 .44369 L
s
0 .46308 m
.00375 .46308 L
s
0 .48246 m
.00375 .48246 L
s
0 .52123 m
.00375 .52123 L
s
0 .54062 m
.00375 .54062 L
s
0 .56001 m
.00375 .56001 L
s
0 .57939 m
.00375 .57939 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01719 m
1 .01719 L
s
.99375 .11412 m
1 .11412 L
s
.99375 .21105 m
1 .21105 L
s
.99375 .30798 m
1 .30798 L
s
.99375 .40492 m
1 .40492 L
s
.99375 .50185 m
1 .50185 L
s
.99375 .59878 m
1 .59878 L
s
.125 Mabswid
.99625 .03658 m
1 .03658 L
s
.99625 .05596 m
1 .05596 L
s
.99625 .07535 m
1 .07535 L
s
.99625 .09474 m
1 .09474 L
s
.99625 .13351 m
1 .13351 L
s
.99625 .15289 m
1 .15289 L
s
.99625 .17228 m
1 .17228 L
s
.99625 .19167 m
1 .19167 L
s
.99625 .23044 m
1 .23044 L
s
.99625 .24983 m
1 .24983 L
s
.99625 .26921 m
1 .26921 L
s
.99625 .2886 m
1 .2886 L
s
.99625 .32737 m
1 .32737 L
s
.99625 .34676 m
1 .34676 L
s
.99625 .36614 m
1 .36614 L
s
.99625 .38553 m
1 .38553 L
s
.99625 .4243 m
1 .4243 L
s
.99625 .44369 m
1 .44369 L
s
.99625 .46308 m
1 .46308 L
s
.99625 .48246 m
1 .48246 L
s
.99625 .52123 m
1 .52123 L
s
.99625 .54062 m
1 .54062 L
s
.99625 .56001 m
1 .56001 L
s
.99625 .57939 m
1 .57939 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30798 m
1 .30798 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .30798 m
.02608 .26522 L
.02847 .22013 L
.02964 .19804 L
.03089 .17441 L
.03126 .16743 L
.03145 .164 L
.03153 .16249 L
.03161 .16083 L
.03177 .46248 L
.03185 .4609 L
.03193 .45943 L
.03227 .453 L
.03355 .42884 L
.03823 .34068 L
.0406 .29587 L
.0432 .24695 L
.0444 .22428 L
.04568 .20012 L
.0463 .18838 L
.04689 .17733 L
.04715 .1725 L
.04742 .1674 L
.04756 .16473 L
.04771 .46632 L
.04786 .46366 L
.04799 .46117 L
.05268 .3727 L
.05767 .27865 L
.06016 .23159 L
.06126 .2109 L
.06185 .1999 L
.06247 .18805 L
.06277 .18251 L
.06308 .17668 L
.06334 .1717 L
.06349 .16888 L
.06363 .47078 L
.06377 .46811 L
.0639 .46559 L
.06415 .46088 L
.06472 .45031 L
.0671 .40542 L
.07174 .31795 L
.07409 .27365 L
.07667 .22491 L
.07785 .2026 L
.07851 .1903 L
.07883 .18424 L
.07898 .18129 L
Mistroke
.07913 .17862 L
.07927 .17592 L
.0794 .4779 L
.07955 .47521 L
.0797 .47231 L
.08033 .46051 L
.08142 .43984 L
.08637 .34648 L
.08884 .29996 L
.09114 .25658 L
.09336 .21482 L
.09399 .2028 L
.0946 .19143 L
.09486 .18647 L
.095 .18376 L
.09514 .18121 L
.09529 .48299 L
.09536 .48154 L
.09545 .47997 L
.09573 .47464 L
.1007 .38098 L
.10548 .29076 L
.10789 .24528 L
.10895 .22546 L
.11008 .204 L
.11039 .19818 L
.11072 .19203 L
.11085 .18949 L
.111 .18677 L
.11116 .48831 L
.1113 .48552 L
.11245 .46384 L
.11498 .41617 L
.11997 .3222 L
.12246 .2752 L
.12356 .25452 L
.12477 .23168 L
.12532 .22121 L
.12592 .20992 L
.1262 .20473 L
.12649 .19926 L
.12674 .19459 L
.12688 .19194 L
.12701 .494 L
.12715 .4912 L
.12732 .48816 L
.12761 .48264 L
.12816 .47231 L
.12939 .44912 L
.13432 .35616 L
Mistroke
.13677 .30993 L
.13907 .26665 L
.14127 .22517 L
.1419 .21323 L
.14221 .20734 L
.1425 .20188 L
.14264 .19934 L
.14276 .19695 L
.14291 .49871 L
.14304 .49621 L
.14363 .4851 L
.14828 .3974 L
.15323 .30413 L
.1557 .25767 L
.1569 .23498 L
.158 .21431 L
.15826 .20933 L
.15854 .20405 L
.15869 .20129 L
.15877 .50424 L
.15885 .50277 L
.15913 .49741 L
.16021 .47713 L
.16258 .43245 L
.16725 .34445 L
.16962 .29975 L
.17087 .27611 L
.17221 .25088 L
.17288 .23828 L
.17351 .2264 L
.17407 .21573 L
.17423 .21281 L
.17439 .20972 L
.17453 .20708 L
.17469 .50869 L
.17484 .50579 L
.17499 .50304 L
.17526 .49787 L
.17588 .48625 L
.17699 .46527 L
.18161 .37827 L
.18418 .32968 L
.18652 .28571 L
.18769 .26362 L
.18895 .23978 L
.18953 .22882 L
.18985 .22284 L
.19015 .21726 L
.19028 .21481 L
.1904 .2125 L
Mistroke
.19054 .51435 L
.19067 .51192 L
.19124 .50111 L
.19588 .41381 L
.2008 .32093 L
.20325 .27477 L
.20445 .25218 L
.20555 .23151 L
.20581 .2266 L
.20609 .22136 L
.20617 .21981 L
.20624 .21835 L
.20639 .52013 L
.20653 .51757 L
.20667 .5148 L
.20774 .49461 L
.21011 .45005 L
.21505 .35687 L
.21751 .31047 L
.21981 .26714 L
.22095 .24576 L
.22151 .23524 L
.22175 .23061 L
.22202 .2255 L
.22217 .2227 L
.22231 .5246 L
.22246 .52183 L
.22262 .51884 L
.22326 .50667 L
.22439 .48537 L
.22935 .39189 L
.23183 .34525 L
.23413 .30185 L
.23635 .25999 L
.23699 .24794 L
.2373 .24202 L
.23759 .23656 L
.23786 .2316 L
.23799 .2291 L
.23813 .53086 L
.23828 .5281 L
.23844 .52514 L
.23872 .51978 L
.2437 .42599 L
.24849 .33565 L
.25091 .29006 L
.25197 .27021 L
.2531 .24876 L
.25341 .24291 L
.25358 .23972 L
Mistroke
.25374 .23674 L
.25388 .2342 L
.25402 .53599 L
.2541 .53444 L
.25418 .53297 L
.25433 .53021 L
.25548 .5085 L
.25801 .46082 L
.26264 .37362 L
.26498 .3295 L
.26622 .30608 L
.26756 .28086 L
.26818 .26913 L
.26884 .2568 L
.2694 .24627 L
.26955 .24339 L
.26963 .2418 L
.26971 .24031 L
.26987 .54192 L
.27001 .53928 L
.2723 .49606 L
.27695 .40856 L
.2793 .36422 L
.28189 .31549 L
.28307 .29315 L
.28434 .26917 L
.28496 .25755 L
.28526 .25183 L
.2854 .24932 L
.28555 .24654 L
.28568 .24407 L
.2858 .54626 L
.28593 .54381 L
.28607 .54117 L
.28664 .5304 L
.2916 .43703 L
.29637 .34711 L
.29878 .30183 L
.29982 .28208 L
.30038 .27167 L
.30096 .26064 L
.30126 .25498 L
.30135 .25343 L
.30143 .25177 L
.30152 .25019 L
.30159 .55327 L
.30174 .55058 L
.30189 .54765 L
.30218 .5423 L
.30332 .52069 L
Mistroke
.30585 .47313 L
.31075 .38079 L
.31302 .33808 L
.31547 .2919 L
.31613 .27958 L
.31682 .26656 L
.3171 .2612 L
.31726 .25825 L
.31741 .25545 L
.31749 .55839 L
.31758 .55667 L
.31774 .55366 L
.31806 .54778 L
.32049 .50197 L
.32541 .40934 L
.32785 .36334 L
.33014 .32016 L
.33121 .30006 L
.33234 .27891 L
.33292 .26782 L
.33309 .26479 L
.33317 .26312 L
.33326 .26155 L
.33334 .5646 L
.33342 .563 L
.33357 .56022 L
.3347 .53896 L
.33963 .44605 L
.34439 .35659 L
.34677 .31165 L
.34782 .292 L
.34837 .28163 L
.34867 .27594 L
.34896 .27059 L
.34911 .26762 L
.3492 .26595 L
.34928 .56894 L
.34943 .56622 L
.34958 .56336 L
.35016 .55246 L
.3513 .53096 L
.35382 .48355 L
.35841 .39726 L
.36097 .34919 L
.36329 .30543 L
.36385 .29486 L
.36445 .28365 L
.36476 .27781 L
.36485 .2762 L
.36494 .27448 L
Mistroke
.36502 .27285 L
.3651 .57588 L
.36525 .5731 L
.36541 .57006 L
.36571 .56452 L
.36799 .52157 L
.37289 .42946 L
.37761 .34081 L
.37885 .31753 L
.3795 .30527 L
.38019 .29232 L
.38048 .28685 L
.38064 .28384 L
.38079 .28098 L
.38088 .27937 L
.38097 .58214 L
.38105 .58054 L
.38113 .57906 L
.38145 .57305 L
.38262 .55115 L
.38735 .46224 L
.3919 .3768 L
.39443 .32936 L
.39554 .30858 L
.39612 .29759 L
.39644 .29155 L
.3966 .28858 L
.39675 .28584 L
.39689 .58767 L
.39704 .58481 L
.39736 .5788 L
.39792 .56829 L
.39902 .54775 L
.40141 .50287 L
.40598 .41723 L
.40852 .36962 L
.41084 .32611 L
.41199 .3046 L
.4123 .29871 L
.41247 .29548 L
.41256 .2939 L
.41264 .29244 L
.41279 .59411 L
.41287 .59262 L
.41295 .59104 L
.41324 .58567 L
.41552 .54299 L
.4201 .45722 L
.42265 .40948 L
.42498 .36601 L
Mistroke
.42613 .34442 L
.42674 .33304 L
.42739 .32095 L
.42796 .31042 L
.42811 .30753 L
.42828 .30442 L
.42843 .30149 L
.42858 .60332 L
.42871 .60085 L
.42883 .59855 L
.42911 .59334 L
.42967 .58284 L
.43439 .49497 L
.4394 .40175 L
.44422 .31214 L
.44886 .22616 L
.4538 .13503 L
.45626 .08984 L
.45746 .0678 L
.45856 .04771 L
.4591 .0378 L
.45969 .02701 L
.45996 .02207 L
.46011 .01937 L
.46025 .01683 L
.46038 .31897 L
.46052 .3164 L
.46076 .31192 L
.46313 .26881 L
.46808 .17924 L
.47055 .13503 L
.47286 .09418 L
.474 .07409 L
.47507 .05521 L
.47567 .04482 L
.47583 .04198 L
.476 .03897 L
.47615 .0364 L
.47624 .33946 L
.47632 .3381 L
.47745 .31856 L
.48212 .23957 L
.48709 .16049 L
.48957 .12393 L
.49078 .10709 L
.49135 .09938 L
.49161 .09605 L
.49175 .09418 L
.49188 .09244 L
.49201 .09075 L
Mistroke
.49215 .39347 L
.4923 .39156 L
.49243 .38983 L
.49303 .38232 L
.49411 .36921 L
.49649 .34273 L
.50129 .29559 L
.50349 .27352 L
.50474 .25999 L
.50591 .2465 L
.50706 .23255 L
.50737 .2286 L
.50755 .22642 L
.50771 .22438 L
.50784 .22262 L
.50799 .52525 L
.50807 .52416 L
.50815 .52313 L
.5083 .5212 L
.51083 .48624 L
.51547 .41554 L
.51782 .37739 L
.5204 .33416 L
.52159 .31402 L
.52224 .30284 L
.52286 .29217 L
.52343 .28225 L
.52359 .27952 L
.52368 .27802 L
.52376 .27661 L
.52392 .57839 L
.52406 .5759 L
.52516 .55676 L
.52981 .47443 L
.53476 .38542 L
.53723 .34066 L
.53843 .31874 L
.539 .30834 L
.53925 .30377 L
.5394 .30117 L
.53953 .29873 L
.53966 .29641 L
.53979 .59842 L
.53994 .59574 L
.54007 .59329 L
.54067 .58246 L
.54174 .56276 L
.54411 .51927 L
.5489 .43116 L
.5535 .34607 L
Mistroke
.5584 .25523 L
.56311 .16755 L
.56552 .12275 L
.56812 .0742 L
.56934 .05141 L
.57001 .03896 L
.57064 .02731 L
.57091 .02222 L
.57117 .01738 L
.57131 .01472 L
.57147 .31633 L
.57161 .31369 L
.57174 .31125 L
.57295 .28862 L
.57768 .20021 L
.58223 .11513 L
.58476 .06785 L
.58586 .04713 L
.58645 .03616 L
.58677 .03013 L
.58693 .02717 L
.58707 .02444 L
.58722 .02175 L
.58737 .32343 L
.58752 .32057 L
.58769 .31743 L
.58825 .30694 L
.58934 .28644 L
.59174 .24162 L
.5966 .15049 L
.59883 .10853 L
.60127 .06274 L
.60191 .05072 L
.60227 .04413 L
.6026 .03792 L
.60291 .03211 L
.60299 .03052 L
.60308 .02884 L
.60316 .0274 L
.60324 .33035 L
.60339 .32762 L
.60354 .32468 L
.60382 .3194 L
.60625 .27391 L
.61124 .18021 L
.61374 .1333 L
.61605 .08991 L
.6172 .06818 L
.61829 .04778 L
.61855 .04279 L
Mistroke
.61883 .03754 L
.61898 .03478 L
.61906 .33775 L
.61914 .3363 L
.61942 .33102 L
.62067 .30754 L
.62538 .219 L
.62778 .17383 L
.63039 .12488 L
.63161 .10195 L
.6329 .07768 L
.634 .05696 L
.6343 .05128 L
.63447 .04815 L
.63463 .04518 L
.63477 .04243 L
.63486 .04087 L
.63493 .34395 L
.63507 .3414 L
.63521 .33869 L
.64023 .24421 L
.64507 .15316 L
.6473 .11135 L
.64856 .08763 L
.64917 .07606 L
.64973 .06553 L
.65002 .06013 L
.65033 .05427 L
.65047 .05158 L
.65062 .04873 L
.65075 .0463 L
.6509 .34814 L
.65098 .34658 L
.65106 .34509 L
.65121 .34231 L
.65154 .33603 L
.65214 .32469 L
.65469 .27684 L
.65929 .19019 L
.66186 .14183 L
.66419 .09796 L
.66536 .07601 L
.66597 .06446 L
.6663 .05814 L
.66647 .05506 L
.66662 .05225 L
.66676 .35412 L
.66689 .35161 L
.66719 .34607 L
.66781 .33433 L
Mistroke
.66891 .31368 L
.67353 .22669 L
.67586 .1827 L
.67844 .13412 L
.67962 .11201 L
.68088 .08816 L
.68147 .07719 L
.68178 .07121 L
.68208 .06564 L
.68233 .06088 L
.68248 .05821 L
.6826 .3603 L
.68275 .35764 L
.6829 .35475 L
.68318 .34951 L
.68811 .25661 L
.69286 .16715 L
.69525 .12221 L
.69629 .10256 L
.69743 .08113 L
.69773 .07544 L
.69805 .06938 L
.69821 .06644 L
.69835 .06367 L
.69849 .3657 L
.69863 .36301 L
.69977 .3415 L
.70229 .29405 L
.70724 .20082 L
.70971 .15436 L
.71201 .11103 L
.71314 .08961 L
.7137 .07907 L
.71395 .07444 L
.71408 .07198 L
.71422 .06933 L
.71437 .37105 L
.71451 .36842 L
.71481 .36265 L
.71546 .35048 L
.71659 .32919 L
.72156 .23564 L
.72403 .18894 L
.72634 .14552 L
.72856 .1036 L
.7292 .09153 L
.72952 .0856 L
.72981 .08014 L
.72995 .07757 L
.73007 .07517 L
Mistroke
.73021 .37719 L
.73035 .37444 L
.73094 .36337 L
.73563 .27506 L
.74061 .18118 L
.7431 .13423 L
.7442 .11357 L
.74478 .10259 L
.74541 .09074 L
.7457 .08522 L
.74586 .08221 L
.74601 .07941 L
.74614 .38153 L
.74627 .37896 L
.74656 .37353 L
.74764 .3531 L
.75002 .30826 L
.75502 .21406 L
.75753 .16686 L
.75863 .14613 L
.75984 .1233 L
.7604 .11275 L
.761 .10141 L
.76129 .09592 L
.76157 .0907 L
.76169 .08844 L
.76182 .08602 L
.76196 .38789 L
.76209 .38543 L
.76447 .3405 L
.76949 .24598 L
.772 .19854 L
.77432 .1549 L
.77658 .11228 L
.77713 .10193 L
.77743 .09622 L
.77758 .09342 L
.77772 .09082 L
.7778 .39386 L
.77788 .39229 L
.77806 .38897 L
.77837 .38316 L
.77897 .37178 L
.78352 .28597 L
.78837 .19457 L
.7906 .15257 L
.79186 .12876 L
.79248 .11716 L
.79304 .10662 L
.79333 .10118 L
Mistroke
.79348 .09832 L
.79356 .09675 L
.79364 .09529 L
.79378 .39716 L
.79393 .39424 L
.79421 .38911 L
.79546 .36558 L
.798 .31761 L
.80268 .22935 L
.80506 .18445 L
.80632 .16074 L
.80766 .13551 L
.80833 .12282 L
.80866 .1166 L
.80897 .11089 L
.80924 .10567 L
.80938 .10305 L
.80954 .40469 L
.80969 .4018 L
.80985 .3987 L
.81015 .39312 L
.81246 .34963 L
.81745 .25547 L
.81995 .20833 L
.82226 .16476 L
.82342 .14291 L
.82451 .12242 L
.82506 .11213 L
.82521 .10931 L
.82536 .10635 L
.8255 .40834 L
.82564 .40557 L
.82689 .38202 L
.83179 .28968 L
.83651 .20078 L
.83775 .17743 L
.83909 .15215 L
.8397 .14055 L
.84035 .12829 L
.84091 .11781 L
.84106 .11494 L
.84114 .11336 L
.84122 .11187 L
.84138 .41348 L
.84152 .41083 L
.84614 .32375 L
.85105 .2311 L
.85349 .1851 L
.85469 .16257 L
.85578 .14189 L
Mistroke
.85634 .13148 L
.85685 .1218 L
.85698 .11929 L
.85711 .11691 L
.85725 .4187 L
.85739 .41621 L
.85797 .40515 L
.86033 .36064 L
.86497 .27325 L
.86732 .229 L
.8699 .18028 L
.87108 .158 L
.87173 .14572 L
.87235 .13405 L
.87263 .12881 L
.87278 .12594 L
.87293 .12323 L
.87301 .12169 L
.8731 .42454 L
.87325 .42163 L
.87355 .41595 L
.87465 .39528 L
.8796 .302 L
.88206 .25552 L
.88436 .21216 L
.88657 .17046 L
.88721 .15845 L
.88781 .14708 L
.88836 .13687 L
.8885 .13407 L
.88866 .1311 L
.8888 .12857 L
.88894 .43029 L
.88909 .42752 L
.88923 .42494 L
.88954 .4191 L
.89016 .40732 L
.89128 .38626 L
.8938 .33883 L
.89851 .25 L
.90091 .20468 L
.90218 .18083 L
.90352 .15559 L
.90409 .14472 L
.90441 .13873 L
.90457 .13577 L
.90471 .13304 L
.90479 .43601 L
.90488 .43436 L
.90507 .43086 L
Mistroke
.90539 .42475 L
.90603 .41277 L
.90834 .36915 L
.91336 .27443 L
.91589 .22685 L
.91821 .18315 L
.91938 .16103 L
.91995 .15023 L
.9202 .14552 L
.92047 .14041 L
.92062 .13763 L
.92076 .43958 L
.92089 .43713 L
.92102 .43453 L
.92161 .42341 L
.92286 .39985 L
.92743 .31384 L
.92996 .26602 L
.93228 .22225 L
.93343 .20065 L
.93468 .17707 L
.93525 .16629 L
.93586 .1548 L
.93616 .14921 L
.9363 .14647 L
.93644 .14395 L
.93656 .44617 L
.93669 .44375 L
.93696 .43863 L
.94154 .35231 L
.94641 .26042 L
.94866 .21806 L
.94984 .19571 L
.9511 .17197 L
.95173 .16005 L
.95191 .15678 L
.95209 .15326 L
.95218 .15164 L
.95227 .14994 L
.95235 .14848 L
.95243 .45141 L
.95251 .44985 L
.95259 .44837 L
.95274 .4456 L
.95307 .43939 L
.95366 .42821 L
.95609 .38246 L
.96073 .29501 L
.96308 .25072 L
.96566 .20199 L
Mistroke
.96684 .17969 L
.9675 .16739 L
.96782 .16134 L
.96797 .15839 L
.96812 .15572 L
.96826 .45754 L
.96839 .455 L
.96869 .44942 L
.96932 .43761 L
.97041 .41694 L
.97507 .32918 L
.97619 .30799 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.03968 .30798 m
.03968 .31323 L
s
.05556 .30798 m
.05556 .31849 L
s
.07143 .30798 m
.07143 .32374 L
s
.0873 .30798 m
.0873 .32899 L
s
.10317 .30798 m
.10317 .33425 L
s
.11905 .30798 m
.11905 .33952 L
s
.13492 .30798 m
.13492 .34479 L
s
.15079 .30798 m
.15079 .35007 L
s
.16667 .30798 m
.16667 .35536 L
s
.18254 .30798 m
.18254 .36066 L
s
.19841 .30798 m
.19841 .36598 L
s
.21429 .30798 m
.21429 .37131 L
s
.23016 .30798 m
.23016 .37666 L
s
.24603 .30798 m
.24603 .38204 L
s
.2619 .30798 m
.2619 .38744 L
s
.27778 .30798 m
.27778 .39289 L
s
.29365 .30798 m
.29365 .39837 L
s
.30952 .30798 m
.30952 .40392 L
s
.3254 .30798 m
.3254 .40954 L
s
.34127 .30798 m
.34127 .41525 L
s
.35714 .30798 m
.35714 .42109 L
s
.37302 .30798 m
.37302 .42711 L
s
.38889 .30798 m
.38889 .43337 L
s
.40476 .30798 m
.40476 .44 L
s
.42063 .30798 m
.42063 .44723 L
s
.43651 .30798 m
.43651 .45547 L
s
.45238 .30798 m
.45238 .1612 L
s
.46825 .30798 m
.46825 .17619 L
s
.48413 .30798 m
.48413 .20689 L
s
.5 .30798 m
.5 .30798 L
s
.51587 .30798 m
.51587 .40908 L
s
.53175 .30798 m
.53175 .43978 L
s
.54762 .30798 m
.54762 .45477 L
s
.56349 .30798 m
.56349 .1605 L
s
.57937 .30798 m
.57937 .16874 L
s
.59524 .30798 m
.59524 .17597 L
s
.61111 .30798 m
.61111 .1826 L
s
.62698 .30798 m
.62698 .18886 L
s
.64286 .30798 m
.64286 .19488 L
s
.65873 .30798 m
.65873 .20072 L
s
.6746 .30798 m
.6746 .20643 L
s
.69048 .30798 m
.69048 .21205 L
s
.70635 .30798 m
.70635 .2176 L
s
.72222 .30798 m
.72222 .22308 L
s
.7381 .30798 m
.7381 .22853 L
s
.75397 .30798 m
.75397 .23393 L
s
.76984 .30798 m
.76984 .23931 L
s
.78571 .30798 m
.78571 .24466 L
s
.80159 .30798 m
.80159 .24999 L
s
.81746 .30798 m
.81746 .25531 L
s
.83333 .30798 m
.83333 .26061 L
s
.84921 .30798 m
.84921 .2659 L
s
.86508 .30798 m
.86508 .27118 L
s
.88095 .30798 m
.88095 .27645 L
s
.89683 .30798 m
.89683 .28172 L
s
.9127 .30798 m
.9127 .28698 L
s
.92857 .30798 m
.92857 .29223 L
s
.94444 .30798 m
.94444 .29748 L
s
.96032 .30798 m
.96032 .30274 L
s
.97619 .30798 m
.97619 .30798 L
s
.015 w
.03968 .31323 Mdot
.05556 .31849 Mdot
.07143 .32374 Mdot
.0873 .32899 Mdot
.10317 .33425 Mdot
.11905 .33952 Mdot
.13492 .34479 Mdot
.15079 .35007 Mdot
.16667 .35536 Mdot
.18254 .36066 Mdot
.19841 .36598 Mdot
.21429 .37131 Mdot
.23016 .37666 Mdot
.24603 .38204 Mdot
.2619 .38744 Mdot
.27778 .39289 Mdot
.29365 .39837 Mdot
.30952 .40392 Mdot
.3254 .40954 Mdot
.34127 .41525 Mdot
.35714 .42109 Mdot
.37302 .42711 Mdot
.38889 .43337 Mdot
.40476 .44 Mdot
.42063 .44723 Mdot
.43651 .45547 Mdot
.45238 .1612 Mdot
.46825 .17619 Mdot
.48413 .20689 Mdot
.5 .30798 Mdot
.51587 .40908 Mdot
.53175 .43978 Mdot
.54762 .45477 Mdot
.56349 .1605 Mdot
.57937 .16874 Mdot
.59524 .17597 Mdot
.61111 .1826 Mdot
.62698 .18886 Mdot
.64286 .19488 Mdot
.65873 .20072 Mdot
.6746 .20643 Mdot
.69048 .21205 Mdot
.70635 .2176 Mdot
.72222 .22308 Mdot
.7381 .22853 Mdot
.75397 .23393 Mdot
.76984 .23931 Mdot
.78571 .24466 Mdot
.80159 .24999 Mdot
.81746 .25531 Mdot
.83333 .26061 Mdot
.84921 .2659 Mdot
.86508 .27118 Mdot
.88095 .27645 Mdot
.89683 .28172 Mdot
.9127 .28698 Mdot
.92857 .29223 Mdot
.94444 .29748 Mdot
.96032 .30274 Mdot
.97619 .30798 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0161421 0.0147151 0.0289582 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18523 -0.0125 -6 -9 ]
[.18523 -0.0125 6 0 ]
[.34665 -0.0125 -6 -9 ]
[.34665 -0.0125 6 0 ]
[.50807 -0.0125 -6 -9 ]
[.50807 -0.0125 6 0 ]
[.66949 -0.0125 -6 -9 ]
[.66949 -0.0125 6 0 ]
[.83091 -0.0125 -6 -9 ]
[.83091 -0.0125 6 0 ]
[.99233 -0.0125 -6 -9 ]
[.99233 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15951 -6 -4.5 ]
[-0.0125 .15951 0 4.5 ]
[-0.0125 .3043 -12 -4.5 ]
[-0.0125 .3043 0 4.5 ]
[-0.0125 .44909 -12 -4.5 ]
[-0.0125 .44909 0 4.5 ]
[-0.0125 .59388 -12 -4.5 ]
[-0.0125 .59388 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18523 0 m
.18523 .00625 L
s
[(10)] .18523 -0.0125 0 1 Mshowa
.34665 0 m
.34665 .00625 L
s
[(20)] .34665 -0.0125 0 1 Mshowa
.50807 0 m
.50807 .00625 L
s
[(30)] .50807 -0.0125 0 1 Mshowa
.66949 0 m
.66949 .00625 L
s
[(40)] .66949 -0.0125 0 1 Mshowa
.83091 0 m
.83091 .00625 L
s
[(50)] .83091 -0.0125 0 1 Mshowa
.99233 0 m
.99233 .00625 L
s
[(60)] .99233 -0.0125 0 1 Mshowa
.125 Mabswid
.05609 0 m
.05609 .00375 L
s
.08838 0 m
.08838 .00375 L
s
.12066 0 m
.12066 .00375 L
s
.15295 0 m
.15295 .00375 L
s
.21751 0 m
.21751 .00375 L
s
.2498 0 m
.2498 .00375 L
s
.28208 0 m
.28208 .00375 L
s
.31437 0 m
.31437 .00375 L
s
.37893 0 m
.37893 .00375 L
s
.41122 0 m
.41122 .00375 L
s
.4435 0 m
.4435 .00375 L
s
.47579 0 m
.47579 .00375 L
s
.54036 0 m
.54036 .00375 L
s
.57264 0 m
.57264 .00375 L
s
.60492 0 m
.60492 .00375 L
s
.63721 0 m
.63721 .00375 L
s
.70178 0 m
.70178 .00375 L
s
.73406 0 m
.73406 .00375 L
s
.76634 0 m
.76634 .00375 L
s
.79863 0 m
.79863 .00375 L
s
.8632 0 m
.8632 .00375 L
s
.89548 0 m
.89548 .00375 L
s
.92776 0 m
.92776 .00375 L
s
.96005 0 m
.96005 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15951 m
.00625 .15951 L
s
[(5)] -0.0125 .15951 1 0 Mshowa
0 .3043 m
.00625 .3043 L
s
[(10)] -0.0125 .3043 1 0 Mshowa
0 .44909 m
.00625 .44909 L
s
[(15)] -0.0125 .44909 1 0 Mshowa
0 .59388 m
.00625 .59388 L
s
[(20)] -0.0125 .59388 1 0 Mshowa
.125 Mabswid
0 .04367 m
.00375 .04367 L
s
0 .07263 m
.00375 .07263 L
s
0 .10159 m
.00375 .10159 L
s
0 .13055 m
.00375 .13055 L
s
0 .18846 m
.00375 .18846 L
s
0 .21742 m
.00375 .21742 L
s
0 .24638 m
.00375 .24638 L
s
0 .27534 m
.00375 .27534 L
s
0 .33326 m
.00375 .33326 L
s
0 .36221 m
.00375 .36221 L
s
0 .39117 m
.00375 .39117 L
s
0 .42013 m
.00375 .42013 L
s
0 .47805 m
.00375 .47805 L
s
0 .50701 m
.00375 .50701 L
s
0 .53596 m
.00375 .53596 L
s
0 .56492 m
.00375 .56492 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18523 .61178 m
.18523 .61803 L
s
.34665 .61178 m
.34665 .61803 L
s
.50807 .61178 m
.50807 .61803 L
s
.66949 .61178 m
.66949 .61803 L
s
.83091 .61178 m
.83091 .61803 L
s
.99233 .61178 m
.99233 .61803 L
s
.125 Mabswid
.05609 .61428 m
.05609 .61803 L
s
.08838 .61428 m
.08838 .61803 L
s
.12066 .61428 m
.12066 .61803 L
s
.15295 .61428 m
.15295 .61803 L
s
.21751 .61428 m
.21751 .61803 L
s
.2498 .61428 m
.2498 .61803 L
s
.28208 .61428 m
.28208 .61803 L
s
.31437 .61428 m
.31437 .61803 L
s
.37893 .61428 m
.37893 .61803 L
s
.41122 .61428 m
.41122 .61803 L
s
.4435 .61428 m
.4435 .61803 L
s
.47579 .61428 m
.47579 .61803 L
s
.54036 .61428 m
.54036 .61803 L
s
.57264 .61428 m
.57264 .61803 L
s
.60492 .61428 m
.60492 .61803 L
s
.63721 .61428 m
.63721 .61803 L
s
.70178 .61428 m
.70178 .61803 L
s
.73406 .61428 m
.73406 .61803 L
s
.76634 .61428 m
.76634 .61803 L
s
.79863 .61428 m
.79863 .61803 L
s
.8632 .61428 m
.8632 .61803 L
s
.89548 .61428 m
.89548 .61803 L
s
.92776 .61428 m
.92776 .61803 L
s
.96005 .61428 m
.96005 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15951 m
1 .15951 L
s
.99375 .3043 m
1 .3043 L
s
.99375 .44909 m
1 .44909 L
s
.99375 .59388 m
1 .59388 L
s
.125 Mabswid
.99625 .04367 m
1 .04367 L
s
.99625 .07263 m
1 .07263 L
s
.99625 .10159 m
1 .10159 L
s
.99625 .13055 m
1 .13055 L
s
.99625 .18846 m
1 .18846 L
s
.99625 .21742 m
1 .21742 L
s
.99625 .24638 m
1 .24638 L
s
.99625 .27534 m
1 .27534 L
s
.99625 .33326 m
1 .33326 L
s
.99625 .36221 m
1 .36221 L
s
.99625 .39117 m
1 .39117 L
s
.99625 .42013 m
1 .42013 L
s
.99625 .47805 m
1 .47805 L
s
.99625 .50701 m
1 .50701 L
s
.99625 .53596 m
1 .53596 L
s
.99625 .56492 m
1 .56492 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .04367 L
s
.03995 .01472 m
.03995 .07221 L
s
.05609 .01472 m
.05609 .15288 L
s
.07224 .01472 m
.07224 .52758 L
s
.08838 .01472 m
.08838 .60332 L
s
.10452 .01472 m
.10452 .23099 L
s
.12066 .01472 m
.12066 .1544 L
s
.1368 .01472 m
.1368 .12051 L
s
.15295 .01472 m
.15295 .10109 L
s
.16909 .01472 m
.16909 .08839 L
s
.18523 .01472 m
.18523 .0794 L
s
.20137 .01472 m
.20137 .07268 L
s
.21751 .01472 m
.21751 .06747 L
s
.23366 .01472 m
.23366 .06332 L
s
.2498 .01472 m
.2498 .05994 L
s
.26594 .01472 m
.26594 .05715 L
s
.28208 .01472 m
.28208 .05482 L
s
.29822 .01472 m
.29822 .05285 L
s
.31437 .01472 m
.31437 .05118 L
s
.33051 .01472 m
.33051 .04976 L
s
.34665 .01472 m
.34665 .04855 L
s
.36279 .01472 m
.36279 .04751 L
s
.37893 .01472 m
.37893 .04663 L
s
.39508 .01472 m
.39508 .04589 L
s
.41122 .01472 m
.41122 .04528 L
s
.42736 .01472 m
.42736 .04477 L
s
.4435 .01472 m
.4435 .04437 L
s
.45964 .01472 m
.45964 .04406 L
s
.47579 .01472 m
.47579 .04384 L
s
.49193 .01472 m
.49193 .04372 L
s
.50807 .01472 m
.50807 .04367 L
s
.52421 .01472 m
.52421 .04372 L
s
.54036 .01472 m
.54036 .04384 L
s
.5565 .01472 m
.5565 .04406 L
s
.57264 .01472 m
.57264 .04437 L
s
.58878 .01472 m
.58878 .04477 L
s
.60492 .01472 m
.60492 .04528 L
s
.62107 .01472 m
.62107 .04589 L
s
.63721 .01472 m
.63721 .04663 L
s
.65335 .01472 m
.65335 .04751 L
s
.66949 .01472 m
.66949 .04855 L
s
.68563 .01472 m
.68563 .04976 L
s
.70178 .01472 m
.70178 .05118 L
s
.71792 .01472 m
.71792 .05285 L
s
.73406 .01472 m
.73406 .05482 L
s
.7502 .01472 m
.7502 .05715 L
s
.76634 .01472 m
.76634 .05994 L
s
.78249 .01472 m
.78249 .06332 L
s
.79863 .01472 m
.79863 .06747 L
s
.81477 .01472 m
.81477 .07268 L
s
.83091 .01472 m
.83091 .0794 L
s
.84705 .01472 m
.84705 .08839 L
s
.8632 .01472 m
.8632 .10109 L
s
.87934 .01472 m
.87934 .12051 L
s
.89548 .01472 m
.89548 .1544 L
s
.91162 .01472 m
.91162 .23099 L
s
.92776 .01472 m
.92776 .60332 L
s
.94391 .01472 m
.94391 .52758 L
s
.96005 .01472 m
.96005 .15288 L
s
.97619 .01472 m
.97619 .07221 L
s
.015 w
.02381 .04367 Mdot
.03995 .07221 Mdot
.05609 .15288 Mdot
.07224 .52758 Mdot
.08838 .60332 Mdot
.10452 .23099 Mdot
.12066 .1544 Mdot
.1368 .12051 Mdot
.15295 .10109 Mdot
.16909 .08839 Mdot
.18523 .0794 Mdot
.20137 .07268 Mdot
.21751 .06747 Mdot
.23366 .06332 Mdot
.2498 .05994 Mdot
.26594 .05715 Mdot
.28208 .05482 Mdot
.29822 .05285 Mdot
.31437 .05118 Mdot
.33051 .04976 Mdot
.34665 .04855 Mdot
.36279 .04751 Mdot
.37893 .04663 Mdot
.39508 .04589 Mdot
.41122 .04528 Mdot
.42736 .04477 Mdot
.4435 .04437 Mdot
.45964 .04406 Mdot
.47579 .04384 Mdot
.49193 .04372 Mdot
.50807 .04367 Mdot
.52421 .04372 Mdot
.54036 .04384 Mdot
.5565 .04406 Mdot
.57264 .04437 Mdot
.58878 .04477 Mdot
.60492 .04528 Mdot
.62107 .04589 Mdot
.63721 .04663 Mdot
.65335 .04751 Mdot
.66949 .04855 Mdot
.68563 .04976 Mdot
.70178 .05118 Mdot
.71792 .05285 Mdot
.73406 .05482 Mdot
.7502 .05715 Mdot
.76634 .05994 Mdot
.78249 .06332 Mdot
.79863 .06747 Mdot
.81477 .07268 Mdot
.83091 .0794 Mdot
.84705 .08839 Mdot
.8632 .10109 Mdot
.87934 .12051 Mdot
.89548 .1544 Mdot
.91162 .23099 Mdot
.92776 .60332 Mdot
.94391 .52758 Mdot
.96005 .15288 Mdot
.97619 .07221 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0161421 0.309017 0.0983632 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18523 -0.0125 -6 -9 ]
[.18523 -0.0125 6 0 ]
[.34665 -0.0125 -6 -9 ]
[.34665 -0.0125 6 0 ]
[.50807 -0.0125 -6 -9 ]
[.50807 -0.0125 6 0 ]
[.66949 -0.0125 -6 -9 ]
[.66949 -0.0125 6 0 ]
[.83091 -0.0125 -6 -9 ]
[.83091 -0.0125 6 0 ]
[.99233 -0.0125 -6 -9 ]
[.99233 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01393 -12 -4.5 ]
[-0.0125 .01393 0 4.5 ]
[-0.0125 .11229 -12 -4.5 ]
[-0.0125 .11229 0 4.5 ]
[-0.0125 .21065 -12 -4.5 ]
[-0.0125 .21065 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40738 -6 -4.5 ]
[-0.0125 .40738 0 4.5 ]
[-0.0125 .50574 -6 -4.5 ]
[-0.0125 .50574 0 4.5 ]
[-0.0125 .60411 -6 -4.5 ]
[-0.0125 .60411 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18523 0 m
.18523 .00625 L
s
[(10)] .18523 -0.0125 0 1 Mshowa
.34665 0 m
.34665 .00625 L
s
[(20)] .34665 -0.0125 0 1 Mshowa
.50807 0 m
.50807 .00625 L
s
[(30)] .50807 -0.0125 0 1 Mshowa
.66949 0 m
.66949 .00625 L
s
[(40)] .66949 -0.0125 0 1 Mshowa
.83091 0 m
.83091 .00625 L
s
[(50)] .83091 -0.0125 0 1 Mshowa
.99233 0 m
.99233 .00625 L
s
[(60)] .99233 -0.0125 0 1 Mshowa
.125 Mabswid
.05609 0 m
.05609 .00375 L
s
.08838 0 m
.08838 .00375 L
s
.12066 0 m
.12066 .00375 L
s
.15295 0 m
.15295 .00375 L
s
.21751 0 m
.21751 .00375 L
s
.2498 0 m
.2498 .00375 L
s
.28208 0 m
.28208 .00375 L
s
.31437 0 m
.31437 .00375 L
s
.37893 0 m
.37893 .00375 L
s
.41122 0 m
.41122 .00375 L
s
.4435 0 m
.4435 .00375 L
s
.47579 0 m
.47579 .00375 L
s
.54036 0 m
.54036 .00375 L
s
.57264 0 m
.57264 .00375 L
s
.60492 0 m
.60492 .00375 L
s
.63721 0 m
.63721 .00375 L
s
.70178 0 m
.70178 .00375 L
s
.73406 0 m
.73406 .00375 L
s
.76634 0 m
.76634 .00375 L
s
.79863 0 m
.79863 .00375 L
s
.8632 0 m
.8632 .00375 L
s
.89548 0 m
.89548 .00375 L
s
.92776 0 m
.92776 .00375 L
s
.96005 0 m
.96005 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01393 m
.00625 .01393 L
s
[(-3)] -0.0125 .01393 1 0 Mshowa
0 .11229 m
.00625 .11229 L
s
[(-2)] -0.0125 .11229 1 0 Mshowa
0 .21065 m
.00625 .21065 L
s
[(-1)] -0.0125 .21065 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .40738 m
.00625 .40738 L
s
[(1)] -0.0125 .40738 1 0 Mshowa
0 .50574 m
.00625 .50574 L
s
[(2)] -0.0125 .50574 1 0 Mshowa
0 .60411 m
.00625 .60411 L
s
[(3)] -0.0125 .60411 1 0 Mshowa
.125 Mabswid
0 .0336 m
.00375 .0336 L
s
0 .05327 m
.00375 .05327 L
s
0 .07295 m
.00375 .07295 L
s
0 .09262 m
.00375 .09262 L
s
0 .13196 m
.00375 .13196 L
s
0 .15164 m
.00375 .15164 L
s
0 .17131 m
.00375 .17131 L
s
0 .19098 m
.00375 .19098 L
s
0 .23033 m
.00375 .23033 L
s
0 .25 m
.00375 .25 L
s
0 .26967 m
.00375 .26967 L
s
0 .28934 m
.00375 .28934 L
s
0 .32869 m
.00375 .32869 L
s
0 .34836 m
.00375 .34836 L
s
0 .36803 m
.00375 .36803 L
s
0 .38771 m
.00375 .38771 L
s
0 .42705 m
.00375 .42705 L
s
0 .44673 m
.00375 .44673 L
s
0 .4664 m
.00375 .4664 L
s
0 .48607 m
.00375 .48607 L
s
0 .52542 m
.00375 .52542 L
s
0 .54509 m
.00375 .54509 L
s
0 .56476 m
.00375 .56476 L
s
0 .58443 m
.00375 .58443 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18523 .61178 m
.18523 .61803 L
s
.34665 .61178 m
.34665 .61803 L
s
.50807 .61178 m
.50807 .61803 L
s
.66949 .61178 m
.66949 .61803 L
s
.83091 .61178 m
.83091 .61803 L
s
.99233 .61178 m
.99233 .61803 L
s
.125 Mabswid
.05609 .61428 m
.05609 .61803 L
s
.08838 .61428 m
.08838 .61803 L
s
.12066 .61428 m
.12066 .61803 L
s
.15295 .61428 m
.15295 .61803 L
s
.21751 .61428 m
.21751 .61803 L
s
.2498 .61428 m
.2498 .61803 L
s
.28208 .61428 m
.28208 .61803 L
s
.31437 .61428 m
.31437 .61803 L
s
.37893 .61428 m
.37893 .61803 L
s
.41122 .61428 m
.41122 .61803 L
s
.4435 .61428 m
.4435 .61803 L
s
.47579 .61428 m
.47579 .61803 L
s
.54036 .61428 m
.54036 .61803 L
s
.57264 .61428 m
.57264 .61803 L
s
.60492 .61428 m
.60492 .61803 L
s
.63721 .61428 m
.63721 .61803 L
s
.70178 .61428 m
.70178 .61803 L
s
.73406 .61428 m
.73406 .61803 L
s
.76634 .61428 m
.76634 .61803 L
s
.79863 .61428 m
.79863 .61803 L
s
.8632 .61428 m
.8632 .61803 L
s
.89548 .61428 m
.89548 .61803 L
s
.92776 .61428 m
.92776 .61803 L
s
.96005 .61428 m
.96005 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01393 m
1 .01393 L
s
.99375 .11229 m
1 .11229 L
s
.99375 .21065 m
1 .21065 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .40738 m
1 .40738 L
s
.99375 .50574 m
1 .50574 L
s
.99375 .60411 m
1 .60411 L
s
.125 Mabswid
.99625 .0336 m
1 .0336 L
s
.99625 .05327 m
1 .05327 L
s
.99625 .07295 m
1 .07295 L
s
.99625 .09262 m
1 .09262 L
s
.99625 .13196 m
1 .13196 L
s
.99625 .15164 m
1 .15164 L
s
.99625 .17131 m
1 .17131 L
s
.99625 .19098 m
1 .19098 L
s
.99625 .23033 m
1 .23033 L
s
.99625 .25 m
1 .25 L
s
.99625 .26967 m
1 .26967 L
s
.99625 .28934 m
1 .28934 L
s
.99625 .32869 m
1 .32869 L
s
.99625 .34836 m
1 .34836 L
s
.99625 .36803 m
1 .36803 L
s
.99625 .38771 m
1 .38771 L
s
.99625 .42705 m
1 .42705 L
s
.99625 .44673 m
1 .44673 L
s
.99625 .4664 m
1 .4664 L
s
.99625 .48607 m
1 .48607 L
s
.99625 .52542 m
1 .52542 L
s
.99625 .54509 m
1 .54509 L
s
.99625 .56476 m
1 .56476 L
s
.99625 .58443 m
1 .58443 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .30902 m
.02381 .30902 L
s
.03995 .30902 m
.03995 .41161 L
s
.05609 .30902 m
.05609 .44276 L
s
.07224 .30902 m
.07224 .45797 L
s
.08838 .30902 m
.08838 .15935 L
s
.10452 .30902 m
.10452 .16772 L
s
.12066 .30902 m
.12066 .17505 L
s
.1368 .30902 m
.1368 .18178 L
s
.15295 .30902 m
.15295 .18814 L
s
.16909 .30902 m
.16909 .19424 L
s
.18523 .30902 m
.18523 .20017 L
s
.20137 .30902 m
.20137 .20596 L
s
.21751 .30902 m
.21751 .21166 L
s
.23366 .30902 m
.23366 .21729 L
s
.2498 .30902 m
.2498 .22286 L
s
.26594 .30902 m
.26594 .22839 L
s
.28208 .30902 m
.28208 .23387 L
s
.29822 .30902 m
.29822 .23933 L
s
.31437 .30902 m
.31437 .24476 L
s
.33051 .30902 m
.33051 .25017 L
s
.34665 .30902 m
.34665 .25556 L
s
.36279 .30902 m
.36279 .26094 L
s
.37893 .30902 m
.37893 .26631 L
s
.39508 .30902 m
.39508 .27167 L
s
.41122 .30902 m
.41122 .27702 L
s
.42736 .30902 m
.42736 .28236 L
s
.4435 .30902 m
.4435 .2877 L
s
.45964 .30902 m
.45964 .29303 L
s
.47579 .30902 m
.47579 .29836 L
s
.49193 .30902 m
.49193 .30369 L
s
.50807 .30902 m
.50807 .30902 L
s
.52421 .30902 m
.52421 .31434 L
s
.54036 .30902 m
.54036 .31967 L
s
.5565 .30902 m
.5565 .325 L
s
.57264 .30902 m
.57264 .33034 L
s
.58878 .30902 m
.58878 .33567 L
s
.60492 .30902 m
.60492 .34102 L
s
.62107 .30902 m
.62107 .34637 L
s
.63721 .30902 m
.63721 .35172 L
s
.65335 .30902 m
.65335 .35709 L
s
.66949 .30902 m
.66949 .36247 L
s
.68563 .30902 m
.68563 .36786 L
s
.70178 .30902 m
.70178 .37327 L
s
.71792 .30902 m
.71792 .37871 L
s
.73406 .30902 m
.73406 .38416 L
s
.7502 .30902 m
.7502 .38965 L
s
.76634 .30902 m
.76634 .39517 L
s
.78249 .30902 m
.78249 .40074 L
s
.79863 .30902 m
.79863 .40637 L
s
.81477 .30902 m
.81477 .41207 L
s
.83091 .30902 m
.83091 .41787 L
s
.84705 .30902 m
.84705 .42379 L
s
.8632 .30902 m
.8632 .4299 L
s
.87934 .30902 m
.87934 .43625 L
s
.89548 .30902 m
.89548 .44298 L
s
.91162 .30902 m
.91162 .45032 L
s
.92776 .30902 m
.92776 .45868 L
s
.94391 .30902 m
.94391 .16007 L
s
.96005 .30902 m
.96005 .17528 L
s
.97619 .30902 m
.97619 .20643 L
s
.015 w
.02381 .30902 Mdot
.03995 .41161 Mdot
.05609 .44276 Mdot
.07224 .45797 Mdot
.08838 .15935 Mdot
.10452 .16772 Mdot
.12066 .17505 Mdot
.1368 .18178 Mdot
.15295 .18814 Mdot
.16909 .19424 Mdot
.18523 .20017 Mdot
.20137 .20596 Mdot
.21751 .21166 Mdot
.23366 .21729 Mdot
.2498 .22286 Mdot
.26594 .22839 Mdot
.28208 .23387 Mdot
.29822 .23933 Mdot
.31437 .24476 Mdot
.33051 .25017 Mdot
.34665 .25556 Mdot
.36279 .26094 Mdot
.37893 .26631 Mdot
.39508 .27167 Mdot
.41122 .27702 Mdot
.42736 .28236 Mdot
.4435 .2877 Mdot
.45964 .29303 Mdot
.47579 .29836 Mdot
.49193 .30369 Mdot
.50807 .30902 Mdot
.52421 .31434 Mdot
.54036 .31967 Mdot
.5565 .325 Mdot
.57264 .33034 Mdot
.58878 .33567 Mdot
.60492 .34102 Mdot
.62107 .34637 Mdot
.63721 .35172 Mdot
.65335 .35709 Mdot
.66949 .36247 Mdot
.68563 .36786 Mdot
.70178 .37327 Mdot
.71792 .37871 Mdot
.73406 .38416 Mdot
.7502 .38965 Mdot
.76634 .39517 Mdot
.78249 .40074 Mdot
.79863 .40637 Mdot
.81477 .41207 Mdot
.83091 .41787 Mdot
.84705 .42379 Mdot
.8632 .4299 Mdot
.87934 .43625 Mdot
.89548 .44298 Mdot
.91162 .45032 Mdot
.92776 .45868 Mdot
.94391 .16007 Mdot
.96005 .17528 Mdot
.97619 .20643 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 311.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0001=b000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`008?ooool3o`0000Cooooo0_l0000[ooooo`?o0000
;?ooool2o`0002oooooo0ol0000[ooooo`?o00001?ooool2o`0002oooooo0ol00004ooooo`;o0000
:oooool3o`0002gooooo0_l0000_ooooo`?o0000:oooool3o`0000Cooooo0_l0000Booooo`008Ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002Wooooo00Go0000oooooooooooo
ooooo`00000Zooooo`04o`000?ooooooooooo`0002gooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000;oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0002Wooooo00Go0000ooooooooooooooooo`00000[ooooo`04
o`000?ooooooooooo`0002gooooo00Go0000ooooooooooooooooo`00000[ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00004Oooool001Wooooo1Ol00003ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00008oooool5o`0000Gooooo00?o0000ooooooooool0:?oo
ool01?l0003oooooooooool0000aooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool0000Wooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0002?ooooo1Ol00005ooooo`03o`000?oooooooooo02Wooooo00Co0000oooo
oooooooo0000<Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00004Oooool0027ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
000]ooooo`03o`000?oooooooooo02Sooooo00Co0000oooooooooooo0000<Oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000;oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0002gooooo00?o0000ooooooooool0:Oooool01?l0
003oooooooooool0000aooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Aooooo`008Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0002Wooooo1?l0000[ooooo`04o`000?ooooooooooo`0002gooooo1?l0000/ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo0000;oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0002Wooooo1?l0000/ooooo`04o`000?ooooooooooo`0002gooooo1?l0000/
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004Oooool0023ooooo0_l00004
ooooo`04o`000?ooooooooooo`0002Wooooo00?o0000ooooooooool0;?ooool01?l0003ooooooooo
ool0000]ooooo`03o`000?oooooooooo02cooooo0_l00004ooooo`04o`000?ooooooooooo`0002ko
oooo0_l00004ooooo`04o`000?ooooooooooo`0002Wooooo00?o0000ooooooooool0;Oooool01?l0
003oooooooooool0000]ooooo`03o`000?oooooooooo02cooooo0_l00004ooooo`04o`000?oooooo
ooooo`00017ooooo000Qooooo`03o`000?oooooooooo00?ooooo0_l0000Zooooo`Go0000:oooool2
o`0002kooooo1Ol0000[ooooo`03o`000?oooooooooo00?ooooo0_l0000`ooooo`03o`000?oooooo
oooo00?ooooo0_l0000Zooooo`Go0000;?ooool2o`0002kooooo1Ol0000[ooooo`03o`000?oooooo
oooo00?ooooo0_l0000Booooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooo
oooiooooo`007Oooooo@o`0002[ooooodOl0000@ooooo`005_ooool2o`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Pooooo`?o00001Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00kooooo000Eooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0I?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01oooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`0>ooooo`005Oooool01?l0003oooooooooool00004ooooo`;o00001?ooool2
o`00o`04ool00?ooooooooooool000?ooooo00_oo`00o`00ooooooooo`00ooooool00?ooo`00oooo
ool00?ooooooool00002ooooo`04ool00?l00?oo003oool000;ooooo00Goo`00ooooool00?oooooo
ool00002ooooo`0;ool00?oooooo003oool00?oooooo003ooooooooo003o003ooooooooo00000_oo
ool02?oo003oooooo`00oooo003oooooo`00ooooooooo`000_ooool02?oo003oooooo`00oooo003o
ooooo`00ooooooooo`000_ooool01?oo003o003oo`00oooo0002ooooo`0;ool00?oooooooooooooo
oooo003o003ooooooooo003oooooo`00oooo00000oooool01?oo003ooooooooooooo0002o`00o`0;
ool00?oooooo003oool00?oooooo003ooooooooo003o003ooooooooo00000_ooool01Ooo003ooooo
ooooooooooooo`0000;ooooo00_oo`00ooooool00?ooo`00ooooool00?ooo`00ooooool00?oooooo
ool00002ooooo`0;ool00?ooooooooooool00?oooooo003ooooooooo003o003ooooooooo00000_oo
ool03_oo003oooooo`00oooo003oooooo`00ooooooooo`00o`00ooooooooo`00ooooool00?ooo`00
0oooool02ooo003o003ooooooooo003o003ooooooooo003oooooo`00ooooooooo`0000;ooooo01So
o`00o`00ool00?ooo`00ooooool00?ooo`00ooooool00?ooooooool00?l00?ooooooool00?oooooo
003oool00?oooooo003ooooooooo003o003ooooooooo0002o`00o`04ool00?ooooooooooooooo`;o
00006oooool5o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`03
o`000?oooooooooo00cooooo00?o003oooooooooool0E_ooool00ol0003oooooooooo`0>ooooo`00
5Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo0_l00?l02ooo003o
003oo`00oooo003oooooo`00ooooooooo`00ooooool00?ooo`0000;o003o00Soo`00ooooool00?oo
ooooool00?l00?ooooooool000;o003o00_oo`00o`00ool00?ooo`00ooooool00?ooooooool00?l0
0?ooooooool00002o`00o`0Eool00?oooooo003ooooooooo003o003ooooooooo003oooooo`00oooo
003oooooo`00oooo003oooooo`00ooooooooo`00o`00ooooooooo`0000;o003o00Soo`00ooooool0
0?ooooooool00?l00?ooooooool000;o003o00koo`00ooooool00?ooo`00ooooool00?ooooooool0
0?l00?ooooooool00?oooooo003oool000?ooooo00Coo`00o`00ooooooooo`000_l00?l03_oo003o
ooooo`00oooo003oooooo`00ooooooooo`00o`00ooooooooo`00ooooool00?ooo`000oooool01?oo
003o003ooooooooo0002o`00o`0Eool00?oooooo003oool00?oooooo003ooooooooo003o003ooooo
oooo003oooooo`00oooo003oooooo`00ooooooooo`00o`00ooooooooo`0000;o003o02coo`00oooo
ool00?ooo`00ooooool00?ooooooool00?l00?ooooooool00?oooooo003oool00?oooooo003ooooo
oooo003o003ooooooooo003o003ooooooooo003oooooo`00ooooooooo`00o`00ooooooooo`00oooo
ool00?ooo`00ooooool00?ooo`00ooooool00?ooooooool00?l00?ooooooool000;o003o00_oo`00
ooooool00?ooooooool00?l00?ooooooool00?l00?ooooooool00004ooooo`03o`000?oooooooooo
027ooooo0_l00005ooooo`;o0000G_ooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo
00cooooo00?o003oooooooooool0EOooool2o`00013ooooo000Eooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool01Oooool01Ooo003o003oo`00oooo003ooooo00;o003o00Coo`00
o`00ool00?ooo`000_ooool01Ooo003o003oo`00ooooooooo`0000;o003o00Coo`00oooooooooooo
o`000_l00?l01Ooo003oooooo`00ooooooooo`0000;o003o00Coo`00ooooooooooooo`000_l00?l0
1Oooooooo`00ooooooooooooo`0000;o003o00Soo`00o`00ool00?ooo`00ooooool00?ooooooool0
00;o003o00Coo`00o`00ooooooooo`000oooool05?oo003o003ooooooooo003o003ooooooooo003o
ooooo`00oooo003oooooo`00ooooooooo`00o`00ooooooooo`00ooooool00?ooo`000oooool01?oo
003o003ooooooooo0002ooooo`0>ool00?l00?oo003oool00?oooooo003ooooooooo003o003ooooo
oooo003oooooo`00oooo0003ooooo`04ool00?l00?ooooooool000;ooooo00Soo`00ooooool00?oo
o`00ooooool00?ooooooool000;o003o00_oo`00ooooool00?ooo`00ooooool00?ooooooool00?l0
0?ooooooool00002o`00o`08ool00?l00?oo003oool00?oooooo003ooooooooo0002o`00o`08ool0
0?l00?ooooooool00?oooooo003ooooooooo0002ooooo`05ool00?l00?oo003oool00?l00?l00_oo
ool01?oo003o003oo`00oooo0002o`00o`04ool00?l00?ooooooool000?ooooo00Coo`00o`00ool0
0?ooo`000_ooool01Ooo003oooooo`00ooooooooo`0000;ooooo00Coo`00o`00ool00?ooo`001?oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0GOoo
ool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo00oooooo00?o003oooooooooool0Dooo
ool00ol0003oooooooooo`0>ooooo`005Oooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00;ooooo0_l00?l6ool00003oooooooo003oo`0000Ooo`0000Koooooool00?oo003oo`00
o`00oooo0002o`00o`05ool00?l00?oo003oool00?l00?l00_ooool01?oo003o003oo`00oooo0002
o`00o`08ool00?l00?oo003ooooooooo003oooooo`00oooo0002o`00o`05ool00?oooooo003oool0
0?ooool00_l00?l01ooo003o003oo`00oooo003oooooo`00oooo00000_l00?l05Oooooooo`00o`00
ool00?ooo`00ooooool00?ooo`00ooooool00?ooo`00ooooool00?ooooooool00?l00?ooooooool0
0?oooooo003oool00003ooooo`08ool00?l00?ooooooool00?oooooo003oool00?ooool3ool00009
ooooool00?ooo`00o`00ooooooooo`00ooooool00?ooo`0000?ooooo00Coo`00o`00ooooooooo`00
0_l00?l02?oo003oooooo`00oooo003oooooo`00ooooooooo`000_l00?l02ooo003o003oo`00oooo
003oooooo`00ooooooooo`00ooooool00?ooo`0000;o003o00koo`00o`00ooooooooo`00ooooool0
0?ooooooool00?l00?ooooooool00?oooooo003oool000;o003o01?oooooool00?l00?ooooooool0
0?oooooo003oool00?oooooo003ooooooooo003oooooo`00oooo003o003ooooooooo003ooooo00?o
o`0000?oooooool00?oo00001ooo00000oooooooo`00ool00007ool000?ooooo00?o0000oooooooo
ool07oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0IOooool00ol0
003oooooooooo`0<ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool0Coooool0
0ol0003oooooooooo`0>ooooo`005_ooool2o`0000Gooooo0_l00003ooooo`03o`00ooooooooo`00
00Goo`0000?oooooool00?oo00001ooo00000oooooooo`00ool0000:ool00003oooooooo003oo`00
00Ooo`0000coooooool00?oo003oo`00o`00oooo003o003ooooooooo003o003ooooooooo0002oooo
o`05o`00oooo003o003ooooooooo00000_l00?l01Ooo003o003oo`00ooooooooo`0000;ooooo017o
o`00o`00ool00?ooo`00o`00ooooooooo`00ooooool00?ooooooool00?l00?ooooooool00?oooooo
003oool00003ooooo`04ool00?l00?ooooooool000;o003o00?oo`00o`00oooo00000_oo00000ooo
oooo003oool00002o`00o`04ool00?oooooo003oool000?ooooo00Coo`00o`00ooooooooo`000_l0
0?l04_oo003oooooo`00oooo003oooooo`00ooooooooo`00ooooool00?ooo`00ooooool00?ooo`00
ooooool00?ooooooool000;o003o00Soo`00ooooooooooooo`00o`00ooooooooo`00ooooo`;o003o
00Goo`00o`00ool00?ooo`00o`00o`03ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo
00002_oo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Ooo`000_ooool2o`0002;o
oooo0ol00005ooooo`03o`000?oooooooooo05gooooo00?o003oooooooooool01Oooool00ol0003o
ooooooooo`0<ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool0Coooool00ol0
003oooooooooo`0>ooooo`007Oooool00ol0003oooooooooo`04ooooo`Koo`0000?oooooool00?oo
00001ooo00000oooooooo`00ool0000:ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo
00002_oo0002ooooo`04ool00?oooooo003oool000;o003o00Soo`00o`00oooooooo003oool00?l0
0?ooooooool000;o003o00Soo`00ooooool00?ooo`00ooooool00?ooooooool000;o003o00Coo`00
o`00ool00?ooo`000oooool01?oo003o003ooooooooo0002o`00o`03ool00?l00?ooo`0000;oo`00
0_ooool01ooo003o003oo`00oooo003oooooo`00oooo00000oooool01?oo003o003ooooooooo0002
o`00o`05ool00?l00?oo003oool00?ooool00_l00?l02ooo003o003ooooooooo003o003ooooooooo
003o003oooooool00?ooo`0000;o003o00Goo`00o`00ool00?ooo`00ooooo`03ool00003oooooooo
003oo`0000Ooo`0000?oooooool00?oo00001ooo00000oooooooo`00ool0000:ool00003oooooooo
003oo`0000Ooo`0000?oooooool00?oo00001ooo0003ooooo`03o`000?oooooooooo02Sooooo0_l0
001Nooooo`04o`00ooooooooooooo`00o`Cooooo00?o0000ooooooooool03?ooool01?l00?oooooo
ooooool00?l2ooooo`;o003o0_ooool00ol00?ooooooooooo`1;ooooo`;o00004?ooool001gooooo
00?o0000ooooooooool06?ooool9ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo0000
2_oo00002Oooooooo`00ool00?oo003o003oool00?l00?ooooooool00003ooooo`07ool00?oooooo
003oool00?l00?ooooooool00002o`00o`0;ool00?oooooo003ooooooooo003o003ooooooooo003o
ooooo`00oooo00000oooool02_oo003o003ooooooooo003o003ooooooooo003o003oooooool00002
ooooo`05o`00oooo003oooooo`00oooo00000_l00?l03ooo003oooooooooooooooooo`00o`00oooo
ooooo`00o`00ooooooooo`00ooooool00?ooo`00ooooo`02o`00o`04ool00?l00?oo003oool000;o
003o00Woo`00o`00ooooooooooooool00?oooooo003oool00?ooool01_oo00000oooooooo`00ool0
0007ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00001ooo000Jooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0G?ooool2o`00o`;ooooo00?o003oooooooooool00_oo
ool00ol0003oooooooooo`0<ooooo`04o`00ooooooooooooo`00o`;ooooo00Go003ooooooooooooo
ooooo`00o`02ooooo`03o`00oooooooooooo04Wooooo00?o0000ooooooooool03_ooool001gooooo
00?o0000ooooooooool0;oooool9ool00003oooooooo003oo`0000Ooo`000_ooool01ooo003ooooo
o`00oooo003oooooo`00oooo00000_l00?l02ooo003oooooo`00ool00?ooo`00ooooool00?ooo`00
o`00ooooooooo`0000?ooooo00Goo`00o`00ooooooooo`00o`00o`03ool00004ooooool0003ooooo
ooooo`?oo`0000Goooooool00?l00?oo003oool00003ooooo`0:ool00?l00?ooooooool00?oooooo
003oool00?l00?ooooooool000;ooooo00So003oool00?l00?oo003oool00?l00?ooooooool000;o
oooo3?oo00000oooooooo`00ool00004ool0037ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`1Pooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool03?ooool01?l00?oo
ooooooooool00?l2ooooo`;o003o0_ooool01?l00?ooooooooooool00?m;ooooo`03o`000?oooooo
oooo00kooooo000Mooooo`;o0000>_ooool9ool00006oooooooo003oo`00ool00?l00?ooo`000_l0
0?l01Ooo003o003ooooooooo003o003o00;ooooo00Coo`00o`00ool00?ooo`000_l00?l02Ooo003o
ooooooooooooooooo`00o`00ooooooooo`00ooooo`03ool00004ooooool0003oooooooooo`?oo`00
00Go003oool00?l00?ooooooool00003ooooo`04ool00?l00?ooooooool000;o003o00Goo`00o`00
ool00?ooo`00o`00o`02ooooo`05ool00?oooooo003oool00?ooool00ooo00000oooooooo`00ool0
0007ool003[ooooo0_l0000Zooooo`03o`000?oooooooooo05cooooo0_l00?l2ooooo`03o`00oooo
oooooooo00;ooooo00?o0000ooooooooool02oooool2o`00o`;ooooo00Go003ooooooooooooooooo
o`00o`02ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool0A_ooool00ol0003o
ooooooooo`0>ooooo`007Oooool00ol0003oooooooooo`0looooo`Koo`0000?oooooool00?oo0000
1?oo00002Ol00?ooo`00ooooool00?ooo`00o`00oooooooo003oool00002o`00o`04ool00?l00?oo
003oool000?ooooo00Goo`00ooooool00?ooo`00o`00o`03ool00004ooooool0003oooooooooo`?o
o`0000Go003oool00?oooooo003oool00003ooooo`04ool00?l00?ooooooool000;o003o00Goo`00
o`00ool00?ooo`00o`00o`02ooooo`03ool00?ooooooo`0000Goo`0000?oooooool00?oo00001?oo
000nooooo`03o`000?oooooooooo02Sooooo0_l0001Mooooo`;o003o0_ooool00ol00?oooooooooo
o`02ooooo`03o`000?oooooooooo00_ooooo0_l00?l2ooooo`03o`00oooooooooooo00;o003o1Ooo
ool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo047ooooo0_l0000@ooooo`007Ooo
ool00ol0003oooooooooo`13ooooo`Koo`0000Goooooool00?l00?oo003oool00002ooooo`08o`00
oooo003o003ooooooooo003oooooo`00oooo0003ooooo`05ool00?l00?oo003oool00?l00?l01?oo
ool00ol0003oooooooooo`03ooooo`05o`00oooo003o003oo`00oooo00000oooool01ooo003o003o
oooooooo003o003ooooooooo00000_ooool01_oo003o003oooooool00?ooo`00ooooo`Koo`00AOoo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo05cooooo0_l00?l2ooooo`03o`00oooo
oooooooo00;ooooo00?o0000ooooooooool02oooool01Ol00?oooooooooooooooooo003o00;ooooo
00?o003oooooooooool00_l00?l2ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooo
oooo003o@Oooool00ol0003oooooooooo`0>ooooo`007Oooool00ol0003oooooooooo`16ooooo`Ko
o`0000Koooooool00?l00?ooooooo`00oooo0002ooooo`04ool00?l00?ooooooool000?ooooo00Go
o`00o`00ool00?ooo`00o`00o`04ooooo`03o`000?oooooooooo00Cooooo00Coo`00o`00ool00?oo
o`000oooool01?oo003o003ooooooooo0002ooooo`04ool00?l00?ooooooool000;ooooo1_oo0018
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0H?ooool00ol00?ooooooooooo`02
ooooo`03o`000?oooooooooo00cooooo00Co003ooooooooooooo003o0_ooool2o`00o`03ooooool0
0?oo003o00;ooooo00?o003oooooooooool01?ooool01?l00?ooooooooooool00?l2ooooo`03o`00
oooooooooooo03cooooo00?o0000ooooooooool03_ooool001gooooo0_l0001:ooooo`?oo`0000?o
ooooool00?l00?l00_ooool01?oo003o003oo`00oooo0002o`00o`08ool00?oooooooooooooooooo
003o003ooooooooo0005ooooo`03o`000?oooooooooo00?ooooo00Go003oool00?l00?ooooooool0
0003ooooo`04ool00?l00?oo003oool000;o003o00Koo`00o`00ooooooooo`00o`00ooooool3ool0
04[ooooo0_l0000Zooooo`03o`000?oooooooooo05cooooo0_l00?l2ooooo`03o`00oooooooooooo
00;ooooo00?o0000ooooooooool02oooool2o`00o`;ooooo00Ko003oooooooooooooooooo`00oooo
ool2o`00o`;ooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool00?l2ooooo`05
o`00ooooooooooooooooool00?l0>_ooool00ol0003oooooooooo`0>ooooo`007Oooool00ol0003o
ooooooooo`19ooooo`?oo`0000Koooooool00?l00?ooooooo`00oooo0002o`00o`04ool00?l00?oo
003oool000?ooooo00Goo`00ooooooooooooo`00o`00o`04ooooo`03o`000?oooooooooo00?ooooo
00Go003oool00?oooooo003oool00003ooooo`04ool00?ooooooooooool000;o003o00Koo`00o`00
ooooooooo`00o`00ooooool3ool004_ooooo00?o0000ooooooooool0:?ooool2o`0005gooooo0_l0
0?l2ooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool02oooool2o`00o`;ooooo00?o
003oooooooooool00_l00?l00ooooooo003oooooo`02ooooo`04o`00ooooooooooooo`00o`;ooooo
00Go003oooooooooooooooooo`00o`02ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol0
0?ooooooooooo`0dooooo`;o00004?ooool001gooooo00?o0000ooooooooool0C?ooool3ool00003
ooooool00?ooo`0000;o003o00Coo`00o`00ool00?ooo`000oooool01Ooo003o003oo`00oooo003o
003o00Cooooo00?o0000ooooooooool00oooool01Ol00?ooo`00o`00ool00?ooo`0000?ooooo00Co
o`00o`00ool00?ooo`000_l00?l00ooo003oooooool00002ool004oooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`1Looooo`;o003o0_ooool00ol00?ooooooooooo`02ooooo`03o`00
0?oooooooooo00_ooooo0_l00?l2ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooooooooooo003o0_ooool2o`00
o`;ooooo00Co003ooooooooooooo003o=?ooool00ol0003oooooooooo`0>ooooo`007Oooool00ol0
003oooooooooo`1<ooooo`?oo`0000?oooooo`00oooo00000_ooool01?oo003o003ooooooooo0003
ooooo`04ool00?l00?oo003oool000Gooooo00?o0000ooooooooool01?ooool01?oo003o003oo`00
oooo0003ooooo`04ool00?l00?oo003oool000;ooooo00?oo`00oooooooo00000_oo001?ooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool0Goooool2o`00o`Cooooo00?o0000oooooooo
ool03_ooool2o`00o`;ooooo0_l00?l00ooooooo003oo`00o`02ooooo`03o`00oooooooooooo00?o
oooo0_l00?l2ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o0_ooool0
1Ol00?oooooooooooooooooo003o033ooooo00?o0000ooooooooool03_ooool001gooooo0_l0001=
ooooo`?oo`000_ooool01?oo003oooooo`00oooo0002o`00o`05ool00?oooooooooooooooooo0000
0_l00?l00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Coo`00o`00oooooooo
o`000oooool01?oo003o003oo`00oooo0002o`00o`03ool00?l00?ooo`0000;oo`00C_ooool2o`00
02[ooooo00?o0000ooooooooool0G?ooool2o`00o`;ooooo00Ko003ooooooooooooo003oooooool0
000=ooooo`;o003o0_ooool01_l00?oooooooooooooooooo003oooooo`;o003o0_ooool01?l00?oo
ooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00Co003ooooooooooooo003o0ooo
ool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00obgooooo00?o0000oooooooo
ool03_ooool001gooooo00?o0000ooooooooool0D?ooool01Ol00?ooo`00ooooool00?ooo`0000;o
003o00Goo`00ooooooooooooooooool00002ooooo`03ool00?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01?oo003o003oo`00oooo0003ooooo`04ool00?ooooooooooool000;o003o00?o
o`00o`00ooooool0DOooool00ol0003oooooooooo`0Xooooo`;o0000GOooool2o`00o`03ooooool0
0?oo003o00;ooooo00?o003oooooool000003Oooool2o`00o`03ooooool00?oooooo00;ooooo0_l0
0?l00ooooooo003oooooo`02ooooo`04o`00ooooooooooooo`00o`;ooooo00Go003ooooooooooooo
ooooo`00o`02ooooo`03o`00oooooooooooo00;o003o0_ooool01?l00?ooooooooooool00?l2oooo
o`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Wooooo`;o00004?ooool0
01Gooooo0ol00005ooooo`03o`000?oooooooooo053ooooo00Go003oool00?oooooo003oool00002
o`00o`06ool00?oooooooooooooooooo003ooooo0ooo0004ooooo`03o`000?oooooooooo00?ooooo
0ooo00000ol00?ooo`00ooooo`02ooooo`08ool00?l00?oo003oool00?l00?ooooooool00?l00?mB
ooooo`03o`000?oooooooooo01oooooo1Ol00004ooooo`03o`000?oooooooooo05cooooo0_l00?l0
0ooooooo003oooooo`02ooooo`03o`00oooooooo000000gooooo0_l00?l00ooooooo003oo`00o`02
ooooo`05o`00ooooooooooooooooool00?l00_ooool01?l00?ooooooooooool00?l2ooooo`;o003o
0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o0_ooool01?l00?ooooooooooool00?l3oooo
o`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool0:?ooool00ol0003oooooooooo`0>
ooooo`005?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0D?ooool3
ool00005oooooooo003ooooooooooooo00000oooool00ooo003o003oool00002ool000Cooooo00?o
0000ooooooooool00oooool3ool00003o`00oooo003ooooo00;ooooo00Goo`00o`00ool00?ooo`00
ooooo`03ool005;ooooo00?o0000ooooooooool08?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo05oooooo0_l00?l2ooooo`03o`00oooooooo0000013ooooo0_l00?l2ooooo`;o
003o00Goooooo`00ool00?ooooooo`00o`06ooooo`;o003o0_ooool01?l00?ooooooooooool00?l3
ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool00_l00?l2ooooo`04o`00oooo
ooooooooo`00o`;ooooo00Go003oooooooooooooooooo`00o`0Sooooo`03o`000?oooooooooo00ko
oooo000Hooooo`03o`000?oooooooooo00;ooooo0_l0001Aooooo`?oo`0000Go003oool00?l00?oo
003oool00003ooooo`03ool00?l00?ooo`0000;oo`001?ooool00ol0003oooooooooo`03ooooo`?o
o`0000?oooooool00?ooool00_ooool01Ooo003o003oo`00oooo003o003o00?oo`00DOooool2o`00
01_ooooo1Ol00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0G?ooool2o`00
o`;ooooo00Ko003ooooooooooooo003oooooool0000=ooooo`;o003o0_ooool00ol00?oooooooooo
o`02o`00o`04ooooool00?oo003oooooo`;o003o0_ooool01_l00?oooooooooooooooooo003ooooo
o`;o003o0_ooool00ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooooooooooo003o0_ooool2
o`00o`;ooooo00Co003ooooooooooooo003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo
00?o003oooooooooool07_ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo053ooooo0ooo00001Ol00?ooo`00o`00ool00?ooo`0000?ooooo
00?oo`00o`00ooooool01_ooool00ol0003oooooooooo`07ooooo`05ool00?oooooooooooooooooo
00000_ooool00ooo003o003oool00002ool005;ooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`03ooooo`;o0000GOooool2o`00o`03ooooool00?oo003o00;ooooo00?o003oooooool0
00003Oooool2o`00o`03ooooool00?oooooo00?ooooo00Go003oooooool00?oo003oooooo`02o`00
o`;ooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool00?l2ooooo`03o`00oooo
oooooooo00;o003o0_ooool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`;o
oooo00Go003oooooooooooooooooo`00o`02ooooo`04o`00ooooooooooooo`00oacooooo0_l0000@
ooooo`005?ooool4o`0000Gooooo00?o0000ooooooooool0Doooool01Ol00?ooo`00o`00ool00?oo
o`0000?ooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00oooo003o
oooo00;ooooo00Goo`00o`00ooooooooo`00o`00o`1Eooooo`03o`000?oooooooooo01oooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo05cooooo0_l00?l00ooooooo003o
ooooo`02ooooo`03o`00oooooooo000000gooooo0_l00?l00ooooooo003oo`00o`02ooooo`03o`00
oooooooooooo00Cooooo00Co003ooooooooooooo003o0_ooool2o`00o`03ooooool00?oooooo00;o
oooo00?o003oooooooooool00_l00?l00ooooooo003oooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00_ooool01?l00?ooooooooooool00?l2ooooo`05o`00ooooooooooooooooool00?l00_oo
ool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo01Oooooo00?o0000ooooooooool0
3_ooool001Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Dooooo`04ool00?oo
ooooooooool000?ooooo00?oo`00o`00ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
oooo003ooooo00;ooooo00Coo`00o`00ool00?ooo`00E_ooool00ol0003oooooooooo`0Oooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1Oooooo`;o003o0_ooool00ol0
0?ooooooo`00000@ooooo`;o003o0_ooool00ol00?ooooooooooo`02o`00o`03ooooool00?oooooo
00Gooooo0_l00?l00ooooooo003oo`00o`02ooooo`06o`00ooooooooooooooooool00?oooooo0_l0
0?l2ooooo`03o`00oooooooooooo00;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`05o`00
ooooooooooooooooool00?l00_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo
01Oooooo00?o0000ooooooooool03_ooool001Cooooo1Ol00004ooooo`;o0000E?ooool01Ol00?oo
o`00o`00ooooooooo`0000?ooooo00?oo`00o`00ooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`00oooo003ooooo00;ooooo00Coo`00o`00ool00?ooo`00EOooool2o`0002;ooooo0ol00005
ooooo`03o`000?oooooooooo063ooooo00Ko003ooooooooooooo003oooooool0000=ooooo`;o003o
0_ooool01_l00?ooooooo`00oooooooo003oooooo`;o003o00Goooooo`00ool00?ooooooo`00o`04
ooooo`04o`00oooooooo003oo`00o`;ooooo00?o003oooooooooool00_l00?l2ooooo`04o`00oooo
ooooooooo`00o`;ooooo0_l00?l00ooooooo003oo`00o`02ooooo`04o`00ooooooooooooo`00o`?o
oooo00Co003ooooooooooooo003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003o
ooooooooool05?ooool00ol0003oooooooooo`0>ooooo`007Oooool00ol0003oooooooooo`1Doooo
o`04ool00?l00?oo003oool000?ooooo00?oo`00o`00ooooool01_ooool00ol0003oooooooooo`07
ooooo`08ool00?oooooooooooooooooo003oooooo`00oooo001Fooooo`03o`000?oooooooooo02So
oooo0_l0001Looooo`03o`00oooooooo003o00;ooooo00Ko003ooooooooooooo003oooooool0000=
ooooo`;o003o00?oooooo`00ooooool00oooool01Ol00?ooooooo`00ool00?oooooo00;o003o00?o
ooooo`00ool00?l00_ooool00ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooooooooooo003o
0_ooool2o`00o`;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`;ooooo00Co003ooooooooo
oooo003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00
o`02ooooo`04o`00ooooooooooooo`00oa;ooooo0_l0000@ooooo`007Oooool00ol0003ooooooooo
o`1Dooooo`04ool00?l00?oo003oool000?ooooo00?oo`00ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`00oooo003ooooo00;ooooo00Coo`00o`00ooooooooo`00E_ooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo05_ooooo00Go003oooooool00?ooooooo`00o`03oooo
o`03o`00oooooooo000000cooooo00Co003oooooool00?oooooo0_l00?l01?oooooo003oooooool0
0?l5ooooo`04o`00oooooooo003oo`00o`;ooooo0_l00?l5ooooo`03o`00oooooooooooo00;o003o
00?oooooo`00ooooool00_ooool01ol00?oooooooooooooooooo003oooooool00?l00oooool01?l0
0?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00Go003ooooooooooooooooo
o`00o`02ooooo`04o`00ooooooooooooo`00oa?ooooo00?o0000ooooooooool03_ooool001gooooo
00?o0000ooooooooool0E?ooool01?oo003oooooo`00oooo0003ooooo`03ool00?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol00?ooo`00ooooo`02ooooo`04ool00?l00?oo003oool0
05Kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1Kooooo`04o`00oooooooo003o
ooooo`;o003o0_ooool00ol00?ooooooo`00000@ooooo`;o003o00?oooooo`00ooooool00_ooool2
o`00o`03ooooool00?oooooo00;ooooo00?o003oooooooooool00_l00?l00ooooooo003oo`00o`06
ooooo`04o`00oooooooo003oo`00o`;ooooo00?o003oooooooooool00_l00?l2ooooo`04o`00oooo
ooooooooo`00o`;ooooo00?o003oooooooooool00_l00?l2ooooo`04o`00ooooooooooooo`00o`;o
oooo0_l00?l2ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`007Oooool00ol0003oooooooooo`1Dooooo`04ool00?l00?ooooooool0
00?ooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00oooo003ooooo
00;ooooo00Coo`00o`00ool00?ooo`00E_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo05oooooo0_l00?l2ooooo`03o`00oooooooo000000cooooo00?o003oooooool00?l00_ooool0
1_l00?ooooooo`00oooooooo003oooooo`;o003o00Goooooo`00ool00?ooooooo`00o`04ooooo`06
o`00oooooooo003oo`00oooooooo003o1?ooool01Ol00?ooooooooooool00?oooooo00;o003o0_oo
ool2o`00o`03ooooool00?oo003o00;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`;ooooo
00?o003oooooooooool01?ooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooooooo00;o
003o0_ooool01?l00?ooooooooooool00?l9ooooo`03o`000?oooooooooo00kooooo000Mooooo`;o
0000E?ooool3ool00003o`00oooo003ooooo00;ooooo00?oo`00ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`06ool00?oooooooooooooooooo003ooooo0ooo001Dooooo`;o0000:_ooool2
o`0005cooooo00?o003oooooool00?l00_ooool01_l00?ooooooo`00ool00?ooooooo`0000cooooo
00Go003oooooool00?ooooooo`00o`04ooooo`;o003o00?oooooo`00ooooool00_l00?l00ooooooo
003oo`00o`02ooooo`03o`00oooooooooooo00;o003o00?oooooo`00ool00?l00_ooool00ol00?oo
ooooooooo`02o`00o`;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`03ooooool00?oo003o
00;ooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool00?l2ooooo`05o`00oooo
ooooooooooooool00?l00_ooool00ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooooooooooo
003o2?ooool2o`00013ooooo000Mooooo`03o`000?oooooooooo05?ooooo0ooo00000ol00?ooo`00
ooooo`02ooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol00?ooo`00
ooooo`02ooooo`03ool00?l00?ooo`0000;oo`00EOooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo05[ooooo0ooo00001?l00?ooooooo`00ool00?l2ooooo`03o`00oooooooo000000_o
oooo0ooo00002?l00?ooooooo`00ool00?ooooooo`00oooooooo003o1Oooool01?l00?ooooooo`00
ool00?l2ooooo`;o003o1?ooool2o`00o`;ooooo0_l00?l01?oooooo003oooooooooool2o`00o`?o
oooo00?o003oooooool00?l00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooo
oooooooo003o0_ooool00ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooooooooooo003o1_oo
ool01?l00?ooooooooooool00?l2ooooo`;o003o1Oooool00ol0003oooooooooo`0>ooooo`007Ooo
ool00ol0003oooooooooo`1Cooooo`?oo`0000?o003oool00?ooool00_ooool00ooo003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o003oool00?ooool00_ooool00ooo003o003oool0
0002ool005Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`04ooooo`04o`00oooo
ooooooooo`00oe;ooooo0ooo00000ol00?ooooooo`00o`02ooooo`;o003o00?oooooo`000?ooool0
2_ooool3ool00006oooooooo003oo`00ool00?oooooo003o0_ooool01Ol00?ooooooo`00oooooooo
003o00;ooooo0_l00?l01Ooooooo003oooooool00?oooooo00;o003o0_ooool00ol00?oooooooooo
o`02o`00o`05ooooool00?oo003oooooool00?l00oooool2o`00o`;ooooo00Co003oooooool00?oo
003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Co003ooooooooooooo003o0_ooool2
o`00o`;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`;ooooo00Co003ooooooooooooo003o
0_ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00kooooo000Mooooo`03o`000?oo
oooooooo05Oooooo00Goo`00ooooooooooooooooool00008ooooo`03o`000?oooooooooo00Kooooo
00?o003oool00?ooool00_ooool00ooo003o003oooooo`1Gooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool00oooool2o`00o`;ooooo00Co003ooooooooooooo003oCoooool3ool000;o
oooo0_l00?l01Ooooooo003ooooooooooooo000000_ooooo0ooo00001ol00?ooo`00ool00?oo003o
ooooo`00ooooool00_l00?l00ooooooo003oooooo`02o`00o`Kooooo00Ko003oooooool00?oo003o
ooooool00?l4ooooo`05o`00ooooooooooooo`00ooooool00_l00?l2ooooo`;o003o00?oooooo`00
ool00?l00_ooool01?l00?ooooooooooool00?l2ooooo`;o003o00?oooooo`00ool00?l00_ooool0
1Ol00?oooooooooooooooooo003o00;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`;ooooo
00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00ko
oooo000Mooooo`;o0000Eoooool00ol00?ooo`00ooooo`02ooooo`03ool00?oooooooooo00Kooooo
00?o0000ooooooooool01oooool01Ooo003oooooooooooooooooo`0005Sooooo0_l0000Zooooo`;o
00002?ooool01?l00?ooooooooooool00?m@ooooo`03ool00?ooooooo`0000;oo`0000Ko003ooooo
ool00?oo003oooooool0000<ooooo`03ool00?oooooo003o00Koo`000_l00?l00ooooooo003ooooo
o`02o`00o`03ooooool00?oo003o00Gooooo0_l00?l00ooooooo003oo`00o`02ooooo`03o`00oooo
oooooooo00;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o00?oooooo`00ool00?l0
0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o0_ooool00ol00?ooooooooooo`02o`00o`;o
oooo00Co003ooooooooooooo003o0_ooool2o`00o`;ooooo00Co003ooooooooooooo003o0_ooool2
o`00o`Cooooo0_l0000@ooooo`007Oooool00ol0003oooooooooo`1Fooooo`03o`00oooo003ooooo
00;ooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00oooo003ooooo
00;ooooo00?oo`00o`00ooooool0Eoooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
00?ooooo0_l00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool0Boooool0
0ooo003oooooool00002ool00006o`00ooooooooooooo`00oooooooo00003?ooool01_oo003ooooo
o`00ool00?ooo`00o`00o`Koo`000oooool02?l00?ooooooo`00ool00?ooooooo`00oooooooo003o
1?ooool2o`00o`;ooooo0_l00?l00ooooooo003oo`00o`02ooooo`07o`00ooooooooooooooooool0
0?ooooooo`00o`02ooooo`05o`00ooooooooooooooooool00?l00_ooool2o`00o`03ooooool00?oo
oooo00;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`;ooooo00?o003oooooooooool01?oo
ool01?l00?ooooooooooool00?l2ooooo`;o003o1Oooool00ol0003oooooooooo`0>ooooo`007Ooo
ool00ol0003oooooooooo`1Fooooo`03o`00oooo003ooooo00;ooooo00?oo`00ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`00oooo003ooooo00;ooooo00?oo`00o`00ooooool0Eooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00?ooooo0_l00?l2ooooo`04o`00oooo
ooooooooo`00o`;ooooo00Go003oooooooooooooooooo`00o`19ooooo`03ool00?ooooooo`0000;o
o`000_ooool2o`00o`03ooooool0003ooooo00_ooooo00Koo`00oooooooooooo003oool00?l00?l9
ool000;ooooo0_l00?l01_oooooo003oooooool00?ooooooo`00o`?ooooo00Oo003oooooool00?oo
ooooo`00oooooooo003o00;ooooo00Ko003ooooooooooooo003oooooool00?l2ooooo`04o`00oooo
oooo003oo`00o`;ooooo00Ko003oooooooooooooooooo`00ooooool2o`00o`;ooooo00?o003ooooo
ooooool00_l00?l00ooooooo003oooooo`02ooooo`03o`00oooooooooooo00;o003o0_ooool01?l0
0?ooooooooooool00?l2ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool03_ooool0
01gooooo00?o0000ooooooooool0Eoooool01Ooo003oooooooooooooooooo`0000Sooooo00?o0000
ooooooooool01oooool01Ooo003oooooooooooooooooo`0005Wooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`03ooooo`;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`05o`00
ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`14ooooo`08ool00?ooooooooooool0
0?oooooo003oooooool00?l2ooooo`03o`000?oooooooooo00[ooooo00Woo`00ooooool00?oooooo
ool00?l00?ooooooool00?ooool01_oo00000ol00?ooooooooooo`02ooooo`04o`00oooooooo003o
ooooo`;o003o00?oooooo`00ooooool00oooool01_l00?ooooooo`00ool00?ooooooo`00o`;ooooo
00Co003oooooool00?oooooo0_l00?l00ooooooo003oo`00o`02ooooo`03o`00oooooooooooo00;o
003o0_ooool01?l00?ooooooooooool00?l3ooooo`04o`00oooooooo003oo`00o`;ooooo00?o003o
ooooooooool00_l00?l00ooooooo003oooooo`02ooooo`05o`00ooooooooooooooooool00?l01Ooo
ool00ol0003oooooooooo`0>ooooo`007Oooool2o`0005Oooooo00?o003oool00?ooool00_ooool0
0ooo003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00Goo`00ooooooooooooooooool0
001Hooooo`;o0000:_ooool2o`0000Sooooo00Co003ooooooooooooo003o0_ooool00ol00?oooooo
ooooo`04ooooo`04o`00ooooooooooooo`00od?ooooo00Soo`00ooooool00?ooo`00ooooool00?oo
ooooo`00o`;ooooo00?o0000ooooooooool02_ooool03?oo003oooooo`00ooooooooo`00o`00oooo
ooooo`00ooooool00?ooo`00ooooo`?oo`0000Co003oool00?oo003oo`000oooool01Ol00?oooooo
o`00ool00?oooooo00;o003o00?oooooo`00ooooool00oooool01_l00?ooooooo`00ool00?oooooo
o`00o`?ooooo0_l00?l01Ooooooo003oo`00oooooooo003o00?ooooo00?o003oooooooooool00_l0
0?l2ooooo`03o`00oooooooooooo00;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o
00?oooooo`00ool00?l00_ooool00ol00?ooooooooooo`02o`00o`Cooooo0_l0000@ooooo`003ooo
ool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo05Kooooo00?o003oool00?ooool00_oo
ool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00Goo`00oooooooooooooooo
ool0001Iooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool00oooool2o`00o`Gooooo
00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooooooo
047ooooo00Koo`00ooooool00?ooo`00ooooool00?l2ooooo`03o`00oooooooo000000cooooo00Go
o`00ooooool00?oo003oool00002ooooo`04ool00?oooooo003oool000;ooooo00?oo`00ooooool0
0?l01_oo0003ooooo`09o`00oooooooo003oo`00oooooooo003oooooool00?oooooo00;o003o0_oo
ool01ol00?ooooooo`00oooooooo003oooooool00?l00_ooool01Ol00?oooooooooooooooooo003o
00;ooooo0_l00?l00ooooooo003oo`00o`02ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003o
oooooooooooo003o1Oooool2o`00o`;ooooo00?o003oooooooooool00_l00?l5ooooo`03o`000?oo
oooooooo00kooooo000@ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`1Fooooo`03o`00oooo003ooooo00;ooooo00?oo`00ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`05ool00?oooooooooooooooooo0000FOooool00ol0003ooooo
ooooo`0Pooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`;o003o00?oooooo`00ool00?l0
0_ooool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00Go003ooooo
ooooooooooooo`00o`0oooooo`04ool00?oooooo003oool000;ooooo0ooo00000ooooooo0000oooo
o`0;ooooo`08ool00?oooooo003oo`00oooo003o003ooooooooo0002ooooo`04ool00?oooooo003o
ool000;ooooo2Ooo0003ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`;o003o
0oooool00ol00?ooooooooooo`02ooooo`;o003o00?oooooo`00ool00?l00oooool00ol00?oooooo
o`00o`02ooooo`;o003o0_ooool2o`00o`03ooooool00?oooooo00;ooooo00Co003ooooooooooooo
003o0oooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooooooo00Cooooo00?o0000oooo
ooooool03_ooool0013ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo05Oooooo00Goo`00ooooooooooooooooool00008ooooo`03o`000?oooooo
oooo00Oooooo00Goo`00ooooooooooooooooool0001Iooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`;o003o00?oooooo`00ool00?l00_oo
ool01?l00?ooooooooooool00?l2ooooo`;o003o0_ooool01?l00?ooooooooooool00?l3ooooo`04
o`00ooooooooooooo`00occooooo00Koo`00ooooooooooooo`00ooooool00?l3ool00003ooooool0
003ooooo00_ooooo01?oo`00oooooooooooo003oool00?l00?ooooooool00?oooooo003oool00?oo
oooo003oool00?oooooo003ooooooooo003ooooo00Koo`0000Co003oool00?oo003oo`000oooool2
o`00o`04ooooool00?ooooooo`00o`;ooooo00Co003oooooool00?oooooo0_l00?l01?oooooo003o
o`00ooooool2o`00o`;ooooo0_l00?l2ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooo
ool00?oo003o0_ooool00ol00?ooooooooooo`02o`00o`03ooooool00?oooooo00;ooooo00Co003o
oooooooooooo003o1_ooool00ol0003oooooooooo`0>ooooo`004?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Cooooo0_l0001Gooooo`03o`00oooo003ooooo00;ooooo00?o
o`00ooooooooool01_ooool00ol0003oooooooooo`07ooooo`05ool00?oooooooooooooooooo0000
F?ooool2o`0001_ooooo1Ol00003ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`;o003o
0_ooool01?l00?ooooooooooool00?l6ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooo
oooooooo003o0_ooool01Ol00?oooooooooooooooooo003o03Gooooo00Koo`00ooooool00?ooo`00
ooooool00?l3ool00003ooooool0003ooooo00_ooooo01Koo`00ooooool00?ooooooool00?l00?oo
ooooool00?oooooo003oool00?oooooo003oool00?oooooo003ooooooooo003o003ooooooooo003o
oooo0ooo00000ol00?ooo`00ool00004ool000?ooooo00Ko003oooooool00?oo003oooooool00?l3
ooooo`;o003o0_ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00;o003o00?ooooo
o`00ooooool00_ooool2o`00o`04ooooool00?oo003oooooo`;o003o0_ooool2o`00o`03ooooool0
0?oo003o00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`;o00004?ooool0013ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo05Kooooo
00?o003oool00?ooool00_ooool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00Goo`00ooooooooooooooooool0001Iooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`;o003o1Oooool01?l00?ooooooooooool00?l2oooo
o`;o003o0_ooool01?l00?ooooooooooool00?l6ooooo`04o`00ooooooooooooo`00o`?ooooo00?o
003oooooooooool0<oooool02ooo003oooooo`00oooo003oooooo`00ooooooooo`00o`00oooooooo
000000cooooo00_oo`00ooooool00?oo003oool00?oooooo003oool00?oooooo003oool00002oooo
o`08ool00?oooooo003ooooooooo003o003ooooooooo0002ooooo`03ool00?oooooo003o00Koo`00
0_l00?l01ooooooo003ooooooooooooo003oooooool00?l00_ooool01?l00?ooooooo`00ooooool2
o`00o`;ooooo00?o003oooooooooool00_l00?l01?oooooo003oo`00ooooool2o`00o`;ooooo00Go
003oooooooooooooooooo`00o`02ooooo`06o`00ooooooooooooooooool00?oooooo0_l00?l00ooo
oooo003oo`00o`02ooooo`;o003o1Oooool00ol0003oooooooooo`0>ooooo`003oooool2o`0000Co
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Fooooo`03o`00oooo003ooooo
00;ooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`07ooooo`05ool00?oooooooooo
oooooooo0000FOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool2o`00o`03ooooool00?oo003o00;ooooo00Co003ooooooooooooo003o0_oo
ool2o`00o`;ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`03ooooo`04o`00
ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o;_ooool01Ol00?ooo`00ooooool00?oo
o`0000?ooooo00Coo`00o`00oooooooo00003?ooool01Ooo003oooooo`00ool00?ooo`0000;o003o
017oo`00ooooooooooooo`00ooooool00?ooo`00ooooool00?ooooooool00?l00?ooooooool00?oo
oooo003oool00003ooooo`03ool00?l00?ooo`0000Goo`000_ooool2o`00o`?ooooo0_l00?l3oooo
o`03o`00oooooooooooo00;o003o0oooool00ol00?ooooooo`00o`02ooooo`;o003o0_ooool2o`00
o`03ooooool00?oooooo00;ooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooo`00ool0
0?l2ooooo`;o003o1Oooool00ol0003oooooooooo`0>ooooo`004?ooool00ol0003oooooooooo`03
ooooo`;o00001Oooool00ol0003oooooooooo`1Gooooo`05ool00?oooooooooooooooooo00002?oo
ool00ol0003oooooooooo`07ooooo`05ool00?oooooooooooooooooo0000FOooool00ol0003ooooo
ooooo`0Pooooo`;o00001_ooool00ol0003oooooooooo`03ooooo`;o003o00?oooooo`00ool00?l0
0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o0_ooool01?l00?ooooooooooool00?l2oooo
o`;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o0_ooool01?l00?ooooooooooool0
0?l_ooooo`0=ool00?ooooooooooool00?oooooo003ooooooooo003o003oooooool0003oooooo`00
o`0:ooooo`05ool00?ooooooooooo`00oooo00000_l00?l01ooo003oooooo`00oooo003oooooo`00
oooo00000oooool02ooo003ooooooooooooo003oooooo`00oooo003oooooo`00ooooooooo`0000;o
oooo00?oo`00oooooooo00000_oo00002?l00?ooo`00ool00?oo003oooooo`00oooooooo003o0_oo
ool01Ol00?ooooooo`00ool00?oooooo00;o003o00Coooooo`00oooooooo003o0_ooool01?l00?oo
ooooo`00ool00?l3ooooo`03o`00oooooooo003o00;ooooo0_l00?l2ooooo`;o003o00?oooooo`00
ooooool00_ooool01?l00?ooooooooooool00?l6ooooo`03o`000?oooooooooo00kooooo000Moooo
o`;o0000F?ooool01Ooo003oooooooooooooooooo`0000Sooooo00?o0000ooooooooool01oooool0
1Ooo003oooooooooooooooooo`0005Sooooo0_l0000Sooooo`03o`000?oooooooooo00Cooooo0_l0
0007ooooo`;o003o00?oooooo`00ool00?l00_ooool00ol00?ooooooooooo`04ooooo`04o`00oooo
ooooooooo`00o`;ooooo0_l00?l2ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooo
oooo003o0_ooool00ol00?ooooooooooo`02o`00ob[ooooo00Wo003oool00?oooooo003oool00?oo
oooo003ooooooooo00000_ooool00ol0003oooooo`00o`09ooooo`0@o`00oooo003oooooo`00oooo
ooooo`00o`00ooooooooo`00ooooool00?ooo`00ooooool00?ooo`00ooooo`;o003o00ooo`00o`00
ooooooooo`00ooooool00?ooo`00ooooool00?ooooooool00?l00?ooooooool00?ooool00ooo0000
0ol00?ooo`00ool00004ool000;o003o00Ooooooo`00ooooooooooooo`00oooooooo003o00;ooooo
00Co003ooooooooooooooooo0_l00?l6ooooo`06o`00oooooooo003oo`00oooooooo003o0oooool2
o`00o`05ooooool00?oo003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`;o00004?oo
ool001gooooo00?o0000ooooooooool0Eoooool01Ooo003oooooooooooooooooo`0000Sooooo00?o
0000ooooooooool01oooool01Ooo003oooooooooooooooooo`0005Wooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`03ooooo`;o003o1Oooool01?l00?ooooooooooool00?l2ooooo`05
o`00ooooooooooooooooool00?l00_ooool01?l00?ooooooooooool00?l3ooooo`04o`00oooooooo
ooooo`00o`;ooooo0_l00?l2ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo
003o9oooool01_l00?ooo`00ooooool00?ooo`00ooooo`;o003o00Coo`00o`00oooooooo00000_l0
0?l9ooooo`03o`00oooo003ooooo00;o003o00Ooo`00ooooooooooooo`00ooooool00?ooo`0000;o
oooo00Soo`00ooooool00?oo003oool00?l00?ooooooool000;ooooo00Soo`00ooooool00?oo003o
ool00?l00?ooooooool000;ooooo00?oo`00ooooool00?l02Ooo00001?l00?ooooooo`00ool00?l2
ooooo`03o`00oooooooo003o00?ooooo0_l00?l01Ooooooo003oo`00oooooooo003o00Cooooo00Co
003oooooool00?oo003o0oooool01Ol00?ooooooo`00ool00?oooooo00;o003o0_ooool2o`00o`Go
oooo00?o0000ooooooooool03_ooool001gooooo00?o0000ooooooooool0Eoooool01Ooo003ooooo
ooooooooooooo`0000Sooooo00?o0000ooooooooool01oooool01Ooo003oooooooooooooooooo`00
05Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`03ooooo`;o003o00?oooooo`00
ool00?l01Oooool00ol00?ooooooooooo`02o`00o`03ooooool00?oooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o
0_ooool2o`00o`;ooooo00Co003ooooooooooooo003o9?ooool01Ol00?ooo`00ooooool00?ooo`00
00?ooooo00Koo`00o`00oooooooo0000ooooool00?l9ooooo`03o`00oooo003ooooo00;o003o00Co
o`00o`00ool00?ooo`000_ooool01Ooo003ooooooooooooo003ooooo00;o003o00Ooo`00o`00oooo
ooooo`00ooooool00?ooo`0000?ooooo00Ooo`00o`00ooooooooo`00ooooool00?ooo`0000;ooooo
00?o003oool00?l00?l01_oo00001Oooooooo`00ool00?oo003ooooo00;o003o0oooool00ol00?oo
ooooo`00o`02ooooo`;o003o00Goooooo`00oooooooo003oooooo`02o`00o`;ooooo00?o003ooooo
ool00?l01?ooool01?l00?ooooooo`00ool00?l2ooooo`;o003o1Oooool00ol0003oooooooooo`0>
ooooo`007Oooool00ol0003oooooooooo`1Gooooo`05ool00?oooooooooooooooooo00002?ooool0
0ol0003oooooooooo`07ooooo`05ool00?oooooooooooooooooo0000FOooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00?ooooo0_l00?l01?oooooo003oo`00ooooool2o`00o`;ooooo
00?o003oooooooooool00_l00?l00ooooooo003oo`00o`02ooooo`03o`00oooooooooooo00;o003o
0_ooool01?l00?ooooooooooool00?l2ooooo`05o`00ooooooooooooooooool00?l00_ooool01?l0
0?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool08?oo
ool01Ooo003ooooooooooooo003ooooo00;o003o00Goo`00o`00oooooooo0000o`00o`0;ooooo`05
ool00?ooooooooooo`00oooo00000_l00?l01ooo003oooooo`00oooo003oooooo`00oooo00000ooo
ool02?oo003ooooooooooooo003oooooo`00oooo003ooooo0_l00?l02?oo003ooooooooooooo003o
ooooo`00oooo003ooooo0_l00?l01Ooo003ooooooooooooo003ooooo00?oo`0000?o003oool00?oo
00001?oo00001?oooooo003oooooool00?l2ooooo`0:o`00oooooooo003oo`00oooooooo003ooooo
ool00?ooooooo`00o`;ooooo0_l00?l01Ooooooo003oooooool00?oooooo00;o003o0_ooool00ol0
0?ooooooo`00o`07ooooo`03o`000?oooooooooo00kooooo000Mooooo`;o0000F?ooool01Ooo003o
ooooooooooooooooo`0000Sooooo00?o0000ooooooooool01oooool01Ooo003ooooooooooooooooo
o`0005Sooooo0_l0000Zooooo`;o00001oooool2o`00o`03ooooool00?oo003o00;ooooo00Ko003o
ooooooooooooooooo`00ooooool2o`00o`;ooooo00?o003oooooooooool00_l00?l00ooooooo003o
o`00o`02ooooo`05o`00ooooooooooooooooool00?l00_ooool01?l00?ooooooooooool00?l2oooo
o`;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`05o`00ooooooooooooooooool00?l07Ooo
ool01_l00?ooo`00ooooooooooooo`00ooooo`;o003o00Coo`00oooooooooooo00000_l00?l9oooo
o`06o`00oooo003oooooo`00ooooooooo`000_l00?l02?oo003oooooo`00oooo003oooooo`00oooo
003ooooo0_l00?l02?oo003ooooooooooooo003oooooo`00oooo003ooooo0_l00?l02?oo003o003o
oooooooo003oooooo`00oooo003ooooo0_l00?l02Ooo003o003ooooooooo003oooooo`00oooo003o
ooooo`00o`09ool00004o`00oooooooo003oo`00o`Kooooo00Ko003oooooool00?oo003oooooool0
0?l2ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo0_l0000@ooooo`007Oooool00ol0003oooooooooo`1Gooooo`05ool00?oo
oooooooooooooooo00002?ooool00ol0003oooooooooo`07ooooo`05ool00?oooooooooooooooooo
0000FOooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00;ooooo00?o003oooooool0
0?l01?ooool2o`00o`;ooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool00?l2
ooooo`03o`00oooooooooooo00;o003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o
003oooooooooool01?ooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool06oooool01_l00?ooo`00ooooool00?ooo`00ooooo`;o003o00Coo`00o`00
oooooooo00000_l00?l9ooooo`03o`00oooo003ooooo00;o003o00_oo`00ooooooooooooo`00oooo
ool00?ooo`00ooooool00?ooo`00ooooo`02o`00o`04ool00?l00?oo003oool000;ooooo00Soo`00
ooooool00?oo003oool00?l00?ooooooool000;ooooo00Soo`00ooooool00?ooooooool00?l00?oo
ooooool000;ooooo00Koo`00ooooool00?oo003oool00?l00?l9ool00006o`00oooooooo003oo`00
oooooooo003o1?ooool02Ol00?ooooooo`00ool00?ooooooo`00oooooooo003oooooo`02o`00o`03
ooooool00?oooooo00?ooooo00?o003oooooooooool00oooool00ol0003oooooooooo`0>ooooo`00
7Oooool00ol0003oooooooooo`1Gooooo`05ool00?oooooooooooooooooo00002?ooool00ol0003o
ooooooooo`07ooooo`05ool00?oooooooooooooooooo0000FOooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo00;ooooo00Co003oooooool00?oooooo0_l00?l5ooooo`03o`00oooooooo
oooo00;o003o00?oooooo`00ooooool00_ooool01ol00?oooooooooooooooooo003oooooool00?l0
0oooool00ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`Go
oooo00Co003ooooooooooooo003o1_ooool00ol00?ooooooooooo`0Hooooo`05o`00oooo003ooooo
o`00oooo00000oooool01_oo003o003oooooool0003oooooo`00o`Wooooo00?o003oool00?ooool0
0_l00?l01ooo003o003oo`00oooo003oooooo`00oooo00000_ooool01Ooo003oooooo`00ool00?oo
o`0000;o003o00Coo`00ooooool00?ooo`000oooool01ooo003o003ooooooooo003oooooo`00oooo
00000_ooool02?l00?ooo`00o`00ooooooooo`00ooooool00?ooo`000_ooool01_l00?ooo`00oooo
ooooooooo`00o`00o`Koo`0000Woooooool00?oo003oo`00ooooool00?ooooooo`00ooooool00_l0
0?l2ooooo`03o`00oooooooooooo00Cooooo00So003oooooool00?oo003oooooool00?ooooooo`00
o`Gooooo00?o0000ooooooooool03_ooool001gooooo00?o0000ooooooooool0Eoooool01Ooo003o
ooooooooooooooooo`0000Sooooo00?o0000ooooooooool01oooool01Ooo003ooooooooooooooooo
o`0005Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`04o`00oooooooo
003oooooo`;o003o00?oooooo`00ool00?l01Oooool2o`00o`03ooooool00?oo003o00;ooooo00?o
003oooooooooool00_l00?l5ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l2ooooo`04o`00
ooooooooooooo`00o`;ooooo0_l00?l2ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooo
oooooooo003o0_ooool00ol00?ooooooooooo`0Eooooo`06o`00oooo003oooooo`00oooo003ooooo
0_l00?l01?oo003o003oooooool00002o`00o`[ooooo00Goo`00ooooool00?ooooooool00002o`00
o`07ool00?oooooo003oool00?oooooo003oool00003ooooo`0;ool00?l00?oo003oool00?oooooo
003oool00?oooooo003ooooooooo00000_ooool01Ooo003oooooo`00oooo003ooooo00;o003o00So
o`00ooooooooooooo`00ooooool00?ooo`00ooooo`;o003o00Soo`00o`00ooooooooo`00o`00oooo
ooooo`00ooooo`?oo`0000[o003oool00?oo003oo`00ooooool00?ooooooo`00oooooooo003o0_oo
ool2o`00o`05ooooool00?ooooooo`00ooooool00_l00?l2ooooo`03o`00oooooooo003o00Oooooo
00?o0000ooooooooool03_ooool001gooooo0_l0001Hooooo`05ool00?oooooooooooooooooo0000
2?ooool00ol0003oooooooooo`07ooooo`05ool00?oooooooooooooooooo0000F?ooool2o`0002[o
oooo0_l00005ooooo`05o`00oooooooo003oo`00ooooool00_l00?l00ooooooo003oooooo`03oooo
o`04o`00oooooooo003oo`00o`;ooooo00?o003oooooooooool00_l00?l00ooooooo003oo`00o`05
ooooo`;o003o1Oooool00ol00?ooooooooooo`02o`00o`03ooooool00?oo003o00;ooooo00Co003o
oooooooooooo003o0oooool01?l00?ooooooooooool00?l2ooooo`05o`00ooooooooooooooooool0
0?l05?ooool01Ooo003oooooo`00oooo003ooooo00;o003o00Goo`00oooooooooooo0000o`00o`0:
ooooo`06o`00oooo003oooooo`00ooooooooo`000_l00?l02?oo003oooooo`00oooo003oooooo`00
oooo003ooooo0_l00?l02?oo003ooooooooooooo003oooooo`00oooo003ooooo0_l00?l02?oo003o
ooooo`00oooo003oooooo`00oooo003ooooo0_l00?l03_oo003o003ooooooooo003oooooo`00oooo
003oooooo`00ooooooooo`00o`00ooooooooo`000_ooool01_oo003oooooo`00oooo003oooooo`00
o`Koo`000_l00?l01?oooooo003oooooool00?l2ooooo`05o`00oooooooo003oooooool00?l00_oo
ool2o`00o`04ooooool00?ooooooo`00o`Cooooo0_l0000@ooooo`007Oooool00ol0003ooooooooo
o`1Gooooo`05ool00?oooooooooooooooooo00002?ooool00ol0003oooooooooo`07ooooo`05ool0
0?oooooooooooooooooo0000FOooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00;o
oooo00?o003oooooooooool01?ooool2o`00o`03ooooool00?oo003o00;ooooo00Ko003ooooooooo
ooooooooo`00ooooool2o`00o`;ooooo0_l00?l00ooooooo003oo`00o`02ooooo`06o`00oooooooo
ooooooooool00?oooooo0_l00?l6ooooo`04o`00oooooooo003oo`00o`;ooooo00Co003ooooooooo
oooo003o0oooool01?l00?ooooooooooool00?l2ooooo`05o`00ooooooooooooooooool00?l00_oo
ool00ol00?ooooooooooo`0>ooooo`06o`00oooo003oooooo`00oooo003ooooo0_l00?l01?oo003o
003oooooool00002o`00o`Wooooo00Ko003oool00?oooooo003ooooooooo0002ooooo`08ool00?oo
oooo003oool00?oooooo003oool00?ooool2o`00o`04ool00?l00?oo003oool000;ooooo00Goo`00
ooooool00?oo003oool00002o`00o`08ool00?ooooooooooool00?oooooo003ooooooooo0002o`00
o`05ool00?ooooooooooool00?ooool00_l00?l01ooo003o003ooooooooo003o003ooooooooo0000
0_ooool01_oo003oooooo`00ooooooooo`00o`00o`Koo`0000Oo003oooooool00?oo003oooooool0
0?oooooo00;o003o00Coooooo`00oooooooo003o1?ooool00ol00?ooooooooooo`03ooooo`03o`00
0?oooooooooo00kooooo000Mooooo`03o`000?oooooooooo05Oooooo00Goo`00oooooooooooooooo
ool00008ooooo`03o`000?oooooooooo00Oooooo00Goo`00ooooooooooooooooool0001Iooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool00_ooool01Ol00?ooooooo`00oooooooo003o
00?ooooo00Co003oooooool00?oo003o0_ooool2o`00o`03ooooool00?oooooo00;ooooo00?o003o
ooooooooool00oooool2o`00o`;ooooo00?o003oooooooooool00_l00?l00ooooooo003oo`00o`02
ooooo`03o`00oooooooooooo00;o003o1Oooool01?l00?ooooooooooool00?l2ooooo`05o`00oooo
ooooooooooooool00?l00_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Co003ooooooooo
oooo003o3Oooool03_l00?ooo`00ooooool00?ooo`00ooooool00?ooooooool00?l00?ooooooo`00
0?oooooo003o0_ooool00ol00?ooooooooooo`04ooooo`06o`00oooo003oooooo`00ooooooooo`00
0_l00?l01?oo003oooooo`00oooo0002ooooo`05ool00?oooooo003oo`00oooo00000_l00?l01?oo
003oooooo`00oooo0002ooooo`08o`00oooo003o003oo`00oooo003oooooo`00oooo0002ooooo`08
o`00oooo003o003ooooooooo003oooooo`00oooo0002ooooo`0;o`00oooo003ooooooooooooo003o
003ooooooooo003oooooo`00oooo00000oooool00ooo003o003oool00005ool00004o`00oooo003o
o`00ool000Cooooo00Co003oooooool00?oooooo0_l00?l01?oooooo003oooooool00?l5ooooo`03
o`000?oooooooooo00kooooo000Mooooo`03o`000?oooooooooo05Oooooo00Goo`00oooooooooooo
ooooool00008ooooo`03o`000?oooooooooo00Oooooo00Goo`00ooooooooooooooooool0001Ioooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool00_ooool01?l00?ooooooo`00ooooool2
o`00o`03ooooool00?oooooo00;ooooo00?o003oooooooooool00_l00?l01?oooooo003oo`00oooo
ool2o`00o`;ooooo0_l00?l4ooooo`;o003o0_ooool00ol00?ooooooooooo`02o`00o`;ooooo00Co
003ooooooooooooo003o0_ooool2o`00o`;ooooo00Co003ooooooooooooo003o0oooool01?l00?oo
ooooooooool00?l5ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0;
ooooo`05o`00oooo003oooooo`00oooo00000_ooool01Ol00?ooo`00o`00oooooooo000000;o003o
0_ooool00ol00?ooooooooooo`05ooooo`05ool00?oooooo003ooooooooo00000_l00?l01ooo003o
ooooo`00oooo003oooooo`00oooo00000oooool02ooo003o003oo`00oooo003oooooo`00oooo003o
ooooo`00ooooooooo`0000;o003o00Goo`00ooooool00?ooo`00ooooo`02o`00o`08ool00?oooooo
003oool00?oooooo003oool00?ooool2o`00o`0Bool00?l00?oo003oool00?l00?ooooooool00?oo
oooo003oool00?oooooo003ooooooooo003o003ooooooooo003ooooo0ooo00000oooooooo`00ool0
0004ool00004o`00ooooooooooooo`00o`;ooooo00?o003oooooool00?l01oooool00ol0003ooooo
ooooo`0>ooooo`007Oooool2o`0005Sooooo00Goo`00ooooooooooooooooool00008ooooo`03o`00
0?oooooooooo00Oooooo00Goo`00ooooooooooooooooool0001Hooooo`;o0000:_ooool2o`0000?o
oooo00Oo003oooooool00?oo003oooooool00?oooooo00;o003o00?oooooo`00ooooool00oooool0
1_l00?ooooooo`00ool00?ooooooo`00o`?ooooo0_l00?l00ooooooo003oo`00o`05ooooo`;o003o
1?ooool2o`00o`;ooooo0_l00?l00ooooooo003oo`00o`02ooooo`04o`00ooooooooooooo`00o`;o
oooo0_l00?l2ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o0_ooool0
1Ol00?oooooooooooooooooo003o00[ooooo00Goo`00ooooool00?ooo`00ooooo`02o`00o`05ool0
0?ooooooooooo`000?l00?l00oooool00ol00?ooooooooooo`05ooooo`05ool00?oooooo003ooooo
oooo00000_l00?l02ooo003oooooo`00oooo003oooooo`00oooo003oooooo`00ooooooooo`0000;o
oooo00Goo`00ooooool00?ooo`00ooooo`02o`00o`08ool00?ooooooooooool00?oooooo003oool0
0?ooool2o`00o`0;ool00?l00?oo003oool00?oooooo003oool00?oooooo003ooooooooo00000_l0
0?l02ooo003ooooooooooooo003oooooo`00oooo003oooooo`00ooooooooo`0000;ooooo00Koo`00
ooooool00?ooo`00ooooool00?l9ool000?ooooo00Go003oooooool00?ooooooo`00o`04ooooo`;o
00004?ooool000oooooo0ol00003ooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`05ool0
0?oooooooooooooooooo00002?ooool00ol0003oooooooooo`07ooooo`05ool00?oooooooooooooo
oooo0000FOooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Oooooo00Go003ooooo
ool00?oo003oooooo`02o`00o`Kooooo00Co003oooooool00?oo003o0_ooool2o`00o`04ooooool0
0?oo003oooooo`;o003o0oooool01?l00?ooooooo`00ool00?l5ooooo`;o003o00?oooooo`00ool0
0?l00_ooool01?l00?ooooooooooool00?l2ooooo`;o003o0_ooool01?l00?ooooooooooool00?l2
ooooo`;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o2Oooool01_l00?ooo`00oooo
ool00?ooo`00ooooo`;o003o00Koo`00o`00oooooooo003oooooool00?l2ooooo`03o`00oooooooo
oooo00Cooooo00Ko003oool00?oooooo003ooooooooo0002ooooo`08ool00?oooooo003oool00?oo
oooo003oool00?ooool2o`00o`08ool00?l00?oo003oool00?oooooo003oool00?ooool2o`00o`0;
ool00?l00?oo003oool00?oooooo003oool00?oooooo003ooooooooo00000_l00?l01Ooo003ooooo
oooooooo003ooooo00;o003o00Ooo`00o`00ool00?ooo`00o`00ooooooooo`0000;ooooo00Goo`00
ooooool00?oo003oool00002ooooo`09ool00?oooooo003oool00?oooooo003ooooooooo003o003o
00Koo`0000Co003oool00?oo003oo`000oooool00ol00?ooooooooooo`03ooooo`03o`000?oooooo
oooo00kooooo000@ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo05Oooooo00Goo`00ooooooooooooooooool00008ooooo`03o`000?oo
oooooooo00Oooooo00Goo`00ooooooooooooooooool0001Iooooo`03o`000?oooooooooo027ooooo
0_l00005ooooo`03o`000?oooooooooo00;ooooo00Co003oooooool00?oo003o1?ooool02_l00?oo
ooooo`00ool00?ooooooo`00oooooooo003oooooool00?l3ooooo`03o`00oooooooooooo00?ooooo
0_l00?l00ooooooo003oo`00o`02ooooo`;o003o00Coooooo`00ool00?oooooo0_l00?l3ooooo`03
o`00oooooooooooo00;ooooo0_l00?l2ooooo`04o`00ooooooooooooo`00o`Kooooo00?o003ooooo
ooooool00_l00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l2ooooo`03o`00oooooooo
oooo00Cooooo00ko003oool00?oooooo003oool00?oooooo003ooooooooo003o003oooooool0003o
ooooo`00o`;ooooo00Co003ooooooooooooo003o0oooool03?l00?ooo`00ooooool00?ooooooool0
0?l00?ooooooool00?oooooo003oool000;ooooo00Goo`00ooooool00?oo003oool00002o`00o`04
ool00?oooooo003oool000;ooooo00So003oool00?l00?oo003oool00?oooooo003oool000;ooooo
00So003oool00?l00?ooooooool00?oooooo003oool000;ooooo00_o003oool00?ooooooooooool0
0?l00?ooooooool00?oooooo003oool00002ooooo`05o`00oooo003o003ooooooooo00000_ooool0
2Ooo003oooooo`00ooooooooo`00o`00ooooooooo`00ooooo`03ool00003o`00oooo003oo`0000Co
o`0000?o003oooooooooool00oooool00ol0003oooooooooo`0>ooooo`004?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Eoooool01Ooo003ooooo
ooooooooooooo`0000Sooooo00?o0000ooooooooool01oooool01Ooo003oooooooooooooooooo`00
05Wooooo00?o0000ooooooooool08?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00;ooooo00So003oooooool00?oo003oooooool00?ooooooo`00o`?ooooo00Ko003oooooool0
0?ooooooo`00ooooool2o`00o`03ooooool00?oo003o00;ooooo0_l00?l4ooooo`;o003o0_ooool0
0ol00?ooooooooooo`02o`00o`03ooooool00?oo003o00;ooooo00Co003ooooooooooooo003o0_oo
ool2o`00o`;ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00?ooooo
00Go003oooooooooooooooooo`00o`02ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003ooooo
ooooool01?ooool01Ol00?ooo`00ooooool00?ooo`0000;ooooo00?o003oool00?l00?l00ooo0000
1?l00?ooooooooooool00?l2ooooo`0Co`00ooooooooooooooooool00?ooo`00ooooool00?oooooo
ool00?l00?ooooooool00?oooooo003oool00?oooooo003oool00002ooooo`08o`00oooo003o003o
o`00oooo003oooooo`00oooo0003ooooo`07ool00?l00?oo003oool00?oooooo003oool00002oooo
o`09o`00oooo003oooooo`00oooo003oooooo`00oooo003ooooo00;o003o00_oo`00o`00ool00?oo
o`00o`00ooooooooo`00ooooool00?ooo`00ooooo`02o`00o`07ool00?l00?ooooooool00?oooooo
003oool00002ooooo`0:o`00oooo003o003ooooooooo003oooooo`00oooo003oooooo`00o`Woo`00
0oooool00ol0003oooooooooo`0>ooooo`004?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo0_l0001Hooooo`05ool00?oooooooooooooooooo00002?ooool00ol0003ooooo
ooooo`07ooooo`05ool00?oooooooooooooooooo0000F?ooool2o`0002;ooooo00Co0000oooooooo
oooo00001?ooool5o`000003o`00ool0003oo`0000;oo`0000Ko003oo`000?oo003o003oo`000?oo
0002o`000004ool00?l0003o003oool000;o003o00Go0000ool00?l0003o0000ool00002o`00o`05
ool00?l00?oo003oo`000?oo00000_l000002ooo003o003oo`00oooo003o0000o`00ool0003oo`00
o`00ool0003oo`0000;o003o00Goo`00o`00ool00?ooo`00o`00o`02o`000004ool00?l00?oo0000
ool000;o003o01;oo`00o`000?l00?oo0000ool00?l00?oo0000ool00?l0003o003oool00?l0003o
003oo`000?oo003o003oo`000?oo0002o`00o`08ool00?l0003o003oo`000?oo003o003oo`000?oo
0002o`000005ool00?l0003o003oool00?l000000_l00?l00ooo003o0000ool00002ool00003o`00
0?oo003o000000;o000000Coo`00o`00ool0003oo`000_l000006Ooo003o0000o`00ool0003oo`00
o`00ool0003oo`00o`000?l00?ooo`00o`000?l00?ooo`00o`000?l00?oo0000ool00?l0003o003o
ool00?l0003o003oool00?l000000_l00?l02?oo003o0000o`000?oo003o0000o`00oooo003o0000
0_l00?l02ooo003o0000o`00oooo003o0000o`00oooo003o0000o`00ool0003oo`0000;o003o01;o
o`00o`00ool0003oo`00o`000?l00?ooo`00o`000?l00?oo0000ool00?l00?oo0000ool00?l0003o
003oool00?l00002o`00o`07ool00?l0003o0000ool00?l0003o003oool00003o`000003ool00?l0
0?ooo`0000Goo`001?l0000@ooooo`004?ooool01?l0003oooooooooooooool4o`0000Gooooo00?o
0000ooooooooool0Eoooool01Ooo003oooooooooooooooooo`0000Sooooo00?o0000ooooooooool0
1oooool01Ooo003oooooooooooooooooo`0005Wooooo00?o0000ooooooooool08?ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00Cooooo0ooo00002Ol00?ooo`00ool00?oo003o
ooooool00?l00?ooooooool00002ooooo`0;ool00?oooooo003ooooooooo003o003ooooooooo003o
ooooo`00oooo00000_l00?l02Oooooooo`00o`00ooooooooo`00ooooool00?ooo`00o`00o`02oooo
o`04ool00?ooooooooooool000;o003o00_oo`00o`00ool00?ooo`00ooooool00?ooooooool00?l0
0?ooooooool00002o`00o`0Eool00?l00?oo003ooooooooo003o003ooooooooo003oooooo`00oooo
003oooooo`00ooooooooo`00o`00ooooooooo`00ooooool00?ooo`0000?ooooo00Goo`00o`00oooo
ooooo`00o`00o`03ooooo`04o`00ooooooooooooo`00o`;ooooo00oo003oool00?oo003oo`00o`00
oooo003oooooo`00ooooooooo`00o`00ooooooooo`00ooooool00?l00_ooool01?l00?oooooooooo
ool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l00ooooooo003oooooo`02ooooo`03
o`00oooooooooooo00;o003o00?oooooo`00ool00?l01Oooool2o`00o`03ooooool00?oo003o00;o
oooo00Co003ooooooooooooo003o0_ooool2o`00o`?ooooo00Go003ooooooooooooo003oooooo`02
o`00o`?ooooo00?o003oooooool00?l00_ooool2o`00o`05ooooool00?ooooooo`00ooooool00_l0
0?l00ooooooo003oo`00o`05ooooo`?oo`000oooool00ol0003oooooooooo`0>ooooo`003oooool2
o`0000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Gooooo`05ool00?oooooo
oooooooooooo00002?ooool00ol0003oooooooooo`07ooooo`05ool00?oooooooooooooooooo0000
FOooool00ol0003oooooooooo`0Pooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool01?ooool3ool00003oooooooo003oo`0000Coo`0000coooooool00?oooooo003oool00?oooooo
003ooooooooo003o003ooooooooo0002ooooo`0;ool00?l00?oo003ooooooooo003o003ooooooooo
003oooooo`00oooo00000_l00?l02?ooooooo`00ooooooooooooo`00ooooool00?ooo`000_l00?l0
2?oo003o003oo`00ooooooooo`00o`00ooooooooo`000_l00?l02?oo003oooooooooooooooooo`00
o`00ooooooooo`000_l00?l02?oo003oooooo`00ooooooooo`00o`00ooooooooo`000_l00?l02Ooo
003oooooo`00ooooooooo`00o`00ooooooooo`00o`00o`03ooooo`04o`00ooooooooooooo`00o`;o
oooo00oo003oooooool0003oooooo`00oooo003oooooo`00ooooooooo`00o`00ooooooooo`00oooo
ool00?l00_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00?ooooo0_l00?l0
0ooooooo003oo`00o`05ooooo`;o003o00?oooooo`00ool00?l00_ooool01?l00?ooooooooooool0
0?l2ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`;o003o
0_ooool2o`00o`07ooooool00?oo003oooooool00?ooooooo`00o`04ooooo`04o`00oooooooooooo
o`00o`Cooooo00Wo003oooooool00?oo003oooooool00?ooooooo`00ooooool00_l00?l4ooooo`03
o`000?oooooooooo00kooooo000@ooooo`04o`000?ooooooooooooooo`Go00001?ooool00ol0003o
ooooooooo`1Gooooo`05ool00?oooooooooooooooooo00002?ooool00ol0003oooooooooo`07oooo
o`05ool00?oooooooooooooooooo0000FOooool00ol0003oooooooooo`0Pooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool01?ooool2o`00o`03ooooool00?ooo`0000Goo`0000Ko
ooooool00?oooooo003oool00?l00?l2ooooo`07ool00?l00?ooooooool00?oooooo003oool00003
ooooo`04ool00?l00?ooooooool000;ooooo00Soo`00o`00ool00?ooooooool00?l00?ooooooool0
00;ooooo00Coo`00ooooooooooooo`000_l00?l01Oooooooo`00o`00ooooooooo`0000;ooooo00Go
o`00o`00ool00?ooooooool00002ooooo`04ool00?l00?ooooooool000;o003o00coooooool00?l0
0?ooooooool00?l00?ooooooool00?oooooo003ooooooooo0002ooooo`03ool00?l00?oooooo00;o
oooo00Co003ooooooooooooo003o0_ooool01_l00?ooooooo`00oooooooo003oool000;o003o00Ko
ooooool00?l00?ooooooool00?l00?l6ooooo`03o`00oooooooooooo00Cooooo00Co003ooooooooo
oooo003o0_ooool2o`00o`;ooooo00?o003oooooooooool00oooool2o`00o`;ooooo00Oo003ooooo
ooooooooooooo`00oooooooo003o00?ooooo00Ko003oooooooooooooooooo`00ooooool2o`00o`03
ooooool00?oooooo00;ooooo0_l00?l2ooooo`04o`00oooooooo003oo`00o`;ooooo0_l00?l2oooo
o`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`;o003o00Coooooo`00oooooooo003o
0_ooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00kooooo000Mooooo`;o0000F?oo
ool01Ooo003oooooooooooooooooo`0000Sooooo00?o0000ooooooooool01oooool01Ooo003ooooo
ooooooooooooo`0005Sooooo0_l0000Sooooo`;o00001Oooool2o`0000Gooooo0_l00?l01Ooooooo
003oo`00oooooooo003o00Koo`0000Ko003oool00?l00?oo003ooooooooo0002ooooo`04ool00?oo
oooo003oool000;o003o01;oooooool00?ooooooooooool00?oooooo003oool00?oooooo003ooooo
oooo003o003ooooooooo003oooooo`00oooo0002o`00o`08ool00?l00?oooooooooooooo003o003o
oooooooo0002o`00o`08ool00?l00?oo003ooooooooo003o003ooooooooo0002o`00o`08ool00?l0
0?oooooooooooooo003o003ooooooooo0002o`00o`08ool00?oooooo003ooooooooo003o003ooooo
oooo0007ooooo`06o`00ooooooooooooo`00oooooooo003o0_ooool02?oo003ooooooooooooooooo
o`00o`00ooooooooo`002oooool01?l00?ooooooooooool00?l2ooooo`05o`00oooooooooooooooo
ool00?l00_ooool01?l00?ooooooooooool00?l6ooooo`03o`00oooooooooooo00;o003o0_ooool0
1?l00?ooooooooooool00?l2ooooo`;o003o00Coooooo`00ool00?oooooo0_l00?l2ooooo`04o`00
ooooooooooooo`00o`;ooooo00Co003ooooooooooooooooo0_l00?l00ooooooo003oo`00o`03oooo
o`04o`00oooooooo003oo`00o`Cooooo00?o003oooooool00?l00_ooool01?l00?oooooooooooooo
ool2o`00013ooooo000Mooooo`03o`000?oooooooooo05Oooooo00Goo`00ooooooooooooooooool0
0008ooooo`03o`000?oooooooooo00Oooooo00Goo`00ooooooooooooooooool0001Iooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool01Oooool01ol00?ooooooo`00ool00?ooooooo`00
ooooool00_l00?l6ool00009o`00ooooooooo`00o`00ooooooooo`00ooooool00?ooo`0000;o003o
00Woooooool00?l00?ooooooool00?oooooo003oool00?l00?l00_ooool01ooo003o003ooooooooo
003oooooo`00oooo00000_l00?l01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00o`00ool0
0?ooo`000_l00?l02?ooooooo`00o`00ooooooooo`00ooooool00?ooo`000_l00?l02Oooooooo`00
o`00ooooooooo`00ooooool00?ooo`00o`00o`02ooooo`05ool00?l00?ooooooool00?l00?l01_oo
ool00ol00?ooooooooooo`02ooooo`04o`00oooooooo003oool000;o003o00Koooooool00?l00?oo
ooooool00?l00?l:ooooo`04o`00ooooooooooooo`00o`;ooooo00Co003ooooooooooooo003o0ooo
ool01?l00?ooooooooooool00?l2ooooo`;o003o1Oooool00ol00?ooooooooooo`02o`00o`;ooooo
00Co003ooooooooooooo003o0_ooool2o`00o`;ooooo00Ko003oooooooooooooooooo`00ooooool2
o`00o`;ooooo00?o003oooooooooool00_l00?l01?oooooo003oo`00ooooool2o`00o`;ooooo0_l0
0?l00ooooooo003oo`00o`05ooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool03_oo
ool001gooooo00?o0000ooooooooool0Eoooool01Ooo003oooooooooooooooooo`0000Sooooo00?o
0000ooooooooool01oooool01Ooo003oooooooooooooooooo`0005Wooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00Co003oooooool00?oo
003o1_oo00001_l00?ooo`00ool00?oo003oooooool000;ooooo00_oo`00o`00ool00?ooooooool0
0?l00?ooooooool00?oooooo003oool00002o`00o`08oooooooo003ooooooooooooo003oooooo`00
oooo0002o`00o`08ool00?l00?oo003ooooooooo003o003ooooooooo0002o`00o`08ool00?oooooo
oooooooooooo003o003ooooooooo0002o`00o`08ool00?oooooo003ooooooooo003o003ooooooooo
0002o`00o`09ool00?oooooo003ooooooooo003o003ooooooooo003o003o00Kooooo00Wo003ooooo
oooooooo003oooooool00?ooooooo`00oooo00000_l00?l01_ooooooo`00o`00ooooooooo`00o`00
oa3ooooo00?o003oooooooooool00_l00?l5ooooo`03o`00oooooooooooo00;o003o0_ooool01?l0
0?ooooooooooool00?l2ooooo`;o003o0_ooool00ol00?ooooooooooo`02o`00o`04ooooool00?oo
ooooooooo`;o003o0_ooool2o`00o`04ooooool00?oo003oooooo`;o003o1Oooool01?l00?oooooo
ooooool00?l3ooooo`;o003o00Coooooo`00ool00?oooooo0_l00?l2ooooo`;o003o1?ooool00ol0
003oooooooooo`0>ooooo`007Oooool00ol0003oooooooooo`1Gooooo`05ool00?oooooooooooooo
oooo00002?ooool00ol0003oooooooooo`07ooooo`05ool00?oooooooooooooooooo0000FOooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Cooooo0_l00?l00ooooooo003oo`00o`04
ooooo`04o`00oooooooo003oooooo`?oo`0000?oooooool00?oo00001?oo00000ol00?ooo`00oooo
o`02ooooo`04ool00?l00?ooooooool000;ooooo00Soo`00o`00ool00?ooooooool00?l00?oooooo
ool000;ooooo00Coo`00ooooooooooooo`000_l00?l01Oooooooo`00o`00ooooooooo`0000;ooooo
00Goo`00o`00ool00?ooooooool00002ooooo`04ool00?l00?ooooooool000;o003o00Soooooool0
0?l00?ooooooool00?l00?ooooooool000;o003o00Koooooool00?ooooooooooool00?l00?l9oooo
o`06o`00oooooooo0000ooooool00?ooo`000_l00?l01_ooooooo`00o`00ooooooooo`00o`00oa3o
oooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooooooo00?ooooo0_l00?l2ooooo`04
o`00ooooooooooooo`00o`;ooooo00Go003oooooooooooooooooo`00o`03ooooo`06o`00oooooooo
ooooo`00oooooooo003o0oooool2o`00o`;ooooo00Co003oooooool00?oo003o0_ooool2o`00o`;o
oooo00Co003oooooool00?oo003o1Oooool2o`00o`03ooooool00?oo003o00;ooooo0_l00?l4oooo
o`03o`000?oooooooooo00kooooo000Mooooo`;o0000F?ooool01Ooo003oooooooooooooooooo`00
00Sooooo00?o0000ooooooooool01oooool01Ooo003oooooooooooooooooo`0005Sooooo0_l0000Z
ooooo`;o00001Oooool2o`00o`07ooooool00?oo003oooooool00?ooooooo`00o`02ooooo`06o`00
oooooooo003oo`00oooooooo003o2Ooo00000ol00?ooooooool00002ooooo`0;ool00?oooooo003o
ool00?oooooo003ooooooooo003o003ooooooooo00000_ooool01?oo003o003oo`00oooo0002o`00
o`05oooooooo003o003ooooooooo00000_l00?l02ooo003o003oo`00ooooooooo`00o`00oooooooo
o`00o`00ooooooooo`0000;o003o00Goooooool00?l00?ooooooool00002o`00o`08ool00?l00?oo
003ooooooooo003o003ooooooooo000:ooooo`;o003o00co0000ooooooooooooo`00ooooool00?oo
ooooool00?l00?ooooooool00?l00?lDooooo`04o`00ooooooooooooo`00o`;ooooo00?o003ooooo
ooooool01?ooool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00?o
003oooooooooool00_l00?l00ooooooo003oo`00o`02ooooo`04o`00ooooooooooooo`00o`;ooooo
00Co003ooooooooooooooooo0_l00?l2ooooo`04o`00oooooooo003oo`00o`;ooooo0_l00?l4oooo
o`;o003o0oooool01?l00?ooooooooooooooool2o`00013ooooo000Mooooo`03o`000?oooooooooo
05Oooooo00Goo`00ooooooooooooooooool00008ooooo`03o`000?oooooooooo00Oooooo00Goo`00
ooooooooooooooooool0001Iooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01Ooo
ool01ol00?ooooooo`00ool00?ooooooo`00ooooool00_l00?l4ooooo`04o`00oooooooo003ooooo
o`;o003o1_oo00002Ol00?ooo`00ool00?oo003oooooool00?oooooo003oool00003ooooo`07ool0
0?l00?ooooooool00?oooooo003oool00002o`00o`05ool00?oooooooooooooooooo00000_ooool0
1?oo003o003oo`00oooo0002o`00o`09oooooooo003o003ooooooooo003oooooo`00oooo003o003o
00;ooooo00Soo`00o`00ooooooooo`00ooooool00?ooo`00o`00o`;ooooo00Goo`00o`00oooooooo
o`00o`00o`0:ooooo`06o`00ool0003oooooo`00oooo003o003o0_ooool01Ooo003o003ooooooooo
003o003o01Oooooo00Co003ooooooooooooo003o0_ooool2o`00o`;ooooo00Co003ooooooooooooo
003o0_ooool2o`00o`;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`;ooooo00Co003ooooo
oooooooo003o0_ooool00ol00?ooooooooooo`04ooooo`;o003o00?oooooo`00ool00?l00_ooool0
0ol00?ooooooooooo`02o`00o`03ooooool00?oo003o00Gooooo00?o003oooooooooool00oooool0
0ol0003oooooooooo`0>ooooo`007Oooool00ol0003oooooooooo`1Gooooo`03ool00?oooooooooo
00?oo`001oooool00ol0003oooooooooo`06ooooo`?oo`000_ooool00ooo003oooooooooo`1Goooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`03oooo
o`;o003o00Coooooo`00oooooooo003o1?ooool01ol00?ooooooo`00ool00?ooooooo`00ooooool0
0ooo00000ol00?ooo`00ool00004ool00006o`00oooo003oooooo`00ooooooooo`000_ooool03_oo
003oooooo`00oooo003oooooo`00oooo003oooooo`00ooooooooo`00o`00ooooooooo`000_l00?l0
2?oo003oooooooooooooooooo`00o`00ooooooooo`000_l00?l01Ooo003oooooo`00ooooooooo`00
00;ooooo00coo`00o`00ool00?ooo`00ooooool00?ooooooool00?l00?ooooooool00?l00?l9oooo
o`;o003o00Co0000ooooool00?ooo`000_l00?l01Oooooooo`00o`00ooooooooo`0001_ooooo00?o
003oooooooooool00_l00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l2ooooo`04o`00
ooooooooooooo`00o`;ooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooooooo00;o
003o00?oooooo`00ool00?l01Oooool2o`00o`03ooooool00?oooooo00;ooooo0_l00?l01?oooooo
003oo`00ooooool2o`00o`;ooooo0_l00?l4ooooo`03o`000?oooooooooo00kooooo000Mooooo`03
o`000?oooooooooo05Oooooo00?oo`00ooooooooool00ooo0007ooooo`03o`000?oooooooooo00Ko
oooo0ooo0002ooooo`03ool00?oooooooooo05Oooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`04ooooo`;o003o00?oooooo`00ool00?l01?ooool01?l00?ooooooo`00ooooool2o`00
o`Cooooo00Go003oooooool00?ooooooo`00o`03ooooo`Woo`0000Wo003ooooooooo003o003ooooo
oooo003oooooo`00oooo00000_ooool02?oo003o003oo`00ooooooooo`00o`00ooooooooo`000_oo
ool01Ooo003o003oo`00ooooooooo`0000;ooooo00Coo`00o`00ool00?ooo`000_l00?l02?oooooo
o`00o`00ooooooooo`00o`00ooooooooo`000_l00?l01_ooooooo`00ooooooooooooo`00o`00o`Wo
oooo00Ko003oooooool0003oooooo`00oooo0002o`00o`06oooooooo003o003ooooooooo003o003o
7Oooool01Ol00?oooooooooooooooooo003o00;ooooo00Co003ooooooooooooo003o0oooool01?l0
0?ooooooooooool00?l3ooooo`03o`00oooooooo003o00?ooooo00Ko003oooooooooooooooooo`00
ooooool2o`00o`;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`Gooooo0_l00?l00ooooooo
003oo`00o`02ooooo`;o003o1?ooool00ol0003oooooooooo`0>ooooo`007Oooool2o`0005Sooooo
00?oo`00ooooooooool00ooo0007ooooo`03o`000?oooooooooo00Kooooo0ooo0002ooooo`03ool0
0?oooooooooo05Kooooo0_l0000Zooooo`;o00001Oooool2o`00o`04ooooool00?oo003oooooo`;o
003o0oooool01Ol00?ooooooo`00ool00?oooooo00;o003o1Oooool2o`00o`05ooooool00?oooooo
o`00ooooool01_oo00001_l00?ooo`00ool00?oo003oooooool000;ooooo00Coo`00ooooool00?oo
o`000_l00?l02?ooooooo`00o`00ooooooooo`00ooooool00?ooo`000_l00?l02?ooooooo`00o`00
ooooooooo`00o`00ooooooooo`000_l00?l02?ooooooo`00o`00ooooooooo`00o`00ooooooooo`00
0_l00?l01Oooooooo`00o`00ooooooooo`0000[ooooo0_l00?l03?l0003ooooooooooooo003ooooo
o`00ooooooooo`00o`00ooooooooo`00o`00ob7ooooo00Co003ooooooooooooo003o0_ooool01Ol0
0?oooooooooooooooooo003o00;ooooo00?o003oooooooooool00_l00?l00ooooooo003oo`00o`02
ooooo`03o`00oooooooooooo00;o003o00?oooooo`00ool00?l00_ooool01_l00?oooooooooooooo
oooo003oooooo`;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o0oooool01?l00?oo
ooooooooooooool2o`00013ooooo000Mooooo`03o`000?oooooooooo05Oooooo00Coo`00oooooooo
oooo003o2Oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo05Oooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`05ooooo`05o`00oooooooo003oo`00ooooool00_l00?l0
0ooooooo003oooooo`02ooooo`;o003o00Soooooo`00ool00?ooooooo`00oooooooo003oooooo`;o
003o00Goooooo`00ooooooooooooo`00o`03ooooo`?oo`0000goooooool00?oo003oo`00oooooooo
003oooooo`00oooo003oooooo`00oooo003o003o00;ooooo00Ooo`00o`00ooooooooo`00ooooool0
0?ooo`0000;o003o00Woooooool00?l00?ooooooool00?oooooo003oool00?l00?l00_ooool02?oo
003o003ooooooooo003oooooo`00oooo003o003o0_ooool01Ooo003o003ooooooooo003o003o00[o
oooo00Ko003oo`000?oooooo003oool00?l00?l2ooooo`05ool00?l00?ooooooool00?l00?l08Ooo
ool01?l00?ooooooooooool00?l2ooooo`05o`00ooooooooooooooooool00?l00_ooool01?l00?oo
ooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooooooooooo003o0oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool03_ooool001gooooo00?o0000
ooooooooool0Eoooool00ooo003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00Go003o
ooooooooooooooooool0001Iooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01?oo
ool01_l00?oooooooooooooooooo003oooooo`;o003o00Coooooo`00oooooooo003o1?ooool2o`00
o`04ooooool00?ooooooo`00o`;ooooo00Wo003oooooool00?oo003oooooool00?ooooooo`00oooo
ool00_l00?l00ooooooo003oool00005ool00009o`00oooo003oooooo`00oooo003oooooo`00oooo
ooooo`0000;ooooo00Coo`00ooooool00?ooo`000oooool02ooo003o003ooooooooo003oooooo`00
oooo003oooooo`00ooooooooo`0000;ooooo00coo`00o`00ool00?ooo`00ooooool00?ooooooool0
0?l00?ooooooool00?l00?l9ooooo`;o003o00Co0000ooooool00?ooo`000_l00?l01Oooooooo`00
o`00ooooooooo`0002Gooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool00?l2
ooooo`03o`00oooooooooooo00;o003o0_ooool00ol00?ooooooooooo`02o`00o`03ooooool00?oo
003o00Gooooo0_l00?l00ooooooo003oooooo`02ooooo`03o`00oooooooooooo00;o003o0_ooool0
1?l00?ooooooooooool00?l5ooooo`03o`000?oooooooooo00kooooo000Mooooo`03o`000?oooooo
oooo05Oooooo00?oo`00ooooooooool02_ooool00ol0003oooooooooo`07ooooo`05o`00oooooooo
oooooooooooo0000FOooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Cooooo00Co
003ooooooooooooo003o1Oooool01?l00?ooooooo`00ooooool2o`00o`Cooooo00Co003oooooool0
0?oooooo0_l00?l2ooooo`06o`00oooooooo003oooooool00?oooooo0_l00?l01Ooooooo003oo`00
oooooooo003o00Koo`0000Woooooool00?l00?oo003ooooooooo003o003ooooooooo00000_ooool0
1Ooo003o003oo`00ooooooooo`0000;ooooo00Coo`00ooooool00?ooo`000_l00?l01Oooooooo`00
o`00ooooooooo`0000;o003o00Goo`00o`00ool00?ooooooool00002ooooo`03ool00?l00?oooooo
00Sooooo00Ko003oooooool0003oooooo`00oooo0002o`00o`06oooooooo003o003ooooooooo003o
003o9oooool01Ol00?oooooooooooooooooo003o00;ooooo00Co003ooooooooooooo003o0_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Co003oooooool00?oo003o0_ooool01?l00?oooooo
ooooool00?l2ooooo`03o`00oooooooooooo00Cooooo0_l00?l00ooooooo003oo`00o`02ooooo`03
o`00oooooooooooo00?ooooo00?o0000ooooooooool03_ooool001gooooo0_l0001Hooooo`04ool0
0?ooooooooooo`00o`Wooooo00?o0000ooooooooool01oooool01Ol00?ooooooooooooooooooo`00
05Sooooo0_l0000Zooooo`;o00001Oooool00ol00?ooooooooooo`02o`00o`03ooooool00?oo003o
00?ooooo00Go003oooooool00?oo003oooooo`02o`00o`Gooooo00?o003oooooooooool00_l00?l3
ooooo`05o`00ooooooooooooo`00ooooool00_l00?l00ooooooo003oool00008ool00009o`00oooo
ooooo`00o`00ooooooooo`00ooooool00?ooo`0000;o003o00Goooooool00?l00?ooooooool00002
ooooo`08ool00?l00?oo003ooooooooo003o003ooooooooo0002ooooo`08ool00?l00?oo003ooooo
oooo003o003ooooooooo000:ooooo`;o003o00So0000ooooool00?ooo`00ooooool00?ooooooool0
00;ooooo00?oo`00o`00ooooool0:_ooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooo
oooo00;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o0_ooool01_l00?oooooooooo
oooooooo003oooooo`;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o0_ooool00ol0
0?ooooooooooo`02ooooo`;o00004?ooool001gooooo00?o0000ooooooooool0Eoooool01?oo003o
ooooooooool00?l9ooooo`03o`000?oooooooooo00_ooooo00?oo`00ooooooooool0Eoooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool00_l00?l00ooo
oooo003oo`00o`05ooooo`;o003o00Soooooo`00ool00?ooooooo`00oooooooo003oooooo`;o003o
00?oooooo`00ooooool00oooool00ol00?ooooooo`00o`03ooooo`06o`00oooooooo003oooooool0
0?oooooo1_oo00002Oooooooo`00ool00?oo003oooooool00?oooooo003oool00002o`00o`09oooo
oooo003o003ooooooooo003oooooo`00oooo003o003o00;ooooo00Ooo`00o`00ooooooooo`00oooo
ool00?ooo`0000;o003o00Goooooool00?l00?ooooooool0000:ooooo`03o`00oooooooo000000;o
oooo00Woo`00o`00ooooooooooooool00?l00?ooooooool00?l00?l0:oooool01?l00?oooooooooo
ool00?l2ooooo`05o`00ooooooooooooooooool00?l00_ooool01?l00?ooooooooooool00?l6oooo
o`03o`00oooooooooooo00;o003o0_ooool01?l00?ooooooooooool00?l3ooooo`04o`00oooooooo
003oo`00o`;ooooo00?o003oooooooooool00oooool00ol0003oooooooooo`0>ooooo`003_ooool5
o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo05Oooooo00Coo`00oooooooooooo003o2Ooo
ool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo05Oooooo00?o0000ooooooooool08?oo
ool3o`0000Gooooo00?o0000ooooooooool02?ooool01Ol00?ooooooo`00ool00?oooooo00;o003o
1Oooool2o`00o`05ooooool00?ooooooo`00ooooool00_l00?l01Ooooooo003oo`00oooooooo003o
00?ooooo0_l00?l00ooooooo003oooooo`05ooooo`;o003o00Goooooool00?oo003oo`00o`00o`06
ool00003o`00oooo003ooooo00;ooooo00_oo`00o`00ooooooooo`00ooooool00?ooo`00ooooool0
0?ooooooool00002ooooo`04ool00?oooooo003oool000?ooooo00Goo`00o`00ooooooooo`00o`00
o`09ooooo`06o`00oooooooo0000ooooool00?ooo`000_l00?l01Oooooooo`00o`00ooooooooo`00
02oooooo00Co003ooooooooooooo003o0_ooool2o`00o`;ooooo00Co003ooooooooooooo003o0_oo
ool2o`00o`Gooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooooooo00;o003o1Ooo
ool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00kooooo000?ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Gooooo`03ool0
0?oooooooooo00[ooooo00?o0000ooooooooool01oooool01Ol00?ooooooooooooooooooo`0005Wo
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o003oooooooooool01?ooool01?l00?ooooooo`00ool00?l2ooooo`;o003o1?ooool2o`00
o`?ooooo00Wo003oooooool00?oo003oooooool00?ooooooo`00ooooool00_l00?l02Ooooooo003o
o`00oooooooo003oooooool00?ooooooo`00o`03ooooo`03o`00oooooooo003o00Woo`0000Wo003o
oooooooo003o003ooooooooo003oooooo`00oooo00000_l00?l02?ooooooo`00o`00ooooooooo`00
ooooool00?ooo`000_l00?l01_ooooooo`00o`00ooooooooo`00o`00o`_ooooo00co0000ooooool0
0?ooo`00ooooool00?ooooooool00?l00?ooooooool00?l00?ldooooo`05o`00oooooooooooooooo
ool00?l00_ooool00ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooooooooooo003o0_ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;o003o0_ooool00ol00?ooooooooooo`03
ooooo`03o`000?oooooooooo00kooooo000@ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001?ooool2o`0005Sooooo00Coo`00oooooooooooo003o2Oooool00ol0003ooooooooo
o`07ooooo`05o`00oooooooooooooooooooo0000F?ooool2o`0002?ooooo00?o0000ooooooooool0
1?ooool2o`0000Gooooo00?o003oooooooooool00_l00?l4ooooo`;o003o0_ooool2o`00o`05oooo
ool00?oo003oooooool00?l00oooool02Ol00?oooooooooooooooooo003oooooool00?ooooooo`00
o`02ooooo`08o`00oooooooo003oo`00oooooooo003oooooool00?l2ooooo`07o`00oooooooo003o
o`00oooooooo003oooooo`02o`00o`Koo`0000Ko003oool00?oo003oo`00oooooooo0002ooooo`08
ool00?l00?oo003ooooooooo003o003ooooooooo0002ooooo`05ool00?l00?oo003ooooooooo0000
0_ooool00ooo003oooooooooo`0:ooooo`03o`000?ooooooo`0000;oo`0000?o003ooooooooo0000
0_ooool00ooo003o003oooooo`0cooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oo
ooooooooo`02o`00o`;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`;ooooo00Co003ooooo
oooooooo003o0_ooool2o`00o`;ooooo00?o003oooooooooool00_ooool2o`00013ooooo000Aoooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo05Kooooo0ooo00000ooooooo003oooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o003o
oooooooo00000_oo001Hooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`00oooooooooooo00;o003o00?oooooo`00ool00?l01Oooool2
o`00o`03ooooool00?oo003o00;ooooo00?o003oooooooooool00_l00?l00ooooooo003oooooo`02
ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003oooooool00?oo003o0_ooool2o`00o`03oooo
ool00?oo003o00?ooooo0_l00?l00ooooooo003oooooo`03ool00009o`00oooo003oo`00ool00?oo
ooooo`00ooooool00?ooo`0000?ooooo00Ooo`00o`00ooooooooo`00ooooool00?ooo`0000;o003o
00Goooooool00?l00?ooooooool0000<ooooo`03o`000?ooooooo`0000;oo`000_ooool01?oo003o
003ooooooooo000iooooo`04o`00ooooooooooooo`00o`Kooooo00Co003ooooooooooooo003o0ooo
ool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooooooo00;o003o0_ooool00ol00?oooooo
ooooo`03ooooo`03o`000?oooooooooo00kooooo000>ooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo05Kooooo0ooo00000ooooooo
003oooooo`08ooooo`03o`000?oooooooooo00[ooooo0ooo001Hooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00;o
003o00?oooooo`00ool00?l01Oooool2o`00o`03ooooool00?oo003o00;ooooo0_l00?l01Ooooooo
003oo`00oooooooo003o00?ooooo0_l00?l00ooooooo003oooooo`02ooooo`03o`00oooooooooooo
00;o003o00Ooooooo`00ooooooooooooo`00oooooooo003o00;ooooo00Co003oooooool00?oo003o
0_ooool6ool00006o`00oooo003oooooo`00ooooooooo`000_ooool01?oo003oooooo`00oooo0003
ooooo`04ool00?l00?ooooooool000cooooo00?o0000oooooooo00000_oo00001_l00?ooooooool0
0?l00?ooooooool003cooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool00?l2
ooooo`;o003o0_ooool01?l00?ooooooooooool00?l6ooooo`03o`00oooooooooooo00?ooooo00?o
0000ooooooooool03_ooool000kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0E_ooool3ool000_ooooo00?o0000ooooooooool0
2?ooool00ol00?ooooooool00002ool005Sooooo00?o0000ooooooooool08?ooool2o`0000Kooooo
00?o0000ooooooooool01?ooool00ol00?ooooooooooo`03ooooo`;o003o00?oooooo`00ool00?l0
0_ooool2o`00o`Cooooo0_l00?l3ooooo`05o`00oooooooo003oo`00ooooool00_l00?l2ooooo`;o
003o00Goooooo`00ool00?ooooooo`00o`03ooooo`07o`00ooooooooooooooooool00?ooooooo`00
o`02ooooo`03o`00oooooooo003o00Kooooo0_l00?l6ool00003o`00ooooooooo`0000;ooooo00_o
o`00ooooool00?ooo`00ooooool00?ooooooool00?l00?ooooooool0000<ooooo`0;o`000?oooooo
003oo`00oooooooo003ooooooooo003o003ooooooooo0000?oooool01Ol00?oooooooooooooooooo
003o00;ooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool00?l2ooooo`;o003o
0_ooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00kooooo000?ooooo`?o00001?oo
ool2o`0000Gooooo0_l0001Hooooo`04o`00ooooooooooooo`00o`Wooooo00?o0000ooooooooool0
2?ooool01?l00?ooooooooooool00?mHooooo`;o00008oooool00ol0003oooooooooo`04ooooo`;o
00001Oooool01?l00?ooooooooooool00?l5ooooo`;o003o0_ooool2o`00o`05ooooool00?oo003o
ooooool00?l00oooool01_l00?oooooooooooooooooo003oooooo`;o003o0oooool01Ol00?oooooo
o`00ool00?oooooo00;o003o0oooool01Ol00?ooooooooooool00?oooooo00;o003o00?oooooo`00
ooooool00_ooool2o`00o`03ooooool00?oooooo00;ooooo1_oo00001_l00?ooo`00ool00?oo003o
ooooool000;ooooo00Goo`00ooooool00?ooooooool00002ooooo`03ool00?oooooooooo00[ooooo
00?o0000ooooool00?l00_ooool00ol00?ooooooool00002ooooo`03ool00?oooooooooo047ooooo
00Co003ooooooooooooo003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003ooooo
ooooool00_l00?l2ooooo`03o`00oooooooooooo00;ooooo0_l0000@ooooo`007Oooool00ol0003o
ooooooooo`1Jooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol00?oo
ooooo`00o`1Jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01?ooool01?l00?oo
ooooooooool00?l2ooooo`;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o0_ooool0
0ol00?ooooooooooo`02o`00o`03ooooool00?oooooo00;ooooo00Co003ooooooooooooo003o0ooo
ool01?l00?ooooooo`00ool00?l2ooooo`;o003o00?oooooo`00ool00?l00_ooool01_l00?oooooo
o`00oooooooo003oooooo`;o003o00Goooooo`00ool00?ooooooo`00o`03ooooo`?oo`0000?ooooo
ool00?oo00001?oo00002Ol00?ooo`00ooooool00?ooooooool00?l00?ooooooool0000<ooooo`03
o`000?oooooooooo00Cooooo00Coo`00o`00ooooooooo`00A_ooool01?l00?ooooooooooool00?l3
ooooo`03o`00oooooooooooo00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`000?oo
oooooooo00kooooo000Mooooo`03o`000?oooooooooo05Oooooo00Co003ooooooooooooo003o2Ooo
ool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01ooo
ool00ol00?ooooooooooo`02o`00o`03ooooool00?oooooo00Gooooo0_l00?l00ooooooo003oo`00
o`02ooooo`;o003o00Goooooo`00ool00?ooooooo`00o`03ooooo`;o003o1Oooool00ol00?oooooo
ooooo`02o`00o`04ooooool00?ooooooooooo`;o003o0oooool01Ol00?ooooooo`00ool00?oooooo
00;o003o00Goooooo`00oooooooo003oooooo`02o`00o`03ooooool00?ooo`0000Goo`0000?o003o
ool00?ooool00_ooool01?oo003o003ooooooooo000<ooooo`0;o`000?oooooo003oo`00oooooooo
003ooooooooo003o003ooooooooo0000A_ooool01?l00?ooooooooooool00?l3ooooo`04o`00oooo
ooooooooo`00o`Kooooo00?o003oooooooooool00oooool00ol0003oooooooooo`0>ooooo`007Ooo
ool00ol0003oooooooooo`1Gooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool02?oo
ool00ol00?ooooooo`00o`1Jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01?oo
ool00ol00?ooooooooooo`03ooooo`;o003o00?oooooo`00ool00?l00_ooool01?l00?oooooooooo
ool00?l2ooooo`;o003o0_ooool00ol00?ooooooooooo`02o`00o`03ooooool00?oo003o00;ooooo
0_l00?l00ooooooo003oo`00o`05ooooo`03o`00oooooooooooo00;o003o00Woooooo`00oooooooo
ooooo`00oooooooo003oooooool00?l00oooool01ol00?ooooooo`00oooooooo003oooooool00?l0
0_ooool2o`00o`;ooooo1_oo00001_l00?ooooooool00?l00?ooooooool000cooooo00Ko0000oooo
ool00?oo003oooooool00?l3ool00003oooooooo003ooooo04Sooooo00Go003ooooooooooooooooo
o`00o`02ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool00oooool00ol0003o
ooooooooo`0>ooooo`007Oooool2o`0005Sooooo00Co003ooooooooooooo003o2Oooool00ol0003o
ooooooooo`08ooooo`03o`00oooooooo003o05Wooooo0_l0000Zooooo`;o00001Oooool01?l00?oo
ooooooooool00?l5ooooo`;o003o0_ooool01ol00?oooooooooooooooooo003oooooool00?l00ooo
ool01_l00?oooooooooooooooooo003oooooo`;o003o0_ooool00ol00?ooooooooooo`02o`00o`03
ooooool00?oo003o00Kooooo00Ko003oooooool00?oo003oooooool00?l4ooooo`03o`00oooooooo
003o00Cooooo00Ko003ooooooooooooo003oooooool00?l2ooooo`04o`00oooooooo003oooooo`?o
o`0000Ko003oool00?oo003oo`00oooooooo000<ooooo`06o`000?oooooo003oo`00oooooooo003o
0ooo00000oooooooo`00ooooo`1?ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003ooooooooo
ool00_ooool2o`00013ooooo000Mooooo`03o`000?oooooooooo05[ooooo00?o003oooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`00oooooooo003o05[ooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`04ooooo`04o`00ooooooooooooo`00o`;ooooo00Go003ooooooooo
ooooooooo`00o`02ooooo`03o`00oooooooooooo00;o003o0_ooool01?l00?ooooooooooool00?l2
ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`02o`00o`03ooooool0
0?oo003o00;ooooo00?o003oooooooooool00_l00?l2ooooo`06o`00oooooooo003oooooool00?oo
oooo0_l00?l02?oooooo003oo`00oooooooo003oooooool00?oooooo0_l00?l4ooooo`04o`00oooo
oooo003oooooo`?oo`0000Ko003oool00?oo003oo`00oooooooo000<ooooo`03o`000?oooooooooo
00?ooooo0ooo00000oooooooo`00ooooo`1Booooo`05o`00ooooooooooooooooool00?l01Oooool0
0ol0003oooooooooo`0>ooooo`007Oooool00ol0003oooooooooo`1Gooooo`04o`00oooooooooooo
o`00o`Wooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00Cooooo00Co003ooooooooooooo003o0_ooool01?l00?ooooooooooool00?l3ooooo`04o`00
ooooooooooooo`00o`;ooooo0_l00?l2ooooo`03o`00oooooooooooo00;o003o00?oooooo`00oooo
ool00_ooool00ol00?ooooooooooo`03ooooo`;o003o0_ooool01?l00?ooooooooooool00?l3oooo
o`06o`00ooooooooooooooooool00?oooooo0_l00?l01Ooooooo003oo`00oooooooo003o00?ooooo
0_l00?l01Ooooooo003oo`00oooooooo003o00?ooooo00Co003ooooooooooooooooo1_oo000;oooo
o`06o`000?oooooo003oo`00oooooooo003o0_ooool01?l00?ooo`00ool00?oo001Fooooo`03o`00
oooooooooooo00?ooooo00?o0000ooooooooool03_ooool001gooooo00?o0000ooooooooool0Eooo
ool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o003oooooool00?l0F_oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`;ooooo
00?o003oooooooooool00_l00?l00ooooooo003oo`00o`02ooooo`03o`00oooooooooooo00;o003o
1Oooool00ol00?ooooooooooo`02o`00o`04ooooool00?ooooooooooo`;o003o0_ooool02ol00?oo
oooooooooooooooo003oooooool00?ooooooo`00oooooooo003o00;ooooo0_l00?l3ooooo`03o`00
oooooooo003o00;ooooo00Co003ooooooooooooo003o0ooo000;ooooo`05o`000?oooooo003oo`00
ooooool00_l00?l00ooooooo003oool00002ool005Kooooo00?o003oooooooooool00oooool00ol0
003oooooooooo`0>ooooo`007Oooool2o`0005Wooooo00?o003oooooool00?l02Oooool00ol0003o
ooooooooo`08ooooo`03o`00oooooooo003o05Wooooo0_l0000Zooooo`;o00001Oooool01?l00?oo
ooooooooool00?l5ooooo`;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`05o`00oooooooo
ooooooooool00?l00_ooool00ol00?ooooooooooo`02o`00o`;ooooo00?o003oooooooooool00_l0
0?l00ooooooo003oo`00o`06ooooo`06o`00oooooooo003oo`00oooooooo003o1?ooool00ol00?oo
ooooo`00o`04ooooo`05o`00ooooooooooooo`00ooooool00_l00?l01?oooooo003oooooool00?l2
ooooo`04o`00oooooooo003oo`00o`;ooooo0ooo000;ooooo`05o`000?oooooo003oo`00ooooool0
0_l00?l00ooooooo003oool00002ool005_ooooo0_l0000@ooooo`007Oooool00ol0003ooooooooo
o`1Jooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol00?ooooooo`00
o`1Jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01oooool01?l00?oooooooooo
ool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00Go003oooooooooooooooooo`00o`02oooo
o`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o0_ooool2o`00o`03ooooool0
0?oo003o00;ooooo00?o003oooooooooool00_l00?l01?oooooo003oo`00ooooool2o`00o`;ooooo
0_l00?l01?oooooo003oo`00ooooool2o`00o`?ooooo00?o003oooooool00?l00_ooool01?l00?oo
ooooo`00ooooool2o`00o`05ooooool00?oo003oooooool00?l03_ooool00ol0003oooooooooo`02
ooooo`;o003o0oooool00ol00?ooooooooooo`1Kooooo`03o`000?oooooooooo00kooooo000Moooo
o`03o`000?oooooooooo05Sooooo00?o003oooooool00?l02Oooool00ol0003oooooooooo`1Uoooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02_ooool01Ol00?oooooooooooooooooo
003o00;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`;ooooo00Co003ooooooooooooo003o
0_ooool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l2ooooo`04o`00ooooooooooooo`00
o`?ooooo00Co003ooooooooooooo003o0_ooool2o`00o`05ooooool00?oo003oooooool00?l00ooo
ool2o`00o`;ooooo00?o003oooooool00?l00oooool2o`00o`;ooooo00Go003oooooool00?oooooo
o`00o`0<ooooo`04o`000?oooooo003oo`00o`Cooooo00?o003oooooool00?l0GOooool00ol0003o
ooooooooo`0>ooooo`007Oooool00ol0003oooooooooo`1Hooooo`03o`00oooooooooooo00Wooooo
00?o0000ooooooooool02?ooool00ol00?ooooooo`00o`1Jooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool03_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;o003o
0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o0_ooool01?l00?ooooooooooool00?l6oooo
o`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool00_l00?l2ooooo`06o`00oooooooo
ooooooooool00?oooooo0_l00?l2ooooo`03o`00oooooooooooo00;o003o0_ooool01?l00?oooooo
ooooool00?l2ooooo`06o`00ooooooooooooo`00oooooooo003o3?ooool01Ol0003oooooo`00ool0
0?oooooo00Co003oGoooool00ol0003oooooooooo`0>ooooo`007Oooool2o`0005Wooooo00?o003o
ooooool00?l02Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooo003o05Wooooo0_l0000Z
ooooo`03o`000?oooooooooo00kooooo00Co003ooooooooooooo003o1Oooool01Ol00?oooooooooo
oooooooo003o00;ooooo00?o003oooooooooool00_l00?l2ooooo`04o`00ooooooooooooo`00o`;o
oooo0_l00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l00ooooooo003oooooo`03oooo
o`03o`00oooooooo003o00?ooooo00?o003oooooooooool00_l00?l01?oooooo003oo`00ooooool2
o`00o`?ooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooo
003o00;ooooo0_l00?l01?oooooo003oooooool00?mMooooo`03o`000?oooooooooo00kooooo000M
ooooo`03o`000?oooooooooo05[ooooo00?o003oooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`00oooooooo003o05[ooooo00?o0000ooooooooool0:?ooool2o`0001;ooooo00Co003o
oooooooooooo003o1_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool00_l00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l00ooooooo
003oo`00o`02ooooo`;o003o00Coooooo`00ool00?oooooo0_l00?l3ooooo`03o`00oooooooo003o
00;ooooo0_l00?l2ooooo`;o003o00Goooooo`00ool00?ooooooo`00o`0>ooooo`03o`000?oooooo
oooo00;ooooo0_l00?l3ooooo`03o`00oooooooooooo05[ooooo0_l0000@ooooo`003_ooool5o`00
00;ooooo0ol00005ooooo`03o`000?oooooooooo05Sooooo00?o003oooooool00?l02Oooool00ol0
003oooooooooo`0:ooooo`03o`00oooooooooooo05Sooooo00?o0000ooooooooool07oooool5o`00
00Cooooo00?o0000ooooooooool05?ooool01?l00?ooooooooooool00?l3ooooo`04o`00oooooooo
ooooo`00o`;ooooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o0_ooool01?l00?oooooo
ooooool00?l3ooooo`04o`00oooooooo003oo`00o`;ooooo00?o003oooooooooool00_l00?l00ooo
oooo003oooooo`02ooooo`;o003o0_ooool00ol00?ooooooo`00o`03ooooo`;o003o0_ooool01?l0
0?ooooooo`00ool00?l=ooooo`03o`000?oooooo003o00Gooooo00?o003oooooool00?l0GOooool0
0ol0003oooooooooo`0>ooooo`003oooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1Hooooo`03o`00oooooooooooo00Wooooo00?o
0000ooooooooool02?ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo023ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0Gooooo`05o`00ooooooooooooooooool0
0?l00_ooool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`Kooooo00Co003o
oooooooooooo003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Ko003ooooooooooooo
ooooo`00ooooool2o`00o`;ooooo00?o003oooooooooool00_l00?l2ooooo`04o`00oooooooooooo
o`00o`;ooooo0_l00?l00ooooooo003oo`00o`0=ooooo`03o`000?oooooo003o00;ooooo0_l00?l0
0ooooooo003oooooo`1Nooooo`03o`000?oooooooooo00kooooo000@ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool2o`0005Wooooo00?o003oooooool00?l02Oooool00ol0
003oooooooooo`08ooooo`03o`00oooooooo003o05Wooooo0_l0000Sooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool07_ooool01?l00?ooooooooooool00?l3ooooo`04o`00oooooooo
ooooo`00o`;ooooo0_l00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l00ooooooo003o
ooooo`02ooooo`03o`00oooooooooooo00;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`;o
003o00?oooooo`00ool00?l00_ooool2o`00o`03ooooool00?oooooo00;ooooo00?o003ooooooooo
ool02oooool00ol0003oooooo`00o`02ooooo`;o003o00?oooooo`00ool00?l0G_ooool00ol0003o
ooooooooo`0>ooooo`004Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0F_ooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o003oooooool00?l0F_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo
0_l0000Oooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o0_ooool2o`00
o`;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`03ooooool00?oo003o00;ooooo00Co003o
oooooooooooo003o0_ooool2o`00o`;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`?ooooo
00Ko003oooooool00?oo003oooooool00?l>ooooo`03o`000?oooooo003o00;ooooo0_l00?l2oooo
o`03o`00oooooooooooo05_ooooo0_l0000@ooooo`003_ooool01_l0003ooooooooooooooooo0000
ooooo`Co00001Oooool00ol0003oooooooooo`1Hooooo`03o`00oooooooo003o00Wooooo00?o0000
ooooooooool02_ooool00ol00?ooooooooooo`1Hooooo`03o`000?oooooooooo01oooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo02Gooooo00?o003oooooooooool00ooo
ool01Ol00?oooooooooooooooooo003o00;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`;o
oooo00?o003oooooooooool00_l00?l00ooooooo003oooooo`02ooooo`07o`00oooooooooooooooo
ool00?ooooooo`00o`03ooooo`03o`00oooooooooooo00;o003o00?oooooo`00ool00?l03Oooool0
0ol0003oooooo`00o`05ooooo`;o003oG_ooool00ol0003oooooooooo`0>ooooo`003_ooool01ol0
003ooooooooooooooooo0000ooooool000002?ooool00ol0003oooooooooo`1Hooooo`03o`00oooo
oooooooo00Wooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`1Jooooo`03o`000?oo
oooooooo01oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo02Gooooo
00Co003ooooooooooooo003o1_ooool01?l00?ooooooooooool00?l2ooooo`05o`00oooooooooooo
ooooool00?l00_ooool01_l00?oooooooooooooooooo003oooooo`;o003o0_ooool00ol00?oooooo
ooooo`02o`00o`;ooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooo`00ool00?l=oooo
o`03o`000?oooooo003o00;ooooo0_l00?l00ooooooo003oooooo`1Nooooo`03o`000?oooooooooo
00kooooo000?ooooo`?o00000_ooool5o`0000Cooooo00?o0000ooooooooool0F?ooool00ol00?oo
ooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o003oooooool00?l0F_ooool00ol0003o
ooooooooo`0Pooooo`?o00001Oooool00ol0003oooooooooo`0Xooooo`04o`00ooooooooooooo`00
o`?ooooo00Co003ooooooooooooo003o0_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooo
oooooooo00;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o00?oooooo`00ool00?l0
0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o3Oooool00ol0003oooooo`00o`02ooooo`;o
003o00?oooooo`00ool00?l0G_ooool00ol0003oooooooooo`0>ooooo`007Oooool2o`0005_ooooo
00?o003oooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`00oooooooo003o05Wooooo
0_l0000Zooooo`;o0000;?ooool01Ol00?oooooooooooooooooo003o00;ooooo00Co003ooooooooo
oooo003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00
o`02ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l2ooooo`03o`00oooooooooooo00;o003o
0_ooool00ol00?ooooooooooo`0;ooooo`03o`000?oooooo003o00;ooooo0_l00?l2ooooo`03o`00
oooooooooooo05_ooooo0_l0000@ooooo`007Oooool00ol0003oooooooooo`1Hooooo`03o`00oooo
oooo003o00Wooooo00?o0000ooooooooool02_ooool00ol00?ooooooooooo`1Hooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0;oooool01?l00?ooooooooooool00?l2ooooo`03o`00
oooooooooooo00;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`05o`00oooooooooooooooo
ool00?l00_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00;o003o00?ooooo
o`00ooooool03Oooool00ol0003oooooooooo`05ooooo`;o003oG_ooool00ol0003oooooooooo`0>
ooooo`007Oooool00ol0003oooooooooo`1Hooooo`03o`00oooooooo003o00Wooooo00?o0000oooo
ooooool0IOooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02oooooo00Co003ooooo
oooooooo003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Co003ooooooooooooo003o
0_ooool2o`00o`;ooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool00?l3oooo
o`04o`00oooooooo003oo`00o`gooooo00?o0000ooooooooool00_ooool2o`00o`03ooooool00?oo
oooo05kooooo00?o0000ooooooooool03_ooool001gooooo00?o0000ooooooooool0F?ooool00ol0
0?ooooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o003oooooool00?l0F_ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo03Gooooo00?o003oooooooooool00_l00?l2oooo
o`04o`00ooooooooooooo`00o`;ooooo0_l00?l2ooooo`04o`00ooooooooooooo`00o`?ooooo00Co
003ooooooooooooo003o0_ooool00ol00?ooooooooooo`02o`00o`gooooo00?o0000ooooooooool0
0_ooool2o`00o`03ooooool00?oo003o05kooooo00?o0000ooooooooool03_ooool001gooooo0_l0
001Kooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol00?ooooooo`00
o`1Iooooo`;o0000:_ooool2o`0003Kooooo00Co003ooooooooooooo003o0oooool01?l00?oooooo
ooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool00_l00?l2oooo
o`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool02oooool00ol0003oooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l0GOooool2o`00013ooooo000Mooooo`03o`000?oooooo
oooo05Sooooo00?o003oooooool00?l02Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooo
003o05[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0hooooo`05o`00oooooooo
ooooooooool00?l00_ooool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`;o
oooo00Go003oooooooooooooooooo`00o`02ooooo`04o`00ooooooooooooo`00o`kooooo00?o0000
ooooooooool01Oooool2o`00oekooooo00?o0000ooooooooool03_ooool001gooooo00?o0000oooo
ooooool0F?ooool00ol00?ooooooo`00o`09ooooo`03o`000?oooooooooo06Gooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0looooo`04o`00ooooooooooooo`00o`;ooooo00Go003o
ooooooooooooooooo`00o`02ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo
003o0_ooool2o`00o`gooooo00?o0000ooooooooool00_ooool01?l00?ooooooooooool00?mOoooo
o`03o`000?oooooooooo00kooooo000Mooooo`03o`000?oooooooooo05Sooooo00?o003ooooooooo
ool02Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooo003o05[ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0oooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooo
oooooooo003o0oooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooooooo00;o003o3Ooo
ool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00;o003oG_ooool00ol0003ooooooooo
o`0>ooooo`007Oooool2o`0005Wooooo0_l00?l:ooooo`03o`000?oooooooooo00Sooooo00?o003o
ooooool00?l0FOooool2o`0002[ooooo0_l00013ooooo`05o`00ooooooooooooooooool00?l00_oo
ool00ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooooooooooo003o0oooool00ol00?oooooo
ooooo`0;ooooo`03o`000?oooooooooo00;ooooo00Go003oooooooooooooooooo`00o`1Mooooo`;o
00004?ooool001gooooo00?o0000ooooooooool0FOooool00ol00?ooooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o003oooooool00?l0F_ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo04Kooooo00Co003ooooooooooooo003o0_ooool01Ol00?oooooooooooooooooo003o
00;ooooo00Co003ooooooooooooo003o3_ooool00ol0003oooooooooo`02ooooo`03o`00oooooooo
oooo00;o003oG_ooool00ol0003oooooooooo`0>ooooo`007Oooool00ol0003oooooooooo`1Hoooo
o`;o003o2_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0A_ooool01?l00?ooooooooooool00?l2ooooo`05o`00ooooooooooooooooool00?l00_oo
ool00ol00?ooooooooooo`02o`00o`gooooo00?o0000ooooooooool00_ooool01?l00?oooooooooo
ool00?mOooooo`03o`000?oooooooooo00kooooo000Mooooo`03o`000?oooooooooo05Sooooo00?o
003oooooooooool02Oooool00ol0003oooooooooo`09ooooo`;o003oF_ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo04Wooooo00Co003ooooooooooooo003o0oooool01?l00?oooooo
ooooool00?l2ooooo`;o003o3Oooool00ol0003oooooooooo`02ooooo`04o`00ooooooooooooo`00
oeoooooo00?o0000ooooooooool03_ooool001gooooo0_l0001Iooooo`;o003o2_ooool00ol0003o
ooooooooo`09ooooo`;o003oFOooool2o`0002[ooooo0_l0001=ooooo`05o`00oooooooooooooooo
ool00?l00_ooool01?l00?ooooooooooool00?l>ooooo`03o`000?oooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`1Mooooo`;o00004?ooool000oooooo0ol00004ooooo`;o00001Oooool0
0ol0003oooooooooo`1Iooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02Oooool0
0ol00?ooooooooooo`1Iooooo`03o`000?oooooooooo023ooooo0ol00005ooooo`03o`000?oooooo
oooo053ooooo00Co003ooooooooooooo003o0_ooool00ol00?ooooooooooo`0<ooooo`03o`000?oo
oooooooo00Kooooo00?o003oooooooooool0G?ooool00ol0003oooooooooo`0>ooooo`003_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`1Hooooo`;o003o2_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01oooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo05?ooooo00Co003ooooooooo
oooo003o3_ooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo05gooooo00?o0000oooo
ooooool03_ooool001;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo05Wooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`09oooo
o`03o`00oooooooooooo05Wooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo05Kooooo00?o003oooooooooool03?ooool00ol0003oooooooooo`05oooo
o`03o`00oooooooooooo05gooooo00?o0000ooooooooool03_ooool0013ooooo0_l00003ooooo`04
o`000?ooooooooooo`0000Cooooo0_l0001Jooooo`03o`00oooooooooooo00Sooooo00?o0000oooo
ooooool02Oooool00ol00?ooooooooooo`1Hooooo`;o00008oooool2o`0000Gooooo0_l0001Goooo
o`03o`00oooooooooooo00cooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`1Loooo
o`;o00004?ooool001;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Uoooo
o`03o`000?oooooooooo00kooooo000>ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool000oooooo0ol00004
ooooo`;o00001Oooooo@o`0002;ooooo0ol00005ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool03_ooool00?oooooo6?oooooAo`00013ooooo003oooooooWooooo003oooooooWooooo
003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo
003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo
003oooooooWooooo003oooooooWooooo000Nooooo`;o00007?ooool3o`0000Cooooo0_l0000Hoooo
o`Go00000oooool2o`0001Sooooo0ol00004ooooo`;o00006_ooool3o`0000?ooooo0_l0000Ioooo
o`?o00001?ooool2o`0001Wooooo0ol00004ooooo`;o0000;?ooool2o`0001_ooooo0ol00004oooo
o`;o00006?ooool5o`0000?ooooo0_l0000Hooooo`?o00001?ooool2o`0001Wooooo0ol00003oooo
o`;o00006Oooool3o`0000Cooooo0_l0000Hooooo`?o00001?ooool2o`00017ooooo000Mooooo`04
o`000?ooooooooooo`0001cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000H
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00005_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00006_ooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool05Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00005oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo0000:_ooool01?l0003oooooooooool0000Kooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00006?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Ko
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001Wooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo01Gooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0001Kooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`00013ooooo000Mooooo`04o`000?ooooooooooo`0001cooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000Iooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00006_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo01Go
oooo1Ol00002ooooo`04o`000?ooooooooooo`0001_ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool0000Zooooo`04o`000?ooooooooooo`0001_ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000Iooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00006_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo01Cooooo1Ol00002ooooo`04o`000?oo
ooooooooo`0001_ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Dooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000@ooooo`007Oooool01?l0
003oooooooooool0000Looooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00006_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool05_ooool2o`0000?ooooo
00Co0000oooooooooooo00005oooool01?l0003oooooooooool00003ooooo`04o`000?oooooooooo
o`0001_ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Eooooo`Co00000ooo
ool01?l0003oooooooooool0000Zooooo`04o`000?ooooooooooo`0001_ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool0000Jooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`0Fooooo`;o00000oooool01?l0003oooooooooool0000Fooooo`04o`000?oo
ooooooooo`0000?ooooo00Co0000oooooooooooo00006oooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo01Cooooo1?l00003ooooo`04o`000?ooooooooooo`00013ooooo000Moooo
o`04o`000?ooooooooooo`0001cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
000Gooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Jooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool05_ooool00ol0003oooooo`000003oooo
o`04o`000?ooooooooooo`0001Oooooo1?l00003ooooo`04o`000?ooooooooooo`0001Oooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooool0000Zooooo`04o`000?ooooooooooo`0001_o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Gooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool0000Jooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool05Oooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0001Oo
oooo1?l00003ooooo`04o`000?ooooooooooo`0001Kooooo00?o0000ooooooooool01?ooool01?l0
003oooooooooool0000@ooooo`007Oooool01?l0003oooooooooool0000Kooooo`;o00001?ooool0
1?l0003oooooooooool0000Gooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool0000Fooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000I
ooooo`;o00000oooool01?l0003oooooooooool0000Gooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooo00006?ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0002[o
oooo00Co0000oooooooooooo00006_ooool2o`0000Cooooo00Co0000oooooooooooo00005oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00005_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00006?ooool2o`0000?ooooo00Co0000oooo
oooooooo00005oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0001Oooooo00?o
0000ooooooooool00oooool01?l0003oooooooooool0000@ooooo`007_ooool2o`0001gooooo00?o
0000ooooooooool00oooool2o`0001Wooooo0ol00004ooooo`;o00006?ooool3o`0000Cooooo0_l0
000Kooooo`03o`000?oooooooooo00;ooooo0_l0000Hooooo`Go00000oooool2o`0001[ooooo0_l0
0004ooooo`;o0000;?ooool2o`0001cooooo00?o0000ooooooooool00oooool2o`0001Wooooo0ol0
0004ooooo`;o00006?ooool3o`0000Cooooo0_l0000Jooooo`03o`000?oooooooooo00;ooooo0_l0
000Hooooo`Go00000oooool2o`0001Wooooo0_l00004ooooo`;o00004Oooool00?oooooonOooool0
0?oooooonOooool00?oooooonOooool00?oooooonOooool001[oooood_l0000Sooooo`?o00001?oo
ooo@o`0001;ooooo000Dooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`;o00008_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00
000Booooo`004oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo0<kooooo00?o
0000ooooooooool06_ooool5o`0000Gooooo00Go0000ooooooooooooooooo`00003>ooooo`03o`00
0?oooooooooo013ooooo000Cooooo`04o`000?ooooooooooo`0000?ooooo0ol00002ooooo`05ool0
0?oooooooooooooooooo00000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00oooo
ooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo0000
0_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000?ooooo00Coo`00oooo
ooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`00
0oooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooo
ooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`00
0_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Goo`00ooooooooooooooooool00002oooo
o`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003ooooooooo
ooooooooo`0000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool0
00?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Co
o`00ooooooooooooo`000oooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool0
00;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Co
o`00ooooooooooooo`000oooool2o`0002Cooooo0_l00004ooooo`;o0000boooool3o`0001;ooooo
000Cooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool01Ooo003ooooo
ooooooooooooo`0000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oooooooooo
ool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo
00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0003ooooo`04ool00?oooooooooo
ool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo
00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooo
oooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo
00Goo`00ooooooooooooooooool00002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo
003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooooooooooooooo
ool00002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003oooo
o`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oo
ooooooooool000?ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002oooo
o`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?oo
ooooooooool000Cooooo00?o0000ooooooooool09?ooool01Ol0003ooooooooooooooooo00000<ko
oooo00?o0000ooooooooool04?ooool001?ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`02ooooo`05ool00?oooooooooooooooooo00000_ooool01Ooo003ooooooooooooooooo
o`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`05ool0
0?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?oooooooooo
ool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo
00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0003ooooo`04ool00?oooooooooo
ool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo
00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Goo`00oooo
ooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`00
0_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Goo`00ooooooooooooooooool00002oooo
o`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003ooooooooo
ooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0003oooo
o`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oo
ooooooooool000?ooooo00Coo`00ooooooooooooo`001?ooool00ol0003oooooooooo`0Pooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo
013ooooo000Cooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool01Ooo
003oooooooooooooooooo`0000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oo
ooooooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`00
00;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0003ooooo`04ool00?oo
ooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool0
00?ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`05ool00?oo
oooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool0
00;ooooo00Goo`00ooooooooooooooooool00002ooooo`05ool00?oooooooooooooooooo00000_oo
ool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooooooo
ooooooooool00002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo
0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04
ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo
0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04
ool00?ooooooooooool000Cooooo00?o0000ooooooooool08Oooool3o`0000Cooooo00?o0000oooo
ooooool0c?ooool00ol0003oooooooooo`0@ooooo`005?ooool2o`0000Cooooo00?o0000oooooooo
ool00_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Goo`00ooooooooooooooooool00002
ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003ooooo
ooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0003
ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool0
0?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002
ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04ool0
0?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`05ool00?oooooooooo
oooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo
00Goo`00ooooooooooooooooool00002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo
003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooooooooooooooo
ool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000oooool01?oo
003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooo
oooo0003ooooo`04ool00?ooooooooooool000Cooooo00?o0000ooooooooool0:?ooool2o`000<co
oooo0_l0000Booooo`006_ooool01?l0003oooooooooooooool3ool000;ooooo00Coo`00oooooooo
ooooo`000oooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_oo
ool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooooooo
ooooooooool00002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo
0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`05
ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`Woo`0000?ooooo
ool00?oo00001ooo00000oooooooo`00ool00004ool00003oooooooo003oo`0000Ooo`000_ooool0
1?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01Ooo003ooooo
ooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002
ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04ool0
0?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003ooooooooooooooooo
o`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0004ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0@ooooo`006_oo
ool2o`0000;ooooo0ooo0002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00oooooooooooo
o`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool0
1?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01Ooo003ooooo
ooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01Ooo003ooooooooooooo003o
oooo00?oo`0000?oooooool00?oo00001ooo00000oooooooo`00ool00004ool00003oooooooo003o
o`0000Ooo`0000?oooooool00?oo00001ooo00000oooooooo`00ool00004ool00003oooooooo003o
o`0000Ooo`0000?oooooool00?oo00001ooo00000oooooooo`00ool00007ool000;ooooo00Coo`00
ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo
00000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000?ooooo00Coo`00
ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00oooooooooooo
o`000oooool01?oo003ooooooooooooo0003ooooo`;o0000:_ooool00ol0003oooooooooo`3<oooo
o`03o`000?oooooooooo013ooooo000Jooooo`04o`000?ooooooooooooooo`?oo`000_ooool01?oo
003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooooooooooooooo
ool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo
003oooooooooooooooooo`0000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oo
ooooooooool000;ooooo2Ooo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Coo`00
00?oooooool00?oo00001ooo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Coo`00
00?oooooool00?oo00001ooo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Ooo`00
00?oooooool00?oo00001?oo0002ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooooooo
ooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000ooo
ool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003o
oooooooooooo0003ooooo`04ool00?ooooooooooool000Cooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`3<ooooo`03o`000?oooooooooo013ooooo000Jooooo`03o`000?oooooooooo
00Kooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`05ool00?oo
oooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool0
00;ooooo00Goo`00ooooooooooooooooool00002ooooo`06ool00?oooooooooooooooooo003ooooo
1_oo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo0000
1?oo000Vooooo`Woo`0000?oooooool00?oo00001ooo00000oooooooo`00ool00004ool00003oooo
oooo003oo`0000Coo`0000?oooooool00?ooool00_ooool01?oo003ooooooooooooo0002ooooo`05
ool00?oooooooooooooooooo00000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00
ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo
00000_ooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo02Sooooo0_l0003<ooooo`;o
00004_ooool001[ooooo00?o0000ooooooooool01_ooool01?oo003ooooooooooooo0003ooooo`04
ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oooooo
ooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01_oo003oooooooooooooooooo`00oooo
o`?oo`0000?oooooool00?oo00001ooo00000oooooooo`00ool00004ool004kooooo1_oo00000ooo
ooooo`00ool00007ool00006oooooooo003oo`00ool00?ooooooo`000_ooool01Ooo003ooooooooo
ooooooooo`0000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool0
00?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00?o
o`00ooooooooool00_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0<cooooo00?o
0000ooooooooool04?ooool001[ooooo00?o0000ooooooooool01_ooool01?oo003ooooooooooooo
0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04
ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`06
ool00003oooooooo003oo`0000Ooo`00G?ooool9ool00003oooooooo003oo`0000Coo`0000?ooooo
ool00?ooool00_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo
00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00oooo
ooooooooo`001?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0<cooooo00?o0000
ooooooooool04?ooool001[ooooo00?o0000ooooooooool01Oooool3ool00003oooooooo003ooooo
00;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Co
o`00ooooooooooooo`000oooool01Ooo003ooooooooooooo003ooooo00?oo`0000?oooooool00?oo
00001?oo00001?ooooooo`00ool00?oo001Xooooo`?oo`0000?oooooool00?oo00001ooo0002oooo
o`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003ooooooooo
ooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool00ooo003oooooool00002ool000?o
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo013o
oooo000Jooooo`;o00001_ooool3ool00003oooooooo003ooooo00;ooooo00Coo`00oooooooooooo
o`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool0
1Ooo003ooooooooooooo003ooooo00?oo`0000Coooooool00?oo003oo`00M_ooool6ool000;ooooo
00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooo
oooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`03ool00?ooooooo`0000;oo`000_oo
ool2o`0002[ooooo0_l0003<ooooo`;o00004_ooool001[ooooo00?o0000ooooooooool01Oooool3
ool00003oooooooo003ooooo00;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003ooooooooo
ooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool00ooo003oooooool00005ool007go
oooo0ooo00001_ooooooo`00ool00?oo003oooooool000?ooooo00Coo`00ooooooooooooo`000_oo
ool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool00ooo003o
ooooool00002ool000?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`3<ooooo`03
o`000?oooooooooo013ooooo000Jooooo`03o`000?oooooooooo00Wooooo00Goo`00oooooooooooo
ooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_ooool0
1_oo003oooooooooooooooooo`00ooooo`?oo`00Q?ooool3ool00003oooooooo003ooooo00;ooooo
00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00oooo
ooooooooo`000oooool00ooo003oooooooooo`05ooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool0c?ooool00ol0003oooooooooo`0@ooooo`006_ooool00ol0003oooooooooo`09oooo
o`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?oo
ooooooooool000;ooooo00?oo`00ooooooooool01_oo0024ooooo`Koo`000_ooool01?oo003ooooo
oooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003
ooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`3<
ooooo`03o`000?oooooooooo013ooooo000Jooooo`03o`000?oooooooooo00Wooooo00Goo`00oooo
ooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`00
0_ooool00ooo003oooooooooo`03ool008[ooooo0ooo0002ooooo`04ool00?ooooooooooool000;o
oooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00?oo`00
ooooooooool01Oooool00ol0003oooooooooo`0Xooooo`;o0000c?ooool2o`0001;ooooo000Joooo
o`03o`000?oooooooooo00Wooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oooooo
ooooool000?ooooo00Goo`00ooooooooooooo`00ooooo`03ool00004oooooooo003oo`00ool008[o
oooo0ooo00001_ooooooo`00ool00?oo003oooooool000;ooooo00Goo`00ooooooooooooooooool0
0002ooooo`04ool00?ooooooooooool000?ooooo00?oo`00ooooooooool01Oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool04?ooool001[ooooo0_l0
000:ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`05
ool00?ooooooooooool00?ooool00ooo002Booooo`?oo`0000Goooooool00?ooooooooooool00003
ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00006ooooo`;o0000
8_ooool5o`0000?ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0@ooooo`006_oo
ool00ol0003oooooooooo`09ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooo
oooooooo0003ooooo`05ool00?ooooooooooool00?ooool00ooo002Booooo`?oo`0000Goooooool0
0?ooooooooooool00003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooooooooooooooo
ool00007ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`3<ooooo`03o`000?oooooooooo013ooooo000Jooooo`03o`000?oooooooooo00Wooooo
00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00oooo
ooooooooo`00V_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo
00Goo`00ooooooooooooooooool00007ooooo`03o`000?oooooooooo01[ooooo1Ol00003ooooo`03
o`000?oooooooooo00?ooooo0_l0003;ooooo`?o00004_ooool001[ooooo00?o0000ooooooooool0
2Oooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool00ooo
003oooooool00002ool009Sooooo0ooo00000oooooooo`00ooooo`02ooooo`04ool00?oooooooooo
ool000;ooooo00Goo`00ooooooooooooooooool00007ooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo013ooooo000J
ooooo`03o`000?oooooooooo00Wooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oo
ooooooooool000?ooooo00?oo`00oooooooo00000_oo002Hooooo`?oo`0000?oooooool00?ooool0
0_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00001oooool00ol0
003oooooooooo`0Pooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`3<
ooooo`03o`000?oooooooooo013ooooo000Jooooo`03o`000?oooooooooo00Wooooo00Goo`00oooo
ooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00?oo`00oooooooo00000_oo
002Hooooo`?oo`0000?oooooool00?ooool00_ooool01?oo003ooooooooooooo0002ooooo`05ool0
0?oooooooooooooooooo00001oooool00ol0003oooooooooo`0Pooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo013ooooo000Jooooo`;o
00002_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool0
0ooo003oooooooooo`2Nooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooo
oooo0003ooooo`03ool00?oooooooooo00Cooooo0_l0000Sooooo`?o00001?ooool2o`000<cooooo
0_l0000Booooo`006_ooool00ol0003oooooooooo`09ooooo`05ool00?oooooooooooooooooo0000
0_ooool01?oo003ooooooooooooo0003ooooo`03ool00?oooooooooo09kooooo00Goo`00oooooooo
ooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00?oo`00ooooooooool01Oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool04?ooool0
01[ooooo00?o0000ooooooooool02Oooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00
ooooooooooooo`000oooool00ooo003oooooooooo`2Nooooo`05ool00?oooooooooooooooooo0000
0_ooool01?oo003ooooooooooooo0003ooooo`03ool00?oooooooooo00Gooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo013ooooo000Jooooo`03o`00
0?oooooooooo00Wooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool0
00?ooooo00?oo`00ooooooooool0W_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00
ooooooooooooo`000oooool00ooo003oooooooooo`05ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool0c?ooool00ol0003oooooooooo`0@ooooo`004oooool3o`0000Cooooo00?o0000
ooooooooool02?ooool3ool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003ooooooooo
o`03ool009kooooo0ooo0002ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool0
0ooo0006ooooo`03o`000?oooooooooo02Sooooo0_l0003<ooooo`;o00004_ooool001;ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Sooooo0ooo0002ooooo`04ool0
0?ooooooooooool000;ooooo00?oo`00ooooooooool00ooo002Nooooo`?oo`000_ooool01?oo003o
oooooooooooo0002ooooo`03ool00?oooooooooo00?oo`001_ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo00kooooo0ooo002^ooooo`?oo`002_ooool00ol0003oooooooooo`0@oooo
o`005_ooool01?l0003oooooooooooooool3o`0000Sooooo0ooo0002ooooo`04ool00?oooooooooo
ool000;ooooo00?oo`00ooooooooool00ooo002Nooooo`?oo`000_ooool01?oo003ooooooooooooo
0002ooooo`03ool00?oooooooooo00?oo`001Oooool2o`0002[ooooo00?o0000ooooooooool03_oo
ool3ool00:kooooo0ooo000:ooooo`03o`000?oooooooooo013ooooo000Fooooo`05o`000?oooooo
ooooooooool000003oooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo0:Kooooo
00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool03_ooool3ool00004oooooooo003oo`00ool00:[ooooo0ooo000:oooo
o`03o`000?oooooooooo013ooooo000Booooo`Co00001?ooool00ol0003oooooooooo`0=ooooo`04
ool00?ooooooooooool000;ooooo00?oo`00ooooooooool0Y_ooool01?oo003ooooooooooooo0002
ooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool0:?ooool2o`00013ooooo00?oo`00
ooooooooool01_oo002Xooooo`03ool00?ooooooo`0000;oo`001_ooool2o`0001;ooooo000Boooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool01?oo003ooooooooooooo0002
ooooo`03ool00?oooooooooo0:Kooooo00Coo`00ooooooooooooo`000_ooool00ooo003ooooooooo
o`09ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03oooool00ooo003ooooooooo
o`09ool00:Gooooo00?oo`00oooooooo00000_oo0007ooooo`03o`000?oooooooooo013ooooo000B
ooooo`Go00000oooool00ol0003oooooooooo`0=ooooo`04ool00?ooooooooooool000;ooooo00?o
o`00ooooooooool0Y_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo00Wooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0?ooooo`06ool00?oooooooooooooooooo
003ooooo1_oo002Uooooo`03ool00?ooooooo`0000;oo`001oooool00ol0003oooooooooo`0@oooo
o`006_ooool00ol0003oooooooooo`0=ooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooo
ooooool0Y_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo00Wooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0?ooooo`05ool00?oooooooooooooooooo00000_oo
ool00ooo003oooooool00002ool00004oooooooo003oo`00ool00:7ooooo00Coo`00oooooooooooo
o`002?ooool00ol0003oooooooooo`0@ooooo`006_ooool2o`0000kooooo00Coo`00oooooooooooo
o`000_ooool00ooo003oooooooooo`2Vooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooo
ooooool02?ooool2o`0002[ooooo0_l0000@ooooo`05ool00?oooooooooooooooooo00000_ooool0
1?oo003ooooooooooooo0002ooooo`Koo`00W_ooool01?oo003ooooooooooooo0007ooooo`;o0000
4_ooool001[ooooo00?o0000ooooooooool03Oooool01?oo003ooooooooooooo0002ooooo`03ool0
0?oooooooooo0:Kooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`09ooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool03oooool01Ooo003oooooooooooooooooo`00
00;ooooo00Coo`00ooooooooooooo`000_ooool9ool009_ooooo00Coo`00ooooooooooooo`002?oo
ool00ol0003oooooooooo`0@ooooo`006_ooool00ol0003oooooooooo`0=ooooo`04ool00?oooooo
ooooool000;ooooo00?oo`00ooooooooool0Y_ooool01?oo003ooooooooooooo0002ooooo`03ool0
0?oooooooooo00Wooooo00?o0000ooooooooool08Oooool3o`0000Cooooo00?o0000ooooooooool0
3oooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool00ooo
003oooooool00005ool00004oooooooo003oo`00ool009Oooooo00Coo`00ooooooooooooo`002?oo
ool00ol0003oooooooooo`0@ooooo`006_ooool00ol0003oooooooooo`0=ooooo`04ool00?oooooo
ooooool000;ooooo00?oo`00ooooooooool0Y_ooool01?oo003ooooooooooooo0002ooooo`03ool0
0?oooooooooo00Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00oooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool0
00?ooooo00Goo`00ooooooooooooo`00ooooo`03ool00004oooooooo003oo`00ool009Oooooo00Co
o`00ooooooooooooo`000_ooool3ool000?ooooo00?o0000ooooooooool04?ooool001[ooooo00?o
0000ooooooooool03Oooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo0:Kooooo
00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo01[o
oooo1Ol00003ooooo`03o`000?oooooooooo00?ooooo0_l0000@ooooo`05ool00?oooooooooooooo
oooo00000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00?o
o`00ooooooooool01_oo002Dooooo`04ool00?ooooooooooool000;ooooo0ooo00001?oooooo0000
o`000?l0000Booooo`006_ooool00ol0003oooooooooo`0=ooooo`04ool00?ooooooooooool000;o
oooo00?oo`00ooooooooool0Y_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo
00Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00oooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Co
o`00ooooooooooooo`000_ooool01_oo003oooooooooooooooooo`00ooooo`Koo`00TOooool01?oo
003ooooooooooooo0002ooooo`?oo`000oooool00ol0003oooooooooo`0@ooooo`006_ooool2o`00
00kooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`2Vooooo`04ool00?oooooo
ooooool000;ooooo00?oo`00ooooooooool02?ooool2o`0002Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0?ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooo
oooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Koo`00ooooooooooooooooool00?oo
ool6ool00004oooooooo003oo`00ool008gooooo00Coo`00ooooooooooooo`000oooool00ooo003o
ooooooooo`02ooooo`03o`000?oooooooooo013ooooo000Jooooo`03o`000?oooooooooo00gooooo
00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`2Vooooo`04ool00?ooooooooooool0
00;ooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`;o00001Oooool00ol0
003oooooooooo`0?ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo
0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`03
ool00?ooooooo`0000;oo`0000?oooooool00?oo00001?oo002:ooooo`04ool00?ooooooooooool0
00?ooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`006_ooool00ol0003o
ooooooooo`0=ooooo`05ool00?ooooooooooool00?ooool00ooo002Vooooo`?oo`0000Goooooool0
0?ooooooooooool0000;ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00oooool2
o`00013ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo
00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00oooo
ooooooooo`000_ooool9ool008Oooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooo
ooooool2o`0001;ooooo000Jooooo`03o`000?oooooooooo00gooooo00Goo`00ooooooooooooo`00
ooooo`03ool00:Kooooo0ooo00001Oooooooo`00ooooooooooooo`0000_ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0?ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo
003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooooooooooooooo
ool00002ooooo`04ool00?ooooooooooool000?ooooo00?oo`00oooooooo00001Ooo00001?oooooo
o`00ool00?oo0023ooooo`04ool00?ooooooooooool000?ooooo00?oo`00ooooooooool00_ooool0
0ol0003oooooooooo`0@ooooo`006_ooool00ol0003oooooooooo`0=ooooo`05ool00?oooooooooo
ool00?ooool00ooo002Vooooo`?oo`0000Goooooool00?ooooooooooool0000;ooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool03oooool01Ooo003oooooooooooooooooo`0000;ooooo
00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooo
oooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`05ool00?ooooooooooool00?ooool0
0ooo00000oooooooo`00ool00004ool0083ooooo00Coo`00ooooooooooooo`000oooool00ooo003o
ooooooooo`02ooooo`03o`000?oooooooooo013ooooo000Jooooo`03o`000?oooooooooo00gooooo
00Coo`00ooooooooooooo`00[_ooool01?oo003ooooooooooooo000;ooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool03oooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00
ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo
00000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00?oo`00
ooooooooool01_oo0020ooooo`04ool00?ooooooooooool000?ooooo00?oo`00ooooooooool00_oo
ool00ol0003oooooooooo`0@ooooo`006_ooool2o`0000kooooo00Coo`00ooooooooooooo`00[_oo
ool01?oo003ooooooooooooo000:ooooo`;o0000:_ooool00ol0003oooooooooo`0?ooooo`05ool0
0?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?oooooooooo
ool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo
00Coo`00ooooooooooooo`000_ooool01_oo003oooooooooooooooooo`00ooooo`Koo`00OOooool0
1?oo003ooooooooooooo0003ooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool04?oo
ool001[ooooo00?o0000ooooooooool03Oooool01?oo003ooooooooooooo002^ooooo`04ool00?oo
ooooooooool000_ooooo00?o0000ooooooooool0:?ooool2o`00013ooooo00Goo`00oooooooooooo
ooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_ooool0
1Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooo
oooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool00ooo003oooooool00002ool0
0004oooooooo003oo`00ool007Wooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooo
ooooool2o`0001;ooooo000Jooooo`03o`000?oooooooooo00gooooo00Coo`00ooooooooooooo`00
[_ooool01?oo003ooooooooooooo000;ooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool03oooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool0
1?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooo
oooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002
ooooo`03ool00?ooooooo`0000;oo`0000?oooooool00?oo00001?oo001fooooo`04ool00?oooooo
ooooool000?ooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`006_ooool0
0ol0003oooooooooo`0=ooooo`04ool00?ooooooooooool00:kooooo00Coo`00ooooooooooooo`00
2oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00oooooo00Goo`00oooooooooooo
ooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_ooool0
1Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooo
oooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0002
ooooo`Woo`00Loooool01?oo003ooooooooooooo0003ooooo`03ool00?oooooooooo00;ooooo00?o
0000ooooooooool04?ooool001[ooooo00?o0000ooooooooool03Oooool01?oo003ooooooooooooo
002^ooooo`04ool00?ooooooooooool000_ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0?ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003oooo
o`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oo
ooooooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`00
00;ooooo00Coo`00ooooooooooooo`000oooool00ooo003oooooool00005ool00004oooooooo003o
o`00ool006oooooo00Coo`00ooooooooooooo`000oooool00ooo003oooooooooo`02ooooo`03o`00
0?oooooooooo013ooooo000Jooooo`03o`000?oooooooooo00gooooo00Coo`00ooooooooooooo`00
[_ooool01?oo003ooooooooooooo000;ooooo`03o`000?oooooooooo02Sooooo0_l0000@ooooo`05
ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?oooooo
ooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?o
oooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00
ooooooooooooo`000oooool01Ooo003ooooooooooooo003ooooo00?oo`0000?oooooool00?oo0000
1?oo001/ooooo`04ool00?ooooooooooool000?ooooo00Coo`00oooooooooooooooo0_l0000Boooo
o`006_ooool00ol0003oooooooooo`0=ooooo`04ool00?ooooooooooool00:kooooo00Coo`00oooo
ooooooooo`002oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00oooooo00Goo`00
ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00oooooooooooo
o`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool0
1?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooo
oooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool02Ooo001Yoooo
o`04ool00?ooooooooooool000?ooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`0@
ooooo`006_ooool2o`0000kooooo00Coo`00ooooooooooooo`00[_ooool01?oo003ooooooooooooo
000:ooooo`;o0000:_ooool00ol0003oooooooooo`0?ooooo`05ool00?oooooooooooooooooo0000
0_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooo
ooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`00
0_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo
003ooooooooooooo0002ooooo`06ool00?oooooooooooooooooo003ooooo1_oo00001?ooooooo`00
ool00?oo001Uooooo`04ool00?ooooooooooool000?ooooo00?oo`00ooooooooool00_ooool00ol0
003oooooooooo`0@ooooo`006_ooool00ol0003oooooooooo`0=ooooo`04ool00?ooooooooooool0
0:kooooo00Coo`00ooooooooooooo`002oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00oooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo
00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00oooo
ooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo0000
0_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooo
ooooooooooooool00002ooooo`03ool00?ooooooo`0000;oo`0000?oooooool00?oo00001?oo001R
ooooo`04ool00?ooooooooooool000?ooooo00?oo`00ooooooooool00_ooool00ol0003ooooooooo
o`0@ooooo`006_ooool00ol0003oooooooooo`0=ooooo`04ool00?ooooooooooool00:kooooo00Co
o`00ooooooooooooo`002oooool00ol0003oooooooooo`0Xooooo`;o00004?ooool01Ooo003ooooo
ooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002
ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04ool0
0?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oooooooooo
ool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo
00Coo`00ooooooooooooo`000_ooool6ool006;ooooo00Coo`00ooooooooooooo`000oooool01?oo
003oooooooooooooool2o`0001;ooooo000=ooooo`?o00001?ooool2o`0000Cooooo00?o0000oooo
ooooool03Oooool01?oo003ooooooooooooo002^ooooo`04ool00?ooooooooooool000_ooooo00?o
0000ooooooooool08_ooool2o`0000Cooooo00?o0000ooooooooool03oooool01Ooo003ooooooooo
ooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002oooo
o`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?oo
ooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool0
00?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Co
o`00ooooooooooooo`000oooool00ooo003oooooool00005ool005oooooo00Coo`00oooooooooooo
o`000oooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo000>ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0=ooooo`04
ool00?ooooooooooool00:kooooo00Coo`00ooooooooooooo`002oooool00ol0003oooooooooo`0Q
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool03oooool01Ooo003ooooooooo
ooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002oooo
o`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?oo
ooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool0
00?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Co
o`00ooooooooooooo`000oooool01Ooo003ooooooooooooo003ooooo00?oo`0000Coooooool00?oo
003oo`00Foooool01?oo003ooooooooooooo0003ooooo`03ool00?oooooooooo00;ooooo00?o0000
ooooooooool04?ooool000kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo00gooooo00Coo`00ooooooooooooo`00[_ooool01?oo003ooooooooo
oooo000;ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00000oooool01?l0003o
ooooooooooooool3ool000_ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oooooo
ooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;o
oooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooo
oooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;o
oooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Goo`00
ooooooooooooo`00ooooo`03ool00003oooooooo003oo`0000Coo`00F?ooool01?oo003ooooooooo
oooo0003ooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool04?ooool000kooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`?o00003Oooool01?oo003ooooo
oooooooo002^ooooo`04ool00?ooooooooooool000[ooooo0_l0000Sooooo`04o`000?oooooooooo
o`0000?ooooo0_l00002ooooo`?oo`0000?oooooool00?ooool00_ooool01?oo003ooooooooooooo
0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04
ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oooooo
ooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;o
oooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooo
oooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;o
oooo00?oo`00ooooooooool02Ooo0002ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooo
ooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`00
0_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo
003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooo
oooo0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002oooo
o`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003ooooooooo
ooooooooo`0000;ooooo0ol0000Booooo`003_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool03Oooool01?oo003ooooooooooooo002^ooooo`04
ool00?ooooooooooool000_ooooo00?o0000ooooooooool08Oooool01?l0003oooooooooool00003
ooooo`04o`000?ooooooooooooooo`?oo`0000?oooooool00?ooool00_ooool01?oo003ooooooooo
oooo001Hooooo`Koo`0000Koooooool00?oo003oo`00oooooooo0002ooooo`05ool00?oooooooooo
oooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo
00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00oooo
ooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`00
0oooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo
003ooooooooooooo0003ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool04?ooool0
00gooooo0_l00004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool03Oooool0
1?oo003ooooooooooooo002^ooooo`04ool00?ooooooooooool000_ooooo00?o0000ooooooooool0
8Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00Goo`00oooooooo
ooooooooool00002ooooo`03ool00?oooooooooo05Wooooo0ooo00000oooooooo`00ool00004ool0
0003oooooooo003ooooo00;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003ooooooooooooo
ooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`05
ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?oooooo
ooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?o
oooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000kooooo00?o0000
ooooooooool04?ooool000kooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000oooo
ooooool03Oooool01?oo003ooooooooooooo002^ooooo`04ool00?ooooooooooool000_ooooo00?o
0000ooooooooool08_ooool2o`0000Cooooo00?o0000ooooooooool01Oooool01Ooo003ooooooooo
ooooooooo`0000;ooooo00?oo`00ooooooooool0GOooool9ool000;ooooo00Coo`00oooooooooooo
o`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool0
1?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooo
oooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002
ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003ooooo
ooooooooooooo`0000kooooo00?o0000ooooooooool04?ooool001[ooooo00?o0000ooooooooool0
3Oooool01?oo003ooooooooooooo002^ooooo`04ool00?ooooooooooool000_ooooo00?o0000oooo
ooooool0:?ooool2o`0000Kooooo00Goo`00ooooooooooooooooool00002ooooo`03ool00?oooooo
oooo063ooooo1_oo00001_ooooooo`00ool00?oo003oooooool000;ooooo00Goo`00oooooooooooo
ooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_ooool0
1Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooo
oooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003
ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool0000=ooooo`;o0000
4_ooool001[ooooo00?o0000ooooooooool03Oooool01?oo003ooooooooooooo002^ooooo`04ool0
0?ooooooooooool000_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`05ooooo`05
ool00?oooooooooooooooooo00000_ooool00ooo003oooooooooo`1Sooooo`?oo`0000?oooooool0
0?oo00001?oo00000oooooooo`00ooooo`02ooooo`04ool00?ooooooooooool000;ooooo00Goo`00
ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00oooooooooooo
o`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool0
1?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooo
oooooooo0003ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool04?ooool001[ooooo
0_l0000>ooooo`04ool00?ooooooooooool00:kooooo00Coo`00ooooooooooooo`002_ooool2o`00
02[ooooo00?o0000ooooooooool01Oooool01Ooo003oooooooooooooooooo`0000;ooooo00?oo`00
ooooooooool0Ioooool9ool000;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003ooooooooo
ooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002oooo
o`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?oo
ooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool0
00?ooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`006_ooool00ol0003o
ooooooooo`0=ooooo`04ool00?ooooooooooool00:kooooo00Coo`00ooooooooooooo`002oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Gooooo00Goo`00ooooooooooooooooool0
0002ooooo`03ool00?oooooooooo06[ooooo1_oo0002ooooo`04ool00?ooooooooooool000;ooooo
00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00oooo
ooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`00
0oooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo
003ooooooooooooo0003ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool04?ooool0
01[ooooo00?o0000ooooooooool03Oooool01?oo003ooooooooooooo002^ooooo`04ool00?oooooo
ooooool000_ooooo00?o0000ooooooooool0:?ooool2o`0000Kooooo00Goo`00oooooooooooooooo
ool00002ooooo`03ool00?oooooooooo06gooooo0ooo00001_ooooooo`00ool00?oo003oooooool0
00;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Co
o`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00oooooooo
ooooo`000oooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_oo
ool01?oo003ooooooooooooo0003ooooo`03ool00?oooooooooo00_ooooo0_l0000Booooo`006_oo
ool00ol0003oooooooooo`0=ooooo`04ool00?ooooooooooool00:kooooo00Coo`00oooooooooooo
o`002oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Gooooo00Goo`00oooooooo
ooooooooool00002ooooo`03ool00?oooooooooo077ooooo1_oo00000oooooooo`00ooooo`02oooo
o`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oo
ooooooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`00
00;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`05ool00?oo
oooooooooooooooo00003_ooool00ol0003oooooooooo`0@ooooo`006_ooool00ol0003ooooooooo
o`0=ooooo`04ool00?ooooooooooool00:kooooo00Coo`00ooooooooooooo`002oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo00Gooooo00Goo`00ooooooooooooooooool00002oooo
o`03ool00?oooooooooo077ooooo2Ooo0002ooooo`04ool00?ooooooooooool000;ooooo00Goo`00
ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00oooooooooooo
o`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool0
1?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00003_ooool00ol0003ooooo
ooooo`0@ooooo`006_ooool00ol0003oooooooooo`0=ooooo`04ool00?ooooooooooool00:kooooo
00Coo`00ooooooooooooo`002oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Go
oooo00Goo`00ooooooooooooooooool00002ooooo`03ool00?oooooooooo07Cooooo1_oo00001_oo
ooooo`00ool00?oo003oooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool0
0?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003ooooooooooooooooo
o`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`05ool0
0?oooooooooooooooooo00003_ooool00ol0003oooooooooo`0@ooooo`006_ooool2o`0000kooooo
00Coo`00ooooooooooooo`00[_ooool01?oo003ooooooooooooo000:ooooo`;o0000:_ooool2o`00
00Kooooo00Goo`00ooooooooooooooooool00002ooooo`03ool00?oooooooooo07Oooooo0ooo0000
0oooooooo`00ool00004ool00003oooooooo003ooooo00;ooooo00Coo`00ooooooooooooo`000_oo
ool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003o
oooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo
0003ooooo`03ool00?oooooooooo00_ooooo0_l0000Booooo`006_ooool00ol0003oooooooooo`0=
ooooo`04ool00?ooooooooooool00:kooooo00Coo`00ooooooooooooo`002oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo00Gooooo00Goo`00ooooooooooooooooool00002ooooo`03
ool00?oooooooooo07_ooooo2Ooo0002ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooo
ooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`00
0_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool00ooo
003oooooooooo`0<ooooo`03o`000?oooooooooo013ooooo000Jooooo`03o`000?oooooooooo00go
oooo00Coo`00ooooooooooooo`00[_ooool01?oo003ooooooooooooo000;ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool01Oooool01Ooo003oooooooooooooooooo`0000;ooooo00?o
o`00ooooooooool0O_ooool6ool00006oooooooo003oo`00ool00?ooooooo`000_ooool01Ooo003o
ooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo
0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`03
ool00?oooooooooo00cooooo00?o0000ooooooooool04?ooool001[ooooo00?o0000ooooooooool0
3Oooool01?oo003ooooooooooooo002^ooooo`04ool00?ooooooooooool000_ooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`05ooooo`05ool00?oooooooooooooooooo00000_ooool0
0ooo003oooooooooo`21ooooo`?oo`0000?oooooool00?oo00001?oo00000oooooooo`00ooooo`02
ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool0
0?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003ooooooooooooooooo
o`0000kooooo00?o0000ooooooooool04?ooool001[ooooo00?o0000ooooooooool03Oooool01?oo
003ooooooooooooo002^ooooo`04ool00?ooooooooooool000_ooooo00?o0000ooooooooool0:?oo
ool2o`0000Kooooo00Goo`00ooooooooooooooooool00002ooooo`03ool00?oooooooooo08Gooooo
1_oo00000oooooooo`00ooooo`02ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooooooo
ooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_oo
ool01Ooo003oooooooooooooooooo`0000gooooo0_l0000Booooo`006_ooool00ol0003ooooooooo
o`0=ooooo`04ool00?ooooooooooool00:kooooo00Coo`00ooooooooooooo`002oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo00Gooooo00Goo`00ooooooooooooooooool00002oooo
o`03ool00?oooooooooo08Sooooo1_oo0002ooooo`04ool00?ooooooooooool000;ooooo00Goo`00
ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00oooooooooooo
o`000_ooool01Ooo003oooooooooooooooooo`0000kooooo00?o0000ooooooooool04?ooool001[o
oooo0_l0000>ooooo`04ool00?ooooooooooool00:kooooo00Coo`00ooooooooooooo`002_ooool2
o`0002?ooooo0ol00004ooooo`03o`000?oooooooooo00Gooooo00Goo`00ooooooooooooooooool0
0002ooooo`03ool00?oooooooooo08_ooooo0ooo00001_ooooooo`00ool00?oo003oooooool000;o
oooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00
ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000kooooo00?o0000ooooooooool0
4?ooool001[ooooo00?o0000ooooooooool03Oooool01?oo003ooooooooooooo002^ooooo`04ool0
0?ooooooooooool000_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Gooooo00Goo`00ooooooooooooooooool00002ooooo`03ool00?oooooooooo
08_ooooo0ooo00000oooooooo`00ool00004ool00003oooooooo003ooooo00;ooooo00Coo`00oooo
ooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`00
0oooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo013ooooo000Jooooo`03o`000?oo
oooooooo00gooooo00Coo`00ooooooooooooo`00[_ooool01?oo003ooooooooooooo000;ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool00oooool2o`0000Gooooo0ooo0002ooooo`04
ool00?ooooooooooool0097ooooo2Ooo0002ooooo`04ool00?ooooooooooool000;ooooo00Goo`00
ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00?oo`00ooooooooool0
2_ooool3o`0001;ooooo000Jooooo`03o`000?oooooooooo00gooooo00Coo`00ooooooooooooo`00
[_ooool01?oo003ooooooooooooo000;ooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`?oo`000_ooool01?oo003ooooooooooooo002Doooo
o`Koo`0000Koooooool00?oo003oo`00oooooooo0002ooooo`05ool00?oooooooooooooooooo0000
0_ooool01?oo003ooooooooooooo0003ooooo`03ool00?oooooooooo00cooooo00?o0000oooooooo
ool04?ooool001[ooooo00?o0000ooooooooool03Oooool01?oo003ooooooooooooo002^ooooo`04
ool00?ooooooooooool000_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo0ooo0002ooooo`04ool00?ooooooooooool009Oooooo0ooo0000
0oooooooo`00ool00004ool00003oooooooo003ooooo00;ooooo00Coo`00ooooooooooooo`000_oo
ool01Ooo003oooooooooooooooooo`0000kooooo00?o0000ooooooooool04?ooool001[ooooo00?o
0000ooooooooool03Oooool01?oo003ooooooooooooo002^ooooo`04ool00?ooooooooooool000_o
oooo00?o0000ooooooooool08Oooool2o`0000Gooooo00?o0000ooooooooool02Oooool01?oo003o
oooooooooooo002Kooooo`Koo`0000?oooooool00?ooool00_ooool01?oo003ooooooooooooo0002
ooooo`05ool00?oooooooooooooooooo00003_ooool00ol0003oooooooooo`0@ooooo`006_ooool2
o`0000kooooo00Coo`00ooooooooooooo`00[_ooool01?oo003ooooooooooooo000:ooooo`;o0000
9?ooool00ol0003oooooooooo`03ooooo`;o00002_ooool01?oo003ooooooooooooo002Nooooo`Ko
o`000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00003Oooool2
o`0001;ooooo000Jooooo`03o`000?oooooooooo00gooooo00Coo`00ooooooooooooo`00[_ooool0
1?oo003ooooooooooooo000;ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02Ooo
ool01?oo003ooooooooooooo002Qooooo`?oo`0000Koooooool00?oo003oo`00oooooooo0002oooo
o`05ool00?oooooooooooooooooo00003_ooool00ol0003oooooooooo`0@ooooo`006_ooool00ol0
003oooooooooo`0=ooooo`04ool00?ooooooooooool00:kooooo00Coo`00ooooooooooooo`002ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Sooooo0ooo00000oooooooo`00oooo
o`2Pooooo`?oo`0000?oooooool00?oo00001?oo00000oooooooo`00ooooo`02ooooo`03ool00?oo
oooooooo00cooooo00?o0000ooooooooool04?ooool000gooooo0ol00003ooooo`?o00001?ooool0
0ol0003oooooooooo`0=ooooo`04ool00?ooooooooooool00:kooooo00Coo`00ooooooooooooo`00
2oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Sooooo0ooo00000oooooooo`00
ooooo`2Tooooo`Koo`0000?oooooool00?ooool00_ooool00ooo003oooooooooo`0<ooooo`03o`00
0?oooooooooo013ooooo000>ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000oooooo00Coo`00ooooooooooooo`00[_ooool01?oo003ooooooooooooo000;
ooooo`03o`000?oooooooooo02Sooooo0_l00009ooooo`?oo`0000?oooooool00?ooool0Yoooool6
ool000;ooooo00?oo`00ooooooooool02oooool2o`0001;ooooo000>ooooo`03o`000?oooooooooo
00Gooooo00Go0000ooooooooooooooooo`00000?ooooo`04ool00?ooooooooooool00:kooooo00Co
o`00ooooooooooooo`002oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00_ooooo
0ooo002Zooooo`?oo`000_ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo013ooooo
000>ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo0ol0000=ooooo`04ool0
0?ooooooooooool00:kooooo00Coo`00ooooooooooooo`002_ooool2o`0002[ooooo00?o0000oooo
ooooool02oooool3ool00:[ooooo0ooo00001?ooooooo`00ool00?oo000=ooooo`03o`000?oooooo
oooo013ooooo000>ooooo`04o`000?ooooooooooooooo`Co00001?ooool00ol0003oooooooooo`0=
ooooo`04ool00?ooooooooooool00:kooooo00Coo`00ooooooooooooo`002oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo00_ooooo0ooo002^ooooo`?oo`003Oooool00ol0003ooooo
ooooo`0@ooooo`003Oooool2o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0=ooooo`04ool00?ooooooooooool00:kooooo00Coo`00ooooooooooooo`002oooool00ol0003o
ooooooooo`0Xooooo`;o0000_Oooool3ool000cooooo0_l0000Booooo`003_ooool01?l0003ooooo
ooooooooool5o`0000?ooooo00?o0000ooooooooool03Oooool01?oo003ooooooooooooo002^oooo
o`04ool00?ooooooooooool000_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`3<
ooooo`03o`000?oooooooooo013ooooo000Jooooo`03o`000?oooooooooo00gooooo00Coo`00oooo
ooooooooo`00[_ooool01?oo003ooooooooooooo000;ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool0c?ooool00ol0003oooooooooo`0@ooooo`006_ooool00ol0003oooooooooo`0=
ooooo`04ool00?ooooooooooool00:kooooo00Coo`00ooooooooooooo`002oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool04?ooool001[ooooo0_l0
000>ooooo`04ool00?ooooooooooool00:kooooo00Coo`00ooooooooooooo`002_ooool2o`0002[o
oooo0_l0003<ooooo`;o00004_ooool001[ooooo00?o0000ooooooooool03Oooool01?oo003ooooo
oooooooo002^ooooo`04ool00?ooooooooooool000_ooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`3<ooooo`03o`000?oooooooooo013ooooo000Jooooo`03o`000?oooooooooo00go
oooo00Coo`00ooooooooooooo`00[_ooool01?oo003ooooooooooooo000;ooooo`03o`000?oooooo
oooo023ooooo1Ol00003ooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool04?ooool0
01[ooooo00?o0000ooooooooool03Oooool01?oo003ooooooooooooo002^ooooo`04ool00?oooooo
ooooool000_ooooo00?o0000ooooooooool08Oooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo0<cooooo00?o0000ooooooooool04?ooool001[ooooo00?o0000ooooooooool03Ooo
ool01?oo003ooooooooooooo002^ooooo`04ool00?ooooooooooool000_ooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`03ooooo`;o0000boooool3o`0001;ooooo000Jooooo`03o`00
0?oooooooooo00gooooo00Coo`00ooooooooooooo`00[_ooool01?oo003ooooooooooooo000;oooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3<oooo
o`03o`000?oooooooooo013ooooo000Jooooo`;o00003_ooool01?oo003ooooooooooooo002^oooo
o`04ool00?ooooooooooool000[ooooo0_l0000Rooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo013ooooo000Jooooo`03o`000?oooooo
oooo00gooooo00Coo`00ooooooooooooo`00[_ooool01?oo003ooooooooooooo000;ooooo`03o`00
0?oooooooooo023ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo0<co
oooo00?o0000ooooooooool04?ooool001[ooooo00?o0000ooooooooool03Oooool01?oo003ooooo
oooooooo002^ooooo`04ool00?ooooooooooool000_ooooo00?o0000ooooooooool08Oooool3o`00
00Cooooo0_l0003<ooooo`;o00004_ooool001[ooooo00?o0000ooooooooool02oooool3ool000;o
oooo00?oo`00ooooooooool0[?ooool00ooo003oooooool00002ool000[ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo013ooooo000Jooooo`03o`00
0?oooooooooo00_ooooo0ooo0002ooooo`03ool00?oooooooooo0:cooooo00?oo`00oooooooo0000
0_oo000:ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0c?ooool00ol0003ooooo
ooooo`0@ooooo`006_ooool00ol0003oooooooooo`0;ooooo`?oo`000_ooool00ooo003ooooooooo
o`2/ooooo`03ool00?ooooooo`0000;oo`002_ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo0<cooooo00?o0000ooooooooool04?ooool001[ooooo0_l0000Aooooo`03ool00?oooooo
oooo0:cooooo00?oo`00ooooooooool02oooool2o`0002[ooooo0_l0003<ooooo`;o00004_ooool0
01[ooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`2/ooooo`03ool00?oooooooooo
00cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo
013ooooo000Jooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0[?ooool00ooo003o
ooooooooo`0<ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0c?ooool00ol0003o
ooooooooo`0@ooooo`006_ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo0:cooooo
00?oo`00ooooooooool03?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0<cooooo
00?o0000ooooooooool04?ooool001[ooooo00?o0000ooooooooool04?ooool00ooo003ooooooooo
o`2/ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`3<ooooo`03o`000?oooooooooo013ooooo000Jooooo`03o`000?oooooooooo013ooooo00?oo`00
ooooooooool0[?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo02Sooooo0_l0003<
ooooo`;o00004_ooool001[ooooo0_l0000Aooooo`03ool00?oooooooooo0:cooooo00?oo`00oooo
ooooool02oooool2o`0002[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0@oooo
o`006_ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo0:cooooo00?oo`00oooooooo
ool03?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0<cooooo00?o0000oooooooo
ool04?ooool001[ooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`2/ooooo`03ool0
0?oooooooooo00cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`3<ooooo`03o`00
0?oooooooooo013ooooo000Jooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0[?oo
ool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo02Sooooo0_l0003<ooooo`;o00004_oo
ool000cooooo1Ol00003ooooo`;o00001?ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooo
oooo0:cooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`0Qooooo`?o00001?ooool0
0ol0003oooooooooo`3<ooooo`03o`000?oooooooooo013ooooo000=ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0@ooooo`03ool00?oo
oooooooo0:cooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`0Pooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo013ooooo
000>ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool3o`00013ooooo
00?oo`00ooooooooool0[?ooool00ooo003oooooooooo`0;ooooo`;o00009_ooool01Ol0003ooooo
oooooooooooo00000<kooooo00?o0000ooooooooool04?ooool000oooooo00Go0000oooooooooooo
ooooo`000002ooooo`05o`000?ooooooooooooooool000004Oooool3ool00:cooooo0ooo000=oooo
o`03o`000?oooooooooo02;ooooo0_l00004ooooo`;o0000boooool3o`0001;ooooo000<ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo00oooooo0ooo002/ooooo`?oo`003Oooool00ol0003oooooooooo`0Tooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool07_ooool00ol0003oooooo`00000Booooo`003?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0?ooooo`?oo`00
[?ooool3ool000gooooo00?o0000ooooooooool08?ooool01Ol0003ooooooooooooooooo000000?o
ooood?l0000Booooo`003Oooool3o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
0_l0000Sooooo`?o0000i_ooool001[oooood_l0003oooooo`gooooo003oooooooWooooo003ooooo
ooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003ooooo
ooWooooo0000\
\>"],
  ImageRangeCache->{{{0, 503}, {310.438, 0}} -> {-0.0514703, -0.0309082, \
0.0041808, 0.0041808}, {{12.3125, 240.062}, {303, 162.25}} -> {-13.4758, \
-5.44608, 0.101361, 0.24669}, {{262.875, 490.688}, {303, 162.25}} -> \
{-38.6937, -4.12096, 0.10088, 0.0495589}, {{12.3125, 240.062}, {148.125, \
7.375}} -> {-9.46515, -29.2917, 0.29678, 0.165433}, {{262.875, 490.688}, \
{148.125, 7.375}} -> {-85.1316, -11.7081, 0.300191, 0.0492634}}]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["DTFT vs. DFT: Example #5: sum of cosine waves (DC, 1Hz, 2Hz)", "Section"],

Cell[CellGroupData[{

Cell["Sampled sequence", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(x[t_] := 1 + \ 2\ Cos[2  \[Pi]\ t] + 4  Cos[4  \[Pi]\ t];\)\), "\n", 
    \(\(xd = \ sampler[x, fs = 10, {0, 3}];\)\), "\[IndentingNewLine]", 
    \(\(If[OddQ[Length[xd]], \ xd\  = \ Drop[xd, \(-1\)]];\)\), "\n", 
    \(\(gx\  = \ 
        DiscreteListPlot2[xd, \ Blue, \ Frame \[Rule] True, 
          Axes \[Rule] {True, False}, \ ImageSize \[Rule] 504, \ 
          AspectRatio \[Rule] 1/3];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
%%ImageSize: 504 168 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0328407 0.0998844 0.0322161 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18801 -0.0125 -3 -9 ]
[.18801 -0.0125 3 0 ]
[.35222 -0.0125 -6 -9 ]
[.35222 -0.0125 6 0 ]
[.51642 -0.0125 -6 -9 ]
[.51642 -0.0125 6 0 ]
[.68062 -0.0125 -6 -9 ]
[.68062 -0.0125 6 0 ]
[.84483 -0.0125 -6 -9 ]
[.84483 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .03545 -12 -4.5 ]
[-0.0125 .03545 0 4.5 ]
[-0.0125 .09988 -6 -4.5 ]
[-0.0125 .09988 0 4.5 ]
[-0.0125 .16432 -6 -4.5 ]
[-0.0125 .16432 0 4.5 ]
[-0.0125 .22875 -6 -4.5 ]
[-0.0125 .22875 0 4.5 ]
[-0.0125 .29318 -6 -4.5 ]
[-0.0125 .29318 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18801 0 m
.18801 .00625 L
s
[(5)] .18801 -0.0125 0 1 Mshowa
.35222 0 m
.35222 .00625 L
s
[(10)] .35222 -0.0125 0 1 Mshowa
.51642 0 m
.51642 .00625 L
s
[(15)] .51642 -0.0125 0 1 Mshowa
.68062 0 m
.68062 .00625 L
s
[(20)] .68062 -0.0125 0 1 Mshowa
.84483 0 m
.84483 .00625 L
s
[(25)] .84483 -0.0125 0 1 Mshowa
.125 Mabswid
.05665 0 m
.05665 .00375 L
s
.08949 0 m
.08949 .00375 L
s
.12233 0 m
.12233 .00375 L
s
.15517 0 m
.15517 .00375 L
s
.22085 0 m
.22085 .00375 L
s
.25369 0 m
.25369 .00375 L
s
.28654 0 m
.28654 .00375 L
s
.31938 0 m
.31938 .00375 L
s
.38506 0 m
.38506 .00375 L
s
.4179 0 m
.4179 .00375 L
s
.45074 0 m
.45074 .00375 L
s
.48358 0 m
.48358 .00375 L
s
.54926 0 m
.54926 .00375 L
s
.5821 0 m
.5821 .00375 L
s
.61494 0 m
.61494 .00375 L
s
.64778 0 m
.64778 .00375 L
s
.71346 0 m
.71346 .00375 L
s
.74631 0 m
.74631 .00375 L
s
.77915 0 m
.77915 .00375 L
s
.81199 0 m
.81199 .00375 L
s
.87767 0 m
.87767 .00375 L
s
.91051 0 m
.91051 .00375 L
s
.94335 0 m
.94335 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .03545 m
.00625 .03545 L
s
[(-2)] -0.0125 .03545 1 0 Mshowa
0 .09988 m
.00625 .09988 L
s
[(0)] -0.0125 .09988 1 0 Mshowa
0 .16432 m
.00625 .16432 L
s
[(2)] -0.0125 .16432 1 0 Mshowa
0 .22875 m
.00625 .22875 L
s
[(4)] -0.0125 .22875 1 0 Mshowa
0 .29318 m
.00625 .29318 L
s
[(6)] -0.0125 .29318 1 0 Mshowa
.125 Mabswid
0 .05156 m
.00375 .05156 L
s
0 .06767 m
.00375 .06767 L
s
0 .08378 m
.00375 .08378 L
s
0 .11599 m
.00375 .11599 L
s
0 .1321 m
.00375 .1321 L
s
0 .14821 m
.00375 .14821 L
s
0 .18042 m
.00375 .18042 L
s
0 .19653 m
.00375 .19653 L
s
0 .21264 m
.00375 .21264 L
s
0 .24486 m
.00375 .24486 L
s
0 .26096 m
.00375 .26096 L
s
0 .27707 m
.00375 .27707 L
s
0 .01934 m
.00375 .01934 L
s
0 .00324 m
.00375 .00324 L
s
0 .30929 m
.00375 .30929 L
s
0 .3254 m
.00375 .3254 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.02381 .32708 m
.02381 .33333 L
s
.18801 .32708 m
.18801 .33333 L
s
.35222 .32708 m
.35222 .33333 L
s
.51642 .32708 m
.51642 .33333 L
s
.68062 .32708 m
.68062 .33333 L
s
.84483 .32708 m
.84483 .33333 L
s
.125 Mabswid
.05665 .32958 m
.05665 .33333 L
s
.08949 .32958 m
.08949 .33333 L
s
.12233 .32958 m
.12233 .33333 L
s
.15517 .32958 m
.15517 .33333 L
s
.22085 .32958 m
.22085 .33333 L
s
.25369 .32958 m
.25369 .33333 L
s
.28654 .32958 m
.28654 .33333 L
s
.31938 .32958 m
.31938 .33333 L
s
.38506 .32958 m
.38506 .33333 L
s
.4179 .32958 m
.4179 .33333 L
s
.45074 .32958 m
.45074 .33333 L
s
.48358 .32958 m
.48358 .33333 L
s
.54926 .32958 m
.54926 .33333 L
s
.5821 .32958 m
.5821 .33333 L
s
.61494 .32958 m
.61494 .33333 L
s
.64778 .32958 m
.64778 .33333 L
s
.71346 .32958 m
.71346 .33333 L
s
.74631 .32958 m
.74631 .33333 L
s
.77915 .32958 m
.77915 .33333 L
s
.81199 .32958 m
.81199 .33333 L
s
.87767 .32958 m
.87767 .33333 L
s
.91051 .32958 m
.91051 .33333 L
s
.94335 .32958 m
.94335 .33333 L
s
.97619 .32958 m
.97619 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .03545 m
1 .03545 L
s
.99375 .09988 m
1 .09988 L
s
.99375 .16432 m
1 .16432 L
s
.99375 .22875 m
1 .22875 L
s
.99375 .29318 m
1 .29318 L
s
.125 Mabswid
.99625 .05156 m
1 .05156 L
s
.99625 .06767 m
1 .06767 L
s
.99625 .08378 m
1 .08378 L
s
.99625 .11599 m
1 .11599 L
s
.99625 .1321 m
1 .1321 L
s
.99625 .14821 m
1 .14821 L
s
.99625 .18042 m
1 .18042 L
s
.99625 .19653 m
1 .19653 L
s
.99625 .21264 m
1 .21264 L
s
.99625 .24486 m
1 .24486 L
s
.99625 .26096 m
1 .26096 L
s
.99625 .27707 m
1 .27707 L
s
.99625 .01934 m
1 .01934 L
s
.99625 .00324 m
1 .00324 L
s
.99625 .30929 m
1 .30929 L
s
.99625 .3254 m
1 .3254 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
0 .09988 m
1 .09988 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .09988 m
.02381 .3254 L
s
.05665 .09988 m
.05665 .22405 L
s
.08949 .09988 m
.08949 .04776 L
s
.12233 .09988 m
.12233 .00794 L
s
.15517 .09988 m
.15517 .1198 L
s
.18801 .09988 m
.18801 .19653 L
s
.22085 .09988 m
.22085 .1198 L
s
.25369 .09988 m
.25369 .00794 L
s
.28654 .09988 m
.28654 .04776 L
s
.31938 .09988 m
.31938 .22405 L
s
.35222 .09988 m
.35222 .3254 L
s
.38506 .09988 m
.38506 .22405 L
s
.4179 .09988 m
.4179 .04776 L
s
.45074 .09988 m
.45074 .00794 L
s
.48358 .09988 m
.48358 .1198 L
s
.51642 .09988 m
.51642 .19653 L
s
.54926 .09988 m
.54926 .1198 L
s
.5821 .09988 m
.5821 .00794 L
s
.61494 .09988 m
.61494 .04776 L
s
.64778 .09988 m
.64778 .22405 L
s
.68062 .09988 m
.68062 .3254 L
s
.71346 .09988 m
.71346 .22405 L
s
.74631 .09988 m
.74631 .04776 L
s
.77915 .09988 m
.77915 .00794 L
s
.81199 .09988 m
.81199 .1198 L
s
.84483 .09988 m
.84483 .19653 L
s
.87767 .09988 m
.87767 .1198 L
s
.91051 .09988 m
.91051 .00794 L
s
.94335 .09988 m
.94335 .04776 L
s
.97619 .09988 m
.97619 .22405 L
s
.005 w
.02381 .3254 Mdot
.05665 .22405 Mdot
.08949 .04776 Mdot
.12233 .00794 Mdot
.15517 .1198 Mdot
.18801 .19653 Mdot
.22085 .1198 Mdot
.25369 .00794 Mdot
.28654 .04776 Mdot
.31938 .22405 Mdot
.35222 .3254 Mdot
.38506 .22405 Mdot
.4179 .04776 Mdot
.45074 .00794 Mdot
.48358 .1198 Mdot
.51642 .19653 Mdot
.54926 .1198 Mdot
.5821 .00794 Mdot
.61494 .04776 Mdot
.64778 .22405 Mdot
.68062 .3254 Mdot
.71346 .22405 Mdot
.74631 .04776 Mdot
.77915 .00794 Mdot
.81199 .1198 Mdot
.84483 .19653 Mdot
.87767 .1198 Mdot
.91051 .00794 Mdot
.94335 .04776 Mdot
.97619 .22405 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 168},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000Z2000`400?l00000o`00003ooooooooi
ooooo`00:Oooool2o`0004Sooooo0ol00015ooooo`?o00001?ooool2o`0004;ooooo0ol00003oooo
o`?o0000@Oooool5o`0000?ooooo0_l00011ooooo`Go00000_ooool3o`0005?ooooo000Xooooo`04
o`000?ooooooooooo`0004Kooooo00Go0000ooooooooooooooooo`000015ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo0000@_ooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool0?oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
047ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo053ooooo000X
ooooo`04o`000?ooooooooooo`0004[ooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0004;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`10ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000@_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo053ooooo000Xooooo`04o`000?ooooooooooo`0004[o
oooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
04;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`11ooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0D?ooool002Sooooo00Co0000oooooooooooo0000A_ooool4o`0004Kooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00012ooooo`04o`000?ooooooooooooooo`Co0000
@Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000@?ooool01_l0
003ooooooooooooooooo0000ooooo`Co0000Doooool002Sooooo00Co0000oooooooooooo0000A_oo
ool00ol0003oooooooooo`16ooooo`;o00001?ooool01?l0003oooooooooool00011ooooo`;o0000
0oooool00ol0003oooooooooo`12ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00010ooooo`07o`000?ooooooooooooooool0003oooooo`00001Fooooo`00:Oooool2
o`0004Oooooo1Ol00015ooooo`03o`000?oooooooooo00?ooooo0_l00013ooooo`04o`000?oooooo
ooooooooo`Go0000@Oooool3o`0000Cooooo0_l00012ooooo`?o00000_ooool5o`0005;ooooo003o
ooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003o
ooooooWooooo003oooooooWooooo000Ooooooooo0000bol0000?ooooo`007oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00gooooo000Oooooo`?o00002?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool2o`0000oooooo000O
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:_ooool2o`00oacooooo00?o0000
ooooooooool06oooool2o`00ob_ooooo00?o0000ooooooooool0:_ooool2o`00oacooooo00?o0000
ooooooooool06oooool2o`00ob_ooooo00?o0000ooooooooool0:_ooool2o`00oacooooo00?o0000
ooooooooool06oooool2o`00obOooooo00?o0000ooooooooool03Oooool001oooooo00?o0000oooo
ooooool0=Oooool2o`00oc[ooooo0_l00?mHooooo`;o003o>_ooool2o`00oeSooooo0_l00?ljoooo
o`;o003o9oooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0eooooo`03
o`00oooooooooooo03Wooooo00?o003oooooooooool0Eoooool00ol00?ooooooooooo`0iooooo`03
o`00oooooooooooo05Oooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0Vooooo`03
o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo03Gooooo00?o003oooooooooool0
>Oooool00ol00?ooooooooooo`1Gooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0
Eoooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo02Kooooo00?o0000ooooooooool0
3Oooool001oooooo00?o0000ooooooooool0=Oooool00ol00?ooooooooooo`0iooooo`03o`00oooo
oooooooo05Oooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`1Gooooo`03o`00oooo
oooooooo03Wooooo00?o003oooooooooool09_ooool00ol0003oooooooooo`0=ooooo`007oooool0
0ol0003oooooooooo`0eooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0Eoooool0
0ol00?ooooooooooo`0iooooo`03o`00oooooooooooo05Oooooo00?o003oooooooooool0>Oooool0
0ol00?ooooooooooo`0Vooooo`03o`000?oooooooooo00gooooo000Oooooo`?o0000=Oooool00ol0
0?ooooooooooo`0iooooo`03o`00oooooooooooo05Oooooo00?o003oooooooooool0>Oooool00ol0
0?ooooooooooo`1Gooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool09Oooool2o`00
00oooooo000Oooooo`03o`000?oooooooooo03Gooooo00?o003oooooooooool0>Oooool00ol00?oo
ooooooooo`1Gooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0Eoooool00ol00?oo
ooooooooo`0iooooo`03o`00oooooooooooo02Kooooo00?o0000ooooooooool03Oooool001oooooo
00?o0000ooooooooool0=Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo05Oooooo
00?o003oooooooooool0>Oooool00ol00?ooooooooooo`1Gooooo`03o`00oooooooooooo03Wooooo
00?o003oooooooooool09_ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003ooooooooo
o`0eooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0Eoooool00ol00?oooooooooo
o`0iooooo`03o`00oooooooooooo05Oooooo00?o003oooooooooool0>Oooool00ol00?oooooooooo
o`0Vooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo03Gooooo00?o003o
ooooooooool0>Oooool00ol00?ooooooooooo`1Gooooo`03o`00oooooooooooo03Wooooo00?o003o
ooooooooool0Eoooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo02Kooooo00?o0000
ooooooooool03Oooool001Cooooo1Ol00006ooooo`03o`000?oooooooooo03Gooooo00?o003ooooo
ooooool0>Oooool00ol00?ooooooooooo`1Gooooo`03o`00oooooooooooo03Wooooo00?o003ooooo
ooooool0Eoooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo02Kooooo00?o0000oooo
ooooool03Oooool001Gooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0eoooo
o`03o`00oooooooooooo03Wooooo00?o003oooooooooool0Eoooool00ol00?ooooooooooo`0ioooo
o`03o`00oooooooooooo05Oooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0Voooo
o`03o`000?oooooooooo00gooooo000>ooooo`Go00000oooool00ol0003oooooooooo`06ooooo`Co
0000=?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo05Oooooo00?o003ooooooooo
ool0>Oooool00ol00?ooooooooooo`1Gooooo`03o`00oooooooooooo03Wooooo00?o003ooooooooo
ool08oooool4o`0000oooooo000Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
=Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo05Oooooo00?o003oooooooooool0
>Oooool00ol00?ooooooooooo`1Gooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0
9_ooool00ol0003oooooooooo`0=ooooo`005?ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0=Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo05Oooooo
00?o003oooooooooool0>Oooool00ol00?ooooooooooo`1Gooooo`03o`00oooooooooooo03Wooooo
00?o003oooooooooool09_ooool00ol0003oooooooooo`0=ooooo`005?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0=Oooool00ol00?ooooooooooo`0iooooo`03o`00
oooooooooooo05Oooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`1Gooooo`03o`00
oooooooooooo03Wooooo00?o003oooooooooool09_ooool00ol0003oooooooooo`0=ooooo`005Ooo
ool3o`0000Oooooo00?o0000ooooooooool0=Oooool00ol00?ooooooooooo`0iooooo`03o`00oooo
oooooooo05Oooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`1Gooooo`03o`00oooo
oooooooo03Wooooo00?o003oooooooooool09_ooool00ol0003oooooooooo`0=ooooo`007oooool0
0ol0003oooooooooo`0eooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0Eoooool0
0ol00?ooooooooooo`0iooooo`03o`00oooooooooooo05Oooooo00?o003oooooooooool0>Oooool0
0ol00?ooooooooooo`0Vooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo
02Kooooo0_l00?l=ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool2o`00
oc[ooooo0_l00?l=ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool2o`00
oc[ooooo0_l00?l=ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool2o`00
oaSooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool09_ooool2o`00o`go
oooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`;o003o>_ooool2o`00o`go
oooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`;o003o>_ooool2o`00o`go
oooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`;o003o6?ooool00ol0003o
ooooooooo`0=ooooo`007oooool3o`0002Kooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo01Kooooo0_l0000?ooooo`007oooool00ol0003ooooooooo
o`0Vooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0Gooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo02Kooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01Oooooo00?o0000
ooooooooool03Oooool001oooooo00?o0000ooooooooool09_ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0ioooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0ioooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool05oooool00ol0003oooooooooo`0=oooo
o`007oooool00ol0003oooooooooo`0Vooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`00
0?oooooooooo02Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo01Oooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool09_oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Ooo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool05ooo
ool00ol0003oooooooooo`0=ooooo`007oooool3o`0002Kooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01Kooooo0_l0000?ooooo`007oooool00ol0
003oooooooooo`0Vooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`0Gooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo02Ko
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wo
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01Oo
oooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool09_ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool05oooool00ol0003ooooo
ooooo`0=ooooo`007oooool00ol0003oooooooooo`0Vooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo00gooooo000O
ooooo`03o`000?oooooooooo02Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0i
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0i
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo01Oooooo00?o0000ooooooooool03Oooool001oooooo00?o0000oooo
ooooool09_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool05oooool00ol0003oooooooooo`0=ooooo`007oooool3o`0002Kooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01Kooooo0_l0000?ooooo`00
7oooool00ol0003oooooooooo`0Vooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oo
oooooooo02Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo01Oooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool09_ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool05oooool0
0ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0Vooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo
00gooooo000Fooooo`;o00001oooool00ol0003oooooooooo`0Vooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wo
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wo
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo00go
oooo000Eooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool09_ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool05oooool00ol0003o
ooooooooo`0=ooooo`005Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo02Ko
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wo
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01Oo
oooo00?o0000ooooooooool03Oooool001Gooooo00Co0000oooooooooooo00001_ooool;o`000003
o`00ool0003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000o`00000<o`000003
o`00ool0003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000o`00000<o`000003
o`00ool0003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000o`00000<o`000003
o`00ool0003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000o`00000<o`000003
o`00ool0003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000o`00000<o`000003
o`00ool0003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000o`00000<o`000003
o`00ool0003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000o`00000<o`000003
o`00ool0003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000o`00000<o`000003
o`00ool0003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000o`00000<o`000003
o`00ool0003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000o`000009o`0000oo
oooo000Eooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool02?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool02?ooool00ol0003o
ooooooooo`0=ooooo`005Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00So
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00So
oooo00?o0000ooooooooool03Oooool001Kooooo0_l00007ooooo`03o`000?oooooooooo00Sooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00Sooooo
00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool02?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool02?ooool00ol0003ooooooooo
o`0=ooooo`007oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool0:_ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00gooooo000Ooooo
o`03o`000?oooooooooo00Sooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Zoooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Zoooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Zoooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Zoooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Zoooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Zoooo
o`03o`00oooooooooooo00Sooooo00?o0000ooooooooool03Oooool001oooooo0ol00008ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`07ooooo`;o
00003oooool001oooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo02[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo02[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo02[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo02[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo02[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo02[ooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0=ooooo`007ooo
ool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0:_oo
ool2o`00o`gooooo00?o003oooooooooool03?ooool2o`00ob_ooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo02[ooooo0_l00?l=ooooo`03o`00oooo
oooooooo00cooooo0_l00?l[ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0Zooooo`;o003o3Oooool00ol00?ooooooooooo`0<ooooo`;o003o:ooo
ool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooo
oooo00Sooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Zooooo`;o003o3Oooool0
0ol00?ooooooooooo`0<ooooo`;o003o:oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool0:_ooool2o`00o`gooooo00?o003oooooooooool03?ooool2
o`00ob_ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo02[ooooo0_l00?l=ooooo`03o`00oooooooooooo00cooooo0_l00?l[ooooo`03o`00oooooooo
oooo00Sooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool02?ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0>Oooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol0
0?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool02?ooool00ol0
003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo03Wo
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wo
oooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00go
oooo000Oooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0>Oooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?oooooo
ooooo`0iooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool03Oooool001oooooo00?o
0000ooooooooool02?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o
003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o
003oooooooooool02?ooool00ol0003oooooooooo`0=ooooo`007oooool3o`0000Sooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003o
ooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool0>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00Oooooo0_l0000?
ooooo`007oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool0>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003ooooo
ooooool0>Oooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00gooooo000Oooooo`03
o`000?oooooooooo00Sooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03
o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo03Wooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0iooooo`03
o`00oooooooooooo00Sooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0
2?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0
>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0
2?ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`08ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooo
oooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo03Wooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`08ooooo`03o`000?oo
oooooooo00gooooo000Oooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0>Oooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool0
0ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool03Oooool0
01oooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
03Wooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo
03Wooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0=ooooo`007oooool3o`0000So
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo03Wo
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wo
oooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00Oo
oooo0_l0000?ooooo`007oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo03Wooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo
00?o003oooooooooool0>Oooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00gooooo
000Oooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0iooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0>Oooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?oooooooooo
o`0iooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool03Oooool001oooooo00?o0000
ooooooooool02?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003o
ooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool0>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o003o
ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`08oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0ioooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0ioooo
o`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo03Wooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`08oooo
o`03o`000?oooooooooo00gooooo000Dooooo`Go00001_ooool00ol0003oooooooooo`08ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0iooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03
o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo03Wooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`08ooooo`03
o`000?oooooooooo00gooooo000Eooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooooooo
ool02?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003ooooooooo
ool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool0>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o003ooooooooo
ool02?ooool00ol0003oooooooooo`0=ooooo`005_ooool00ol0003oooooooooo`06ooooo`Co0000
1oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0
>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0
1Oooool4o`0000oooooo000Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0>Ooo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Ooo
ool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool02?oo
ool00ol0003oooooooooo`0=ooooo`005?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool02?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o
003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o
003oooooooooool02?ooool00ol0003oooooooooo`0=ooooo`005?ooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo03Wooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooo
oooooooo03Wooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0=ooooo`005Oooool3
o`0000Oooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo03Wooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooo
oooo03Wooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0
003oooooooooo`08ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol0
0?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0>Oooool00ol0
0?ooooooooooo`08ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo00So
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo03Wo
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wo
oooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00So
oooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool02?ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0>Oooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?oooooo
ooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool02?ooool00ol0003ooooo
ooooo`0=ooooo`007oooool3o`0000Sooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0iooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0>Oooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?oooooooooo
o`0iooooo`03o`00oooooooooooo00Oooooo0_l0000?ooooo`007oooool00ol0003oooooooooo`08
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0i
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0i
ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`08
ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo00Sooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003ooooo
ooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool0>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00Sooooo00?o0000oooo
ooooool03Oooool001oooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo03Wooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0iooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03
o`00oooooooooooo03Wooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0=ooooo`00
7oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0
>Oooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oo
oooooooo00Sooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooo
oooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo03Wooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooo
oooooooo00Sooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool02?ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0>Oooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool0
0ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool02?ooool0
0ol0003oooooooooo`0=ooooo`007oooool3o`0000Sooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`0iooooo`;o003o>_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool0>Oooool2o`00oc[ooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo0_l00?ljooooo`03o`00oooooooooooo
00Oooooo0_l0000?ooooo`007oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool0>Oooool2o`00oc[ooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo0_l00?ljooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`;o003o>_ooool00ol00?oo
ooooooooo`08ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo00Sooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`1eooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`1eooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`1eooooo`03o`00oooooooooooo00Sooooo
00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool02?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo07Gooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo07Gooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo07Gooooo00?o003oooooooooool02?ooool00ol0003ooooooooo
o`0=ooooo`007oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool0MOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool0MOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool0MOooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00gooooo000Ooooo
o`03o`000?oooooooooo00Sooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1eoooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1eoooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1eoooo
o`03o`00oooooooooooo00Sooooo00?o0000ooooooooool03Oooool001oooooo00?o0000oooooooo
ool02?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo07Gooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo07Gooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo07Gooooo00?o003ooooooooo
ool02?ooool00ol0003oooooooooo`0=ooooo`007oooool3o`0000Sooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`1eooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`1eooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`1eooooo`03o`00oooooooooooo00Oooooo0_l0000?ooooo`007ooo
ool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0MOoo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0MOoo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0MOoo
ool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooo
oooo00Sooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1eooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1eooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1eooooo`03o`00oooooooo
oooo00Sooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool02?ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo07Gooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo07Gooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo07Gooooo00?o003oooooooooool02?ooool00ol0
003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool0MOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool0MOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool0MOooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00go
oooo000Fooooo`?o00001_ooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00cooooo
0_l00?mfooooo`;o003o3Oooool00ol00?ooooooooooo`0<ooooo`;o003oM_ooool2o`00o`gooooo
00?o003oooooooooool03?ooool2o`00ogKooooo0_l00?l9ooooo`03o`000?oooooooooo00gooooo
000Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol00?oooooooooo
o`0<ooooo`;o003oM_ooool2o`00o`gooooo00?o003oooooooooool03?ooool2o`00ogKooooo0_l0
0?l=ooooo`03o`00oooooooooooo00cooooo0_l00?mfooooo`;o003o2Oooool00ol0003ooooooooo
o`0=ooooo`005?ooool5o`0000Kooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`2C
ooooo`03o`00oooooooooooo09?ooooo00?o003oooooooooool0Soooool00ol0003oooooooooo`0=
ooooo`005?ooool01?l0003oooooooooool00007ooooo`Co00001oooool00ol00?ooooooooooo`2C
ooooo`03o`00oooooooooooo09?ooooo00?o003oooooooooool0S?ooool4o`0000oooooo000Eoooo
o`03o`000?oooooo000000Oooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`2Coooo
o`03o`00oooooooooooo09?ooooo00?o003oooooooooool0Soooool00ol0003oooooooooo`0=oooo
o`005_ooool2o`0000Oooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`2Cooooo`03
o`00oooooooooooo09?ooooo00?o003oooooooooool0Soooool00ol0003oooooooooo`0=ooooo`00
5oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool0
Toooool00ol00?ooooooooooo`2Cooooo`03o`00oooooooooooo08oooooo00?o0000ooooooooool0
3Oooool001oooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`2Cooooo`03o`00oooo
oooooooo09?ooooo00?o003oooooooooool0Soooool00ol0003oooooooooo`0=ooooo`007oooool0
0ol0003oooooooooo`08ooooo`03o`00oooooooooooo09?ooooo00?o003oooooooooool0Toooool0
0ol00?ooooooooooo`2?ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo
00Sooooo00?o003oooooooooool0Toooool00ol00?ooooooooooo`2Cooooo`03o`00oooooooooooo
08oooooo00?o0000ooooooooool03Oooool001oooooo0ol00008ooooo`03o`00oooooooooooo09?o
oooo00?o003oooooooooool0Toooool00ol00?ooooooooooo`2>ooooo`;o00003oooool001oooooo
00?o0000ooooooooool02?ooool00ol00?ooooooooooo`2Cooooo`03o`00oooooooooooo09?ooooo
00?o003oooooooooool0Soooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003ooooooooo
o`08ooooo`03o`00oooooooooooo09?ooooo00?o003oooooooooool0Toooool00ol00?oooooooooo
o`2?ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo00Sooooo00?o003o
ooooooooool0Toooool00ol00?ooooooooooo`2Cooooo`03o`00oooooooooooo08oooooo00?o0000
ooooooooool03Oooool001oooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`2Coooo
o`03o`00oooooooooooo09?ooooo00?o003oooooooooool0Soooool00ol0003oooooooooo`0=oooo
o`007oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo09?ooooo00?o003ooooooooo
ool0Toooool00ol00?ooooooooooo`2?ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`00
0?oooooooooo00Sooooo00?o003oooooooooool0Toooool00ol00?ooooooooooo`2Cooooo`03o`00
oooooooooooo08oooooo00?o0000ooooooooool03Oooool001oooooo0ol00008ooooo`03o`00oooo
oooooooo09?ooooo00?o003oooooooooool0Toooool00ol00?ooooooooooo`2>ooooo`;o00003ooo
ool001oooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`2Cooooo`03o`00oooooooo
oooo09?ooooo00?o003oooooooooool0Soooool00ol0003oooooooooo`0=ooooo`007oooool00ol0
003oooooooooo`08ooooo`03o`00oooooooooooo09?ooooo00?o003oooooooooool0Toooool00ol0
0?ooooooooooo`2?ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo00So
oooo00?o003oooooooooool0Toooool00ol00?ooooooooooo`2Cooooo`03o`00oooooooooooo08oo
oooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool02?ooool00ol00?oooooo
ooooo`2Cooooo`03o`00oooooooooooo09?ooooo00?o003oooooooooool0Soooool00ol0003ooooo
ooooo`0=ooooo`007oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo09?ooooo00?o
003oooooooooool0Toooool00ol00?ooooooooooo`2?ooooo`03o`000?oooooooooo00gooooo000O
ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool0Toooool00ol00?ooooooooooo`2C
ooooo`03o`00oooooooooooo08oooooo00?o0000ooooooooool03Oooool001oooooo00?o0000oooo
ooooool02?ooool00ol00?ooooooooooo`2Cooooo`03o`00oooooooooooo09?ooooo00?o003ooooo
ooooool0Soooool00ol0003oooooooooo`0=ooooo`007oooool3o`0000Sooooo00?o003ooooooooo
ool0Toooool00ol00?ooooooooooo`2Cooooo`03o`00oooooooooooo08kooooo0_l0000?ooooo`00
7oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo09?ooooo00?o003oooooooooool0
Toooool00ol00?ooooooooooo`2?ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oo
oooooooo00Sooooo00?o003oooooooooool0Toooool00ol00?ooooooooooo`2Cooooo`03o`00oooo
oooooooo08oooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool02?ooool0
0ol00?ooooooooooo`2Cooooo`03o`00oooooooooooo09?ooooo00?o003oooooooooool0Soooool0
0ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo
09?ooooo00?o003oooooooooool0Toooool00ol00?ooooooooooo`2?ooooo`03o`000?oooooooooo
00gooooo000Eooooo`?o00001oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo09?o
oooo00?o003oooooooooool0Toooool00ol00?ooooooooooo`2?ooooo`03o`000?oooooooooo00go
oooo000Dooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`08ooooo`03
o`00oooooooooooo09?ooooo00?o003oooooooooool0Toooool00ol00?ooooooooooo`2?ooooo`03
o`000?oooooooooo00gooooo000Dooooo`05o`000?ooooooooooooooool000001_ooool4o`0000Oo
oooo00?o003oooooooooool0Toooool00ol00?ooooooooooo`2Cooooo`03o`00oooooooooooo08co
oooo1?l0000?ooooo`005?ooool4o`0000Oooooo00?o0000ooooooooool02?ooool00ol00?oooooo
ooooo`2Cooooo`03o`00oooooooooooo09?ooooo00?o003oooooooooool0Soooool00ol0003ooooo
ooooo`0=ooooo`005?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o
003oooooooooool0Toooool00ol00?ooooooooooo`2Cooooo`03o`00oooooooooooo08oooooo00?o
0000ooooooooool03Oooool001Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`00oooooooooooo09?ooooo00?o003oooooooooool0Toooool00ol00?ooooooooooo`2?
ooooo`03o`000?oooooooooo00gooooo000Fooooo`;o00001oooool00ol0003oooooooooo`08oooo
o`03o`00oooooooooooo09?ooooo00?o003oooooooooool0Toooool00ol00?ooooooooooo`2?oooo
o`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo00Sooooo00?o003ooooooooo
ool0Toooool00ol00?ooooooooooo`2Cooooo`03o`00oooooooooooo08oooooo00?o0000oooooooo
ool03Oooool001oooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`2Cooooo`03o`00
oooooooooooo09?ooooo00?o003oooooooooool0Soooool00ol0003oooooooooo`0=ooooo`007ooo
ool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo09?ooooo00?o003oooooooooool0Tooo
ool00ol00?ooooooooooo`2?ooooo`03o`000?oooooooooo00gooooo000Oooooo`?o00002?ooool0
0ol00?ooooooooooo`2Cooooo`03o`00oooooooooooo09?ooooo00?o003oooooooooool0S_ooool2
o`0000oooooo000Oooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool0Toooool00ol0
0?ooooooooooo`2Cooooo`03o`00oooooooooooo08oooooo00?o0000ooooooooool03Oooool001oo
oooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`2Cooooo`03o`00oooooooooooo09?o
oooo00?o003oooooooooool0Soooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003ooooo
ooooo`08ooooo`03o`00oooooooooooo09?ooooo00?o003oooooooooool0Toooool00ol00?oooooo
ooooo`2?ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo00Sooooo00?o
003oooooooooool0Toooool00ol00?ooooooooooo`2Cooooo`03o`00oooooooooooo08oooooo00?o
0000ooooooooool03Oooool001oooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`2C
ooooo`03o`00oooooooooooo09?ooooo00?o003oooooooooool0Soooool00ol0003oooooooooo`0=
ooooo`007oooool00ol0003oooooooooo`08ooooo`;o003oU?ooool2o`00oiCooooo0_l00?n@oooo
o`03o`000?oooooooooo00gooooo000Oooooo`?o00002?ooool2o`00oiCooooo0_l00?nDooooo`;o
003oSoooool2o`0000oooooo000Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0
3Oooool001oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`007ooooooo
o`000<_o00003oooool00001\
\>"],
  ImageRangeCache->{{{0, 503}, {167, 0}} -> {-2.84841, -4.09998, 0.0666496, \
0.0679418}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Magnitude plot of DTFT as a function of frequency", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(X\[Theta]\  = DTFT[xd, \[Theta]]\  // \ Simplify; 
    g1 = Plot[
        Abs[X\[Theta]\  /. \ \[Theta] \[Rule] \ 2  \[Pi]\ f/fs], {f, \(-fs\)/
            2, fs/2}, \ PlotStyle \[Rule] {Blue, \ Dashing[{ .01}]}, \ 
        PlotRange \[Rule] All, PlotPoints \[Rule] 200];\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.0147151 0.00967843 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1115 -12 -4.5 ]
[-0.0125 .1115 0 4.5 ]
[-0.0125 .20828 -12 -4.5 ]
[-0.0125 .20828 0 4.5 ]
[-0.0125 .30507 -12 -4.5 ]
[-0.0125 .30507 0 4.5 ]
[-0.0125 .40185 -12 -4.5 ]
[-0.0125 .40185 0 4.5 ]
[-0.0125 .49864 -12 -4.5 ]
[-0.0125 .49864 0 4.5 ]
[-0.0125 .59542 -12 -4.5 ]
[-0.0125 .59542 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1115 m
.00625 .1115 L
s
[(10)] -0.0125 .1115 1 0 Mshowa
0 .20828 m
.00625 .20828 L
s
[(20)] -0.0125 .20828 1 0 Mshowa
0 .30507 m
.00625 .30507 L
s
[(30)] -0.0125 .30507 1 0 Mshowa
0 .40185 m
.00625 .40185 L
s
[(40)] -0.0125 .40185 1 0 Mshowa
0 .49864 m
.00625 .49864 L
s
[(50)] -0.0125 .49864 1 0 Mshowa
0 .59542 m
.00625 .59542 L
s
[(60)] -0.0125 .59542 1 0 Mshowa
.125 Mabswid
0 .03407 m
.00375 .03407 L
s
0 .05343 m
.00375 .05343 L
s
0 .07279 m
.00375 .07279 L
s
0 .09214 m
.00375 .09214 L
s
0 .13086 m
.00375 .13086 L
s
0 .15021 m
.00375 .15021 L
s
0 .16957 m
.00375 .16957 L
s
0 .18893 m
.00375 .18893 L
s
0 .22764 m
.00375 .22764 L
s
0 .247 m
.00375 .247 L
s
0 .26635 m
.00375 .26635 L
s
0 .28571 m
.00375 .28571 L
s
0 .32442 m
.00375 .32442 L
s
0 .34378 m
.00375 .34378 L
s
0 .36314 m
.00375 .36314 L
s
0 .3825 m
.00375 .3825 L
s
0 .42121 m
.00375 .42121 L
s
0 .44057 m
.00375 .44057 L
s
0 .45992 m
.00375 .45992 L
s
0 .47928 m
.00375 .47928 L
s
0 .51799 m
.00375 .51799 L
s
0 .53735 m
.00375 .53735 L
s
0 .55671 m
.00375 .55671 L
s
0 .57606 m
.00375 .57606 L
s
0 .61478 m
.00375 .61478 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1115 m
1 .1115 L
s
.99375 .20828 m
1 .20828 L
s
.99375 .30507 m
1 .30507 L
s
.99375 .40185 m
1 .40185 L
s
.99375 .49864 m
1 .49864 L
s
.99375 .59542 m
1 .59542 L
s
.125 Mabswid
.99625 .03407 m
1 .03407 L
s
.99625 .05343 m
1 .05343 L
s
.99625 .07279 m
1 .07279 L
s
.99625 .09214 m
1 .09214 L
s
.99625 .13086 m
1 .13086 L
s
.99625 .15021 m
1 .15021 L
s
.99625 .16957 m
1 .16957 L
s
.99625 .18893 m
1 .18893 L
s
.99625 .22764 m
1 .22764 L
s
.99625 .247 m
1 .247 L
s
.99625 .26635 m
1 .26635 L
s
.99625 .28571 m
1 .28571 L
s
.99625 .32442 m
1 .32442 L
s
.99625 .34378 m
1 .34378 L
s
.99625 .36314 m
1 .36314 L
s
.99625 .3825 m
1 .3825 L
s
.99625 .42121 m
1 .42121 L
s
.99625 .44057 m
1 .44057 L
s
.99625 .45992 m
1 .45992 L
s
.99625 .47928 m
1 .47928 L
s
.99625 .51799 m
1 .51799 L
s
.99625 .53735 m
1 .53735 L
s
.99625 .55671 m
1 .55671 L
s
.99625 .57606 m
1 .57606 L
s
.99625 .61478 m
1 .61478 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .01472 m
.02847 .04487 L
.03089 .05844 L
.03218 .06466 L
.03355 .07042 L
.03484 .07492 L
.03602 .07816 L
.03659 .07942 L
.0372 .08055 L
.03779 .0814 L
.03832 .08199 L
.03862 .08223 L
.03888 .0824 L
.03903 .08248 L
.03919 .08254 L
.03935 .08258 L
.03949 .08261 L
.03963 .08263 L
.03977 .08263 L
.03989 .08262 L
.04002 .0826 L
.04016 .08256 L
.04031 .08251 L
.04058 .08238 L
.04088 .08218 L
.04119 .0819 L
.04177 .08123 L
.04245 .08016 L
.04307 .07893 L
.04426 .07586 L
.04537 .07227 L
.04787 .06166 L
.05032 .04851 L
.05261 .03434 L
.05368 .02734 L
.0548 .01982 L
.05509 .01789 L
.05539 .01584 L
.05548 .01523 L
.05556 .01477 L
.05572 .01585 L
.05603 .01795 L
.05716 .02556 L
.0618 .05453 L
.06415 .06646 L
.0654 .07171 L
.06674 .07639 L
.06802 .07988 L
.06919 .08215 L
.06976 .08293 L
Mistroke
.07005 .08325 L
.07037 .08354 L
.07068 .08374 L
.07095 .08387 L
.07108 .08392 L
.07123 .08396 L
.07136 .08398 L
.07149 .08399 L
.07164 .08398 L
.07179 .08396 L
.07192 .08393 L
.07206 .08389 L
.07221 .08383 L
.07237 .08374 L
.07267 .08355 L
.07319 .08305 L
.07376 .08229 L
.07438 .08123 L
.07505 .07981 L
.07626 .07652 L
.07868 .06729 L
.08123 .0543 L
.08364 .0396 L
.08583 .02494 L
.08641 .0209 L
.08672 .01875 L
.08705 .01649 L
.08719 .01553 L
.08733 .01493 L
.08742 .01553 L
.08749 .01606 L
.08765 .01712 L
.0882 .02097 L
.09073 .03826 L
.09322 .05399 L
.09553 .06656 L
.09777 .07625 L
.0989 .08006 L
.09951 .08177 L
.10015 .08332 L
.10073 .08449 L
.10136 .08551 L
.10164 .08587 L
.10194 .08619 L
.10222 .08644 L
.10248 .08662 L
.10263 .08671 L
.1028 .08678 L
.10297 .08684 L
.10307 .08686 L
Mistroke
.10315 .08687 L
.10324 .08688 L
.10331 .08689 L
.10346 .08688 L
.10362 .08686 L
.10371 .08684 L
.10379 .08681 L
.10395 .08676 L
.1041 .08669 L
.10437 .08651 L
.10467 .08627 L
.10499 .08593 L
.10558 .08512 L
.10614 .08414 L
.1074 .08114 L
.10862 .07722 L
.10994 .07197 L
.11493 .04393 L
.11614 .03567 L
.11743 .02654 L
.11796 .02271 L
.11853 .01855 L
.11868 .01738 L
.11885 .01616 L
.11899 .01511 L
.11915 .01547 L
.1193 .01655 L
.11945 .01771 L
.11974 .01979 L
.12436 .05244 L
.12677 .06697 L
.12803 .07355 L
.12937 .07954 L
.13057 .08397 L
.1312 .08594 L
.13188 .08775 L
.1325 .08912 L
.13308 .09013 L
.13335 .09053 L
.13365 .09091 L
.13393 .0912 L
.13419 .09142 L
.1345 .09161 L
.13467 .09168 L
.13475 .09171 L
.13484 .09174 L
.13499 .09177 L
.13513 .09178 L
.13521 .09178 L
.13529 .09178 L
Mistroke
.13544 .09175 L
.13558 .09172 L
.13572 .09167 L
.13585 .09161 L
.13598 .09154 L
.13629 .09132 L
.13657 .09105 L
.13721 .09023 L
.13779 .08921 L
.1391 .08601 L
.14029 .08206 L
.14139 .07754 L
.14389 .0645 L
.14861 .03186 L
.14985 .02221 L
.15019 .01952 L
.15037 .01805 L
.15055 .01667 L
.1507 .0155 L
.15085 .0152 L
.15094 .01592 L
.15103 .0166 L
.15119 .01788 L
.15362 .03715 L
.15824 .07011 L
.16063 .08338 L
.16185 .08881 L
.16316 .09351 L
.16376 .09522 L
.16439 .09673 L
.16497 .09785 L
.16551 .09865 L
.16577 .09895 L
.16602 .09918 L
.16615 .09929 L
.1663 .09939 L
.16644 .09946 L
.16656 .09952 L
.1667 .09956 L
.16685 .0996 L
.167 .09961 L
.16708 .09961 L
.16716 .09961 L
.1673 .09958 L
.16744 .09954 L
.16758 .09949 L
.16771 .09942 L
.16803 .0992 L
.16833 .09892 L
.16899 .09803 L
Mistroke
.16957 .09695 L
.17019 .0955 L
.17126 .09225 L
.17244 .08766 L
.17479 .07542 L
.17732 .0584 L
.17971 .0394 L
.18097 .0286 L
.18166 .02253 L
.182 .01953 L
.18215 .01821 L
.18231 .01677 L
.18245 .01548 L
.18259 .01515 L
.18273 .01642 L
.18288 .01778 L
.1835 .02331 L
.18481 .03505 L
.18712 .05512 L
.18952 .07421 L
.19213 .09153 L
.19335 .09811 L
.19464 .10383 L
.19574 .10762 L
.19632 .10919 L
.19696 .11055 L
.19728 .11112 L
.19759 .11156 L
.19787 .11189 L
.19802 .11203 L
.19818 .11216 L
.19833 .11226 L
.19846 .11233 L
.19859 .11238 L
.19873 .11242 L
.19887 .11244 L
.199 .11245 L
.19915 .11243 L
.19931 .11239 L
.19939 .11236 L
.19947 .11232 L
.19963 .11223 L
.1998 .11211 L
.19998 .11195 L
.20032 .11157 L
.20063 .11112 L
.2012 .11004 L
.20183 .10852 L
.20305 .10448 L
.20438 .09852 L
Mistroke
.2068 .08376 L
.20937 .06328 L
.2117 .04138 L
.21287 .02955 L
.21348 .02317 L
.21382 .01965 L
.21398 .01792 L
.21413 .01634 L
.21427 .01485 L
.21441 .016 L
.2147 .01913 L
.21532 .02579 L
.21642 .03753 L
.22105 .08437 L
.22338 .10425 L
.22463 .1132 L
.22596 .12136 L
.22724 .12756 L
.2278 .12975 L
.22841 .13176 L
.22895 .13321 L
.22953 .1344 L
.22984 .13489 L
.23013 .13524 L
.23027 .13537 L
.23043 .13549 L
.23057 .13558 L
.2307 .13564 L
.23085 .13568 L
.231 .1357 L
.23112 .13569 L
.23127 .13566 L
.23142 .13561 L
.2315 .13556 L
.23158 .13551 L
.23187 .13527 L
.23214 .13495 L
.23243 .13451 L
.23296 .13345 L
.2336 .13175 L
.23426 .12945 L
.23545 .12401 L
.2366 .11723 L
.23783 .10835 L
.24004 .08838 L
.24244 .06177 L
.2437 .04604 L
.24439 .03703 L
.24504 .02836 L
.24561 .02055 L
Mistroke
.24577 .01827 L
.24593 .0161 L
.24607 .01528 L
.24623 .01743 L
.24754 .03591 L
.24985 .06879 L
.25242 .10407 L
.25475 .1331 L
.2572 .15874 L
.25946 .17634 L
.26059 .18256 L
.26116 .185 L
.26178 .1871 L
.2621 .18795 L
.26241 .1886 L
.26258 .1889 L
.26276 .18916 L
.26291 .18935 L
.26308 .1895 L
.26324 .18961 L
.26339 .18967 L
.26354 .18969 L
.26363 .18969 L
.26371 .18967 L
.26385 .18962 L
.26399 .18953 L
.26415 .18939 L
.26429 .18923 L
.26461 .18874 L
.2649 .18814 L
.26556 .18623 L
.26614 .18391 L
.26676 .18079 L
.26783 .17378 L
.269 .16369 L
.27134 .1362 L
.27386 .09614 L
.27624 .04918 L
.27689 .03493 L
.27725 .02687 L
.27743 .02286 L
.27759 .01914 L
.27774 .01558 L
.27782 .01566 L
.2779 .01764 L
.27824 .02572 L
.27884 .04011 L
.28363 .16731 L
.28851 .30479 L
.2932 .42755 L
Mistroke
.2956 .4813 L
.2982 .53027 L
.29941 .54921 L
.30069 .56639 L
.3019 .57961 L
.303 .58921 L
.30414 .5965 L
.30473 .59928 L
.30503 .60041 L
.30535 .60142 L
.30564 .60213 L
.3059 .60264 L
.30603 .60283 L
.30616 .603 L
.30629 .60313 L
.30641 .60322 L
.30655 .60329 L
.30667 .60332 L
.30682 .60331 L
.30697 .60326 L
.30713 .60315 L
.30728 .603 L
.30741 .60283 L
.30756 .6026 L
.30787 .60198 L
.3082 .60109 L
.30881 .59891 L
.3094 .5961 L
.30994 .59293 L
.31117 .58364 L
.31247 .57084 L
.31485 .54008 L
.31706 .50386 L
.32176 .40868 L
.32676 .29324 L
.33158 .18349 L
.33621 .09135 L
.33855 .05237 L
.3398 .0341 L
.34048 .02476 L
.34082 .02035 L
.34099 .01825 L
.34114 .01637 L
.34129 .01495 L
.34143 .0167 L
.34175 .02048 L
.34242 .02809 L
.34359 .04023 L
.34588 .05961 L
.34706 .06739 L
Mistroke
.3483 .07409 L
.34936 .07865 L
.35053 .08252 L
.35116 .08414 L
.35176 .0854 L
.3523 .08629 L
.35288 .08703 L
.35318 .08732 L
.35352 .08757 L
.35369 .08767 L
.35387 .08776 L
.35404 .08782 L
.35419 .08786 L
.35434 .08789 L
.35447 .0879 L
.35462 .0879 L
.35478 .08789 L
.35486 .08788 L
.35495 .08786 L
.35511 .08782 L
.35526 .08777 L
.3554 .08771 L
.3557 .08755 L
.35597 .08736 L
.35657 .08681 L
.35713 .08614 L
.35767 .08536 L
.35886 .0832 L
.36016 .08018 L
.36253 .07305 L
.36506 .06321 L
.36748 .05153 L
.37008 .03606 L
.37131 .02766 L
.37198 .02275 L
.37231 .02027 L
.37261 .01796 L
.37274 .01693 L
.37288 .0158 L
.37302 .01472 L
.37314 .01571 L
.37371 .02042 L
.37492 .03097 L
.37966 .07907 L
.38422 .13306 L
.38908 .19272 L
.39375 .24458 L
.39612 .26634 L
.39738 .27618 L
.39872 .28523 L
Mistroke
.40002 .2925 L
.4012 .29772 L
.40177 .29976 L
.40238 .30159 L
.40292 .30289 L
.4035 .30395 L
.40381 .30437 L
.40409 .30468 L
.40423 .30479 L
.40438 .3049 L
.40452 .30498 L
.40464 .30503 L
.40479 .30507 L
.40493 .30509 L
.40509 .30509 L
.40517 .30508 L
.40525 .30506 L
.4054 .30501 L
.40549 .30497 L
.40557 .30492 L
.40573 .30482 L
.4059 .30467 L
.40623 .3043 L
.40654 .30386 L
.40713 .30275 L
.40781 .30102 L
.40844 .29901 L
.40961 .29426 L
.4107 .28864 L
.41319 .27187 L
.41787 .22783 L
.42284 .16938 L
.42763 .10982 L
.43224 .05643 L
.43461 .03213 L
.4353 .02563 L
.43594 .01974 L
.43622 .01723 L
.43637 .01588 L
.43652 .0148 L
.43667 .01614 L
.43684 .0176 L
.43714 .02012 L
.44184 .05307 L
.4444 .06576 L
.44558 .07036 L
.44683 .07441 L
.44797 .07738 L
.44858 .07868 L
.44923 .07986 L
Mistroke
.44983 .08075 L
.45038 .0814 L
.4509 .08188 L
.45116 .08206 L
.45145 .08223 L
.45176 .08235 L
.45193 .08241 L
.45209 .08244 L
.45223 .08246 L
.45238 .08247 L
.45246 .08246 L
.45254 .08246 L
.45269 .08245 L
.45284 .08242 L
.45299 .08238 L
.45314 .08233 L
.45328 .08227 L
.45354 .08214 L
.45382 .08196 L
.4545 .08135 L
.45514 .08055 L
.45635 .07848 L
.45753 .0757 L
.45877 .07195 L
.461 .06309 L
.46338 .05057 L
.46559 .03597 L
.46686 .02637 L
.46748 .02132 L
.46775 .01904 L
.4679 .01781 L
.46805 .01647 L
.46819 .01526 L
.46832 .01529 L
.46845 .01643 L
.46857 .01752 L
.46913 .02251 L
.47029 .03355 L
.4749 .08314 L
.4798 .1427 L
.48451 .20027 L
.48692 .22737 L
.48953 .25348 L
.49183 .27289 L
.49313 .28211 L
.49436 .28941 L
.49561 .29554 L
.49676 .29984 L
.49739 .30167 L
.49798 .30304 L
Mistroke
.49861 .30411 L
.49897 .30454 L
.49913 .30469 L
.4993 .30482 L
.49944 .30491 L
.49959 .30498 L
.49973 .30503 L
.49986 .30506 L
.50001 .30507 L
.50015 .30506 L
.50022 .30504 L
.50031 .30502 L
.50046 .30496 L
.50059 .30489 L
.50073 .3048 L
.50102 .30454 L
.50129 .30423 L
.50155 .30387 L
.50217 .30271 L
.50275 .30131 L
.50403 .29701 L
.50522 .29164 L
.50632 .28551 L
.50883 .26779 L
.51355 .22229 L
.51857 .16302 L
.5234 .10332 L
.52806 .05032 L
.53047 .02631 L
.53105 .0209 L
.53137 .01801 L
.53153 .0166 L
.53168 .01531 L
.53176 .01485 L
.53185 .01562 L
.53204 .01723 L
.53237 .02001 L
.53301 .02527 L
.53756 .05592 L
.5399 .06702 L
.5411 .07153 L
.54242 .07555 L
.54367 .07851 L
.54484 .08052 L
.54548 .08133 L
.54607 .08187 L
.54639 .0821 L
.54656 .0822 L
.54674 .08228 L
.5469 .08235 L
Mistroke
.54708 .0824 L
.54723 .08243 L
.54738 .08245 L
.54753 .08246 L
.54761 .08247 L
.5477 .08246 L
.54784 .08245 L
.54798 .08242 L
.54806 .08241 L
.54815 .08238 L
.5483 .08233 L
.54864 .08218 L
.54893 .082 L
.54921 .08179 L
.54983 .08117 L
.5504 .08044 L
.55091 .07962 L
.55207 .07729 L
.55327 .07413 L
.55438 .07052 L
.55689 .05986 L
.55914 .04722 L
.56044 .03863 L
.56163 .02993 L
.56221 .02544 L
.56283 .02033 L
.56312 .01793 L
.56328 .01659 L
.56342 .01531 L
.56356 .01532 L
.56371 .01663 L
.56397 .01895 L
.56649 .0431 L
.57144 .09851 L
.5762 .15742 L
.58078 .21275 L
.58333 .24039 L
.58565 .26236 L
.58809 .28116 L
.59035 .29405 L
.59146 .29867 L
.59203 .30056 L
.59265 .30224 L
.59326 .30353 L
.59354 .30398 L
.59384 .30439 L
.59417 .30474 L
.59436 .30488 L
.59452 .30498 L
.59468 .30504 L
Mistroke
.59483 .30508 L
.59491 .30509 L
.595 .3051 L
.59515 .30508 L
.5953 .30505 L
.59544 .305 L
.59559 .30492 L
.59574 .30482 L
.59601 .30458 L
.59629 .30424 L
.59695 .30316 L
.59755 .30177 L
.59878 .29782 L
.60009 .29198 L
.60268 .27579 L
.60511 .25553 L
.60977 .20639 L
.61472 .14615 L
.61949 .08869 L
.62407 .04028 L
.62528 .02911 L
.62643 .01924 L
.62674 .01671 L
.62689 .01545 L
.62698 .01474 L
.62706 .01535 L
.62742 .01818 L
.62775 .02073 L
.62895 .02954 L
.63363 .05717 L
.63605 .06783 L
.6386 .07669 L
.63975 .07994 L
.64098 .08286 L
.64214 .08506 L
.6432 .08655 L
.64378 .08716 L
.64411 .08742 L
.64441 .08761 L
.64466 .08774 L
.64479 .08779 L
.64493 .08784 L
.64509 .08787 L
.64524 .08789 L
.64538 .0879 L
.64552 .0879 L
.64566 .08789 L
.64581 .08786 L
.64596 .08782 L
.64609 .08777 L
Mistroke
.64641 .08762 L
.64673 .08739 L
.64705 .0871 L
.64735 .08676 L
.64803 .08577 L
.64863 .0846 L
.64929 .083 L
.65049 .0792 L
.65166 .07428 L
.65273 .06862 L
.65499 .05291 L
.65629 .0414 L
.65748 .02923 L
.65806 .02278 L
.65836 .01922 L
.65853 .01722 L
.65868 .01531 L
.65883 .01597 L
.65892 .01702 L
.65899 .01799 L
.65927 .02159 L
.65982 .02887 L
.66234 .06657 L
.66711 .15553 L
.67169 .25706 L
.67657 .37093 L
.68126 .47234 L
.68365 .51628 L
.68625 .55547 L
.68747 .57014 L
.68875 .58297 L
.68985 .59155 L
.69043 .59516 L
.69106 .59836 L
.69166 .60065 L
.69198 .60161 L
.69228 .60231 L
.69243 .60258 L
.69256 .6028 L
.69269 .60296 L
.69282 .60311 L
.69296 .60322 L
.6931 .60329 L
.69324 .60332 L
.6934 .60331 L
.69348 .60328 L
.69357 .60324 L
.69365 .60318 L
.69372 .60312 L
.69387 .60297 L
Mistroke
.69402 .60276 L
.69438 .60209 L
.6947 .60127 L
.69532 .59905 L
.69591 .59624 L
.6971 .58845 L
.69834 .5772 L
.70057 .54952 L
.70295 .5101 L
.70516 .46514 L
.70986 .34934 L
.71486 .2099 L
.71736 .13979 L
.71967 .07779 L
.72083 .04825 L
.7214 .03428 L
.72192 .0218 L
.72206 .01863 L
.7222 .0152 L
.72234 .01745 L
.72247 .02042 L
.72306 .03378 L
.72431 .06069 L
.72657 .10377 L
.72902 .14113 L
.73037 .15722 L
.7316 .16919 L
.73279 .17806 L
.73344 .18188 L
.73404 .18469 L
.73462 .18684 L
.73518 .18832 L
.73548 .1889 L
.73577 .1893 L
.73591 .18945 L
.73608 .18957 L
.73616 .18962 L
.73625 .18966 L
.7364 .18969 L
.73654 .18968 L
.73667 .18965 L
.73681 .18958 L
.73697 .18946 L
.73713 .1893 L
.73728 .18911 L
.73756 .18866 L
.73807 .18752 L
.73862 .18583 L
.73976 .18084 L
.74101 .17318 L
Mistroke
.74355 .15152 L
.74841 .09293 L
.75065 .06168 L
.75184 .04483 L
.75309 .02695 L
.75345 .02191 L
.75363 .01946 L
.75379 .0172 L
.75394 .01515 L
.75409 .01643 L
.75425 .01859 L
.75442 .02094 L
.75565 .03751 L
.75807 .06778 L
.76063 .0949 L
.76295 .11418 L
.76411 .1216 L
.76537 .12793 L
.76594 .13021 L
.76655 .1322 L
.76707 .13354 L
.76765 .13465 L
.76793 .13505 L
.76824 .13538 L
.7684 .1355 L
.76849 .13555 L
.76857 .1356 L
.76873 .13566 L
.76887 .13569 L
.76901 .1357 L
.76915 .13568 L
.76927 .13565 L
.76941 .13559 L
.76955 .13551 L
.76971 .13539 L
.76999 .13511 L
.77031 .13467 L
.77066 .13405 L
.7713 .13258 L
.77193 .13071 L
.7725 .12861 L
.77475 .1172 L
.77723 .09935 L
.77976 .07677 L
.78208 .0534 L
.78435 .02931 L
.7849 .02341 L
.7852 .02017 L
.78549 .01712 L
.78557 .01628 L
Mistroke
.78565 .01539 L
.78574 .01501 L
.78583 .01591 L
.78614 .01917 L
.78674 .02549 L
.7913 .06907 L
.79364 .08682 L
.79616 .10112 L
.79738 .10605 L
.79803 .1081 L
.79871 .10985 L
.79905 .11056 L
.79937 .11111 L
.79968 .11157 L
.79997 .1119 L
.80024 .11214 L
.80038 .11224 L
.80053 .11232 L
.80068 .11239 L
.80077 .11241 L
.80084 .11243 L
.80099 .11245 L
.80114 .11244 L
.80127 .11242 L
.80142 .11238 L
.80156 .11232 L
.80169 .11225 L
.80199 .11202 L
.8023 .1117 L
.80289 .11083 L
.80354 .10952 L
.80469 .10625 L
.80576 .10219 L
.80823 .08941 L
.81047 .07425 L
.81298 .05428 L
.81529 .03414 L
.81646 .02371 L
.81675 .02108 L
.81703 .01859 L
.81728 .01636 L
.81742 .0151 L
.81755 .01549 L
.81769 .01674 L
.81781 .01786 L
.8181 .02038 L
.81868 .02557 L
.81993 .03638 L
.82246 .0567 L
.82477 .07276 L
Mistroke
.82704 .08528 L
.82818 .0902 L
.82943 .09445 L
.83006 .09613 L
.83066 .09742 L
.8312 .09833 L
.83151 .09873 L
.83179 .09904 L
.83209 .0993 L
.83225 .0994 L
.83243 .09949 L
.83251 .09953 L
.83261 .09956 L
.8327 .09958 L
.83278 .0996 L
.83293 .09961 L
.83302 .09961 L
.8331 .0996 L
.83326 .09958 L
.8334 .09953 L
.83356 .09946 L
.83372 .09937 L
.83401 .09916 L
.83431 .09886 L
.83494 .09799 L
.83554 .09688 L
.83666 .09404 L
.83787 .08992 L
.83919 .08428 L
.8441 .05429 L
.84654 .03586 L
.84774 .02642 L
.84826 .02225 L
.84854 .02004 L
.84883 .01768 L
.84898 .01649 L
.84912 .01537 L
.84925 .01506 L
.84939 .01615 L
.8499 .02023 L
.85102 .02903 L
.85338 .04666 L
.85573 .06225 L
.85832 .07621 L
.8595 .08126 L
.86077 .08564 L
.86139 .08735 L
.86197 .08872 L
.86253 .08981 L
.86307 .09062 L
Mistroke
.86336 .09097 L
.86367 .09128 L
.86396 .0915 L
.86422 .09165 L
.86437 .0917 L
.86451 .09174 L
.86466 .09177 L
.86475 .09178 L
.86482 .09178 L
.86498 .09177 L
.86507 .09176 L
.86515 .09174 L
.8653 .0917 L
.86546 .09163 L
.86572 .09148 L
.866 .09126 L
.86651 .09071 L
.86712 .08981 L
.86768 .08875 L
.86886 .08577 L
.86996 .08213 L
.87246 .07111 L
.87717 .04209 L
.87841 .03332 L
.87975 .02357 L
.88036 .01905 L
.88053 .01785 L
.8807 .01657 L
.88078 .01595 L
.88086 .01536 L
.88101 .01517 L
.88115 .01618 L
.88128 .01712 L
.88157 .01924 L
.88218 .0237 L
.88691 .05554 L
.8895 .06942 L
.89068 .07459 L
.89193 .07912 L
.89309 .08244 L
.89371 .08383 L
.89436 .08503 L
.89497 .08588 L
.89552 .08643 L
.89578 .08662 L
.89592 .0867 L
.89607 .08676 L
.8962 .08681 L
.89634 .08685 L
.89647 .08687 L
Mistroke
.89659 .08688 L
.89674 .08688 L
.89683 .08688 L
.8969 .08686 L
.89705 .08683 L
.89719 .08678 L
.89736 .08671 L
.89751 .08663 L
.89784 .08639 L
.89812 .08613 L
.89842 .08579 L
.89903 .08491 L
.90019 .08254 L
.90127 .07955 L
.90372 .0701 L
.90596 .05871 L
.90846 .04361 L
.91077 .02815 L
.91132 .0243 L
.91192 .02013 L
.9122 .01821 L
.91235 .01716 L
.91249 .01618 L
.91261 .01534 L
.91274 .01498 L
.91288 .01597 L
.91301 .01687 L
.91414 .02472 L
.91539 .0332 L
.9179 .04919 L
.92021 .062 L
.92246 .07206 L
.92361 .07612 L
.92485 .07957 L
.92548 .08097 L
.92608 .08206 L
.92662 .08283 L
.92693 .08318 L
.92721 .08344 L
.9275 .08366 L
.92777 .08382 L
.92791 .08388 L
.92805 .08392 L
.9282 .08396 L
.92836 .08398 L
.92848 .08399 L
.92862 .08398 L
.92875 .08396 L
.92886 .08393 L
.929 .08389 L
Mistroke
.92915 .08383 L
.92942 .08368 L
.9297 .08348 L
.93001 .0832 L
.93056 .08253 L
.93121 .08147 L
.93181 .08027 L
.93304 .07706 L
.93434 .07269 L
.93673 .06228 L
.93895 .05027 L
.94121 .03629 L
.9424 .02848 L
.94366 .02002 L
.94397 .01793 L
.94414 .01678 L
.9443 .01569 L
.94439 .01508 L
.94449 .01502 L
.94458 .01563 L
.94466 .0162 L
.945 .01849 L
.94624 .02679 L
.94867 .04244 L
.95111 .05649 L
.9534 .06748 L
.95559 .07544 L
.95682 .07868 L
.95795 .08083 L
.95852 .0816 L
.95884 .08193 L
.95913 .08219 L
.95941 .08237 L
.95955 .08245 L
.95971 .08252 L
.95984 .08256 L
.95998 .0826 L
.96011 .08262 L
.96023 .08263 L
.96038 .08263 L
.96047 .08262 L
.96055 .08261 L
.9607 .08257 L
.96086 .08252 L
.96101 .08245 L
.96116 .08238 L
.96143 .08219 L
.96176 .08191 L
.96205 .08159 L
.96273 .08066 L
Mistroke
.96329 .07965 L
.9639 .07834 L
.965 .0754 L
.96749 .06614 L
.97005 .05339 L
.97248 .03903 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<oooool3o`0002kooooo1Ol0000]ooooo`;o0000;_ooool5o`00033ooooo0ol0000Roooo
o`00=?ooool00ol0003oooooooooo`0^ooooo`04o`000?ooooooooooo`0002cooooo00Co0000oooo
oooooooo0000;_ooool01?l0003oooooooooool0000aooooo`03o`000?oooooooooo027ooooo000[
ooooo`Go000000?oooooo`000?l000000ol0000Xooooo`Go00000oooool00ol0003oooooooooo`0/
ooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool0;_ooool5o`0002;ooooo000a
ooooo`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool0:oooool01?l0003ooooooooo
ool0000`ooooo`03o`000?oooooooooo02gooooo00Co0000oooooooooooo00008oooool003;ooooo
00?o0000ooooool00000;oooool01Ol0003ooooooooooooooooo000002cooooo00Co0000oooooooo
oooo0000;Oooool01Ol0003ooooooooooooooooo000002oooooo00?o0000ooooool000008oooool0
03?ooooo0_l0000_ooooo`05o`000?ooooooooooooooool00000;?ooool01?l0003oooooooooool0
000]ooooo`05o`000?ooooooooooooooool00000<?ooool2o`0002?ooooo000dooooo`03o`000?oo
oooooooo02kooooo0ol0000^ooooo`;o0000;oooool3o`0003;ooooo00?o0000ooooooooool08Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0017oooooool0
000=o`0000?ooooo000:ooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo007ooooo0009ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00Oooool0
00Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`23ooooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool3
o`0001gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00kooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`000?oooooo
oooo01kooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooo
oooo00[ooooo0ol00003ooooo`002Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00cooooo00?o003oooooooooool01Oooool2o`00o`Oooooo00?o003oooooooooool01Oooool2
o`00o`Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00gooooo0_l00?l7ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`04ooooo`03o`000?oooooooooo007ooooo0009ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Gooooo0_l00?l7ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`05ooooo`;o003o1oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo01Kooooo0_l00?lHooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol00?ooooooooooo`05ooooo`;o003o3oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0>ooooo`;o003o1oooool0
0ol00?ooooooooooo`05ooooo`;o003o1oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o0000ooooooooool00Oooool000[ooooo0_l00005ooooo`03o`000?oooooooooo
00Cooooo00?o003oooooooooool01Oooool2o`00o`Kooooo0_l00?l7ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`;o003o1oooool00ol0
0?ooooooooooo`05ooooo`;o003o6?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`05ooooo`;o003o4?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`0>ooooo`;o003o1oooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool2o`00
o`Oooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`04ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01?ooool2o`00o`Oo
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`;o003o3oooool2o`00o`Oo
oooo00?o003oooooooooool03Oooool2o`00o`Oooooo00?o003oooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`00oooooooooooo00Gooooo0_l00?l@ooooo`03o`00oooooooooooo00Co
oooo0_l00?l@ooooo`03o`00oooooooooooo00Gooooo0_l00?l7ooooo`03o`00oooooooooooo00Go
oooo0_l00?l6ooooo`;o003o1_ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo007o
oooo000Aooooo`;o00001Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooo003o00Kooooo
0_l00?l6ooooo`03o`00oooooooo003o00Oooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0Fooooo`;o003o1_ooool2o`00o`oooooo0_l00?l6ooooo`03o`00oooooooo003o00Oooooo
00?o0000ooooooooool01Oooool00ol00?ooooooooooo`0Fooooo`;o003o6?ooool00ol00?oooooo
ooooo`05ooooo`;o003o1_ooool2o`00o`Oooooo0_l00?lOooooo`03o`00oooooooooooo00cooooo
0_l00003ooooo`004Oooool00ol0003oooooooooo`0;ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooool00?l01Oooool00ol00?ooooooooooo`06ooooo`;o003o1_ooool00ol00?ooooooo`00
o`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05_ooool2o`00o`Kooooo00?o
003oooooooooool03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o
003oooooooooool05oooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool2o`00o`Oooooo0_l0
0?l6ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00?ooooo0_l00?l6ooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`06
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00Kooooo0_l00?l6ooooo`;o003o1oooool2o`00oa3ooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`00oooooooo003o00Kooooo0_l00?l?
ooooo`03o`00oooooooooooo00Gooooo0_l00?l@ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo0_l00?l6
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooooooo00Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool01Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Gooooo00Co003ooooo
oooooooo003o1Oooool00ol00?ooooooo`00o`0@ooooo`03o`00oooooooooooo00Cooooo0_l00?l6
ooooo`03o`00oooooooooooo00Kooooo0_l00?lIooooo`03o`00oooooooooooo01Cooooo00?o003o
ooooool00?l01oooool00ol0003oooooooooo`04ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooool00?l03oooool00ol00?ooooooo`00o`05ooooo`;o003o3oooool2o`00o`oooooo00?o003o
ooooooooool03Oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Gooooo00Co
003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Gooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01Oooool00ol00?oooooooooo
o`03ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Kooooo0_l00?l?ooooo`;o003o2?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooo003o00Oooooo00?o003oooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l04Oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooo003o00oooooo00?o003oooooooooool01Oooool2o`00o`So
oooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00
o`Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`01ooooo`004Oooool2o`00
00Kooooo00?o003oooooooooool04oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003o
oooooooooooo003o1Oooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooool00?l01oooool00ol00?ooooooooooo`0=ooooo`;o003o1Oooool01?l00?oooooooooo
ool00?l>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01oooool00ol0003ooooo
ooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool01?l00?oooooo
ooooool00?lGooooo`03o`00oooooooooooo00Gooooo0_l00?l6ooooo`03o`00oooooooo003o00Go
oooo00?o003oooooool00?l05_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00go
oooo0_l00003ooooo`004Oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo00kooooo
00?o003oooooooooool01_ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Go
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooo003o00Co
oooo00Co003ooooooooooooo003o3_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o
00Oooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0Cooooo`04o`00oooooooooooo
o`00oaKooooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo
003o00Gooooo00?o003oooooool00?l04Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool02_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`06ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool01Oooool01?l00?ooooooooooool00?l7ooooo`03o`00
oooooooooooo00Cooooo0_l00?l>ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003ooooooooo
ool03_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00Sooooo00?o0000oooo
ooooool01?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00?o
003oooooooooool01_ooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooool00?l01Oooool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003o
ooooooooooooooooo`00o`07ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`06ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00cooooo00?o003oooooooooool01_ooool01?l00?ooooooooooool00?l5
ooooo`03o`00oooooooo003o00Kooooo0_l00?lFooooo`04o`00ooooooooooooo`00oaGooooo00Co
003ooooooooooooo003o1oooool00ol0003oooooooooo`04ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o3Oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003o
ooooool00?l03_ooool2o`00o`kooooo00?o003oooooooooool03_ooool01?l00?ooooooooooool0
0?l4ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Kooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool01_ooool01Ol00?oooooooooooooooooo003o
00Cooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`02ooooo`04o`00oooooooo
ooooo`00o`Gooooo00?o003oooooooooool01_ooool2o`00o`kooooo00Co003ooooooooooooo003o
1oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003ooooooooo
ooooooooo`00o`0Aooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0<
ooooo`;o003o1_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l02?ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000Oo
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Kooooo0_l00?l>ooooo`03o`00oooooooo
oooo00Cooooo00Go003oooooooooooooooooo`00o`0=ooooo`05o`00ooooooooooooooooool00?l0
1oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`0Cooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l02?ooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l02?ooool01Ol00?oooooooooooooooooo
003o00Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`;o00000oooool0
017ooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`0>ooooo`;o003o1?ooool01?l0
0?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool05?ooool00ol00?oooooooooo
o`04ooooo`05o`00ooooooooooooooooool00?l03Oooool01Ol00?oooooooooooooooooo003o00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00So
oooo00?o003oooooooooool04_ooool01Ol00?oooooooooooooooooo003o01Gooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003o
ooooooooooooooooo`00o`0Iooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02Ooo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`09ooooo`03o`00oooooooo
oooo00Cooooo0_l00?l6ooooo`03o`00oooooooo003o00Sooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00Sooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`04ooooo`;o003o3_ooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooooooo013ooooo
00?o003oooooooooool00_ooool00ol00?ooooooo`00o`0;ooooo`03o`000?oooooooooo00Sooooo
0ol00?l4ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01Oooool01?l00?oooooo
ooooool00?l>ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01_ooool00ol00?oooooo
ooooo`05ooooo`?o003o2Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`07ooooo`?o003o1_ooool2o`00o`Kooooo00?o003oooooool00?l01Oooool00ol00?oooooooooo
o`05ooooo`05o`00ooooooooooooooooool00?l02?ooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`Kooooo0_l00?lBooooo`03o`00oooooooo003o01Sooooo00?o003ooooo
ooooool02_ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00?ooooo0_l00?l4oooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`03oooo
o`03o`00oooooooooooo00cooooo00?o003oooooool00?l03Oooool00ol00?ooooooooooo`0:oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00
o`06ooooo`;o003o1oooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo01Sooooo0_l00?l6ooooo`?o003o3Oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooo003o01;ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo013ooooo0ol00?l3ooooo`03o`00oooooooooooo00cooooo00?o003oooooool00?l07Ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Kooooo0_l00?lJooooo`03o`000?oo
oooooooo007ooooo000Aooooo`;o00008_ooool2o`00o`Kooooo00?o003oooooool00?l01Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooo`00o`0>ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool03_ooool0
0ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`Sooooo00Go003ooooooooooooooooo
o`00o`0=ooooo`?o003o8Oooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo02Wooooo00?o
003oooooool00?l01Oooool00ol00?ooooooooooo`09ooooo`04o`00ooooooooooooo`00oaKooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool01?ooool00ol0003oooooooooo`0Looooo`03o`00oooooooooooo01[ooooo
00?o003oooooooooool00oooool01?l00?ooooooooooool00?l4ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`;o003o;?ooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`0Yooooo`?o003o1Oooool01?l00?ooooooooooool00?l;oooo
o`03o`00oooooooooooo01Cooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0@oooo
o`03o`000?oooooooooo013ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Hoooo
o`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`02
ooooo`04o`00ooooooooooooo`00o`Kooooo0_l00?l[ooooo`03o`000?oooooooooo007ooooo0003
ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0=?ooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooo003o03[ooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooo003o00Sooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo037ooooo
00?o0000ooooooooool00Oooool000Cooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool01Oooool01Ol00?oooooo
oooooooooooo003o00Sooooo00?o003oooooool00?l06_ooool00ol00?ooooooooooo`0Fooooo`03
o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo01Gooooo00?o003oooooooooool03?ooool00ol00?ooooooo`00o`0<ooooo`03
o`00oooooooooooo03Wooooo00?o0000ooooooooool00Oooool000Cooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03;ooooo00?o003ooooooooo
ool01?ooool01Ol00?oooooooooooooooooo003o00Sooooo00?o003oooooool00?l03_ooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo0_l00?l;ooooo`03o`00oooooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool01_ooool2o`00ocCooooo00?o0000ooooooooool00Oooool000Co
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`?o0000<_ooool2o`00
o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo01Kooooo00?o003o
ooooooooool06_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Co003o
oooooooooooo003o1Oooool2o`00oc;ooooo0ol00003ooooo`001?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0@Oooool00ol00?oooooooooo
o`0Cooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool04?ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`02ooooo`04o`00ooooooooooooo`00oc_ooooo00?o0000ooooooooool00Oooool000?ooooo0_l0
0004ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>_ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l03_ooool00ol00?oooooo
ooooo`0Eooooo`03o`00oooooooooooo017ooooo00?o0000ooooooooool00_ooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool01?l00?oooooo
ooooool00?lkooooo`03o`000?oooooooooo007ooooo0004ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo03[ooooo00?o003oooooool00?l01?ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooo003o01_ooooo00?o003oooooooooool05_ooool00ol00?oooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02oooool00ol00?oooooo
o`00o`0;ooooo`03o`00oooooooooooo03[ooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool0>_ooool00ol00?ooooooo`00o`09ooooo`04o`00ooooooooooooo`00o`cooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool05_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo003o00Cooooo
00?o003oooooooooool0@Oooool00ol0003oooooooooo`01ooooo`004Oooool2o`0003_ooooo00?o
003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`cooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo01Kooooo
00?o003oooooooooool06oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
0_l00?llooooo`;o00000oooool0017ooooo00?o0000ooooooooool0@Oooool00ol00?oooooooooo
o`0Booooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool06oooool00ol00?oooooooooo
o`0Hooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00oooool2o`00occooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0@Oooool00ol00?ooooooooooo`02
ooooo`04o`00ooooooooooooo`00o`cooooo00?o003oooooooooool05_ooool00ol00?oooooooooo
o`0Aooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`11ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo047ooooo00?o003o
ooooooooool00_ooool01?l00?ooooooooooool00?liooooo`03o`000?oooooooooo00;ooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool02_ooool01Ol00?oooooooooooooooooo003o04Oooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool0AOooool01Ol00?oooooooooooooooooo003o01[ooooo
00?o003oooooooooool05_ooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00[ooooo
00Go003oooooooooooooooooo`00o`17ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000
@oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo02Cooooo00?o003ooooooooo
ool03_ooool01?l00?ooooooooooool00?m3ooooo`;o00000oooool0017ooooo00?o0000oooooooo
ool0@_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00_ooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00?ooooo00?o0000oooooooo
ool06oooool00ol00?ooooooooooo`0Looooo`04o`00ooooooooooooo`00odCooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool0@_ooool01?l00?ooooooooooool00?l@oooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`0Aoooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool0@_ooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`12ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003ooooo
ooooool0=oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00[ooooo00Go003ooooo
ooooooooooooo`00o`17ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
04Gooooo00Go003oooooooooooooooooo`00o`0Jooooo`03o`00oooooooooooo01Oooooo00?o003o
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool05Oooool00ol00?ooooooooooo`0:ooooo`05o`00ooooooooooooooooool00?l0Aooo
ool00ol0003oooooooooo`01ooooo`004Oooool2o`0004Kooooo00Go003oooooooooooooooooo`00
o`0<ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00;ooooo00Go0000ooooooooooooooooo`00o`0?ooooo`03o`00
oooooooooooo01Gooooo00?o003oooooooooool03_ooool01?l00?ooooooooooool00?m3ooooo`;o
00000oooool0017ooooo00?o0000ooooooooool0@_ooool00ol00?ooooooooooo`0Aooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00;ooooo00Go0000ooooooooooooooooo`00o`0Iooooo`03o`00oooooooooooo01co
oooo00Co003ooooooooooooo003oA?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`13ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool04Oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`12ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04?ooooo
0_l00?l4ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool05Oooool00ol00?oooooo
ooooo`0Booooo`05o`000?ooooooooooooooool00?l03oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`19ooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04Cooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0
0_ooool01Ol0003ooooooooooooooooo003o013ooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`14ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000AOooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00_ooool01Ol0003ooooo
oooooooooooo003o013ooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00;ooooo0_l00?m4ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0
BOooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00o`0Hooooo`03o`00oooooooooooo06Gooooo00?o0000ooooooooool00Oooool0017ooooo
00?o0000ooooooooool0E_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo01[ooooo
00?o003oooooooooool06Oooool00ol00?ooooooooooo`19ooooo`03o`000?oooooooooo007ooooo
0002ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0BOooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool04oooool00ol0003ooooooooo
o`0Booooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo04Wooooo00?o0000ooooooooool00Oooool000?ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04Wooooo
00?o003oooooooooool06Oooool00ol00?ooooooooooo`0Kooooo`05o`000?ooooooooooooooool0
0?l04?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`19ooooo`03o`000?oooooooooo007ooooo0004ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool3o`0004Wooooo00?o003ooooooooo
ool06Oooool00ol00?ooooooooooo`0Gooooo`05o`00ooooooooooooooooool000000oooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`17ooooo`?o00000oooool000Gooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0BOooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?oooo
o`05o`00ooooooooooooooooool000000_ooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooo
oooo05Gooooo00?o0000ooooooooool00Oooool000;ooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0EOooool00ol00?oooooooooo
o`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool01Ol00?oooooooooo
oooooooo000001cooooo00?o003oooooooooool0IOooool00ol0003oooooooooo`01ooooo`000_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`1Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool04oooool00ol0003o
ooooooooo`0Booooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo04Wooooo00?o0000ooooooooool00Oooool000?ooooo
0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`19ooooo`03o`00oooooooooooo03Oooooo
00Co0000oooooooooooo003o4Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`19ooooo`03o`000?oooooooooo007o
oooo000Aooooo`03o`000?oooooooooo04Wooooo00?o003oooooooooool06_ooool00ol00?oooooo
ooooo`0Fooooo`05o`00ooooooooooooooooool000000_ooool00ol00?ooooooooooo`0?ooooo`03
o`00oooooooooooo01Gooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`19ooooo`03
o`000?oooooooooo007ooooo000Aooooo`;o0000Boooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`05o`00
ooooooooooooooooool000000_ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01Go
oooo00?o003oooooooooool0E?ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo05Gooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo
00Go003oooooooooooooooooo`000002ooooo`03o`00oooooooooooo01Kooooo00?o003ooooooooo
ool0I_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Eooooo`03o`00
oooooooooooo01Cooooo00?o003oooooooooool05?ooool00ol0003oooooooooo`0Cooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`19ooooo`03o`00
0?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04[ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Cooooo00Co0000oooooooooooo003o
4_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`19ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo04[ooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0Gooooo`04o`00oooo
ooooooooo`0000;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00kooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`1:ooooo`03o`00
0?oooooooooo007ooooo000Aooooo`;o0000Boooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Aooooo`06o`00oooo
ooooooooo`000?oooooo003o4oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool0BOooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo04[ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool04Oooool01_l00?ooooooooooool0003oooooo`00oaWooooo00?o003ooooo
ooooool0I_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Eooooo`03
o`00oooooooooooo00oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`04
o`00ooooooooooooo`0001_ooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`1:oooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04[ooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Cooooo00?o0000oooooooo
ool04oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`1:ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo04[ooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0Fooooo`06o`00
ooooooooooooo`000?oooooo003o4oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`1:ooooo`03o`000?oooooooooo
007ooooo000Aooooo`;o0000Boooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo01Ko
oooo00Ko003ooooooooooooo0000ooooool00?lDooooo`03o`00oooooooooooo01?ooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`19ooooo`;o00000oooool0017ooooo00?o0000oooo
ooooool0B_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00oooooo00Co003ooooo
oooooooooooo0_l00?lCooooo`06o`00ooooooooooooo`000?oooooo003o:_ooool00ol00?oooooo
ooooo`1Eooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo05Gooooo00?o
003oooooooooool03oooool01Ol00?oooooooooooooooooo003o01Cooooo00Co003ooooooooooooo
00006_ooool00ol00?ooooooooooo`1Wooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo05Gooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Eooooo`03o`00
0?oooooooooo01Cooooo00Go003oooooooooooooooooo`00o`0Booooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool0B_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`1:ooooo`03o`00oooooooooooo03Kooooo00?o0000o`00ooooool05?ooool01Ol00?oooooo
oooooooooooo003o01;ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`1:ooooo`03
o`000?oooooooooo007ooooo000Aooooo`;o0000Boooool00ol00?ooooooooooo`0Kooooo`03o`00
oooooooooooo01Kooooo00Co003oooooool0003o003o5Oooool00ol00?ooooooooooo`0Dooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool0BOooool2o`0000?ooooo000Aooooo`03o`00
0?oooooooooo04[ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Dooooo`03o`00
oooooooooooo01?ooooo00Co003oooooool0003o003o5Oooool00ol00?ooooooooooo`0Dooooo`03
o`00oooooooooooo05Cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
E?ooool00ol00?ooooooooooo`0Aooooo`04o`00ooooooooooooo`00oaGooooo00?o003oooooool0
00006Oooool00ol00?ooooooooooo`1Xooooo`03o`000?oooooooooo007ooooo0003ooooo`?o0000
1?ooool2o`0000Gooooo00?o0000ooooooooool0E?ooool00ol00?ooooooooooo`0Aooooo`03o`00
oooooooo003o01Sooooo00?o0000ooooooooool05Oooool00ol00?ooooooo`00o`0Mooooo`03o`00
oooooooooooo04[ooooo00?o0000ooooooooool00Oooool000;ooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0B_ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo017ooooo0_l00?lIooooo`03o`00oooooooooooo01Go
oooo00?o003oooooool00?l04oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo04[o
oooo00?o0000ooooooooool00Oooool000Kooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`02ooooo`?o0000B_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01Ko
oooo0_l00?lGooooo`;o003o5?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo04So
oooo0ol00003ooooo`001?ooool2o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`1:ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0;?ooool00ol0003o
ooooooooo`0[ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0B_ooool00ol0003o
ooooooooo`01ooooo`001_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0B_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02co
oooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`01ooooo`000_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Doooo
o`03o`00oooooooooooo02cooooo00?o0000ooooooooool0=Oooool00ol00?ooooooooooo`1:oooo
o`03o`000?oooooooooo007ooooo0003ooooo`?o00001?ooool2o`0000Gooooo00?o0000oooooooo
ool0B_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02cooooo00?o0000oooooooo
ool0:oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo04[ooooo00?o0000oooooooo
ool00Oooool0017ooooo0_l0001;ooooo`03o`00oooooooooooo03Kooooo00?o0000ooooooooool0
:oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo04Wooooo0_l00003ooooo`004Ooo
ool00ol0003oooooooooo`1;ooooo`03o`00oooooooooooo03Gooooo00?o0000ooooooooool0:ooo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo04[ooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0Boooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo02cooooo00?o0000ooooooooool0:oooool00ol00?ooooooooooo`1Dooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo05Cooooo00?o003oooooooooool0;?ooool00ol0
003oooooooooo`22ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo05Co
oooo00?o003oooooooooool0;?ooool00ol0003oooooooooo`0[ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool0B_ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0004cooooo
00?o003oooooooooool0=Oooool00ol0003oooooooooo`0[ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool0BOooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo04_ooooo00?o
003oooooooooool0=Oooool00ol0003oooooooooo`0[ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool0Boooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1;
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0;?ooool00ol0003oooooooooo`0[
ooooo`03o`00oooooooooooo05Cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool0E?ooool00ol00?ooooooooooo`0/ooooo`03o`000?oooooooooo08;ooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool0E?ooool00ol00?ooooooooooo`0/ooooo`03
o`000?oooooooooo03Cooooo00?o003oooooooooool0Boooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`1;ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
;?ooool00ol0003oooooooooo`0[ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
Boooool00ol0003oooooooooo`01ooooo`004Oooool2o`0004cooooo00?o003oooooooooool0=Ooo
ool00ol0003oooooooooo`0[ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0B_oo
ool2o`0000?ooooo000Aooooo`03o`000?oooooooooo04_ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0/ooooo`03o`000?oooooooooo02cooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
04_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0/ooooo`03o`000?oooooooooo
08;ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Doooool00ol00?oo
ooooooooo`0]ooooo`03o`000?oooooooooo03Cooooo00?o003oooooooooool0Boooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1;ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool0;Oooool00ol0003oooooooooo`0/ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool0Boooool00ol0003oooooooooo`01ooooo`004Oooool2o`0004cooooo00?o
003oooooooooool0=Oooool00ol0003oooooooooo`0/ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool0B_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo04_ooooo00?o003o
ooooooooool0=Oooool00ol0003oooooooooo`0/ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool0Boooool00ol0003oooooooooo`01ooooo`001?ooool3o`0000?ooooo0_l00005oooo
o`03o`000?oooooooooo04_ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0]oooo
o`03o`000?oooooooooo02cooooo00?o003oooooooooool0Doooool00ol0003oooooooooo`01oooo
o`001Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1Cooooo`03o`00oooooooooooo02gooooo00?o0000ooooooooool0P_ooool00ol0
003oooooooooo`01ooooo`000_ooool5o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`1Cooooo`03o`00oooooooooooo02gooooo00?o0000ooooooooool0;?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo04_ooooo00?o0000ooooooooool00Oooool000;o
oooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00004ooooo`?o0000Boooool0
0ol00?ooooooooooo`0eooooo`03o`000?oooooooooo02cooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`19ooooo`?o00000oooool000?ooooo00?o0000ooooool000000oooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo04_ooooo00?o003oooooooooool0=Oooool0
0ol0003oooooooooo`0/ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0Boooool0
0ol0003oooooooooo`01ooooo`001?ooool2o`0000?ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`1;ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0;Oooool0
0ol0003oooooooooo`0/ooooo`03o`00oooooooooooo05?ooooo00?o0000ooooooooool00Oooool0
00Gooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000ooooooooool0Doooool00ol0
0?ooooooooooo`0]ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool0Doooool00ol00?ooooooooooo`0]ooooo`03o`000?oooooooooo03Co
oooo00?o003oooooooooool0Boooool00ol0003oooooooooo`01ooooo`004Oooool2o`0004cooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0]ooooo`03o`000?oooooooooo02cooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`1:ooooo`;o00000oooool0017ooooo00?o
0000ooooooooool0Boooool00ol00?ooooooooooo`0eooooo`03o`000?oooooooooo02cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo04cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0]
ooooo`03o`000?oooooooooo02cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`1;
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04cooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0]ooooo`03o`000?oooooooooo08;ooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool0C?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo02gooooo00?o0000ooooooooool0<oooool00ol00?ooooooooooo`1<ooooo`03
o`000?oooooooooo007ooooo000Aooooo`;o0000COooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo02gooooo00?o0000ooooooooool0;?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo04_ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`23ooooo`03o`000?oo
oooooooo02cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1<ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0;Oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo04cooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool0C?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
02gooooo00?o0000ooooooooool0;Oooool00ol00?ooooooooooo`1Booooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo04cooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`0]ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool00Oooool0017ooooo
0_l0001=ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0;_ooool00ol0003ooooo
ooooo`0]ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0Boooool2o`0000?ooooo
000Aooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0;Oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo04cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool0Poooool00ol0003oooooooooo`0]ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool0C?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1<oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool0;_ooool00ol0003oooooooooo`0]oooo
o`03o`00oooooooooooo05;ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0C?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo02kooooo00?o0000oooooooo
ool0P_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1<ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool0;_ooool00ol0003oooooooooo`0cooooo`03o`00
oooooooooooo04cooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001=ooooo`03o`00oooo
oooooooo03Cooooo00?o0000ooooooooool0;Oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo04_ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`23ooooo`03o`000?oooooo
oooo02gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`1<ooooo`03o`000?oooooo
oooo007ooooo0003ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0C?ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo02kooooo00?o0000ooooooooool0;Oooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo04cooooo00?o0000ooooooooool00Oooool000;o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool0C?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo02kooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`01ooooo`001_ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0C?ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo02kooooo00?o0000ooooooooool0<oooool00ol00?ooooooooooo`1<
ooooo`03o`000?oooooooooo007ooooo0006ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00_ooool3o`0004cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0^
ooooo`03o`000?oooooooooo02gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`1:
ooooo`?o00000oooool000;ooooo1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool0Poooool00ol0003oooooooooo`0]ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool0C?ooool00ol0003oooooooooo`01ooooo`000_ooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0D_ooool00ol00?ooooooooooo`0^
ooooo`03o`000?oooooooooo02gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`1<
ooooo`03o`000?oooooooooo007ooooo0002ooooo`Go00000oooool2o`0000Gooooo00?o0000oooo
ooooool0COooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02kooooo00?o0000oooo
ooooool0;Oooool00ol00?ooooooooooo`1Booooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo04gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0^ooooo`03
o`000?oooooooooo08;ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001>ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool0;_ooool00ol0003oooooooooo`0^ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool0Boooool2o`0000?ooooo000Aooooo`03o`000?oo
oooooooo08?ooooo00?o0000ooooooooool0;_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo04cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Poooool0
0ol0003oooooooooo`0^ooooo`05o`00ooooooooooooooooool00?l0Coooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`1=ooooo`05o`00ooooooooooooooooool00?l0<Ooo
ool00ol0003oooooooooo`0^ooooo`03o`00oooooooooooo057ooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0COooool01Ol00?oooooooooooooooooo003o037ooooo00?o
0000ooooooooool0P_ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0004kooooo00Go003o
ooooooooooooooooo`00o`0aooooo`03o`000?oooooooooo03;ooooo00?o003oooooooooool0C?oo
ool2o`0000?ooooo000Aooooo`03o`000?oooooooooo04gooooo00?o003oooooooooool0<oooool0
0ol0003oooooooooo`0^ooooo`05o`00ooooooooooooooooool00?l0Coooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo02kooooo00Go003o
ooooooooooooooooo`00o`1?ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo04gooooo00Go003oooooooooooooooooo`00o`0aooooo`03o`000?oooooooooo02kooooo00?o
003oooooooooool0DOooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1=
ooooo`05o`00ooooooooooooooooool00?l0<Oooool00ol0003oooooooooo`22ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`;o0000C_ooool01Ol00?oooooooooooooooooo003o037ooooo00?o
0000ooooooooool0<_ooool00ol00?ooooooooooo`1<ooooo`;o00000oooool0017ooooo00?o0000
ooooooooool0COooool01Ol00?oooooooooooooooooo003o037ooooo00?o0000ooooooooool0;_oo
ool01Ol00?oooooooooooooooooo003o04oooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool0Poooool00ol0003oooooooooo`0^ooooo`05o`00ooooooooooooooooool00?l0
Coooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Aooooo`03o`00oooo
oooooooo02oooooo00?o0000ooooooooool0;_ooool01Ol00?oooooooooooooooooo003o04oooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0C_ooool01?l00?oooooooooo
ool00?laooooo`03o`000?oooooooooo02kooooo00?o003oooooooooool0DOooool00ol0003ooooo
ooooo`01ooooo`004Oooool2o`0004oooooo00Co003ooooooooooooo003o<Oooool00ol0003ooooo
ooooo`0aooooo`03o`00oooooooooooo04gooooo0_l00003ooooo`004Oooool00ol0003ooooooooo
o`1>ooooo`03o`00oooooooo003o03;ooooo00?o0000ooooooooool0;oooool00ol00?ooooooo`00
o`1@ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo08?ooooo00?o0000
ooooooooool0;oooool00ol00?ooooooo`00o`1@ooooo`03o`000?oooooooooo007ooooo0003oooo
o`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`0_oooo
o`03o`00oooooooo003o053ooooo00?o0000ooooooooool00Oooool000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0C_ooool0
0ol00?ooooooo`00o`0booooo`03o`000?oooooooooo02oooooo00?o003oooooooooool0D?ooool0
0ol0003oooooooooo`01ooooo`000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00001?ooool3o`0004kooooo00?o003oooooool00?l0<_ooool00ol0003ooooooooo
o`0aooooo`03o`00oooooooooooo04cooooo0ol00003ooooo`000_ooool4o`0000?ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`1>ooooo`03o`00oooooooo003o03;ooooo00?o
0000ooooooooool0;oooool00ol00?ooooooo`00o`1@ooooo`03o`000?oooooooooo007ooooo0002
ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`1?ooooo`03o`00oooooooooooo037ooooo00?o0000ooooooooool0<?ooool00ol00?oooooooooo
o`1?ooooo`03o`000?oooooooooo007ooooo0003ooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo033ooooo00?o
003oooooooooool0Coooool00ol0003oooooooooo`01ooooo`001?ooool2o`0000Cooooo0_l00005
ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo007ooooo000Aoooooooo
00003Ol00003ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.95693, -6.30366, \
0.0394232, 0.387934}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Phase plot of DTFT as a function of index k", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(g2 = 
        Plot[Arg[
            X\[Theta]\  /. \ \[Theta] \[Rule] \ 2  \[Pi]\ f/fs], {f, \(-fs\)/
              2, fs/2}, \ PlotStyle \[Rule] {Blue, \ Dashing[{ .01}]}, \ 
          PlotRange \[Rule] All, PlotPoints \[Rule] 200];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309069 0.103352 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .10236 -12 -4.5 ]
[-0.0125 .10236 0 4.5 ]
[-0.0125 .20572 -12 -4.5 ]
[-0.0125 .20572 0 4.5 ]
[-0.0125 .30907 -6 -4.5 ]
[-0.0125 .30907 0 4.5 ]
[-0.0125 .41242 -6 -4.5 ]
[-0.0125 .41242 0 4.5 ]
[-0.0125 .51577 -6 -4.5 ]
[-0.0125 .51577 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10236 m
.00625 .10236 L
s
[(-2)] -0.0125 .10236 1 0 Mshowa
0 .20572 m
.00625 .20572 L
s
[(-1)] -0.0125 .20572 1 0 Mshowa
0 .30907 m
.00625 .30907 L
s
[(0)] -0.0125 .30907 1 0 Mshowa
0 .41242 m
.00625 .41242 L
s
[(1)] -0.0125 .41242 1 0 Mshowa
0 .51577 m
.00625 .51577 L
s
[(2)] -0.0125 .51577 1 0 Mshowa
.125 Mabswid
0 .01968 m
.00375 .01968 L
s
0 .04035 m
.00375 .04035 L
s
0 .06102 m
.00375 .06102 L
s
0 .08169 m
.00375 .08169 L
s
0 .12304 m
.00375 .12304 L
s
0 .14371 m
.00375 .14371 L
s
0 .16438 m
.00375 .16438 L
s
0 .18505 m
.00375 .18505 L
s
0 .22639 m
.00375 .22639 L
s
0 .24706 m
.00375 .24706 L
s
0 .26773 m
.00375 .26773 L
s
0 .2884 m
.00375 .2884 L
s
0 .32974 m
.00375 .32974 L
s
0 .35041 m
.00375 .35041 L
s
0 .37108 m
.00375 .37108 L
s
0 .39175 m
.00375 .39175 L
s
0 .43309 m
.00375 .43309 L
s
0 .45376 m
.00375 .45376 L
s
0 .47443 m
.00375 .47443 L
s
0 .4951 m
.00375 .4951 L
s
0 .53644 m
.00375 .53644 L
s
0 .55711 m
.00375 .55711 L
s
0 .57778 m
.00375 .57778 L
s
0 .59845 m
.00375 .59845 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .10236 m
1 .10236 L
s
.99375 .20572 m
1 .20572 L
s
.99375 .30907 m
1 .30907 L
s
.99375 .41242 m
1 .41242 L
s
.99375 .51577 m
1 .51577 L
s
.125 Mabswid
.99625 .01968 m
1 .01968 L
s
.99625 .04035 m
1 .04035 L
s
.99625 .06102 m
1 .06102 L
s
.99625 .08169 m
1 .08169 L
s
.99625 .12304 m
1 .12304 L
s
.99625 .14371 m
1 .14371 L
s
.99625 .16438 m
1 .16438 L
s
.99625 .18505 m
1 .18505 L
s
.99625 .22639 m
1 .22639 L
s
.99625 .24706 m
1 .24706 L
s
.99625 .26773 m
1 .26773 L
s
.99625 .2884 m
1 .2884 L
s
.99625 .32974 m
1 .32974 L
s
.99625 .35041 m
1 .35041 L
s
.99625 .37108 m
1 .37108 L
s
.99625 .39175 m
1 .39175 L
s
.99625 .43309 m
1 .43309 L
s
.99625 .45376 m
1 .45376 L
s
.99625 .47443 m
1 .47443 L
s
.99625 .4951 m
1 .4951 L
s
.99625 .53644 m
1 .53644 L
s
.99625 .55711 m
1 .55711 L
s
.99625 .57778 m
1 .57778 L
s
.99625 .59845 m
1 .59845 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30907 m
1 .30907 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .47141 m
.02847 .42587 L
.03355 .37621 L
.03832 .32956 L
.04291 .28471 L
.0478 .23696 L
.0525 .19101 L
.05373 .17897 L
.05438 .17262 L
.05474 .16915 L
.05507 .1659 L
.05536 .16307 L
.05544 .16225 L
.05552 .16148 L
.05567 .48471 L
.05575 .48394 L
.05584 .48311 L
.05599 .48162 L
.05633 .47824 L
.0575 .46685 L
.06251 .41785 L
.06735 .37063 L
.072 .32521 L
.07694 .2769 L
.0817 .23038 L
.0841 .20698 L
.08514 .19676 L
.08628 .18565 L
.08659 .18268 L
.08691 .17952 L
.08704 .17822 L
.08719 .17682 L
.08734 .49998 L
.08749 .49854 L
.08864 .48736 L
.09116 .46273 L
.09612 .41428 L
.1009 .36762 L
.10549 .32275 L
.11039 .275 L
.1151 .22905 L
.11633 .21699 L
.11767 .20393 L
.11828 .19793 L
.11862 .19465 L
.11878 .19305 L
.11893 .19159 L
.11907 .51494 L
.1192 .51367 L
.11949 .51086 L
Mistroke
.1201 .5049 L
.12471 .45991 L
.12962 .41203 L
.13435 .36596 L
.13937 .31701 L
.14421 .26985 L
.14643 .24821 L
.14769 .23593 L
.14886 .22449 L
.15003 .21315 L
.15036 .20989 L
.15052 .20828 L
.15068 .2068 L
.15082 .53015 L
.15096 .52872 L
.15127 .52571 L
.15381 .50095 L
.15837 .45655 L
.16323 .4093 L
.1679 .36383 L
.17287 .31551 L
.17765 .26899 L
.18006 .24554 L
.18112 .23533 L
.18167 .22995 L
.18197 .22701 L
.18225 .22427 L
.1824 .22285 L
.18256 .54602 L
.18265 .54515 L
.18273 .54433 L
.18289 .54279 L
.18347 .53711 L
.18462 .52594 L
.18715 .50138 L
.19177 .45654 L
.19669 .40886 L
.20142 .36298 L
.20597 .3189 L
.20849 .29443 L
.21081 .27198 L
.21308 .25001 L
.21363 .24468 L
.21394 .24174 L
.21409 .2403 L
.21422 .23897 L
.2143 .56289 L
.21439 .56208 L
.21456 .56038 L
.21487 .5574 L
Mistroke
.21547 .55157 L
.22004 .50743 L
.2249 .46047 L
.22958 .41533 L
.23455 .36739 L
.23934 .32127 L
.24176 .29802 L
.24395 .27697 L
.24454 .27132 L
.24518 .26522 L
.24547 .26242 L
.24563 .26089 L
.24578 .25946 L
.2459 .25824 L
.24604 .58162 L
.24619 .58017 L
.24633 .57885 L
.24886 .55458 L
.25366 .50851 L
.25829 .46427 L
.26321 .41731 L
.26795 .37219 L
.2725 .32894 L
.27503 .30495 L
.27614 .29447 L
.27673 .28892 L
.27705 .28588 L
.27735 .28301 L
.2775 .28165 L
.27765 .28021 L
.27773 .27946 L
.27782 .60332 L
.27797 .60186 L
.27853 .59657 L
.27963 .58622 L
.28202 .56366 L
.28689 .51793 L
.29158 .47414 L
.29656 .42784 L
.30135 .38357 L
.30597 .34133 L
.31088 .29685 L
.31561 .25458 L
.32063 .21043 L
.32547 .16882 L
.33013 .12994 L
.33508 .0902 L
.33755 .07119 L
.33876 .06214 L
.33985 .05404 L
Mistroke
.3404 .05007 L
.34069 .04798 L
.34099 .04579 L
.34112 .04487 L
.34126 .04388 L
.34141 .36749 L
.34155 .36648 L
.34207 .36282 L
.34444 .34655 L
.34941 .31536 L
.3542 .2896 L
.3588 .26863 L
.36371 .24871 L
.36842 .22899 L
.36966 .22338 L
.371 .21705 L
.37162 .21404 L
.37227 .21079 L
.37254 .20943 L
.37283 .20796 L
.37291 .20752 L
.37299 .20711 L
.37314 .53102 L
.37328 .53028 L
.37344 .52948 L
.37835 .50158 L
.38309 .47122 L
.38764 .43955 L
.39249 .40391 L
.39715 .36838 L
.40211 .32984 L
.40689 .2924 L
.41148 .25645 L
.41637 .2186 L
.42108 .18292 L
.42608 .1462 L
.4309 .11239 L
.43311 .09751 L
.43437 .08925 L
.43498 .08526 L
.43554 .08165 L
.43582 .07983 L
.43613 .07786 L
.43628 .07696 L
.43643 .07601 L
.43657 .3998 L
.4367 .39898 L
.43794 .39122 L
.44047 .37579 L
.44531 .34793 L
Mistroke
.44997 .32254 L
.45492 .29603 L
.45968 .26981 L
.46427 .24309 L
.46662 .22864 L
.4673 .22439 L
.46764 .22228 L
.46794 .22032 L
.46809 .2194 L
.46822 .21854 L
.46837 .54233 L
.46852 .54133 L
.46915 .53729 L
.47382 .50613 L
.47878 .47113 L
.48357 .43595 L
.48817 .40112 L
.49307 .3633 L
.49778 .32648 L
.50279 .28721 L
.50762 .24954 L
.51226 .21374 L
.5172 .17646 L
.52196 .14168 L
.52653 .10962 L
.52908 .09248 L
.53028 .08455 L
.53081 .0811 L
.53112 .07914 L
.5314 .07732 L
.53153 .07648 L
.53167 .0756 L
.53182 .39932 L
.53196 .39844 L
.53255 .39467 L
.53381 .38682 L
.53609 .37292 L
.54068 .3463 L
.54556 .31952 L
.55027 .29434 L
.55527 .26697 L
.55777 .25266 L
.56008 .239 L
.56233 .22524 L
.56288 .22182 L
.56318 .21992 L
.56333 .21899 L
.56347 .21812 L
.56355 .54231 L
.56363 .54178 L
Mistroke
.5638 .54067 L
.56411 .5387 L
.56472 .53482 L
.56973 .50138 L
.57457 .46725 L
.57922 .43299 L
.58416 .39542 L
.58893 .3585 L
.59351 .32265 L
.59838 .28445 L
.60308 .24801 L
.60807 .2101 L
.61287 .17494 L
.6175 .14302 L
.61983 .12782 L
.62241 .11194 L
.62359 .10505 L
.62486 .09788 L
.62544 .09467 L
.62605 .09136 L
.62658 .08858 L
.62672 .08783 L
.62687 .08703 L
.62702 .41097 L
.62715 .41029 L
.63197 .3874 L
.63661 .36815 L
.64155 .348 L
.6463 .32604 L
.65087 .3011 L
.65342 .28555 L
.65574 .27038 L
.65689 .26256 L
.6575 .25835 L
.65783 .25602 L
.65814 .25382 L
.65844 .2517 L
.65852 .25112 L
.65861 .25051 L
.65876 .57409 L
.6589 .5731 L
.65903 .57217 L
.65933 .57006 L
.66042 .56207 L
.66512 .52633 L
.67012 .48617 L
.67493 .44591 L
.67956 .40605 L
.68449 .36274 L
.68923 .32032 L
Mistroke
.69379 .27902 L
.69864 .23459 L
.70332 .19147 L
.70829 .14529 L
.71307 .10055 L
.71768 .05731 L
.72005 .03498 L
.72073 .02854 L
.72137 .02247 L
.72165 .01982 L
.72195 .01701 L
.7221 .01555 L
.72219 .01472 L
.72227 .33863 L
.72242 .33726 L
.72257 .3358 L
.72756 .2886 L
.73236 .24299 L
.73698 .199 L
.7419 .15208 L
.74663 .10681 L
.75118 .06321 L
.75232 .05232 L
.75293 .04637 L
.75351 .04084 L
.75367 .03935 L
.75381 .03794 L
.7539 .03715 L
.75398 .361 L
.75414 .35952 L
.75482 .35294 L
.75603 .34138 L
.76096 .29397 L
.76571 .24825 L
.77027 .20424 L
.77514 .15733 L
.77981 .11213 L
.78219 .08913 L
.78345 .07698 L
.78414 .07031 L
.78479 .06403 L
.78509 .06108 L
.78542 .05797 L
.78558 .05634 L
.78568 .05542 L
.78577 .37924 L
.78593 .37773 L
.78609 .3761 L
.78728 .36467 L
.78958 .34235 L
Mistroke
.79457 .29401 L
.79938 .24741 L
.80401 .20255 L
.80893 .15479 L
.81138 .13105 L
.81367 .10878 L
.81586 .08748 L
.81646 .08164 L
.81679 .07846 L
.8171 .0755 L
.81723 .07419 L
.81736 .07296 L
.8175 .39623 L
.81764 .39494 L
.81823 .38921 L
.82287 .34409 L
.82781 .29608 L
.83256 .24982 L
.83713 .20533 L
.842 .15794 L
.84425 .1361 L
.84669 .11231 L
.84733 .10605 L
.84802 .09939 L
.84835 .09615 L
.84866 .0931 L
.84894 .09036 L
.8491 .08882 L
.84924 .4121 L
.84939 .41073 L
.84954 .40926 L
.84981 .40661 L
.85042 .4006 L
.85167 .38848 L
.85667 .33978 L
.86148 .29285 L
.86611 .24769 L
.87104 .19963 L
.87579 .15335 L
.87817 .13011 L
.87921 .11994 L
.87976 .11457 L
.88035 .10884 L
.88052 .1072 L
.88068 .10566 L
.88082 .10427 L
.88097 .42746 L
.88112 .42603 L
.88127 .42452 L
.88155 .42182 L
Mistroke
.88269 .41069 L
.88521 .38612 L
.88979 .34144 L
.89466 .29386 L
.89935 .24805 L
.90434 .19935 L
.90684 .17498 L
.90915 .15243 L
.91139 .13055 L
.91193 .12523 L
.91222 .12243 L
.91252 .11949 L
.9126 .11874 L
.91268 .11793 L
.91277 .44173 L
.91286 .4409 L
.91316 .43789 L
.91377 .43198 L
.91877 .3831 L
.92359 .33601 L
.92823 .29069 L
.93317 .24248 L
.93792 .19605 L
.94031 .17273 L
.94249 .15141 L
.94306 .14579 L
.94369 .13966 L
.94398 .13685 L
.94414 .13531 L
.94428 .13387 L
.94442 .13251 L
.94457 .45574 L
.94471 .45441 L
.94483 .45319 L
.94735 .42856 L
.95212 .38197 L
.95671 .33716 L
.96159 .28945 L
.96628 .24354 L
.97128 .19473 L
.97609 .1477 L
.97619 .14672 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<oooool3o`0002kooooo1Ol0000]ooooo`;o0000;_ooool5o`00033ooooo0ol0000Roooo
o`00=?ooool00ol0003oooooooooo`0^ooooo`04o`000?ooooooooooo`0002cooooo00Co0000oooo
oooooooo0000;_ooool01?l0003oooooooooool0000aooooo`03o`000?oooooooooo027ooooo000[
ooooo`Go000000?oooooo`000?l000000ol0000Xooooo`Go00000oooool00ol0003oooooooooo`0/
ooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool0;_ooool5o`0002;ooooo000a
ooooo`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool0:oooool01?l0003ooooooooo
ool0000`ooooo`03o`000?oooooooooo02gooooo00Co0000oooooooooooo00008oooool003;ooooo
00?o0000ooooool00000;oooool01Ol0003ooooooooooooooooo000002cooooo00Co0000oooooooo
oooo0000;Oooool01Ol0003ooooooooooooooooo000002oooooo00?o0000ooooool000008oooool0
03?ooooo0_l0000_ooooo`05o`000?ooooooooooooooool00000;?ooool01?l0003oooooooooool0
000]ooooo`05o`000?ooooooooooooooool00000<?ooool2o`0002?ooooo000dooooo`03o`000?oo
oooooooo02kooooo0ol0000^ooooo`;o0000;oooool3o`0003;ooooo00?o0000ooooooooool08Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0017oooooool0
000=o`0000?ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Poooool00ol0003o
ooooooooo`22ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo08?ooooo
00?o0000ooooooooool0>?ooool00ol00?ooooooooooo`17ooooo`03o`000?oooooooooo007ooooo
000Aooooo`;o0000Q?ooool00ol0003oooooooooo`0hooooo`03o`00oooooooooooo04Kooooo0_l0
0003ooooo`004Oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo08;ooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo08?ooooo00?o0000oooooooo
ool0=oooool2o`00odWooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
Poooool00ol0003oooooooooo`0gooooo`;o003oBOooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo03Oooooo0_l00?l7ooooo`03o`00oooo
oooooooo03oooooo00?o0000ooooooooool00Oooool0017ooooo0_l00024ooooo`03o`000?oooooo
oooo043ooooo00?o003oooooooooool0?_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo
08?ooooo00?o0000ooooooooool0@?ooool00ol00?ooooooooooo`0oooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo05Sooooo00?o003oooooooooool0:?ooool00ol0003o
ooooooooo`0gooooo`;o003o1oooool00ol00?ooooooooooo`0oooooo`03o`000?oooooooooo007o
oooo000Aooooo`03o`000?oooooooooo05Sooooo00?o003oooooooooool0:?ooool00ol0003ooooo
ooooo`0gooooo`;o003o1oooool00ol00?ooooooooooo`0oooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo05Sooooo00?o003oooooooooool0:?ooool00ol0003ooooooooo
o`0gooooo`;o003o1oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo03Kooooo00?o
0000ooooooooool00Oooool0017ooooo0_l0001Iooooo`03o`00oooooooooooo02Sooooo00?o0000
ooooooooool0=oooool2o`00o`Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0e
ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0F?ooool00ol00?ooooooooooo`0Xoooo
o`03o`000?oooooooooo043ooooo00?o003oooooooooool0?oooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`1Gooooo`;o003o:_ooool00ol0003oooooooooo`0fooooo`03
o`00oooooooo003o00Kooooo0_l00?l7ooooo`03o`00oooooooooooo03Oooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool0F?ooool00ol00?ooooooooooo`0Xooooo`03o`00
0?oooooooooo03Kooooo00?o003oooooool00?l01oooool00ol00?ooooooooooo`05ooooo`;o003o
>?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Hooooo`03o`00oooo
oooooooo01Oooooo00?o003oooooooooool03_ooool00ol0003oooooooooo`05ooooo`03o`00oooo
oooooooo02kooooo00?o003oooooool00?l01oooool00ol00?ooooooooooo`05ooooo`;o003o1ooo
ool00ol00?ooooooooooo`0^ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo05Oooooo0_l00?lIooooo`03o`00oooooooooooo00kooooo00?o0000ooooooooool01Oooool0
0ol00?ooooooooooo`0^ooooo`03o`00oooooooo003o00Kooooo00?o003oooooooooool01_ooool2
o`00o`Oooooo00?o003oooooooooool0;_ooool00ol0003oooooooooo`01ooooo`004Oooool2o`00
05Sooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooooooo
00Gooooo00?o003oooooooooool0=oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool0;Oooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo05Oo
oooo0_l00?lZooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool05_ooool00ol00?oo
ooooooooo`0Nooooo`;o003o1oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02ko
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0F?ooool00ol00?oooooo
ooooo`0Gooooo`03o`00oooooooooooo00kooooo00?o0000ooooooooool01Oooool00ol00?oooooo
ooooo`0Fooooo`03o`00oooooooooooo01Gooooo00?o003oooooool00?l01_ooool2o`00o`Oooooo
0_l00?l7ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool09Oooool00ol0003ooooo
ooooo`01ooooo`002?ooool5o`0000Cooooo00?o0000ooooooooool0F?ooool00ol00?oooooooooo
o`0Fooooo`;o003o4?ooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo01Kooooo00?o
003oooooooooool05Oooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00Gooooo0_l0
0?l6ooooo`03o`00oooooooooooo00Kooooo0_l00?lWooooo`03o`000?oooooooooo007ooooo0009
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0E_ooool00ol00?ooooooo`00
o`0Hooooo`;o003o4?ooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo01Oooooo00?o
003oooooooooool05?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00Oooooo
0_l00?l6ooooo`03o`00oooooooooooo02oooooo00?o0000ooooooooool00Oooool000;ooooo1Ol0
0003ooooo`03o`000?oooooooooo00Cooooo0ol0001Fooooo`03o`00oooooooooooo01Sooooo00?o
003oooooooooool03oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo01Oooooo00?o
003oooooooooool07Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo0_l0
0?l^ooooo`?o00000oooool000_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1F
ooooo`03o`00oooooooooooo02[ooooo00?o0000ooooooooool01?ooool2o`00oaOooooo0_l00?lO
ooooo`03o`00oooooooo003o00oooooo0_l00?l7ooooo`;o003o1oooool00ol00?ooooooooooo`0M
ooooo`03o`000?oooooooooo007ooooo0008ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`1Hooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool03_ooool0
0ol0003oooooooooo`05ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool0
1?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Kooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`05ooooo`;o003o1oooool00ol00?ooooooooooo`0Mooooo`03o`000?oo
oooooooo007ooooo0008ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`1Hooooo`03o`00oooooooooooo01Gooooo00?o003oooooool00?l04?ooool00ol0003ooooooooo
o`05ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool01?l00?oooooooooo
ool00?l7ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l03oooool2o`00o`Oooooo
00?o003oooooooooool07Oooool00ol0003oooooooooo`01ooooo`002Oooool3o`0000Gooooo00?o
0000ooooooooool0E_ooool00ol00?ooooooo`00o`0Gooooo`03o`00oooooooo003o013ooooo00?o
0000ooooooooool00oooool00ol00?ooooooooooo`0Gooooo`;o003o5_ooool01?l00?oooooooooo
ool00?l7ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01_ooool00ol00?oooooo
ooooo`0?ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05?ooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`1Fooooo`03o`00oooooooooooo01Oooooo00?o
003oooooool00?l04?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo01Sooooo00?o
003oooooooooool05?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool01?ooool2o`00oa3ooooo00?o003oooooooooool01Oooool2o`00oaKooooo
00?o0000ooooooooool00Oooool0017ooooo0_l0001Fooooo`03o`00oooooooooooo01Sooooo00?o
003oooooooooool04?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooo003o01Sooooo00?o
003oooooooooool07Oooool00ol00?ooooooo`00o`0?ooooo`;o003o1oooool2o`00o`oooooo00?o
003oooooooooool05?ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo05Gooooo00Co003o
oooooooooooo003o6Oooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo00?o
003oooooooooool05Oooool2o`00oaKooooo00Co003ooooooooooooo003o1Oooool00ol00?oooooo
o`00o`06ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool2o`00o`Oooooo
00?o003oooooooooool07Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`1Hooooo`03o`00oooooooooooo01Cooooo00Co003ooooooooooooo003o4?ooool00ol0003ooooo
ooooo`05ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool01?l00?oooooo
ooooool00?l7ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooo003o00Kooooo0_l00?l8ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool03?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`1Eooooo`04o`00ooooooooooooo`00oaKooooo00Co003ooooooooooooo003o4?ooool00ol0
003oooooooooo`03ooooo`03o`00oooooooo003o01Kooooo00?o003oooooool00?l05Oooool01Ol0
0?oooooooooooooooooo003o00Oooooo00?o003oooooooooool00oooool01?l00?ooooooooooool0
0?l5ooooo`03o`00oooooooooooo00Kooooo00?o003oooooool00?l01_ooool2o`00o`Oooooo0_l0
0?l7ooooo`03o`00oooooooooooo00cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool0EOooool01?l00?ooooooooooool00?lFooooo`04o`00ooooooooooooo`00oa3ooooo
00?o0000ooooooooool00oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo01?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooo
oooo003o1Oooool00ol00?ooooooo`00o`0?ooooo`03o`00oooooooooooo00Kooooo0_l00?l7oooo
o`03o`00oooooooooooo00cooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001Fooooo`03
o`00oooooooooooo01Oooooo00?o003oooooooooool04Oooool00ol0003oooooooooo`02ooooo`04
o`00ooooooooooooo`00oaSooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0;oooo
o`;o00000oooool0017ooooo00?o0000ooooooooool0EOooool01?l00?ooooooooooool00?lZoooo
o`03o`000?oooooooooo00;ooooo00Co003ooooooooooooo003o5_ooool00ol00?ooooooo`00o`0N
ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool01_ooool00ol00?ooooooo`00
o`06ooooo`03o`00oooooooo003o00Oooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool0F?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00kooooo00?o0000
ooooooooool01Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00Go003o
ooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo
003o1oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Kooooo0_l00?l8ooooo`03
o`00oooooooooooo00Cooooo0_l00?l>ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo05Sooooo00?o003oooooooooool05?ooool01?l00?ooooooooooool00?l@ooooo`03
o`000?oooooooooo00;ooooo00Co003ooooooooooooo003o5Oooool00ol00?ooooooooooo`0Foooo
o`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`03ooooo`04o`00oooooooo
ooooo`00o`Gooooo00?o003oooooooooool01_ooool00ol00?ooooooo`00o`06ooooo`;o003o1_oo
ool00ol00?ooooooo`00o`06ooooo`;o003o1oooool00ol00?ooooooooooo`04ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo05Cooooo00Go003oooooooooooooooooo`00
o`0Fooooo`04o`00ooooooooooooo`00oa3ooooo00?o0000ooooooooool00_ooool00ol00?oooooo
ooooo`0Iooooo`03o`00oooooooooooo01?ooooo00Go003oooooooooooooooooo`00o`04ooooo`03
o`00oooooooooooo00Kooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooooooo`0?oooo
o`;o003o1_ooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Dooooo`03
o`00oooooooooooo01Oooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`02ooooo`03
o`00oooooooooooo01Wooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`05ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooool00?l01oooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Cooooo00?o0000ooooooooool00Oooool0017ooooo0_l0000=ooooo`03o`00
oooooooooooo04Gooooo00?o003oooooooooool0;?ooool00ol0003oooooooooo`02ooooo`04o`00
ooooooooooooo`00oaGooooo00Co003ooooooooooooo003o7_ooool01?l00?ooooooooooool00?l>
ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l01oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool2o`0000?ooooo000Aoooo
o`03o`000?oooooooooo00cooooo00?o003oooooooooool0BOooool00ol00?ooooooooooo`0Goooo
o`03o`00oooooooooooo00kooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`0Coooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`03
ooooo`04o`00ooooooooooooo`00o`Oooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`04ooooo`;o003o3_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0<
ooooo`03o`00oooooooooooo04Wooooo00?o003oooooooooool04oooool01Ol00?oooooooooooooo
oooo003o013ooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`0Cooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00?ooooo00Co003ooooooooooooo003o3Oooool01?l00?ooooooooooool00?l5ooooo`03
o`00oooooooo003o00Sooooo00?o003oooooooooool01?ooool2o`00o`Oooooo00?o003ooooooooo
ool01?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0<ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool0??ooool01Ol00?oooooooooooooooooo003o01Go
oooo00Go003oooooooooooooooooo`00o`0@ooooo`05o`000?ooooooooooooooool00?l06Oooool0
1?l00?ooooooooooool00?lDooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03
o`00oooooooooooo00oooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`07ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo03cooooo00?o003oooooooooool0
5oooool01Ol00?oooooooooooooooooo003o013ooooo00Go0000ooooooooooooooooo`00o`0Loooo
o`03o`00oooooooooooo01Oooooo00Go003oooooooooooooooooo`00o`0<ooooo`03o`00oooooooo
oooo00;ooooo00Co003ooooooooooooo003o3_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooo003o00Oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`;o00003Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo03gooooo00?o003oooooooooool0;?ooool01Ol0003ooooooooooooooooo003o00?ooooo00?o
003oooooooooool04_ooool01Ol00?oooooooooooooooooo003o01gooooo00Go003ooooooooooooo
ooooo`00o`0=ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o3_ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool2
o`0000?ooooo000Aooooo`03o`000?oooooooooo00_ooooo0_l00?l8ooooo`03o`00oooooooooooo
03cooooo00Go003oooooooooooooooooo`00o`0Iooooo`03o`00oooooooooooo00kooooo00?o0000
ooooooooool01Oooool00ol00?ooooooooooo`0Booooo`05o`00ooooooooooooooooool00?l05?oo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00oooool01?l00?oooooo
ooooool00?l7ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03Oooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0;ooooo`;o003o2?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo03Sooooo00?o003oooooooooool04_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00kooooo00?o0000ooooooooool01Oooool00ol00?oooooo
ooooo`0Booooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`07ooooo`03
o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`08oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`05oooo
o`03o`000?oooooooooo007ooooo0009ooooo`?o00001Oooool00ol0003oooooooooo`0;ooooo`;o
003o1oooool2o`00o`Oooooo00?o003oooooooooool0<oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0>ooooo`04
o`000?ooooooooooo`00o`Cooooo00?o003oooooooooool04_ooool01Ol00?oooooooooooooooooo
003o01Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00oooooo00?o
003oooooool00?l01Oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Kooooo
00?o003oooooooooool01Oooool00ol0003oooooooooo`01ooooo`002_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool01_ooool2o`00o`Oooooo00?o
003oooooooooool0<oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0>ooooo`04o`000?ooooooooooo`00oagooooo
00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l02?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o3Oooool0
0ol00?ooooooooooo`06ooooo`04o`00ooooooooooooo`00o`Oooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo007ooooo0002ooooo`Go00000oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0cooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool04oooool0
1?l0003oooooooooool00?l4ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool06ooo
ool01Ol00?oooooooooooooooooo003o00Sooooo00?o003oooooooooool00_ooool01?l00?oooooo
ooooool00?l4ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05oooo
o`03o`000?oooooooooo007ooooo000:ooooo`03o`000?oooooooooo00Cooooo0ol0000;ooooo`;o
003o1oooool2o`00o`Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Zooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Oooooo`04
o`000?ooooooooooo`00o`Cooooo00?o003oooooooooool04_ooool01Ol00?oooooooooooooooooo
003o01?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l02?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooo
ooooo`00o`07ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0<ooooo`?o00000oooool000[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0;ooooo`;o003o2?ooool00ol00?ooooooooooo`04ooooo`;o003o1oooool00ol00?oooooo
ooooo`0`ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00kooooo00?o0000ooooooooool01Oooool00ol00?oooooo
ooooo`0Aooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`05ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooooooooooo
o`00o`Sooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`0>ooooo`03o`000?oooooo
oooo007ooooo0009ooooo`;o00001_ooool00ol0003oooooooooo`0;ooooo`;o003o1oooool2o`00
o`Kooooo0_l00?l7ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03_ooool01?l0
003oooooooooool00?l4ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool05_ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00Go003oooooooooooooooooo`00
o`04ooooo`05o`00ooooooooooooooooool00?l02?ooool01Ol00?oooooooooooooooooo003o00Co
oooo00Co003ooooooooooooo003o1Oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo
003o00Kooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`01ooooo`002_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool01_ooool2o`00
o`Oooooo00?o003oooooooooool01Oooool2o`00obcooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03_ooool01?l0
003oooooooooool00?l=ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool04Oooool0
0ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o017ooooo00Co003ooooooooooooo003o1Oooool01?l00?oo
ooooooooool00?l7ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02;o
oooo00?o003oooooooooool02_ooool2o`00o`[ooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`06ooooo`03o`000?oooooo003o00kooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`0Jooooo`03o`00oooooooooooo00_ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooo
oooo00Kooooo00Co003ooooooooooooo003o1oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00Kooooo00?o0000ooooooooool00Oooool0017ooooo0_l0000=ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`;o003o1oooool0
0ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00_ooooo0_l00?lHooooo`03o`00oooooooo
oooo00Kooooo00?o0000ooooool00?l01Oooool00ol00?ooooooooooo`05ooooo`;o003o2_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0:ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooo
oooooooo003o00Oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00kooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`0:ooooo`03o`00oooo
oooo003o00Sooooo00?o003oooooooooool01?ooool2o`00o`Oooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo00Cooooo0ol00?l@ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00oooo
oooooooo00Gooooo0_l00?l:ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool00ooo
ool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l03?ooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o3_ooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooo003o00Sooooo00?o003ooooo
ooooool01?ooool2o`00o`Oooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04oooo
o`;o003o2?ooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool01Oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool02_ooool0
1Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooooooo`06oooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00[ooooo00?o003oooooool0
0?l01_ooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00Gooooo0_l00?l7ooooo`03
o`00oooooooooooo027ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Aooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool03_ooool00ol0003oooooo`00o`0=ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03
o`00oooooooooooo00Cooooo00Co003ooooooooooooo003o2?ooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l04Oooool01?l00?ooooooooooool00?l4ooooo`05o`00oooo
ooooooooooooool00?l01oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Kooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool04oooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`0Qooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol0003oooooo`00
o`0>ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool05oooool01?l00?oooooooooo
ool00?l=ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Kooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00Cooooo0_l00?l7ooooo`03o`00oooooooooooo01Wo
oooo00?o003oooooooooool02_ooool00ol00?ooooooo`00o`0Gooooo`;o003o2?ooool00ol0003o
ooooo`00o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l02Oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`01oooo
o`004Oooool2o`0000_ooooo00?o003oooooool00?l02?ooool00ol00?ooooooooooo`04ooooo`;o
003o1_ooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool07oooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00oa3ooooo00?o003ooooo
ooooool01?ooool2o`00o`Sooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooo003o00Wooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l=
ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool03_ooool2o`0000?ooooo000Aooooo`03o`000?oooooo
oooo00[ooooo00?o003oooooool00?l02?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
003o00Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo01oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01?ooool2o`00o`Sooooo00?o0000ooooooooool01Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool0
1?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00Gooooo00Go003ooooooooooooooooo
o`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooooooo`06oooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00[ooooo00?o003oooooool0
0?l01Oooool01?l00?ooooooooooool00?l7ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ool00?l01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Sooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`07ooooo`03o`000?l00?oooooo00Gooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool01Oooool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00oa7ooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?oo
ooooooooool00?l5ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool04_ooool01?l00?ooooooooooool00?l7ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01?ooool2o`00oa3ooooo00?o003oooooooooool03oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o0000o`00ooooool03_ooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooo003o00Sooooo00?o003oooooooooool00oooool01?l0
0?ooooooooooool00?l4ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool0
1Ol00?oooooooooooooooooo003o00Oooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`07ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01;ooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo0_l00?l7
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0:
ooooo`04o`00ooooooooooooo`00o`Wooooo00?o003oooooooooool02_ooool00ol00?ooooooo`00
o`08ooooo`03o`000?l00?oooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00Gooooo0_l00?lBooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool01_ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool00Oooool0017o
oooo0_l0000:ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o1Oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooo003o00Oooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l05_ooool00ol00?ooooooo`00
o`08ooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool00oooool01?l00?oooooooooo
ool00?l8ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00oooool01?l00?oooooo
ooooool00?l=ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool03oooool2o`0000?ooooo000Aooooo`03
o`000?oooooooooo00Wooooo00Co003ooooooooooooo003o2?ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooo003o00Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooool00?l02?ooool00ol0003oooooooooo`05ooooo`03o`00oooooooo
oooo00?ooooo00Co003ooooooooooooo003o2?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01Oooool01?l00?ooooooooooool00?l5ooooo`03o`00
oooooooooooo00Gooooo00Co003ooooooooooooo003o1Oooool01?l00?ooooooooooool00?l4oooo
o`03o`00oooooooooooo00Kooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool01oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`09ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o1Ooo
ool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Sooooo00?o0000o`00ooooool01Ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Ooo
ool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Oooooo00?o003ooooooooo
ool00oooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l01?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`07ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Wooooo00?o003o
ooooooooool01_ooool01?l00?ooooooooooool00?l7ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooool00?l01_ooool00ol00?ooooooooooo`0>ooooo`;o003o4Oooool00ol00?oooooooooo
o`04ooooo`05o`00ooooooooooooooooool00?l03Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00kooooo00?o0000o`00ooooool03_ooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Gooooo0_l00?l8ooooo`03o`00oooooooooooo00Gooooo0_l00?l9ooooo`03o`00
oooooooooooo00?ooooo00Co003ooooooooooooo003o4?ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00Oooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
4_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
0oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00Co003ooooooooooooo
003o2?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool01Oooool2o`00oa7ooooo00?o003oooooooooool03Oooool00ol00?ooooooo`00o`05ooooo`04
o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o2?ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01oooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`09ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`05ooooo`04o`00ooooooooooooo`00o`Gooooo00?o
003oooooool00?l01_ooool2o`00o`Oooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0Cooooo`04o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooo003o00Sooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l5oooo
o`03o`00oooooooooooo00Gooooo00Go003oooooooooooooooooo`00o`08ooooo`03o`00oooooooo
oooo013ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0000:ooooo`04o`00oooooooooooo
o`00o`Sooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool01?ooool2o`00o`Oooooo0_l00?l7ooooo`03o`00oooo
oooooooo00kooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`So
oooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l02?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Gooooo0_l00?l6oooo
o`03o`00oooooooo003o00kooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Kooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00_ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`08ooooo`05o`00oooooooo
ooooooooool00?l02?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Gooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`;o003o2?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool01?l00?oooooo
ooooool00?l8ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l01_ooool00ol00?oo
ooooo`00o`08ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o1?ooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l02_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`08ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00Oo
oooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo
00oooooo0_l00?l7ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool01?l0
0?ooooooooooool00?l>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool01?ooool0
0ol00?ooooooo`00o`08ooooo`03o`00oooooooooooo00Gooooo0_l00?l8ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooool00?l04Oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l01?ooool00ol00?ooooooooooo`05ooooo`05o`00ooooooooooooooooool00?l0
2_ooool00ol0003oooooooooo`01ooooo`002_ooool2o`0000Gooooo00?o0000ooooooooool04Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00ooo
ool00ol00?ooooooo`00o`0?ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o013ooooo0_l00?l?ooooo`03o`00oooo
oooo003o00Gooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool01Oooool01Ol00?oooooooooooooooooo003o00[ooooo
00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`0<ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01_ooool2o`00o`Oooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0Booooo`05o`00ooooooooooooooooool0
0?l02?ooool00ol00?ooooooooooo`05ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooo`00o`0Aooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool01Oooool0
1?l00?ooooooooooool00?l8ooooo`03o`00oooooooooooo017ooooo00?o0000ooooooooool00Ooo
ool000Wooooo00Co0000oooooooooooo00001?ooool;o`000005o`00ool0003o0000o`000?l00?l0
2?l000000ol00?oo0000o`000002o`000004o`00ool0003o0000o`00o`Go000000Co003oo`000?l0
003o003o1ol000000ol00?oo0000o`000004o`0000;o003o1ol00002o`00o`Oo000000?o003oo`00
0?l000003_l000001?l00?oo0000o`000?l00?l5o`000003o`00ool0003o000000ko000000Go003o
o`000?l0003o0000o`00o`03o`000003o`00ool0003o000000ko000000Go003oo`000?l0003o0000
o`00o`04o`000003o`00ool0003o000000Go000000?o003oo`000?l000001Ol000000ol00?oo0000
o`000003o`000003o`00ool0003o000000So000000?o003oo`000?l000001_l00002o`00o`Ko0000
00?o003oo`000?l00?l03_l000001?l00?oo0000o`000?l00?l5o`000003o`00ool0003o000000Go
000000?o003oo`000?l000002Ol000000ol00?oo0000o`000002o`000003o`00ool0003o000000go
00000oooool000Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`08ooooo`05
o`00ooooooooooooooooool00?l02?ooool00ol00?ooooooooooo`02ooooo`04o`00oooooooooooo
o`00o`Gooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
003o00Sooooo00?o003oooooooooool01?ooool2o`00oa3ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol00?oooooooooo
oooooooo003o00cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`06ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`05ooooo`03o`00
oooooooooooo00Kooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o
00[ooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`08ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooo
oooo003o00Oooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l4ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?oo0000ooooo`06ooooo`05o`00
ooooooooooooooooool00?l03?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00?o
oooo00Co003ooooooooooooo003o1oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Gooooo0_l00?l7ooooo`;o003o4Oooool00ol00?ooooooooooo`03ooooo`04o`00oooooooooooo
o`00o`Gooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00[ooooo
00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`0Aooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o3_ooool00ol00?ooooooo`00o`0@oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00gooooo00?o003oo`000?ooool03oooool00ol00?ooooooooooo`0=oooo
o`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o1oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00kooooo0_l00?l6ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00Go003o
ooooooooooooooooo`00o`0:ooooo`03o`000?oooooooooo007ooooo000:ooooo`;o00001Oooool0
0ol0003oooooooooo`0Aooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01_oo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`05ooooo`03o`00ool0003ooooo00Kooooo00Co003ooooooooooooo003o
1Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
0oooool01?l00?ooooooooooool00?l@ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool01_ooool2o`00o`Kooooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`08ooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Sooooo00Go003ooooooooooooo
ooooo`00o`08ooooo`05o`00ooooooooooooooooool00?l02?ooool01Ol00?oooooooooooooooooo
003o00Oooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo
003o00Kooooo0_l00?l7ooooo`03o`00oooooooooooo00Kooooo00?o003oooooool00?l01_ooool0
0ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo0_l00?l?ooooo`03o`00oooo
oooo003o00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo017ooooo00?o0000ooooooooool00Oooool0017ooooo0_l00009ooooo`05o`00oooooooo
ooooooooool00?l02?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l0
2?ooool00ol00?ooooooooooo`04ooooo`;o003o4?ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool01oooool01?l00?ooooooooooool00?l4ooooo`03
o`00oooooooooooo00Kooooo00?o0000ooooooooool01Oooool01?l00?ooooooooooool00?l5oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Gooooo0_l00?l7ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ool00?l01_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ool00?l01Oooool01?l00?ooooooooooool00?l:ooooo`;o00000oooool0017ooooo00?o0000oooo
ooooool02?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooool00?l02?ooool00ol00?oooooooooo
o`04ooooo`;o003o1oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`07ooooo`04o`00ooooooooooooo`00o`cooooo
00?o003oo`000?ooool01_ooool01?l00?ooooooooooool00?l<ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Go
oooo0_l00?l7ooooo`;o003o2?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Go
oooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`04o`00oooooooooooo
o`00o`_ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03oooool00ol0
0?ooooooo`00o`0?ooooo`03o`00oooooooooooo00Kooooo0_l00?l>ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool03Oooool00ol00?oo0000ooooo`0?ooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Kooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo0_l00?l6
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o2oooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Gooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooool000004?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`0Qooooo`;o003o1_ooool00ol00?ooooooo`00o`06ooooo`03o`00
oooooooo003o00Oooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`08ooooo`03o`00
oooooooooooo00Wooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol00?oooooo
ooooo`06ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l5oooo
o`03o`00oooooooo003o00Gooooo00?o003oooooooooool01oooool2o`00o`Oooooo00?o003ooooo
ooooool01_ooool2o`00o`Oooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooool000001oooool01?l00?ooooooo`00ool00?l5
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01_ooool01Ol00?oooooooooooooo
oooo003o00_ooooo00?o003oooooooooool03oooool2o`00o`Sooooo00?o003oooooooooool01?oo
ool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l02?oo
ool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo007ooooo000Aooooo`;o00002?ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Kooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`02ooooo`04o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool01?ooool2o`00oa3ooooo
0_l00?l7ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01oooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol00?oooooo
o`00o`06ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool00ol00?oooooo
ooooo`0?ooooo`;o003o3oooool00ol00?ooooooo`00o`06ooooo`;o003o1_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool02oooool2o`0000?ooooo
000Aooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l02?ooool00ol00?ooooooooooo`06ooooo`04o`00ooooooooooooo`00o`Sooooo00?o003o
ooooooooool00oooool00ol00?ooooooo`00o`0@ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooo`000007ooooo`03o`00oooooooo003o00cooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo0_l00?l6
ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool0
0?l;ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Oooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool01Ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0Aooooo`04
o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07oooo
o`;o003o3Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ool000008?ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Kooooo00?o003oooooooooool01Oooool0
1?l00?ooooooooooool00?l;ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo00oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`06ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool03oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool02?ooool2o`00o`Kooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00
000@ooooo`03o`00oooooooooooo00gooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00
oooooooooooo01oooooo00?o003oooooooooool01Oooool2o`00o`Sooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo
003o2oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0<ooooo`04o`00
ooooooooooooo`00o`Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`04o`00oooooooooooo
o`00o`Gooooo00?o003oooooooooool01_ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo
oooo00Oooooo0_l00?l7ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooo000000Oooooo00?o003oooooool00?l01_ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Oooooo00Co003ooooooooooooo003o1Ooo
ool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00Gooooo0_l00?l7ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooool00?l02?ooool00ol00?ooooooooooo`0Booooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`06ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooooooooooooooo
o`00o`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool01?l00?oooooo
ooooool00?l5ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l04?ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00kooooo0_l00?l6ooooo`03o`00oooooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
01Sooooo00?o003oooooooooool01Oooool2o`00o`Oooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03?ooool00ol0
003oooooooooo`01ooooo`004Oooool2o`0000Sooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`06ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`0<
ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o2?ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooo003o01Wooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`08ooooo`;o003o1_ooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0_l0
0?l=ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0Hooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool2o`00o`Kooooo00?o
003oooooooooool01_ooool2o`00o`Kooooo00?o003oooooool00?l02oooool2o`0000?ooooo000A
ooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool00oooool01?l00?ooooooooooool0
0?l5ooooo`03o`00oooooooooooo00Gooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00
ooooooooooooooooool00?l02oooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00
o`Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool02oooool01?l00?ooooooooooool00007ooooo`;o003o3Oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooo003o00Kooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool0
0ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l03?ooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`0;ooooo`04o`00ooooooooooooo`00o`kooooo00?o
003oooooooooool05_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00Co
003ooooooooooooo00004?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo003o00Kooooo
00?o003oooooooooool07oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooool00?l03?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`0<ooooo`04o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool02oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`03oooo
o`04o`00ooooooooooooo`0000Oooooo0_l00?l7ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool02?ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo02Oooooo0_l00?l7
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool01_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Kooooo00Co003ooooo
oooooooo003o2?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l0
1?ooool01?l00?ooooooooooool00?l6ooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo
ool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o0000oooooooo
ool01Oooool2o`00o`Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooo003o00cooooo00?o003oooooooooool08Oooool2o`00o`Oooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o0000oooooooo
ool00Oooool0017ooooo0_l00007ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
1_ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l03?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`02
ooooo`04o`00ooooooooooooo`00oaWooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`;o003o1oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Oooooo00?o
003oooooooooool08Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01_ooool2o`00o`Kooooo00?o003oooooool00?l02oooool2o`0000?ooooo000A
ooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool00oooool01?l00?ooooooooooool0
0?l5ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o2?ooool00ol00?oooooo
ooooo`06ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol00?ooooooooooo`02ooooo`04
o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02oooool01?l00?ooooooooooool00007
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`05
ooooo`;o003o1oooool2o`00o`Kooooo00?o003oooooool00?l03?ooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00Co003ooooo
oooooooo003o4Oooool01Ol00?oooooooooooooooooo003o00gooooo00?o003oooooooooool05_oo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00_ooooo00Co003ooooooooooooo0000
4?ooool00ol00?ooooooooooo`0=ooooo`;o003o1oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo02[ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Gooooo0_l00?l=ooooo`03o`000?oooooooooo007ooooo0009ooooo`?o00001Ooo
ool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?oo
ool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04Oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo0000013ooooo00?o003oooooooooool03Oooool2o`00o`Oooooo00?o003ooooo
ooooool0<?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo0_l00?l7oooo
o`03o`00oooooooooooo00_ooooo00?o0000ooooooooool00Oooool000[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool0
0?l02?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooo
oooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`06ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool04Ooo
ool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool03_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Sooooo0_l00?l<ooooo`03o`00oooo
oooooooo02_ooooo00?o003oooooooooool01Oooool2o`00o`Sooooo00?o003oooooooooool04ooo
ool00ol0003oooooooooo`01ooooo`002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
003o00Gooooo00Co003ooooooooooooo003o3Oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00oaWo
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Ko
oooo00?o0000ooooooooool03_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Ko
oooo00?o003oooooooooool0:oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0<ooooo`03o`000?oooooooooo007o
oooo000:ooooo`03o`000?oooooooooo00Cooooo0ol00005ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`So
oooo00?o003oooooooooool01_ooool01Ol00?oooooooooooooooooo003o00Sooooo00?o003ooooo
ooooool00_ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo017ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00000Dooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0[ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`05ooooo`;o003o2oooool3o`0000?ooooo000:ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01Oooool01?l00?ooooooooooool00?l5ooooo`04o`00oooo
ooooooooo`00oa7ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Gooooo`05o`00oooooooooooooooo
ool00000:Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo03?ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`05ooooo`;o003o3Oooool00ol0003oooooooooo`01oooo
o`002Oooool2o`0000Kooooo00?o0000ooooooooool03_ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool01_ooool00ol00?ooooooo`00o`05ooooo`04
o`00ooooooooooooo`00o`Wooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Foooo
o`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
0000013ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0hooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01Oooool2o`00o`gooooo00?o0000ooooooooool00Oooool0
00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`00oooooooo003o
00Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o
00Gooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00Sooooo00Go
003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool0
5_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool000004?ooool01Ol00?oo
oooooooooooooooo003o01Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0coooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool05?ooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003ooooo
ooooool01Oooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool05oooool01Ol00?oooooo
oooooooooooo003o01Cooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`0>ooooo`05
o`00ooooooooooooooooool00?l06Oooool00ol00?ooooooooooo`0cooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0<ooooo`03o`000?oooooooooo
007ooooo000Aooooo`;o00001_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`04o`00ooooooooooooo`00
o`Cooooo00?o003oooooooooool01_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool05oooool01Ol00?oooooooooooooooooo003o01Cooooo00Go003ooooooooooooooooo
o`00o`04ooooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool04_ooool01Ol00?oooooo
oooooooooooo003o03oooooo00?o003oooooooooool01Oooool2o`00o`cooooo0_l00003ooooo`00
4Oooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l0
1_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l0
3Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`08oooo
o`03o`00oooooooooooo01Kooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`02oooo
o`03o`000?oooooooooo02Oooooo00Go003oooooooooooooooooo`00o`0oooooo`03o`00oooooooo
oooo00Gooooo0_l00?l=ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo
01Kooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo
01Kooooo00?o003oooooooooool0@Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool03?ooool2o`00o`So
oooo00?o003oooooooooool03Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00
o`Cooooo00Go003oooooooooooooooooo`00o`0<ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool04_ooool00ol00?ooooooooooo`0Fooooo`05o`00ooooooooooooooooool00?l01?oo
ool00ol0003oooooooooo`0>ooooo`04o`00ooooooooooooo`00oaGooooo00?o003oooooooooool0
BOooool00ol00?ooooooooooo`0<ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`;o003o2?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o
1?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo01Oooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`06oooo
o`03o`000?oooooooooo00kooooo00Co003ooooooooooooo003o6Oooool00ol00?ooooooooooo`1D
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`06ooooo`;o003o1_ooool00ol00?ooooooo`00o`0>oooo
o`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool01_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool05oooool01?l00?ooooooooooool00?lEooooo`03o`00
oooooooooooo00Kooooo00?o0000ooooooooool03_ooool01?l00?ooooooooooool00?lIooooo`03
o`00oooooooooooo04Gooooo00?o003oooooooooool03?ooool00ol0003oooooooooo`01ooooo`00
4Oooool2o`0000Gooooo00?o003oooooooooool01Oooool2o`00o`Oooooo00?o003oooooooooool0
1Oooool00ol00?ooooooo`00o`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
1_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool04_ooool01?l00?ooooooooooool00?lIooooo`03o`00oooooooooooo00;ooooo00?o0000oooo
ooooool04Oooool00ol00?ooooooooooo`0Cooooo`05o`00ooooooooooooooooool00?l0Aoooool0
0ol00?ooooooooooo`0;ooooo`;o00000oooool0017ooooo00?o0000ooooooooool03Oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol0
0?ooooooo`00o`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`0Eooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool00_ooool00ol0
003oooooooooo`0>ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0F?ooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0=ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool03Oooool2o`00o`Kooooo00?o003oooooool00?l02?ooool00ol00?oo
ooooooooo`0;ooooo`05o`00ooooooooooooooooool00?l05Oooool00ol00?ooooooooooo`0Foooo
o`04o`00ooooooooooooo`00o`Gooooo00?o0000ooooooooool03_ooool01?l00?ooooooooooool0
0?lEooooo`03o`00oooooooooooo05Sooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`;o003o2?ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`05
ooooo`04o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o01Gooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`06ooooo`03o`00
0?oooooooooo00kooooo00?o003oooooool00?l06_ooool00ol00?ooooooooooo`1Dooooo`03o`00
0?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo0_l00?l?ooooo`03o`00oooo
oooo003o00Gooooo00?o003oooooooooool01_ooool01?l00?ooooooooooool00?l4ooooo`03o`00
oooooooooooo01Oooooo00?o003oooooool00?l05_ooool00ol00?ooooooooooo`06ooooo`03o`00
0?oooooooooo00kooooo00?o003oooooool00?l06_ooool00ol00?ooooooooooo`1Dooooo`03o`00
0?oooooooooo007ooooo000Aooooo`;o00003Oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00Gooooo0_l00?l8ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`06ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooooooooooo
ooooo`00o`0Eooooo`03o`00oooooooo003o01Kooooo00Co003ooooooooooooo003o1Oooool00ol0
003oooooooooo`0@ooooo`03o`00oooooooooooo01Cooooo00Co003ooooooooooooo003oE_ooool2
o`0000?ooooo000Aooooo`03o`000?oooooooooo00cooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`05ooooo`;o003o1oooool2o`00oa7ooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05oooool00ol0
0?ooooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00Co003ooooooooooooo003oEoooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`;o003o1_ooool00ol0
0?ooooooo`00o`08ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool05Oooool00ol0
0?ooooooooooo`0Dooooo`03o`00oooooooo003o00Kooooo00?o0000ooooooooool03_ooool00ol0
0?ooooooooooo`0Fooooo`03o`00oooooooooooo05Sooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool01Oooool2o`00o`Kooooo00?o003oooooool00?l01Oooool01?l00?oo
ooooooooool00?l8ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0E
ooooo`03o`00oooooooooooo01Kooooo00?o003oooooool00?l01_ooool00ol0003oooooooooo`0>
ooooo`03o`00oooooooo003o01Kooooo00Co003ooooooooooooo003oEoooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00Gooooo0_l00?l7
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool0
0?l5ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool05oooool00ol00?oooooo
o`00o`0Fooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol00?oooooo
o`00o`0Iooooo`03o`00oooooooooooo05Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool05Oooool00ol00?ooooooooooo`05ooooo`;o003o2?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooooooo01Oooooo00?o003oooooool00?l05_ooool00ol00?ooooooo`00
o`06ooooo`03o`000?oooooooooo00oooooo00?o003oooooooooool05Oooool01?l00?oooooooooo
ool00?mGooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00005_ooool00ol00?oooooooooo
o`05ooooo`;o003o1oooool2o`00o`kooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00
o`08ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05oooool00ol00?oooooooooo
o`04ooooo`03o`000?oooooooooo02Oooooo00Co003ooooooooooooo003oE_ooool2o`0000?ooooo
000Aooooo`03o`000?oooooooooo01gooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05oooool00ol00?oooooooooo
o`04ooooo`03o`000?oooooooooo00kooooo00?o003oooooooooool05_ooool00ol00?oooooooooo
o`1Hooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01gooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool00ol00?ooooooo`00o`08
ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o5_ooool00ol00?oooooooooo
o`0Fooooo`03o`00oooooooo003o00Kooooo00?o0000ooooooooool03_ooool2o`00oaOooooo00?o
003oooooooooool0F?ooool00ol0003oooooooooo`01ooooo`002?ooool5o`0000Cooooo00?o0000
ooooooooool07Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo0_l00?l6
ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`0G
ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`0>
ooooo`;o003o6Oooool00ol00?ooooooooooo`1Fooooo`03o`000?oooooooooo007ooooo0009oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool07Oooool00ol00?ooooooooooo`0>
ooooo`;o003o1_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooooooool05oooool2o`00oaOooooo0_l00?l7ooooo`03o`000?oooooooooo00kooooo0_l00?lI
ooooo`03o`00oooooooooooo05Kooooo00?o0000ooooooooool00Oooool000[ooooo00?o0000oooo
ooooool01?ooool3o`0001gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=oooo
o`03o`00oooooooo003o00Kooooo00?o003oooooool00?l02?ooool00ol00?ooooooooooo`0Doooo
o`;o003o6?ooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo00oooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooo`00o`1Fooooo`?o00000oooool000_ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Vooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool05?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00Gooooo00?o0000oooooooo
ool03_ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo05Sooooo00?o0000oooooooo
ool00Oooool000Sooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo02Ko
oooo00?o003oooooooooool01Oooool2o`00o`Oooooo00?o003oooooooooool03Oooool01?l00?oo
ooooooooool00?lFooooo`03o`00oooooooooooo01Kooooo0_l00?l7ooooo`03o`000?oooooooooo
00kooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`1Hooooo`03o`000?oooooooooo
007ooooo0008ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Voooo
o`03o`00oooooooooooo00Gooooo0_l00?l6ooooo`;o003o2?ooool00ol00?ooooooooooo`04oooo
o`04o`00ooooooooooooo`00oaKooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`06
ooooo`03o`000?oooooooooo00kooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`1F
ooooo`03o`000?oooooooooo007ooooo0009ooooo`?o00001Oooool00ol0003oooooooooo`0^oooo
o`;o003o1_ooool00ol00?ooooooooooo`06ooooo`;o003o1_ooool00ol00?ooooooooooo`0Goooo
o`03o`00oooooooooooo01Kooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`0>oooo
o`03o`00oooooooooooo01Sooooo00?o003oooooooooool0E_ooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`0^ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool01_ooool2o`00o`Kooooo00?o003oooooool00?l0<?ooool2o`00o`Oooooo00?o0000oooooooo
ool03_ooool00ol00?ooooooooooo`0Fooooo`;o003oFOooool00ol0003oooooooooo`01ooooo`00
4Oooool2o`0003Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo02kooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`0Wooooo`;o003o
F?ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo02kooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo003o033ooooo00?o003oooooooooool01_oo
ool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0F?oo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0^ooooo`03o`00oooooooo
oooo00Gooooo0_l00?l8ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l0>Oooool0
0ol0003oooooooooo`0Wooooo`;o003oFOooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`0fooooo`03o`00oooooooooooo00Kooooo0_l00?l6ooooo`03o`00oooooooooooo
03Wooooo00?o0000ooooooooool0:?ooool00ol00?ooooooooooo`1Gooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo03Oooooo00?o003oooooooooool01Oooool2o`00o`Ko
oooo00?o003oooooooooool0>Oooool00ol0003oooooooooo`0Wooooo`;o003oFOooool00ol0003o
ooooooooo`01ooooo`004Oooool2o`0003Sooooo00?o003oooooooooool01Oooool2o`00o`Sooooo
00?o003oooooooooool0=oooool00ol0003oooooooooo`0Wooooo`;o003oF?ooool2o`0000?ooooo
000Aooooo`03o`000?oooooooooo03Oooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo03Oooooo00?o0000ooooooooool09oooool00ol00?oooooooooo
o`1Hooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo03oooooo00?o003o
ooooooooool01Oooool3o`00ocWooooo00?o0000ooooooooool09oooool00ol00?ooooooooooo`1H
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo03oooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0iooooo`03o`000?oooooooooo02Oooooo00?o003ooooo
ooooool0F?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0oooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool0>Oooool00ol0003oooooooooo`0Wooooo`03
o`00oooooooooooo05Sooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
?oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo03Sooooo00?o0000ooooooooool0
9oooool00ol00?ooooooooooo`1Hooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000@?oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo03Sooooo00?o0000ooooooooool0POoo
ool2o`0000?ooooo000Aooooo`03o`000?oooooooooo04Oooooo0_l00?ljooooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Aoooool00ol0
0?ooooooooooo`0iooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool0Aoooool00ol00?ooooooooooo`0iooooo`03o`000?oooooooooo08;o
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Aoooool2o`00oc[ooooo
00?o0000ooooooooool0P_ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0004Wooooo00?o
003oooooooooool0>?ooool00ol0003oooooooooo`21ooooo`;o00000oooool0017ooooo00?o0000
ooooooooool0Aoooool00ol00?ooooooooooo`0iooooo`03o`000?oooooooooo08;ooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Aoooool00ol00?ooooooooooo`0ioooo
o`03o`000?oooooooooo08;ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0Poooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00Oooool0017oooooool0000=o`0000?ooooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.95693, -3.43838, \
0.0394232, 0.0363282}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Magnitude plot of DFT as a function of frequency", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fft\  = \ DFT[xd];\)\), "\n", 
    \(\(g3 = 
        DiscreteListPlot[\({#[\([1]\)], \ Abs[#[\([2]\)]]} &\)\  /@ \ fft, 
          Red, \ PlotRange \[Rule] All, \ Frame \[Rule] True, \ 
          Axes \[Rule] False];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0328407 0.0147151 0.00981006 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18801 -0.0125 -3 -9 ]
[.18801 -0.0125 3 0 ]
[.35222 -0.0125 -6 -9 ]
[.35222 -0.0125 6 0 ]
[.51642 -0.0125 -6 -9 ]
[.51642 -0.0125 6 0 ]
[.68062 -0.0125 -6 -9 ]
[.68062 -0.0125 6 0 ]
[.84483 -0.0125 -6 -9 ]
[.84483 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11282 -12 -4.5 ]
[-0.0125 .11282 0 4.5 ]
[-0.0125 .21092 -12 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18801 0 m
.18801 .00625 L
s
[(5)] .18801 -0.0125 0 1 Mshowa
.35222 0 m
.35222 .00625 L
s
[(10)] .35222 -0.0125 0 1 Mshowa
.51642 0 m
.51642 .00625 L
s
[(15)] .51642 -0.0125 0 1 Mshowa
.68062 0 m
.68062 .00625 L
s
[(20)] .68062 -0.0125 0 1 Mshowa
.84483 0 m
.84483 .00625 L
s
[(25)] .84483 -0.0125 0 1 Mshowa
.125 Mabswid
.05665 0 m
.05665 .00375 L
s
.08949 0 m
.08949 .00375 L
s
.12233 0 m
.12233 .00375 L
s
.15517 0 m
.15517 .00375 L
s
.22085 0 m
.22085 .00375 L
s
.25369 0 m
.25369 .00375 L
s
.28654 0 m
.28654 .00375 L
s
.31938 0 m
.31938 .00375 L
s
.38506 0 m
.38506 .00375 L
s
.4179 0 m
.4179 .00375 L
s
.45074 0 m
.45074 .00375 L
s
.48358 0 m
.48358 .00375 L
s
.54926 0 m
.54926 .00375 L
s
.5821 0 m
.5821 .00375 L
s
.61494 0 m
.61494 .00375 L
s
.64778 0 m
.64778 .00375 L
s
.71346 0 m
.71346 .00375 L
s
.74631 0 m
.74631 .00375 L
s
.77915 0 m
.77915 .00375 L
s
.81199 0 m
.81199 .00375 L
s
.87767 0 m
.87767 .00375 L
s
.91051 0 m
.91051 .00375 L
s
.94335 0 m
.94335 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11282 m
.00625 .11282 L
s
[(10)] -0.0125 .11282 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(20)] -0.0125 .21092 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(30)] -0.0125 .30902 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(40)] -0.0125 .40712 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(50)] -0.0125 .50522 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(60)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .0932 m
.00375 .0932 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .17168 m
.00375 .17168 L
s
0 .1913 m
.00375 .1913 L
s
0 .23054 m
.00375 .23054 L
s
0 .25016 m
.00375 .25016 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .32864 m
.00375 .32864 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .4856 m
.00375 .4856 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .56408 m
.00375 .56408 L
s
0 .5837 m
.00375 .5837 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18801 .61178 m
.18801 .61803 L
s
.35222 .61178 m
.35222 .61803 L
s
.51642 .61178 m
.51642 .61803 L
s
.68062 .61178 m
.68062 .61803 L
s
.84483 .61178 m
.84483 .61803 L
s
.125 Mabswid
.05665 .61428 m
.05665 .61803 L
s
.08949 .61428 m
.08949 .61803 L
s
.12233 .61428 m
.12233 .61803 L
s
.15517 .61428 m
.15517 .61803 L
s
.22085 .61428 m
.22085 .61803 L
s
.25369 .61428 m
.25369 .61803 L
s
.28654 .61428 m
.28654 .61803 L
s
.31938 .61428 m
.31938 .61803 L
s
.38506 .61428 m
.38506 .61803 L
s
.4179 .61428 m
.4179 .61803 L
s
.45074 .61428 m
.45074 .61803 L
s
.48358 .61428 m
.48358 .61803 L
s
.54926 .61428 m
.54926 .61803 L
s
.5821 .61428 m
.5821 .61803 L
s
.61494 .61428 m
.61494 .61803 L
s
.64778 .61428 m
.64778 .61803 L
s
.71346 .61428 m
.71346 .61803 L
s
.74631 .61428 m
.74631 .61803 L
s
.77915 .61428 m
.77915 .61803 L
s
.81199 .61428 m
.81199 .61803 L
s
.87767 .61428 m
.87767 .61803 L
s
.91051 .61428 m
.91051 .61803 L
s
.94335 .61428 m
.94335 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11282 m
1 .11282 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .50522 m
1 .50522 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03434 m
1 .03434 L
s
.99625 .05396 m
1 .05396 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .0932 m
1 .0932 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .15206 m
1 .15206 L
s
.99625 .17168 m
1 .17168 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .23054 m
1 .23054 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .26978 m
1 .26978 L
s
.99625 .2894 m
1 .2894 L
s
.99625 .32864 m
1 .32864 L
s
.99625 .34826 m
1 .34826 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .44636 m
1 .44636 L
s
.99625 .46598 m
1 .46598 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .52484 m
1 .52484 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .56408 m
1 .56408 L
s
.99625 .5837 m
1 .5837 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .30902 L
s
.05665 .01472 m
.05665 .01472 L
s
.08949 .01472 m
.08949 .01472 L
s
.12233 .01472 m
.12233 .30902 L
s
.15517 .01472 m
.15517 .01472 L
s
.18801 .01472 m
.18801 .01472 L
s
.22085 .01472 m
.22085 .60332 L
s
.25369 .01472 m
.25369 .01472 L
s
.28654 .01472 m
.28654 .01472 L
s
.31938 .01472 m
.31938 .01472 L
s
.35222 .01472 m
.35222 .01472 L
s
.38506 .01472 m
.38506 .01472 L
s
.4179 .01472 m
.4179 .01472 L
s
.45074 .01472 m
.45074 .01472 L
s
.48358 .01472 m
.48358 .01472 L
s
.51642 .01472 m
.51642 .01472 L
s
.54926 .01472 m
.54926 .01472 L
s
.5821 .01472 m
.5821 .01472 L
s
.61494 .01472 m
.61494 .01472 L
s
.64778 .01472 m
.64778 .01472 L
s
.68062 .01472 m
.68062 .01472 L
s
.71346 .01472 m
.71346 .01472 L
s
.74631 .01472 m
.74631 .01472 L
s
.77915 .01472 m
.77915 .01472 L
s
.81199 .01472 m
.81199 .60332 L
s
.84483 .01472 m
.84483 .01472 L
s
.87767 .01472 m
.87767 .01472 L
s
.91051 .01472 m
.91051 .30902 L
s
.94335 .01472 m
.94335 .01472 L
s
.97619 .01472 m
.97619 .01472 L
s
.015 w
.02381 .30902 Mdot
.05665 .01472 Mdot
.08949 .01472 Mdot
.12233 .30902 Mdot
.15517 .01472 Mdot
.18801 .01472 Mdot
.22085 .60332 Mdot
.25369 .01472 Mdot
.28654 .01472 Mdot
.31938 .01472 Mdot
.35222 .01472 Mdot
.38506 .01472 Mdot
.4179 .01472 Mdot
.45074 .01472 Mdot
.48358 .01472 Mdot
.51642 .01472 Mdot
.54926 .01472 Mdot
.5821 .01472 Mdot
.61494 .01472 Mdot
.64778 .01472 Mdot
.68062 .01472 Mdot
.71346 .01472 Mdot
.74631 .01472 Mdot
.77915 .01472 Mdot
.81199 .60332 Mdot
.84483 .01472 Mdot
.87767 .01472 Mdot
.91051 .30902 Mdot
.94335 .01472 Mdot
.97619 .01472 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005oooool2o`0002Wooooo0ol0000Uooooo`?o00001?ooool2o`0002?ooooo0ol00003oooo
o`?o00008_ooool5o`0000?ooooo0_l0000Qooooo`Go00000_ooool3o`0002[ooooo000Fooooo`04
o`000?ooooooooooo`0002Oooooo00Go0000ooooooooooooooooo`00000Uooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00008oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool08?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
027ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo02Oooooo000F
ooooo`04o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02Oooooo000Fooooo`04o`000?ooooooooooo`0002_o
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
02?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Rooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool09oooool001Kooooo00Co0000oooooooooooo00009oooool4o`0002Kooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co0000
8_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0
003ooooooooooooooooo0000ooooo`Co0000:_ooool001Kooooo00Co0000oooooooooooo00009ooo
ool00ol0003oooooooooo`0Vooooo`;o00001?ooool01?l0003oooooooooool0000Rooooo`;o0000
0oooool00ol0003oooooooooo`0Sooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool0000Pooooo`07o`000?ooooooooooooooool0003oooooo`00000]ooooo`005oooool2
o`0002Sooooo1Ol0000Uooooo`03o`000?oooooooooo00?ooooo0_l0000Tooooo`04o`000?oooooo
ooooooooo`Go00008_ooool3o`0000Cooooo0_l0000Rooooo`?o00000_ooool5o`0002Wooooo003o
ooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Boooooooo00002ol0
0004ooooo`002oooool2o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`002_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool00_ooool000[ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0:
ooooo`?oo`001_ooool3ool000oooooo0ooo0005ooooo`?oo`003oooool3ool000Kooooo0ooo0005
ooooo`?oo`001_ooool3ool000Kooooo0ooo0005ooooo`?oo`001_ooool3ool000Kooooo0ooo0006
ooooo`?oo`001Oooool3ool000Kooooo0ooo0006ooooo`?oo`001Oooool3ool000Kooooo0ooo0006
ooooo`?oo`001_ooool3ool000Gooooo0ooo000?ooooo`?oo`001Oooool3ool000oooooo0ooo0006
ooooo`?oo`001?ooool00ol0003oooooooooo`02ooooo`002_ooool01?l0003oooooooooool00004
ooooo`?o00000oooool00ooo003oooooooooo`04ooooo`?oo`001_ooool3ool000Oooooo00?oo`00
ooooooooool01Oooool3ool000Gooooo0ooo0008ooooo`03ool00?oooooooooo00Cooooo0ooo0006
ooooo`?oo`001Oooool3ool000Kooooo0ooo0006ooooo`?oo`001Oooool3ool000Kooooo0ooo0006
ooooo`?oo`001_ooool3ool000Gooooo0ooo0006ooooo`?oo`001_ooool3ool000Gooooo0ooo0006
ooooo`?oo`001_ooool3ool000Kooooo0ooo0005ooooo`?oo`001oooool00ooo003oooooooooo`05
ooooo`?oo`001Oooool3ool000Sooooo00?oo`00ooooooooool01?ooool3ool000Kooooo0ooo0003
ooooo`;o00001?ooool000[ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03
ooooo`03ool00?oooooooooo00Cooooo0ooo0006ooooo`?oo`001oooool00ooo003oooooooooo`05
ooooo`?oo`001Oooool3ool000Sooooo00?oo`00ooooooooool01?ooool3ool000Kooooo0ooo0005
ooooo`?oo`001_ooool3ool000Kooooo0ooo0005ooooo`?oo`001_ooool3ool000Kooooo0ooo0006
ooooo`?oo`001Oooool3ool000Kooooo0ooo0006ooooo`?oo`001Oooool3ool000Kooooo0ooo0006
ooooo`?oo`001_ooool3ool000Gooooo0ooo0007ooooo`03ool00?oooooooooo00Gooooo0ooo0005
ooooo`?oo`002?ooool00ooo003oooooooooo`04ooooo`?oo`001_ooool3ool000Cooooo00?o0000
ooooooooool00_ooool000[ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03
ooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`2I
ooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool05?ooool00ol0003oooooooooo`02
ooooo`002oooool2o`0000Gooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0Goooo
o`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool0VOooool00ooo003oooooooooo`0Hoooo
o`03ool00?oooooooooo01Cooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000oooooooo
ool00oooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01Sooooo00?oo`00oooooooo
ool0VOooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo01Cooooo00?o0000oooooooo
ool00_ooool001;ooooo0_l00004ooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool0
6?ooool00ooo003oooooooooo`2Iooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool0
4oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool05ooo
ool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo09Wooooo00?oo`00ooooooooool06?oo
ool00ooo003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooo
oooo00?ooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Hooooo`03ool00?oooooo
oooo09Wooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`0Dooooo`03o`000?oooooo
oooo00;ooooo000Booooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool05oooool00ooo
003oooooooooo`0Hooooo`03ool00?oooooooooo09Wooooo00?oo`00ooooooooool06?ooool00ooo
003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo00?o
oooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo09Wo
oooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`0Dooooo`03o`000?oooooooooo00;o
oooo000Booooo`;o00001?ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01Sooooo
00?oo`00ooooooooool0VOooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo01?ooooo
0_l00004ooooo`004_ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo01Oooooo00?o
o`00ooooooooool06?ooool00ooo003oooooooooo`2Iooooo`03ool00?oooooooooo01Sooooo00?o
o`00ooooooooool05?ooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`03
ooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`2I
ooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool05?ooool00ol0003oooooooooo`02
ooooo`004_ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo01Oooooo00?oo`00oooo
ooooool06?ooool00ooo003oooooooooo`2Iooooo`03ool00?oooooooooo01Sooooo00?oo`00oooo
ooooool05?ooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`03ooooo`03
ool00?oooooooooo01Oooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`2Iooooo`03
ool00?oooooooooo01Sooooo00?oo`00ooooooooool05?ooool00ol0003oooooooooo`02ooooo`00
4_ooool2o`0000Cooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Hooooo`03ool0
0?oooooooooo09Wooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`0Cooooo`;o0000
1?ooool001;ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0Gooooo`03ool00?oo
oooooooo01Sooooo00?oo`00ooooooooool0VOooool00ooo003oooooooooo`0Hooooo`03ool00?oo
oooooooo01Cooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool00oooool0
0ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool0VOooool0
0ooo003oooooooooo`0Hooooo`03ool00?oooooooooo01Cooooo00?o0000ooooooooool00_ooool0
01;ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo
01Sooooo00?oo`00ooooooooool0VOooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo
01Cooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool00oooool00ooo003o
ooooooooo`0Gooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool0VOooool00ooo003o
ooooooooo`0Hooooo`03ool00?oooooooooo01Cooooo00?o0000ooooooooool00_ooool001;ooooo
00?o0000ooooooooool00oooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01Sooooo
00?oo`00ooooooooool0VOooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo01Cooooo
00?o0000ooooooooool00_ooool001;ooooo0_l00004ooooo`03ool00?oooooooooo01Oooooo00?o
o`00ooooooooool06?ooool00ooo003oooooooooo`2Iooooo`03ool00?oooooooooo01Sooooo00?o
o`00ooooooooool04oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo00?ooooo00?oo`00
ooooooooool05oooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo09Wooooo00?oo`00
ooooooooool06?ooool00ooo003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo0004oooo
o`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0Goooo
o`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool0VOooool00ooo003oooooooooo`0Hoooo
o`03ool00?oooooooooo01Cooooo00?o0000ooooooooool00_ooool000Gooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?oo`00oooo
ooooool05oooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo09Wooooo00?oo`00oooo
ooooool06?ooool00ooo003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo0005ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03oooo
o`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`2Ioooo
o`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool05?ooool00ol0003oooooooooo`02oooo
o`001Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo0ol00003oooo
o`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`2Ioooo
o`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool04oooool2o`0000Cooooo0005ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03oooo
o`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`2Ioooo
o`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool05?ooool00ol0003oooooooooo`02oooo
o`001?ooool2o`0000Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03oooo
o`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`2Ioooo
o`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool05?ooool00ol0003oooooooooo`02oooo
o`001Oooool00ol0003oooooooooo`03ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`03
ool00?oooooooooo01Oooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`2Iooooo`03
ool00?oooooooooo01Sooooo00?oo`00ooooooooool05?ooool00ol0003oooooooooo`02ooooo`00
4_ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool0
6?ooool00ooo003oooooooooo`2Iooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool0
5?ooool00ol0003oooooooooo`02ooooo`004_ooool2o`0000Cooooo00?oo`00ooooooooool05ooo
ool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo09Wooooo00?oo`00ooooooooool06?oo
ool00ooo003oooooooooo`0Cooooo`;o00001?ooool001;ooooo00?o0000ooooooooool00oooool0
0ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool0VOooool0
0ooo003oooooooooo`0Hooooo`03ool00?oooooooooo01Cooooo00?o0000ooooooooool00_ooool0
01;ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo
01Sooooo00?oo`00ooooooooool0VOooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo
01Cooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool00oooool00ooo003o
ooooooooo`0Gooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool0VOooool00ooo003o
ooooooooo`0Hooooo`03ool00?oooooooooo01Cooooo00?o0000ooooooooool00_ooool001;ooooo
00?o0000ooooooooool00oooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01Sooooo
00?oo`00ooooooooool0VOooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo01Cooooo
00?o0000ooooooooool00_ooool001;ooooo0_l00004ooooo`03ool00?oooooooooo01Oooooo00?o
o`00ooooooooool06?ooool00ooo003oooooooooo`2Iooooo`03ool00?oooooooooo01Sooooo00?o
o`00ooooooooool04oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo00?ooooo00?oo`00
ooooooooool05oooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo09Wooooo00?oo`00
ooooooooool06?ooool00ooo003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo000Boooo
o`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Hoooo
o`03ool00?oooooooooo09Wooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`0Doooo
o`03o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo00?ooooo00?oo`00oooooooo
ool05oooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo09Wooooo00?oo`00oooooooo
ool06?ooool00ooo003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`00
0?oooooooooo00?ooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Hooooo`03ool0
0?oooooooooo09Wooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`0Dooooo`03o`00
0?oooooooooo00;ooooo000Booooo`;o00001?ooool00ooo003oooooooooo`0Gooooo`03ool00?oo
oooooooo01Sooooo00?oo`00ooooooooool0VOooool00ooo003oooooooooo`0Hooooo`03ool00?oo
oooooooo01?ooooo0_l00004ooooo`004_ooool00ol0003oooooooooo`03ooooo`03ool00?oooooo
oooo01Oooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`2Iooooo`03ool00?oooooo
oooo01Sooooo00?oo`00ooooooooool05?ooool00ol0003oooooooooo`02ooooo`004_ooool00ol0
003oooooooooo`03ooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool06?ooool00ooo
003oooooooooo`2Iooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool05?ooool00ol0
003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo01Oo
oooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`2Iooooo`03ool00?oooooooooo01So
oooo00?oo`00ooooooooool05?ooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003ooooo
ooooo`03ooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool06?ooool00ooo003ooooo
ooooo`2Iooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool05?ooool00ol0003ooooo
ooooo`02ooooo`004_ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo01Oooooo00?o
o`00ooooooooool06?ooool00ooo003oooooooooo`2Iooooo`03ool00?oooooooooo01Sooooo00?o
o`00ooooooooool05?ooool00ol0003oooooooooo`02ooooo`004_ooool2o`0000Cooooo00?oo`00
ooooooooool05oooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo09Wooooo00?oo`00
ooooooooool06?ooool00ooo003oooooooooo`0Cooooo`;o00001?ooool001;ooooo00?o0000oooo
ooooool00oooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01Sooooo00?oo`00oooo
ooooool0VOooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo01Cooooo00?o0000oooo
ooooool00_ooool000?ooooo1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`03
ool00?oooooooooo01Oooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`2Iooooo`03
ool00?oooooooooo01Sooooo00?oo`00ooooooooool05?ooool00ol0003oooooooooo`02ooooo`00
1?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool00oooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01Sooooo00?oo`00oooo
ooooool0VOooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo01Cooooo00?o0000oooo
ooooool00_ooool000Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Hoooo
o`03ool00?oooooooooo09Wooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`0Doooo
o`03o`000?oooooooooo00;ooooo0006ooooo`05o`000?ooooooooooooooool000000_ooool00ol0
003oooooooooo`02ooooo`?o00000oooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo
01Sooooo00?oo`00ooooooooool0VOooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo
01?ooooo0_l00004ooooo`000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo01Oooooo00?oo`00
ooooooooool06?ooool00ooo003oooooooooo`2Iooooo`03ool00?oooooooooo01Sooooo00?oo`00
ooooooooool05?ooool00ol0003oooooooooo`02ooooo`000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03ooooo`03ool00?oo
oooooooo01Oooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`2Iooooo`03ool00?oo
oooooooo01Sooooo00?oo`00ooooooooool05?ooool00ol0003oooooooooo`02ooooo`001?ooool3
o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool05oooool0
0ooo003oooooooooo`0Hooooo`03ool00?oooooooooo09Wooooo00?oo`00ooooooooool06?ooool0
0ooo003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo
00?ooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo
09Wooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`0Dooooo`03o`000?oooooooooo
00;ooooo000Booooo`;o00001?ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01So
oooo00?oo`00ooooooooool0VOooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo01?o
oooo0_l00004ooooo`004_ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo01Oooooo
00?oo`00ooooooooool06?ooool00ooo003oooooooooo`2Iooooo`03ool00?oooooooooo01Sooooo
00?oo`00ooooooooool05?ooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003ooooooooo
o`03ooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool06?ooool00ooo003ooooooooo
o`2Iooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool05?ooool00ol0003ooooooooo
o`02ooooo`004_ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo01Oooooo00?oo`00
ooooooooool06?ooool00ooo003oooooooooo`2Iooooo`03ool00?oooooooooo01Sooooo00?oo`00
ooooooooool05?ooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`03oooo
o`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`2Ioooo
o`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool05?ooool00ol0003oooooooooo`02oooo
o`004_ooool2o`0000Cooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Hooooo`03
ool00?oooooooooo09Wooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`0Cooooo`;o
00001?ooool001;ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0Gooooo`03ool0
0?oooooooooo01Sooooo00?oo`00ooooooooool0VOooool00ooo003oooooooooo`0Hooooo`03ool0
0?oooooooooo01Cooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool00ooo
ool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool0VOoo
ool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo01Cooooo00?o0000ooooooooool00_oo
ool001;ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0Gooooo`03ool00?oooooo
oooo01Sooooo00?oo`00ooooooooool0VOooool00ooo003oooooooooo`0Hooooo`03ool00?oooooo
oooo01Cooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool00oooool00ooo
003oooooooooo`0Gooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool0VOooool00ooo
003oooooooooo`0Hooooo`03ool00?oooooooooo01Cooooo00?o0000ooooooooool00_ooool001;o
oooo0_l00004ooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool06?ooool00ooo003o
ooooooooo`2Iooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool04oooool2o`0000Co
oooo000Booooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool05oooool00ooo003ooooo
ooooo`0Hooooo`03ool00?oooooooooo09Wooooo00?oo`00ooooooooool06?ooool00ooo003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo00?ooooo00?o
o`00ooooooooool05oooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo09Wooooo00?o
o`00ooooooooool06?ooool00ooo003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo000B
ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0H
ooooo`03ool00?oooooooooo09Wooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`0D
ooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo00?ooooo00?oo`00oooo
ooooool05oooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo09Wooooo00?oo`00oooo
ooooool06?ooool00ooo003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo000Booooo`03
o`000?oooooooooo00?ooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Hooooo`03
ool00?oooooooooo09Wooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`0Dooooo`03
o`000?oooooooooo00;ooooo000Booooo`;o00001?ooool00ooo003oooooooooo`0Gooooo`03ool0
0?oooooooooo01Sooooo00?oo`00ooooooooool0VOooool00ooo003oooooooooo`0Hooooo`03ool0
0?oooooooooo01?ooooo0_l00004ooooo`004_ooool00ol0003oooooooooo`03ooooo`03ool00?oo
oooooooo01Oooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`2Iooooo`03ool00?oo
oooooooo01Sooooo00?oo`00ooooooooool05?ooool00ol0003oooooooooo`02ooooo`001?ooool3
o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool05oooool0
0ooo003oooooooooo`0Hooooo`03ool00?oooooooooo09Wooooo00?oo`00ooooooooool06?ooool0
0ooo003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo0003ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o
o`00ooooooooool05oooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo09Wooooo00?o
o`00ooooooooool06?ooool00ooo003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo0007
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`?oo`005oooool3ool001Wooooo00?oo`00ooooooooool0VOooool00ooo003ooooooooo
o`0Fooooo`?oo`005_ooool00ol0003oooooooooo`02ooooo`001Oooool2o`0000?ooooo00Co0000
oooooooooooo00001?ooool3o`0000;ooooo0ooo000Gooooo`?oo`006Oooool00ooo003ooooooooo
o`2Iooooo`03ool00?oooooooooo01Kooooo0ooo000Eooooo`;o00001?ooool000Oooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo0ooo
000Gooooo`?oo`006Oooool00ooo003oooooooooo`2Iooooo`03ool00?oooooooooo01Kooooo0ooo
000Fooooo`03o`000?oooooooooo00;ooooo0003ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03Sooooo00?oo`00ooooooooool0
VOooool00ooo003oooooooooo`0_ooooo`03o`000?oooooooooo00;ooooo0004ooooo`?o00001?oo
ool2o`0000Gooooo00?o0000ooooooooool0>?ooool00ooo003oooooooooo`2Iooooo`03ool00?oo
oooooooo02oooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0>?ooool0
0ooo003oooooooooo`2Iooooo`03ool00?oooooooooo02oooooo00?o0000ooooooooool00_ooool0
01;ooooo0_l0000iooooo`03ool00?oooooooooo09Wooooo00?oo`00ooooooooool0;_ooool2o`00
00Cooooo000Booooo`03o`000?oooooooooo03Sooooo00?oo`00ooooooooool0VOooool00ooo003o
ooooooooo`0_ooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo03Sooooo
00?oo`00ooooooooool0VOooool00ooo003oooooooooo`0_ooooo`03o`000?oooooooooo00;ooooo
000Booooo`03o`000?oooooooooo03Sooooo00?oo`00ooooooooool0VOooool00ooo003ooooooooo
o`0_ooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo03Sooooo00?oo`00
ooooooooool0VOooool00ooo003oooooooooo`0_ooooo`03o`000?oooooooooo00;ooooo000Boooo
o`;o0000>Oooool00ooo003oooooooooo`2Iooooo`03ool00?oooooooooo02kooooo0_l00004oooo
o`004_ooool00ol0003oooooooooo`0hooooo`03ool00?oooooooooo09Wooooo00?oo`00oooooooo
ool0;oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`0hooooo`03ool0
0?oooooooooo09Wooooo00?oo`00ooooooooool0;oooool00ol0003oooooooooo`02ooooo`004_oo
ool00ol0003oooooooooo`0hooooo`03ool00?oooooooooo09Wooooo00?oo`00ooooooooool0;ooo
ool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`0hooooo`03ool00?oooooo
oooo09Wooooo00?oo`00ooooooooool0;oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0
003oooooooooo`0hooooo`03ool00?oooooooooo09Wooooo00?oo`00ooooooooool0;oooool00ol0
003oooooooooo`02ooooo`004_ooool2o`0003Wooooo00?oo`00ooooooooool0VOooool00ooo003o
ooooooooo`0^ooooo`;o00001?ooool001;ooooo00?o0000ooooooooool0>?ooool00ooo003ooooo
ooooo`2Iooooo`03ool00?oooooooooo02oooooo00?o0000ooooooooool00_ooool001;ooooo00?o
0000ooooooooool0>?ooool00ooo003oooooooooo`2Iooooo`03ool00?oooooooooo02oooooo00?o
0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0>?ooool00ooo003oooooooooo`2I
ooooo`03ool00?oooooooooo02oooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000oooo
ooooool0>?ooool00ooo003oooooooooo`2Iooooo`03ool00?oooooooooo02oooooo00?o0000oooo
ooooool00_ooool001;ooooo0_l0000iooooo`03ool00?oooooooooo09Wooooo00?oo`00oooooooo
ool0;_ooool2o`0000Cooooo000Booooo`03o`000?oooooooooo03Sooooo00?oo`00ooooooooool0
VOooool00ooo003oooooooooo`0_ooooo`03o`000?oooooooooo00;ooooo0005ooooo`?o00000ooo
ool2o`0000Gooooo00?o0000ooooooooool0>?ooool00ooo003oooooooooo`2Iooooo`03ool00?oo
oooooooo02oooooo00?o0000ooooooooool00_ooool000Kooooo00Go0000ooooooooooooooooo`00
0002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>?ooool00ooo003ooooooooo
o`2Iooooo`03ool00?oooooooooo02oooooo00?o0000ooooooooool00_ooool000?ooooo1Ol00002
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>?ooool00ooo003ooooooooo
o`2Iooooo`03ool00?oooooooooo02oooooo00?o0000ooooooooool00_ooool000?ooooo00Co0000
oooooooooooo00000oooool01?l0003oooooooooool00004ooooo`?o0000>?ooool00ooo003ooooo
ooooo`2Iooooo`03ool00?oooooooooo02kooooo0_l00004ooooo`001?ooool00ol0003oooooo`00
0003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>?ooool00ooo003ooooo
ooooo`2Iooooo`03ool00?oooooooooo02oooooo00?o0000ooooooooool00_ooool000Gooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>?ooool00ooo003ooooo
ooooo`2Iooooo`03ool00?oooooooooo02oooooo00?o0000ooooooooool00_ooool000Kooooo00?o
0000ooooooooool00_ooool2o`0000Gooooo00?o0000ooooooooool0>?ooool00ooo003ooooooooo
o`2Iooooo`03ool00?oooooooooo02oooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000
ooooooooool0>?ooool00ooo003oooooooooo`2Iooooo`03ool00?oooooooooo02oooooo00?o0000
ooooooooool00_ooool001;ooooo0_l0000iooooo`03ool00?oooooooooo09Wooooo00?oo`00oooo
ooooool0;_ooool2o`0000Cooooo000Booooo`03o`000?oooooooooo03Sooooo00?oo`00oooooooo
ool0VOooool00ooo003oooooooooo`0_ooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`00
0?oooooooooo03Sooooo00?oo`00ooooooooool0VOooool00ooo003oooooooooo`0_ooooo`03o`00
0?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo03Sooooo00?oo`00ooooooooool0VOoo
ool00ooo003oooooooooo`0_ooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooo
oooo03Sooooo00?oo`00ooooooooool0VOooool00ooo003oooooooooo`0_ooooo`03o`000?oooooo
oooo00;ooooo000Booooo`;o0000>Oooool00ooo003oooooooooo`2Iooooo`03ool00?oooooooooo
02kooooo0_l00004ooooo`004_ooool00ol0003oooooooooo`0hooooo`03ool00?oooooooooo09Wo
oooo00?oo`00ooooooooool0;oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003ooooo
ooooo`0hooooo`03ool00?oooooooooo09Wooooo00?oo`00ooooooooool0;oooool00ol0003ooooo
ooooo`02ooooo`004_ooool00ol0003oooooooooo`0hooooo`03ool00?oooooooooo09Wooooo00?o
o`00ooooooooool0;oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`0h
ooooo`03ool00?oooooooooo09Wooooo00?oo`00ooooooooool0;oooool00ol0003oooooooooo`02
ooooo`004_ooool00ol0003oooooooooo`0hooooo`03ool00?oooooooooo09Wooooo00?oo`00oooo
ooooool0;oooool00ol0003oooooooooo`02ooooo`004_ooool2o`0003Wooooo00?oo`00oooooooo
ool0VOooool00ooo003oooooooooo`0^ooooo`;o00001?ooool001;ooooo00?o0000ooooooooool0
>?ooool00ooo003oooooooooo`2Iooooo`03ool00?oooooooooo02oooooo00?o0000ooooooooool0
0_ooool001;ooooo00?o0000ooooooooool0>?ooool00ooo003oooooooooo`2Iooooo`03ool00?oo
oooooooo02oooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0>?ooool0
0ooo003oooooooooo`2Iooooo`03ool00?oooooooooo02oooooo00?o0000ooooooooool00_ooool0
01;ooooo00?o0000ooooooooool0>?ooool00ooo003oooooooooo`2Iooooo`03ool00?oooooooooo
02oooooo00?o0000ooooooooool00_ooool001;ooooo0_l0000iooooo`03ool00?oooooooooo09Wo
oooo00?oo`00ooooooooool0;_ooool2o`0000Cooooo000Booooo`03o`000?oooooooooo03Sooooo
00?oo`00ooooooooool0VOooool00ooo003oooooooooo`0_ooooo`03o`000?oooooooooo00;ooooo
0004ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>?ooool00ooo003ooooooooo
o`2Iooooo`03ool00?oooooooooo02oooooo00?o0000ooooooooool00_ooool000?ooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
>?ooool00ooo003oooooooooo`2Iooooo`03ool00?oooooooooo02oooooo00?o0000ooooooooool0
0_ooool000Oooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo03Sooooo00?oo`00ooooooooool0VOooool00ooo003oooooooooo`0_ooooo`03o`00
0?oooooooooo00;ooooo0007ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
0_ooool3o`0003Sooooo00?oo`00ooooooooool0VOooool00ooo003oooooooooo`0^ooooo`;o0000
1?ooool000?ooooo1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
>?ooool00ooo003oooooooooo`2Iooooo`03ool00?oooooooooo02oooooo00?o0000ooooooooool0
0_ooool000?ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo03Sooooo00?oo`00ooooooooool0VOooool00ooo003oooooooooo`0_ooooo`03o`00
0?oooooooooo00;ooooo0003ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0>?oo
ool00ooo003oooooooooo`2Iooooo`03ool00?oooooooooo02oooooo00?o0000ooooooooool00_oo
ool001;ooooo00?o0000ooooooooool0>?ooool00ooo003oooooooooo`2Iooooo`03ool00?oooooo
oooo02oooooo00?o0000ooooooooool00_ooool001;ooooo0_l0000iooooo`03ool00?oooooooooo
09Wooooo00?oo`00ooooooooool0;_ooool2o`0000Cooooo000Booooo`03o`000?oooooooooo03So
oooo00?oo`00ooooooooool0VOooool00ooo003oooooooooo`0_ooooo`03o`000?oooooooooo00;o
oooo000Booooo`03o`000?oooooooooo03Sooooo00?oo`00ooooooooool0VOooool00ooo003ooooo
ooooo`0_ooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo03Sooooo00?o
o`00ooooooooool0VOooool00ooo003oooooooooo`0_ooooo`03o`000?oooooooooo00;ooooo000B
ooooo`03o`000?oooooooooo03Sooooo00?oo`00ooooooooool0VOooool00ooo003oooooooooo`0_
ooooo`03o`000?oooooooooo00;ooooo000Booooo`;o0000>Oooool00ooo003oooooooooo`2Ioooo
o`03ool00?oooooooooo02kooooo0_l00004ooooo`004_ooool00ol0003oooooooooo`0hooooo`03
ool00?oooooooooo09Wooooo00?oo`00ooooooooool0;oooool00ol0003oooooooooo`02ooooo`00
4_ooool00ol0003oooooooooo`0hooooo`03ool00?oooooooooo09Wooooo00?oo`00ooooooooool0
;oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`0hooooo`03ool00?oo
oooooooo09Wooooo00?oo`00ooooooooool0;oooool00ol0003oooooooooo`02ooooo`004_ooool0
0ol0003oooooooooo`0hooooo`03ool00?oooooooooo09Wooooo00?oo`00ooooooooool0;oooool0
0ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`0hooooo`03ool00?oooooooooo
09Wooooo00?oo`00ooooooooool0;oooool00ol0003oooooooooo`02ooooo`004_ooool2o`0003Wo
oooo00?oo`00ooooooooool0VOooool00ooo003oooooooooo`0^ooooo`;o00001?ooool001;ooooo
00?o0000ooooooooool0>?ooool00ooo003oooooooooo`2Iooooo`03ool00?oooooooooo02oooooo
00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0>?ooool00ooo003ooooooooo
o`2Iooooo`03ool00?oooooooooo02oooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000
ooooooooool0>?ooool00ooo003oooooooooo`2Iooooo`03ool00?oooooooooo02oooooo00?o0000
ooooooooool00_ooool001;ooooo00?o0000ooooooooool0>?ooool00ooo003oooooooooo`2Ioooo
o`03ool00?oooooooooo02oooooo00?o0000ooooooooool00_ooool001;ooooo0_l0000iooooo`03
ool00?oooooooooo09Wooooo00?oo`00ooooooooool0;_ooool2o`0000Cooooo000Booooo`03o`00
0?oooooooooo03Sooooo00?oo`00ooooooooool0VOooool00ooo003oooooooooo`0_ooooo`03o`00
0?oooooooooo00;ooooo0004ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>?oo
ool00ooo003oooooooooo`2Iooooo`03ool00?oooooooooo02oooooo00?o0000ooooooooool00_oo
ool000?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0>?ooool00ooo003oooooooooo`2Iooooo`03ool00?oooooooooo02oooooo
00?o0000ooooooooool00_ooool000?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0=_ooool3ool009[ooooo0ooo000`ooooo`03
o`000?oooooooooo00;ooooo0003ooooo`Co00000oooool01?l0003oooooooooool00004ooooo`?o
0000=_ooool3ool009[ooooo0ooo000_ooooo`;o00001?ooool000?ooooo00?o0000ooooooooool0
1?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03Kooooo0ooo002Jooooo`?o
o`00<?ooool00ol0003oooooooooo`02ooooo`001?ooool00ol0003oooooooooo`03ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`02ooooo`00
1Oooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool001;oooooool0000;o`0000Cooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.83594, -6.23134, \
0.114735, 0.384092}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Phase plot of DFT as a function of index k", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fft\  = \ DFT[xd];\)\), "\n", 
    \(\(g4 = 
        DiscreteListPlot[\({#[\([1]\)], \ 
                Arg[#[\([2]\)] + 0.0000001]} &\)\  /@ \ fft, Red, \ 
          PlotRange \[Rule] {\(-\[Pi]\), \ \[Pi]}, \ Frame \[Rule] True, \ 
          Axes \[Rule] False];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0328407 0.309017 0.0983632 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18801 -0.0125 -3 -9 ]
[.18801 -0.0125 3 0 ]
[.35222 -0.0125 -6 -9 ]
[.35222 -0.0125 6 0 ]
[.51642 -0.0125 -6 -9 ]
[.51642 -0.0125 6 0 ]
[.68062 -0.0125 -6 -9 ]
[.68062 -0.0125 6 0 ]
[.84483 -0.0125 -6 -9 ]
[.84483 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01393 -12 -4.5 ]
[-0.0125 .01393 0 4.5 ]
[-0.0125 .11229 -12 -4.5 ]
[-0.0125 .11229 0 4.5 ]
[-0.0125 .21065 -12 -4.5 ]
[-0.0125 .21065 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40738 -6 -4.5 ]
[-0.0125 .40738 0 4.5 ]
[-0.0125 .50574 -6 -4.5 ]
[-0.0125 .50574 0 4.5 ]
[-0.0125 .60411 -6 -4.5 ]
[-0.0125 .60411 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18801 0 m
.18801 .00625 L
s
[(5)] .18801 -0.0125 0 1 Mshowa
.35222 0 m
.35222 .00625 L
s
[(10)] .35222 -0.0125 0 1 Mshowa
.51642 0 m
.51642 .00625 L
s
[(15)] .51642 -0.0125 0 1 Mshowa
.68062 0 m
.68062 .00625 L
s
[(20)] .68062 -0.0125 0 1 Mshowa
.84483 0 m
.84483 .00625 L
s
[(25)] .84483 -0.0125 0 1 Mshowa
.125 Mabswid
.05665 0 m
.05665 .00375 L
s
.08949 0 m
.08949 .00375 L
s
.12233 0 m
.12233 .00375 L
s
.15517 0 m
.15517 .00375 L
s
.22085 0 m
.22085 .00375 L
s
.25369 0 m
.25369 .00375 L
s
.28654 0 m
.28654 .00375 L
s
.31938 0 m
.31938 .00375 L
s
.38506 0 m
.38506 .00375 L
s
.4179 0 m
.4179 .00375 L
s
.45074 0 m
.45074 .00375 L
s
.48358 0 m
.48358 .00375 L
s
.54926 0 m
.54926 .00375 L
s
.5821 0 m
.5821 .00375 L
s
.61494 0 m
.61494 .00375 L
s
.64778 0 m
.64778 .00375 L
s
.71346 0 m
.71346 .00375 L
s
.74631 0 m
.74631 .00375 L
s
.77915 0 m
.77915 .00375 L
s
.81199 0 m
.81199 .00375 L
s
.87767 0 m
.87767 .00375 L
s
.91051 0 m
.91051 .00375 L
s
.94335 0 m
.94335 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01393 m
.00625 .01393 L
s
[(-3)] -0.0125 .01393 1 0 Mshowa
0 .11229 m
.00625 .11229 L
s
[(-2)] -0.0125 .11229 1 0 Mshowa
0 .21065 m
.00625 .21065 L
s
[(-1)] -0.0125 .21065 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .40738 m
.00625 .40738 L
s
[(1)] -0.0125 .40738 1 0 Mshowa
0 .50574 m
.00625 .50574 L
s
[(2)] -0.0125 .50574 1 0 Mshowa
0 .60411 m
.00625 .60411 L
s
[(3)] -0.0125 .60411 1 0 Mshowa
.125 Mabswid
0 .0336 m
.00375 .0336 L
s
0 .05327 m
.00375 .05327 L
s
0 .07295 m
.00375 .07295 L
s
0 .09262 m
.00375 .09262 L
s
0 .13196 m
.00375 .13196 L
s
0 .15164 m
.00375 .15164 L
s
0 .17131 m
.00375 .17131 L
s
0 .19098 m
.00375 .19098 L
s
0 .23033 m
.00375 .23033 L
s
0 .25 m
.00375 .25 L
s
0 .26967 m
.00375 .26967 L
s
0 .28934 m
.00375 .28934 L
s
0 .32869 m
.00375 .32869 L
s
0 .34836 m
.00375 .34836 L
s
0 .36803 m
.00375 .36803 L
s
0 .38771 m
.00375 .38771 L
s
0 .42705 m
.00375 .42705 L
s
0 .44673 m
.00375 .44673 L
s
0 .4664 m
.00375 .4664 L
s
0 .48607 m
.00375 .48607 L
s
0 .52542 m
.00375 .52542 L
s
0 .54509 m
.00375 .54509 L
s
0 .56476 m
.00375 .56476 L
s
0 .58443 m
.00375 .58443 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18801 .61178 m
.18801 .61803 L
s
.35222 .61178 m
.35222 .61803 L
s
.51642 .61178 m
.51642 .61803 L
s
.68062 .61178 m
.68062 .61803 L
s
.84483 .61178 m
.84483 .61803 L
s
.125 Mabswid
.05665 .61428 m
.05665 .61803 L
s
.08949 .61428 m
.08949 .61803 L
s
.12233 .61428 m
.12233 .61803 L
s
.15517 .61428 m
.15517 .61803 L
s
.22085 .61428 m
.22085 .61803 L
s
.25369 .61428 m
.25369 .61803 L
s
.28654 .61428 m
.28654 .61803 L
s
.31938 .61428 m
.31938 .61803 L
s
.38506 .61428 m
.38506 .61803 L
s
.4179 .61428 m
.4179 .61803 L
s
.45074 .61428 m
.45074 .61803 L
s
.48358 .61428 m
.48358 .61803 L
s
.54926 .61428 m
.54926 .61803 L
s
.5821 .61428 m
.5821 .61803 L
s
.61494 .61428 m
.61494 .61803 L
s
.64778 .61428 m
.64778 .61803 L
s
.71346 .61428 m
.71346 .61803 L
s
.74631 .61428 m
.74631 .61803 L
s
.77915 .61428 m
.77915 .61803 L
s
.81199 .61428 m
.81199 .61803 L
s
.87767 .61428 m
.87767 .61803 L
s
.91051 .61428 m
.91051 .61803 L
s
.94335 .61428 m
.94335 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01393 m
1 .01393 L
s
.99375 .11229 m
1 .11229 L
s
.99375 .21065 m
1 .21065 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .40738 m
1 .40738 L
s
.99375 .50574 m
1 .50574 L
s
.99375 .60411 m
1 .60411 L
s
.125 Mabswid
.99625 .0336 m
1 .0336 L
s
.99625 .05327 m
1 .05327 L
s
.99625 .07295 m
1 .07295 L
s
.99625 .09262 m
1 .09262 L
s
.99625 .13196 m
1 .13196 L
s
.99625 .15164 m
1 .15164 L
s
.99625 .17131 m
1 .17131 L
s
.99625 .19098 m
1 .19098 L
s
.99625 .23033 m
1 .23033 L
s
.99625 .25 m
1 .25 L
s
.99625 .26967 m
1 .26967 L
s
.99625 .28934 m
1 .28934 L
s
.99625 .32869 m
1 .32869 L
s
.99625 .34836 m
1 .34836 L
s
.99625 .36803 m
1 .36803 L
s
.99625 .38771 m
1 .38771 L
s
.99625 .42705 m
1 .42705 L
s
.99625 .44673 m
1 .44673 L
s
.99625 .4664 m
1 .4664 L
s
.99625 .48607 m
1 .48607 L
s
.99625 .52542 m
1 .52542 L
s
.99625 .54509 m
1 .54509 L
s
.99625 .56476 m
1 .56476 L
s
.99625 .58443 m
1 .58443 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .30902 m
.02381 .30902 L
s
.05665 .30902 m
.05665 .30902 L
s
.08949 .30902 m
.08949 .30902 L
s
.12233 .30902 m
.12233 .30902 L
s
.15517 .30902 m
.15517 .30902 L
s
.18801 .30902 m
.18801 .30902 L
s
.22085 .30902 m
.22085 .30902 L
s
.25369 .30902 m
.25369 .30902 L
s
.28654 .30902 m
.28654 .30902 L
s
.31938 .30902 m
.31938 .30902 L
s
.35222 .30902 m
.35222 .30902 L
s
.38506 .30902 m
.38506 .30902 L
s
.4179 .30902 m
.4179 .30902 L
s
.45074 .30902 m
.45074 .30902 L
s
.48358 .30902 m
.48358 .30902 L
s
.51642 .30902 m
.51642 .30902 L
s
.54926 .30902 m
.54926 .30902 L
s
.5821 .30902 m
.5821 .30902 L
s
.61494 .30902 m
.61494 .30902 L
s
.64778 .30902 m
.64778 .30902 L
s
.68062 .30902 m
.68062 .30902 L
s
.71346 .30902 m
.71346 .30902 L
s
.74631 .30902 m
.74631 .30902 L
s
.77915 .30902 m
.77915 .30902 L
s
.81199 .30902 m
.81199 .30902 L
s
.84483 .30902 m
.84483 .30902 L
s
.87767 .30902 m
.87767 .30902 L
s
.91051 .30902 m
.91051 .30902 L
s
.94335 .30902 m
.94335 .30902 L
s
.97619 .30902 m
.97619 .30902 L
s
.015 w
.02381 .30902 Mdot
.05665 .30902 Mdot
.08949 .30902 Mdot
.12233 .30902 Mdot
.15517 .30902 Mdot
.18801 .30902 Mdot
.22085 .30902 Mdot
.25369 .30902 Mdot
.28654 .30902 Mdot
.31938 .30902 Mdot
.35222 .30902 Mdot
.38506 .30902 Mdot
.4179 .30902 Mdot
.45074 .30902 Mdot
.48358 .30902 Mdot
.51642 .30902 Mdot
.54926 .30902 Mdot
.5821 .30902 Mdot
.61494 .30902 Mdot
.64778 .30902 Mdot
.68062 .30902 Mdot
.71346 .30902 Mdot
.74631 .30902 Mdot
.77915 .30902 Mdot
.81199 .30902 Mdot
.84483 .30902 Mdot
.87767 .30902 Mdot
.91051 .30902 Mdot
.94335 .30902 Mdot
.97619 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005oooool2o`0002Wooooo0ol0000Uooooo`?o00001?ooool2o`0002?ooooo0ol00003oooo
o`?o00008Oooool5o`0000?ooooo0_l0000Rooooo`Go00000_ooool3o`0002[ooooo000Fooooo`04
o`000?ooooooooooo`0002Oooooo00Go0000ooooooooooooooooo`00000Uooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00008oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool07oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
02;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo02Oooooo000F
ooooo`04o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02Oooooo000Fooooo`04o`000?ooooooooooo`0002_o
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
02?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Qooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool09oooool001Kooooo00Co0000oooooooooooo00009oooool4o`0002Kooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co0000
8Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00008Oooool01_l0
003ooooooooooooooooo0000ooooo`Co0000:_ooool001Kooooo00Co0000oooooooooooo00009ooo
ool00ol0003oooooooooo`0Vooooo`;o00001?ooool01?l0003oooooooooool0000Rooooo`;o0000
0oooool00ol0003oooooooooo`0Rooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool0000Qooooo`07o`000?ooooooooooooooool0003oooooo`00000]ooooo`005oooool2
o`0002Sooooo1Ol0000Uooooo`03o`000?oooooooooo00?ooooo0_l0000Tooooo`04o`000?oooooo
ooooooooo`Go00008Oooool3o`0000Cooooo0_l0000Sooooo`?o00000_ooool5o`0002Wooooo003o
ooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Boooooooo00002ol0
0004ooooo`002_ooool3o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`002Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`02ooooo`000oooool5o`0000Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool000_ooooo0_l00005ooooo`?o
0000ooooool5ooooo`?o00001?ooool000gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool000Wooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`002_oo
ool3o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000B
ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool2o`00
0?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003o
ooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool0
0_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000B
ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool2o`00
0?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003o
ooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool0
0_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000B
ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool2o`00
0?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003o
ooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool0
0_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000B
ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool2o`00
0?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003o
ooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool0
0_ooool000Wooooo1Ol00004ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooooooo
o`02ooooo`002_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo0?oooooo1ooo
ool00ol0003oooooooooo`02ooooo`000oooool5o`0000?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool000cooooo00?o0000oooo
ooooool00oooool3o`000?oooooo1Oooool3o`0000Cooooo0009ooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool000Wo
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0
003oooooooooo`02ooooo`002_ooool3o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`03
o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooo
ooooo`02ooooo`004_ooool2o`000?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooo
oooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3ooooo
o`Oooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03
o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooo
ooooo`02ooooo`004_ooool2o`000?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooo
oooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3ooooo
o`Oooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03
o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooo
ooooo`02ooooo`004_ooool2o`000?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooo
oooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3ooooo
o`Oooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03
o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooo
ooooo`02ooooo`004_ooool2o`000?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooo
oooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3ooooo
o`Oooooo00?o0000ooooooooool00_ooool000[ooooo0ol00005ooooo`03o`000?oooooooooo0?oo
oooo1oooool00ol0003oooooooooo`02ooooo`002oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`000oooool5o`0000?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_oo
ool000_ooooo00?o0000ooooooooool01?ooool3o`000?oooooo1Oooool3o`0000Cooooo000;oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo
00;ooooo000:ooooo`;o00001_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000oooooooo
ool00_ooool000_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00;ooooo000Booooo`;o0000ooooool7ooooo`;o00001?ooool001;ooooo00?o0000oooo
ooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oo
oooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00;ooooo000Booooo`;o0000ooooool7ooooo`;o00001?ooool001;ooooo00?o0000oooo
ooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oo
oooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00;ooooo000Booooo`;o0000ooooool7ooooo`;o00001?ooool001;ooooo00?o0000oooo
ooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oo
oooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02
ooooo`004_ooool2o`000?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo0?oo
oooo1oooool00ol0003oooooooooo`02ooooo`002oooool2o`0000Gooooo00?o0000ooooooooool0
ooooool7ooooo`03o`000?oooooooooo00;ooooo000:ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000:ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool00_ooool3ool000Kooooo0ooo0005ooooo`?oo`00
1_ooool3ool000Kooooo0ooo0005ooooo`?oo`001_ooool3ool000Kooooo0ooo0006ooooo`?oo`00
1Oooool3ool000Kooooo0ooo0006ooooo`?oo`001Oooool3ool000Kooooo0ooo0006ooooo`?oo`00
1_ooool3ool000Gooooo0ooo0006ooooo`?oo`001_ooool3ool000Gooooo0ooo0006ooooo`?oo`00
1_ooool3ool000Gooooo0ooo0006ooooo`?oo`001_ooool3ool000Kooooo0ooo0005ooooo`?oo`00
1_ooool3ool000Kooooo0ooo0005ooooo`?oo`001Oooool00ol0003oooooooooo`02ooooo`002_oo
ool01?l0003oooooooooool00004ooooo`?o00000_ooool3ool000Kooooo0ooo0005ooooo`?oo`00
1_ooool3ool000Kooooo0ooo0005ooooo`?oo`001_ooool3ool000Kooooo0ooo0006ooooo`?oo`00
1Oooool3ool000Kooooo0ooo0006ooooo`?oo`001Oooool3ool000Kooooo0ooo0006ooooo`?oo`00
1_ooool3ool000Gooooo0ooo0006ooooo`?oo`001_ooool3ool000Gooooo0ooo0006ooooo`?oo`00
1_ooool3ool000Gooooo0ooo0006ooooo`?oo`001_ooool3ool000Kooooo0ooo0005ooooo`?oo`00
1_ooool3ool000Kooooo0ooo0005ooooo`?oo`000oooool3o`0000Cooooo000:ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool00_ooool3ool000Kooooo0ooo0005ooooo`?oo`00
1_ooool3ool000Kooooo0ooo0005ooooo`?oo`001_ooool3ool000Kooooo0ooo0006ooooo`?oo`00
1Oooool3ool000Kooooo0ooo0006ooooo`?oo`001Oooool3ool000Kooooo0ooo0006ooooo`?oo`00
1_ooool3ool000Gooooo0ooo0006ooooo`?oo`001_ooool3ool000Gooooo0ooo0006ooooo`?oo`00
1_ooool3ool000Gooooo0ooo0006ooooo`?oo`001_ooool3ool000Kooooo0ooo0005ooooo`?oo`00
1_ooool3ool000Kooooo0ooo0005ooooo`?oo`001Oooool00ol0003oooooooooo`02ooooo`002_oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooo
ooooo`02ooooo`002oooool2o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02
ooooo`004_ooool2o`000?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo0?oo
oooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02
ooooo`004_ooool2o`000?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo0?oo
oooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02
ooooo`004_ooool2o`000?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo0?oo
oooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02
ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool001;o
oooo0_l0003oooooo`Oooooo0_l00004ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool00_ooool000[ooooo0ol00005ooooo`03o`000?oooooooooo0?oooooo1ooo
ool00ol0003oooooooooo`02ooooo`002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`002oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`002oooool00ol0003o
ooooooooo`04ooooo`?o0000ooooool5ooooo`?o00001?ooool000_ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool000[ooooo0_l0
0006ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`002oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02
ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool001;o
oooo0_l0003oooooo`Oooooo0_l00004ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02
ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool001;o
oooo0_l0003oooooo`Oooooo0_l00004ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02
ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool001;o
oooo0_l0003oooooo`Oooooo0_l00004ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02
ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool001;o
oooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000Booooo`;o0000
ooooool7ooooo`;o00001?ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oo
oooooooo00;ooooo0009ooooo`Go00001?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000
ooooooooool00_ooool000[ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3o
ooooo`Oooooo00?o0000ooooooooool00_ooool000_ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool000cooooo00?o0000oooooooo
ool00oooool3o`000?oooooo1Oooool3o`0000Cooooo0009ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool000Wooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003o
ooooooooo`02ooooo`002_ooool3o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`03o`00
0?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooooooo
o`02ooooo`004_ooool2o`000?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo
0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oo
oooo00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`00
0?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooooooo
o`02ooooo`004_ooool2o`000?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo
0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oo
oooo00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`00
0?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooooooo
o`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool0
01;ooooo0_l0003oooooo`Oooooo0_l00004ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oo
oooo00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`00
0?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooooooo
o`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool0
01;ooooo0_l0003oooooo`Oooooo0_l00004ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oo
oooo00?o0000ooooooooool00_ooool000[ooooo0ol00005ooooo`03o`000?oooooooooo0?oooooo
1oooool00ol0003oooooooooo`02ooooo`002Oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000=ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000;
ooooo`;o00001Oooool3o`000?oooooo1Oooool3o`0000Cooooo000=ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo0009ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
00;ooooo000:ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo000Boooooooo00002ol00004ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.85793, -3.6139, 0.114882, \
0.0383558}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Rearrange and scale DFT result", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g5 = 
        DiscreteListPlot[FourierRearrange[Abs[Last\  /@ \ fft], fs], Red, 
          PlotRange \[Rule] All, ImageSize \[Rule] 504, \ 
          Frame \[Rule] True, \ Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g6\  = \ Show[g1, g5];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.0147151 0.00967843 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1115 -12 -4.5 ]
[-0.0125 .1115 0 4.5 ]
[-0.0125 .20828 -12 -4.5 ]
[-0.0125 .20828 0 4.5 ]
[-0.0125 .30507 -12 -4.5 ]
[-0.0125 .30507 0 4.5 ]
[-0.0125 .40185 -12 -4.5 ]
[-0.0125 .40185 0 4.5 ]
[-0.0125 .49864 -12 -4.5 ]
[-0.0125 .49864 0 4.5 ]
[-0.0125 .59542 -12 -4.5 ]
[-0.0125 .59542 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1115 m
.00625 .1115 L
s
[(10)] -0.0125 .1115 1 0 Mshowa
0 .20828 m
.00625 .20828 L
s
[(20)] -0.0125 .20828 1 0 Mshowa
0 .30507 m
.00625 .30507 L
s
[(30)] -0.0125 .30507 1 0 Mshowa
0 .40185 m
.00625 .40185 L
s
[(40)] -0.0125 .40185 1 0 Mshowa
0 .49864 m
.00625 .49864 L
s
[(50)] -0.0125 .49864 1 0 Mshowa
0 .59542 m
.00625 .59542 L
s
[(60)] -0.0125 .59542 1 0 Mshowa
.125 Mabswid
0 .03407 m
.00375 .03407 L
s
0 .05343 m
.00375 .05343 L
s
0 .07279 m
.00375 .07279 L
s
0 .09214 m
.00375 .09214 L
s
0 .13086 m
.00375 .13086 L
s
0 .15021 m
.00375 .15021 L
s
0 .16957 m
.00375 .16957 L
s
0 .18893 m
.00375 .18893 L
s
0 .22764 m
.00375 .22764 L
s
0 .247 m
.00375 .247 L
s
0 .26635 m
.00375 .26635 L
s
0 .28571 m
.00375 .28571 L
s
0 .32442 m
.00375 .32442 L
s
0 .34378 m
.00375 .34378 L
s
0 .36314 m
.00375 .36314 L
s
0 .3825 m
.00375 .3825 L
s
0 .42121 m
.00375 .42121 L
s
0 .44057 m
.00375 .44057 L
s
0 .45992 m
.00375 .45992 L
s
0 .47928 m
.00375 .47928 L
s
0 .51799 m
.00375 .51799 L
s
0 .53735 m
.00375 .53735 L
s
0 .55671 m
.00375 .55671 L
s
0 .57606 m
.00375 .57606 L
s
0 .61478 m
.00375 .61478 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1115 m
1 .1115 L
s
.99375 .20828 m
1 .20828 L
s
.99375 .30507 m
1 .30507 L
s
.99375 .40185 m
1 .40185 L
s
.99375 .49864 m
1 .49864 L
s
.99375 .59542 m
1 .59542 L
s
.125 Mabswid
.99625 .03407 m
1 .03407 L
s
.99625 .05343 m
1 .05343 L
s
.99625 .07279 m
1 .07279 L
s
.99625 .09214 m
1 .09214 L
s
.99625 .13086 m
1 .13086 L
s
.99625 .15021 m
1 .15021 L
s
.99625 .16957 m
1 .16957 L
s
.99625 .18893 m
1 .18893 L
s
.99625 .22764 m
1 .22764 L
s
.99625 .247 m
1 .247 L
s
.99625 .26635 m
1 .26635 L
s
.99625 .28571 m
1 .28571 L
s
.99625 .32442 m
1 .32442 L
s
.99625 .34378 m
1 .34378 L
s
.99625 .36314 m
1 .36314 L
s
.99625 .3825 m
1 .3825 L
s
.99625 .42121 m
1 .42121 L
s
.99625 .44057 m
1 .44057 L
s
.99625 .45992 m
1 .45992 L
s
.99625 .47928 m
1 .47928 L
s
.99625 .51799 m
1 .51799 L
s
.99625 .53735 m
1 .53735 L
s
.99625 .55671 m
1 .55671 L
s
.99625 .57606 m
1 .57606 L
s
.99625 .61478 m
1 .61478 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .01472 m
.02847 .04487 L
.03089 .05844 L
.03218 .06466 L
.03355 .07042 L
.03484 .07492 L
.03602 .07816 L
.03659 .07942 L
.0372 .08055 L
.03779 .0814 L
.03832 .08199 L
.03862 .08223 L
.03888 .0824 L
.03903 .08248 L
.03919 .08254 L
.03935 .08258 L
.03949 .08261 L
.03963 .08263 L
.03977 .08263 L
.03989 .08262 L
.04002 .0826 L
.04016 .08256 L
.04031 .08251 L
.04058 .08238 L
.04088 .08218 L
.04119 .0819 L
.04177 .08123 L
.04245 .08016 L
.04307 .07893 L
.04426 .07586 L
.04537 .07227 L
.04787 .06166 L
.05032 .04851 L
.05261 .03434 L
.05368 .02734 L
.0548 .01982 L
.05509 .0179 L
.05539 .01584 L
.05548 .01523 L
.05556 .01477 L
.05572 .01585 L
.05603 .01795 L
.05716 .02556 L
.0618 .05453 L
.06415 .06646 L
.0654 .07171 L
.06674 .07639 L
.06802 .07988 L
.06919 .08215 L
.06976 .08293 L
Mistroke
.07005 .08325 L
.07037 .08354 L
.07068 .08374 L
.07095 .08387 L
.07108 .08392 L
.07123 .08396 L
.07136 .08398 L
.07149 .08399 L
.07164 .08398 L
.07179 .08396 L
.07192 .08393 L
.07206 .08389 L
.07221 .08383 L
.07237 .08374 L
.07267 .08355 L
.07319 .08305 L
.07376 .08229 L
.07438 .08123 L
.07505 .07981 L
.07626 .07652 L
.07868 .06729 L
.08123 .0543 L
.08364 .0396 L
.08583 .02494 L
.08641 .0209 L
.08672 .01875 L
.08705 .01649 L
.08719 .01553 L
.08733 .01493 L
.08742 .01553 L
.08749 .01606 L
.08765 .01712 L
.0882 .02097 L
.09073 .03826 L
.09322 .05399 L
.09553 .06656 L
.09777 .07625 L
.0989 .08006 L
.09951 .08177 L
.10015 .08332 L
.10073 .08449 L
.10136 .08551 L
.10164 .08587 L
.10194 .08619 L
.10222 .08644 L
.10248 .08662 L
.10263 .08671 L
.1028 .08678 L
.10297 .08684 L
.10307 .08686 L
Mistroke
.10315 .08687 L
.10324 .08688 L
.10331 .08689 L
.10346 .08688 L
.10362 .08686 L
.10371 .08684 L
.10379 .08681 L
.10395 .08676 L
.1041 .08669 L
.10437 .08651 L
.10467 .08627 L
.10499 .08593 L
.10558 .08512 L
.10614 .08414 L
.1074 .08114 L
.10862 .07722 L
.10994 .07197 L
.11493 .04393 L
.11614 .03567 L
.11743 .02654 L
.11796 .02271 L
.11853 .01855 L
.11868 .01738 L
.11885 .01616 L
.11899 .01511 L
.11915 .01547 L
.1193 .01655 L
.11945 .01771 L
.11974 .01979 L
.12436 .05244 L
.12677 .06697 L
.12803 .07355 L
.12937 .07954 L
.13057 .08397 L
.1312 .08594 L
.13188 .08775 L
.1325 .08912 L
.13308 .09013 L
.13335 .09053 L
.13365 .09091 L
.13393 .0912 L
.13419 .09142 L
.1345 .09161 L
.13467 .09168 L
.13475 .09171 L
.13484 .09174 L
.13499 .09177 L
.13513 .09178 L
.13521 .09178 L
.13529 .09178 L
Mistroke
.13544 .09175 L
.13558 .09172 L
.13572 .09167 L
.13585 .09161 L
.13598 .09154 L
.13629 .09132 L
.13657 .09105 L
.13721 .09023 L
.13779 .08921 L
.1391 .08601 L
.14029 .08206 L
.14139 .07754 L
.14389 .0645 L
.14861 .03186 L
.14985 .02221 L
.15019 .01952 L
.15037 .01805 L
.15055 .01667 L
.1507 .0155 L
.15085 .0152 L
.15094 .01592 L
.15103 .0166 L
.15119 .01788 L
.15362 .03715 L
.15824 .07011 L
.16063 .08338 L
.16185 .08881 L
.16316 .09351 L
.16376 .09522 L
.16439 .09673 L
.16497 .09785 L
.16551 .09865 L
.16577 .09895 L
.16602 .09918 L
.16615 .09929 L
.1663 .09939 L
.16644 .09946 L
.16656 .09952 L
.1667 .09956 L
.16685 .0996 L
.167 .09961 L
.16708 .09961 L
.16716 .09961 L
.1673 .09958 L
.16744 .09954 L
.16758 .09949 L
.16771 .09942 L
.16803 .0992 L
.16833 .09892 L
.16899 .09803 L
Mistroke
.16957 .09695 L
.17019 .0955 L
.17126 .09225 L
.17244 .08766 L
.17479 .07542 L
.17732 .0584 L
.17971 .0394 L
.18097 .0286 L
.18166 .02253 L
.182 .01953 L
.18215 .01821 L
.18231 .01677 L
.18245 .01548 L
.18259 .01515 L
.18273 .01642 L
.18288 .01778 L
.1835 .02331 L
.18481 .03505 L
.18712 .05512 L
.18952 .07421 L
.19213 .09153 L
.19335 .09811 L
.19464 .10383 L
.19574 .10762 L
.19632 .10919 L
.19696 .11055 L
.19728 .11112 L
.19759 .11156 L
.19787 .11189 L
.19802 .11203 L
.19818 .11216 L
.19833 .11226 L
.19846 .11233 L
.19859 .11238 L
.19873 .11242 L
.19887 .11244 L
.199 .11245 L
.19915 .11243 L
.19931 .11239 L
.19939 .11236 L
.19947 .11232 L
.19963 .11223 L
.1998 .11211 L
.19998 .11195 L
.20032 .11157 L
.20063 .11112 L
.2012 .11004 L
.20183 .10852 L
.20305 .10448 L
.20438 .09852 L
Mistroke
.2068 .08376 L
.20937 .06328 L
.2117 .04138 L
.21287 .02955 L
.21348 .02317 L
.21382 .01965 L
.21398 .01792 L
.21413 .01634 L
.21427 .01485 L
.21441 .016 L
.2147 .01913 L
.21532 .02579 L
.21642 .03753 L
.22105 .08437 L
.22338 .10425 L
.22463 .1132 L
.22596 .12136 L
.22724 .12756 L
.2278 .12975 L
.22841 .13176 L
.22895 .13321 L
.22953 .1344 L
.22984 .13489 L
.23013 .13524 L
.23027 .13537 L
.23043 .13549 L
.23057 .13558 L
.2307 .13564 L
.23085 .13568 L
.231 .1357 L
.23112 .13569 L
.23127 .13566 L
.23142 .13561 L
.2315 .13556 L
.23158 .13551 L
.23187 .13527 L
.23214 .13495 L
.23243 .13451 L
.23296 .13345 L
.2336 .13175 L
.23426 .12945 L
.23545 .12401 L
.2366 .11723 L
.23783 .10835 L
.24004 .08838 L
.24244 .06177 L
.2437 .04604 L
.24439 .03703 L
.24504 .02836 L
.24561 .02055 L
Mistroke
.24577 .01827 L
.24593 .0161 L
.24607 .01528 L
.24623 .01743 L
.24754 .03591 L
.24985 .06879 L
.25242 .10407 L
.25475 .1331 L
.2572 .15874 L
.25946 .17634 L
.26059 .18256 L
.26116 .185 L
.26178 .1871 L
.2621 .18795 L
.26241 .1886 L
.26258 .1889 L
.26276 .18916 L
.26291 .18935 L
.26308 .1895 L
.26324 .18961 L
.26339 .18967 L
.26354 .18969 L
.26363 .18969 L
.26371 .18967 L
.26385 .18962 L
.26399 .18953 L
.26415 .18939 L
.26429 .18923 L
.26461 .18874 L
.2649 .18814 L
.26556 .18623 L
.26614 .18391 L
.26676 .18079 L
.26783 .17378 L
.269 .16369 L
.27134 .1362 L
.27386 .09614 L
.27624 .04918 L
.27689 .03493 L
.27725 .02687 L
.27743 .02286 L
.27759 .01914 L
.27774 .01558 L
.27782 .01566 L
.2779 .01764 L
.27824 .02572 L
.27884 .04011 L
.28363 .16731 L
.28851 .30479 L
.2932 .42755 L
Mistroke
.2956 .4813 L
.2982 .53027 L
.29941 .54921 L
.30069 .56639 L
.3019 .57961 L
.303 .58921 L
.30414 .5965 L
.30473 .59928 L
.30503 .60041 L
.30535 .60142 L
.30564 .60213 L
.3059 .60264 L
.30603 .60283 L
.30616 .603 L
.30629 .60313 L
.30641 .60322 L
.30655 .60329 L
.30667 .60332 L
.30682 .60331 L
.30697 .60326 L
.30713 .60315 L
.30728 .603 L
.30741 .60283 L
.30756 .6026 L
.30787 .60198 L
.3082 .60109 L
.30881 .59891 L
.3094 .5961 L
.30994 .59293 L
.31117 .58364 L
.31247 .57084 L
.31485 .54008 L
.31706 .50386 L
.32176 .40868 L
.32676 .29324 L
.33158 .18349 L
.33621 .09135 L
.33855 .05237 L
.3398 .0341 L
.34048 .02476 L
.34082 .02035 L
.34099 .01825 L
.34114 .01637 L
.34129 .01495 L
.34143 .0167 L
.34175 .02048 L
.34242 .02809 L
.34359 .04023 L
.34588 .05961 L
.34706 .06739 L
Mistroke
.3483 .07409 L
.34936 .07865 L
.35053 .08252 L
.35116 .08414 L
.35176 .0854 L
.3523 .08629 L
.35288 .08703 L
.35318 .08732 L
.35352 .08757 L
.35369 .08767 L
.35387 .08776 L
.35404 .08782 L
.35419 .08786 L
.35434 .08789 L
.35447 .0879 L
.35462 .0879 L
.35478 .08789 L
.35486 .08788 L
.35495 .08786 L
.35511 .08782 L
.35526 .08777 L
.3554 .08771 L
.3557 .08755 L
.35597 .08736 L
.35657 .08681 L
.35713 .08614 L
.35767 .08536 L
.35886 .0832 L
.36016 .08018 L
.36253 .07305 L
.36506 .06321 L
.36748 .05153 L
.37008 .03606 L
.37131 .02766 L
.37198 .02275 L
.37231 .02027 L
.37261 .01796 L
.37274 .01693 L
.37288 .0158 L
.37302 .01472 L
.37314 .01571 L
.37371 .02042 L
.37492 .03097 L
.37966 .07907 L
.38422 .13306 L
.38908 .19273 L
.39375 .24458 L
.39612 .26634 L
.39738 .27618 L
.39872 .28523 L
Mistroke
.40002 .2925 L
.4012 .29772 L
.40177 .29976 L
.40238 .30159 L
.40292 .30289 L
.4035 .30395 L
.40381 .30437 L
.40409 .30468 L
.40423 .30479 L
.40438 .3049 L
.40452 .30498 L
.40464 .30503 L
.40479 .30507 L
.40493 .30509 L
.40509 .30509 L
.40517 .30508 L
.40525 .30506 L
.4054 .30501 L
.40549 .30497 L
.40557 .30492 L
.40573 .30482 L
.4059 .30467 L
.40623 .3043 L
.40654 .30386 L
.40713 .30275 L
.40781 .30102 L
.40844 .29901 L
.40961 .29426 L
.4107 .28864 L
.41319 .27187 L
.41787 .22783 L
.42284 .16938 L
.42763 .10982 L
.43224 .05643 L
.43461 .03213 L
.4353 .02563 L
.43594 .01974 L
.43622 .01723 L
.43637 .01588 L
.43652 .0148 L
.43667 .01614 L
.43684 .0176 L
.43714 .02012 L
.44184 .05307 L
.4444 .06576 L
.44558 .07036 L
.44683 .07441 L
.44797 .07738 L
.44858 .07868 L
.44923 .07986 L
Mistroke
.44983 .08075 L
.45038 .0814 L
.4509 .08188 L
.45116 .08206 L
.45145 .08223 L
.45176 .08236 L
.45193 .08241 L
.45209 .08244 L
.45223 .08246 L
.45238 .08247 L
.45246 .08246 L
.45254 .08246 L
.45269 .08245 L
.45284 .08242 L
.45299 .08238 L
.45314 .08233 L
.45328 .08227 L
.45354 .08214 L
.45382 .08196 L
.4545 .08135 L
.45514 .08055 L
.45635 .07848 L
.45753 .0757 L
.45877 .07195 L
.461 .06309 L
.46338 .05057 L
.46559 .03597 L
.46686 .02637 L
.46748 .02132 L
.46775 .01904 L
.4679 .01781 L
.46805 .01647 L
.46819 .01526 L
.46832 .01529 L
.46845 .01643 L
.46857 .01752 L
.46913 .02251 L
.47029 .03355 L
.4749 .08314 L
.4798 .1427 L
.48451 .20027 L
.48692 .22737 L
.48953 .25348 L
.49183 .27289 L
.49313 .28211 L
.49436 .28941 L
.49561 .29554 L
.49676 .29984 L
.49739 .30167 L
.49798 .30304 L
Mistroke
.49861 .30411 L
.49897 .30454 L
.49913 .30469 L
.4993 .30482 L
.49944 .30491 L
.49959 .30498 L
.49973 .30503 L
.49986 .30506 L
.50001 .30507 L
.50015 .30506 L
.50022 .30504 L
.50031 .30502 L
.50046 .30496 L
.50059 .30489 L
.50073 .3048 L
.50102 .30454 L
.50129 .30423 L
.50155 .30387 L
.50217 .30271 L
.50275 .30131 L
.50403 .29701 L
.50522 .29164 L
.50632 .28551 L
.50883 .26779 L
.51355 .22229 L
.51857 .16302 L
.5234 .10332 L
.52806 .05032 L
.53047 .02631 L
.53105 .0209 L
.53137 .01801 L
.53153 .0166 L
.53168 .01531 L
.53176 .01485 L
.53185 .01562 L
.53204 .01723 L
.53237 .02001 L
.53301 .02527 L
.53756 .05592 L
.5399 .06702 L
.5411 .07153 L
.54242 .07555 L
.54367 .07851 L
.54484 .08052 L
.54548 .08133 L
.54607 .08187 L
.54639 .0821 L
.54656 .0822 L
.54674 .08228 L
.5469 .08235 L
Mistroke
.54708 .0824 L
.54723 .08243 L
.54738 .08245 L
.54753 .08246 L
.54761 .08247 L
.5477 .08246 L
.54784 .08245 L
.54798 .08242 L
.54806 .08241 L
.54815 .08238 L
.5483 .08233 L
.54864 .08218 L
.54893 .082 L
.54921 .08179 L
.54983 .08117 L
.5504 .08044 L
.55091 .07962 L
.55207 .07729 L
.55327 .07413 L
.55438 .07052 L
.55689 .05986 L
.55914 .04722 L
.56044 .03863 L
.56163 .02993 L
.56221 .02544 L
.56283 .02033 L
.56312 .01793 L
.56328 .01659 L
.56342 .01531 L
.56356 .01532 L
.56371 .01663 L
.56397 .01895 L
.56649 .0431 L
.57144 .09851 L
.5762 .15742 L
.58078 .21275 L
.58333 .24039 L
.58565 .26236 L
.58809 .28116 L
.59035 .29405 L
.59146 .29867 L
.59203 .30056 L
.59265 .30224 L
.59326 .30353 L
.59354 .30398 L
.59384 .30439 L
.59417 .30474 L
.59436 .30488 L
.59452 .30498 L
.59468 .30504 L
Mistroke
.59483 .30508 L
.59491 .30509 L
.595 .3051 L
.59515 .30508 L
.5953 .30505 L
.59544 .305 L
.59559 .30492 L
.59574 .30482 L
.59601 .30458 L
.59629 .30424 L
.59695 .30316 L
.59755 .30177 L
.59878 .29782 L
.60009 .29198 L
.60268 .27579 L
.60511 .25553 L
.60977 .20639 L
.61472 .14615 L
.61949 .08869 L
.62407 .04028 L
.62528 .02911 L
.62643 .01924 L
.62674 .01671 L
.62689 .01545 L
.62698 .01474 L
.62706 .01535 L
.62742 .01818 L
.62775 .02073 L
.62895 .02954 L
.63363 .05717 L
.63605 .06783 L
.6386 .07669 L
.63975 .07994 L
.64098 .08286 L
.64214 .08506 L
.6432 .08655 L
.64378 .08716 L
.64411 .08742 L
.64441 .08761 L
.64466 .08774 L
.64479 .08779 L
.64493 .08784 L
.64509 .08787 L
.64524 .08789 L
.64538 .0879 L
.64552 .0879 L
.64566 .08789 L
.64581 .08786 L
.64596 .08782 L
.64609 .08777 L
Mistroke
.64641 .08762 L
.64673 .08739 L
.64705 .0871 L
.64735 .08676 L
.64803 .08577 L
.64863 .0846 L
.64929 .083 L
.65049 .0792 L
.65166 .07428 L
.65273 .06862 L
.65499 .05291 L
.65629 .0414 L
.65748 .02923 L
.65806 .02278 L
.65836 .01922 L
.65853 .01722 L
.65868 .01531 L
.65883 .01597 L
.65892 .01702 L
.65899 .01799 L
.65927 .02159 L
.65982 .02887 L
.66234 .06657 L
.66711 .15553 L
.67169 .25706 L
.67657 .37093 L
.68126 .47234 L
.68365 .51628 L
.68625 .55547 L
.68747 .57014 L
.68875 .58297 L
.68985 .59155 L
.69043 .59516 L
.69106 .59836 L
.69166 .60065 L
.69198 .60161 L
.69228 .60231 L
.69243 .60258 L
.69256 .6028 L
.69269 .60296 L
.69282 .60311 L
.69296 .60322 L
.6931 .60329 L
.69324 .60332 L
.6934 .60331 L
.69348 .60328 L
.69357 .60324 L
.69365 .60318 L
.69372 .60312 L
.69387 .60297 L
Mistroke
.69402 .60276 L
.69438 .60209 L
.6947 .60127 L
.69532 .59905 L
.69591 .59624 L
.6971 .58845 L
.69834 .5772 L
.70057 .54952 L
.70295 .5101 L
.70516 .46514 L
.70986 .34934 L
.71486 .2099 L
.71736 .13979 L
.71967 .07779 L
.72083 .04825 L
.7214 .03428 L
.72192 .0218 L
.72206 .01863 L
.7222 .0152 L
.72234 .01745 L
.72247 .02042 L
.72306 .03378 L
.72431 .06069 L
.72657 .10377 L
.72902 .14113 L
.73037 .15722 L
.7316 .16919 L
.73279 .17806 L
.73344 .18188 L
.73404 .18469 L
.73462 .18684 L
.73518 .18832 L
.73548 .1889 L
.73577 .1893 L
.73591 .18945 L
.73608 .18957 L
.73616 .18962 L
.73625 .18966 L
.7364 .18969 L
.73654 .18968 L
.73667 .18965 L
.73681 .18958 L
.73697 .18946 L
.73713 .1893 L
.73728 .18911 L
.73756 .18866 L
.73807 .18752 L
.73862 .18583 L
.73976 .18084 L
.74101 .17318 L
Mistroke
.74355 .15152 L
.74841 .09293 L
.75065 .06168 L
.75184 .04483 L
.75309 .02695 L
.75345 .02192 L
.75363 .01946 L
.75379 .0172 L
.75394 .01515 L
.75409 .01643 L
.75425 .01859 L
.75442 .02094 L
.75565 .03751 L
.75807 .06778 L
.76063 .0949 L
.76295 .11418 L
.76411 .1216 L
.76537 .12793 L
.76594 .13021 L
.76655 .1322 L
.76707 .13354 L
.76765 .13465 L
.76793 .13505 L
.76824 .13538 L
.7684 .1355 L
.76849 .13555 L
.76857 .1356 L
.76873 .13566 L
.76887 .13569 L
.76901 .1357 L
.76915 .13568 L
.76927 .13565 L
.76941 .13559 L
.76955 .13551 L
.76971 .13539 L
.76999 .13511 L
.77031 .13467 L
.77066 .13405 L
.7713 .13258 L
.77193 .13071 L
.7725 .12861 L
.77475 .1172 L
.77723 .09935 L
.77976 .07677 L
.78208 .0534 L
.78435 .02931 L
.7849 .02341 L
.7852 .02017 L
.78549 .01712 L
.78557 .01628 L
Mistroke
.78565 .01539 L
.78574 .01501 L
.78583 .01591 L
.78614 .01917 L
.78674 .02549 L
.7913 .06907 L
.79364 .08682 L
.79616 .10112 L
.79738 .10605 L
.79803 .1081 L
.79871 .10985 L
.79905 .11056 L
.79937 .11111 L
.79968 .11157 L
.79997 .1119 L
.80024 .11214 L
.80038 .11224 L
.80053 .11232 L
.80068 .11239 L
.80077 .11241 L
.80084 .11243 L
.80099 .11245 L
.80114 .11244 L
.80127 .11242 L
.80142 .11238 L
.80156 .11232 L
.80169 .11225 L
.80199 .11202 L
.8023 .1117 L
.80289 .11083 L
.80354 .10952 L
.80469 .10625 L
.80576 .10219 L
.80823 .08941 L
.81047 .07425 L
.81298 .05428 L
.81529 .03414 L
.81646 .02371 L
.81675 .02108 L
.81703 .01859 L
.81728 .01636 L
.81742 .0151 L
.81755 .01549 L
.81769 .01674 L
.81781 .01786 L
.8181 .02038 L
.81868 .02557 L
.81993 .03638 L
.82246 .0567 L
.82477 .07276 L
Mistroke
.82704 .08528 L
.82818 .0902 L
.82943 .09445 L
.83006 .09613 L
.83066 .09742 L
.8312 .09833 L
.83151 .09873 L
.83179 .09904 L
.83209 .0993 L
.83225 .0994 L
.83243 .09949 L
.83251 .09953 L
.83261 .09956 L
.8327 .09958 L
.83278 .0996 L
.83293 .09961 L
.83302 .09961 L
.8331 .0996 L
.83326 .09958 L
.8334 .09953 L
.83356 .09946 L
.83372 .09937 L
.83401 .09916 L
.83431 .09886 L
.83494 .09799 L
.83554 .09688 L
.83666 .09404 L
.83787 .08992 L
.83919 .08428 L
.8441 .05429 L
.84654 .03586 L
.84774 .02642 L
.84826 .02225 L
.84854 .02004 L
.84883 .01768 L
.84898 .01649 L
.84912 .01537 L
.84925 .01506 L
.84939 .01615 L
.8499 .02023 L
.85102 .02903 L
.85338 .04666 L
.85573 .06225 L
.85832 .07621 L
.8595 .08126 L
.86077 .08564 L
.86139 .08735 L
.86197 .08872 L
.86253 .08981 L
.86307 .09062 L
Mistroke
.86336 .09097 L
.86367 .09128 L
.86396 .0915 L
.86422 .09165 L
.86437 .0917 L
.86451 .09174 L
.86466 .09177 L
.86475 .09178 L
.86482 .09178 L
.86498 .09177 L
.86507 .09176 L
.86515 .09174 L
.8653 .0917 L
.86546 .09163 L
.86572 .09148 L
.866 .09126 L
.86651 .09071 L
.86712 .08981 L
.86768 .08875 L
.86886 .08577 L
.86996 .08213 L
.87246 .07111 L
.87717 .04209 L
.87841 .03332 L
.87975 .02357 L
.88036 .01905 L
.88053 .01785 L
.8807 .01657 L
.88078 .01595 L
.88086 .01536 L
.88101 .01517 L
.88115 .01618 L
.88128 .01712 L
.88157 .01924 L
.88218 .0237 L
.88691 .05554 L
.8895 .06942 L
.89068 .07459 L
.89193 .07912 L
.89309 .08244 L
.89371 .08383 L
.89436 .08503 L
.89497 .08588 L
.89552 .08643 L
.89578 .08662 L
.89592 .0867 L
.89607 .08676 L
.8962 .08681 L
.89634 .08685 L
.89647 .08687 L
Mistroke
.89659 .08688 L
.89674 .08688 L
.89683 .08688 L
.8969 .08686 L
.89705 .08683 L
.89719 .08679 L
.89736 .08671 L
.89751 .08663 L
.89784 .08639 L
.89812 .08613 L
.89842 .08579 L
.89903 .08491 L
.90019 .08254 L
.90127 .07955 L
.90372 .0701 L
.90596 .05871 L
.90846 .04361 L
.91077 .02815 L
.91132 .0243 L
.91192 .02013 L
.9122 .01821 L
.91235 .01716 L
.91249 .01618 L
.91261 .01534 L
.91274 .01498 L
.91288 .01597 L
.91301 .01687 L
.91414 .02472 L
.91539 .0332 L
.9179 .04919 L
.92021 .062 L
.92246 .07206 L
.92361 .07612 L
.92485 .07957 L
.92548 .08097 L
.92608 .08206 L
.92662 .08283 L
.92693 .08318 L
.92721 .08344 L
.9275 .08366 L
.92777 .08382 L
.92791 .08388 L
.92805 .08392 L
.9282 .08396 L
.92836 .08398 L
.92848 .08399 L
.92862 .08398 L
.92875 .08396 L
.92886 .08394 L
.929 .08389 L
Mistroke
.92915 .08383 L
.92942 .08368 L
.9297 .08348 L
.93001 .0832 L
.93056 .08253 L
.93121 .08147 L
.93181 .08027 L
.93304 .07706 L
.93434 .07269 L
.93673 .06228 L
.93895 .05027 L
.94121 .03629 L
.9424 .02848 L
.94366 .02002 L
.94397 .01793 L
.94414 .01678 L
.9443 .01569 L
.94439 .01508 L
.94449 .01502 L
.94458 .01563 L
.94466 .0162 L
.945 .01849 L
.94624 .02679 L
.94867 .04244 L
.95111 .05649 L
.9534 .06748 L
.95559 .07544 L
.95682 .07868 L
.95795 .08083 L
.95852 .0816 L
.95884 .08193 L
.95913 .08219 L
.95941 .08237 L
.95955 .08245 L
.95971 .08252 L
.95984 .08256 L
.95998 .0826 L
.96011 .08262 L
.96023 .08263 L
.96038 .08263 L
.96047 .08262 L
.96055 .08261 L
.9607 .08257 L
.96086 .08252 L
.96101 .08245 L
.96116 .08238 L
.96143 .08219 L
.96176 .08191 L
.96205 .08159 L
.96273 .08066 L
Mistroke
.96329 .07965 L
.9639 .07834 L
.965 .0754 L
.96749 .06614 L
.97005 .05339 L
.97248 .03903 L
.97619 .01472 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.05556 .01472 m
.05556 .01472 L
s
.0873 .01472 m
.0873 .01472 L
s
.11905 .01472 m
.11905 .01472 L
s
.15079 .01472 m
.15079 .01472 L
s
.18254 .01472 m
.18254 .01472 L
s
.21429 .01472 m
.21429 .01472 L
s
.24603 .01472 m
.24603 .01472 L
s
.27778 .01472 m
.27778 .01472 L
s
.30952 .01472 m
.30952 .59542 L
s
.34127 .01472 m
.34127 .01472 L
s
.37302 .01472 m
.37302 .01472 L
s
.40476 .01472 m
.40476 .30507 L
s
.43651 .01472 m
.43651 .01472 L
s
.46825 .01472 m
.46825 .01472 L
s
.5 .01472 m
.5 .30507 L
s
.53175 .01472 m
.53175 .01472 L
s
.56349 .01472 m
.56349 .01472 L
s
.59524 .01472 m
.59524 .30507 L
s
.62698 .01472 m
.62698 .01472 L
s
.65873 .01472 m
.65873 .01472 L
s
.69048 .01472 m
.69048 .59542 L
s
.72222 .01472 m
.72222 .01472 L
s
.75397 .01472 m
.75397 .01472 L
s
.78571 .01472 m
.78571 .01472 L
s
.81746 .01472 m
.81746 .01472 L
s
.84921 .01472 m
.84921 .01472 L
s
.88095 .01472 m
.88095 .01472 L
s
.9127 .01472 m
.9127 .01472 L
s
.94444 .01472 m
.94444 .01472 L
s
.97619 .01472 m
.97619 .01472 L
s
.015 w
.05556 .01472 Mdot
.0873 .01472 Mdot
.11905 .01472 Mdot
.15079 .01472 Mdot
.18254 .01472 Mdot
.21429 .01472 Mdot
.24603 .01472 Mdot
.27778 .01472 Mdot
.30952 .59542 Mdot
.34127 .01472 Mdot
.37302 .01472 Mdot
.40476 .30507 Mdot
.43651 .01472 Mdot
.46825 .01472 Mdot
.5 .30507 Mdot
.53175 .01472 Mdot
.56349 .01472 Mdot
.59524 .30507 Mdot
.62698 .01472 Mdot
.65873 .01472 Mdot
.69048 .59542 Mdot
.72222 .01472 Mdot
.75397 .01472 Mdot
.78571 .01472 Mdot
.81746 .01472 Mdot
.84921 .01472 Mdot
.88095 .01472 Mdot
.9127 .01472 Mdot
.94444 .01472 Mdot
.97619 .01472 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<oooool3o`0002kooooo1Ol0000]ooooo`;o0000;_ooool5o`00033ooooo0ol0000Roooo
o`00=?ooool00ol0003oooooooooo`0^ooooo`04o`000?ooooooooooo`0002cooooo00Co0000oooo
oooooooo0000;_ooool01?l0003oooooooooool0000aooooo`03o`000?oooooooooo027ooooo000[
ooooo`Go000000?oooooo`000?l000000ol0000Xooooo`Go00000oooool00ol0003oooooooooo`0/
ooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool0;_ooool5o`0002;ooooo000a
ooooo`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool0:oooool01?l0003ooooooooo
ool0000`ooooo`03o`000?oooooooooo02gooooo00Co0000oooooooooooo00008oooool003;ooooo
00?o0000ooooool00000;oooool01Ol0003ooooooooooooooooo000002cooooo00Co0000oooooooo
oooo0000;Oooool01Ol0003ooooooooooooooooo000002oooooo00?o0000ooooool000008oooool0
03?ooooo0_l0000_ooooo`05o`000?ooooooooooooooool00000;?ooool01?l0003oooooooooool0
000]ooooo`05o`000?ooooooooooooooool00000<?ooool2o`0002?ooooo000dooooo`03o`000?oo
oooooooo02kooooo0ol0000^ooooo`;o0000;oooool3o`0003;ooooo00?o0000ooooooooool08Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0017oooooool0
000=o`0000?ooooo000:ooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo007ooooo0009ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00Oooool0
00Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0;ooooo`?oo`001Oooool3
ool000Kooooo0ooo0005ooooo`?oo`001_ooool3ool000Gooooo0ooo0006ooooo`?oo`001Oooool3
ool000kooooo0ooo0005ooooo`?oo`003_ooool3ool000Kooooo0ooo0007ooooo`03o`000?oooooo
oooo00Cooooo0ooo0005ooooo`?oo`003_ooool3ool000Gooooo0ooo000>ooooo`?oo`001_ooool3
ool000Gooooo0ooo0006ooooo`?oo`001Oooool3ool000Kooooo0ooo0005ooooo`?oo`001_ooool3
ool000Gooooo0ooo0005ooooo`03o`000?oooooooooo007ooooo0009ooooo`04o`000?oooooooooo
o`0000Cooooo0ol0000;ooooo`?oo`001Oooool3ool000Kooooo0ooo0005ooooo`?oo`001_ooool3
ool000Gooooo0ooo0006ooooo`?oo`001Oooool3ool000Oooooo00?oo`00ooooooooool01?ooool3
ool000Gooooo0ooo0007ooooo`03ool00?oooooooooo00Cooooo0ooo0006ooooo`?oo`001oooool0
0ooo003oooooooooo`04ooooo`?oo`001Oooool3ool000Oooooo00?oo`00ooooooooool01?ooool3
ool000Gooooo0ooo0007ooooo`03ool00?oooooooooo00Cooooo0ooo0006ooooo`?oo`001Oooool3
ool000Kooooo0ooo0005ooooo`?oo`001_ooool3ool000Gooooo0ooo0006ooooo`?oo`001Oooool3
ool000?ooooo0ol00003ooooo`002Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00_ooooo0ooo0005ooooo`?oo`001_ooool3ool000Gooooo0ooo0006ooooo`?oo`001Oooool3
ool000Kooooo0ooo0005ooooo`?oo`001oooool00ooo003oooooooooo`04ooooo`?oo`001Oooool3
ool000Oooooo00?oo`00ooooooooool01?ooool3ool000Kooooo0ooo0007ooooo`03ool00?oooooo
oooo00Cooooo0ooo0005ooooo`?oo`001oooool00ooo003oooooooooo`04ooooo`?oo`001Oooool3
ool000Oooooo00?oo`00ooooooooool01?ooool3ool000Kooooo0ooo0005ooooo`?oo`001_ooool3
ool000Gooooo0ooo0006ooooo`?oo`001Oooool3ool000Kooooo0ooo0005ooooo`?oo`001Oooool0
0ol0003oooooooooo`01ooooo`002Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`;o003o1oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool2
o`00o`Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03ool00?oooooo
oooo00gooooo0_l00?l7ooooo`03ool00?oooooooooo00kooooo00?o003oooooooooool01_ooool0
0ooo003oooooooooo`05ooooo`03o`00oooooooooooo00Gooooo0_l00?l7ooooo`03ool00?oooooo
oooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03ool00?oooooo
oooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0>ooooo`;o003o1oooool0
0ol00?ooooooooooo`05ooooo`;o003o1oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o0000ooooooooool00Oooool000[ooooo0_l00005ooooo`03o`000?oooooooooo
00Cooooo00?o003oooooooooool01Oooool2o`00o`Kooooo0_l00?l7ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`;o003o1oooool00ol0
0?ooooooooooo`05ooooo`;o003o1oooool00ooo003oooooooooo`0>ooooo`03o`00oooooooooooo
00Gooooo00?oo`00ooooooooool03_ooool00ol00?ooooooooooo`06ooooo`03ool00?oooooooooo
00Gooooo00?o003oooooooooool01Oooool2o`00o`Oooooo00?oo`00ooooooooool01_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00kooooo0_l00?l7ooooo`03o`00oooooooooooo
00Gooooo0_l00?l6ooooo`;o003o1oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`04ooooo`;o003o1oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Go
oooo0_l00?l7ooooo`03ool00?oooooooooo00Gooooo0_l00?l7ooooo`03o`00oooooooooooo00Go
oooo00?oo`00ooooooooool01Oooool2o`00o`Oooooo00?o003oooooooooool01_ooool00ooo003o
ooooooooo`05ooooo`03o`00oooooooooooo00Gooooo0_l00?l7ooooo`03ool00?oooooooooo00Ko
oooo00?o003oooooooooool01?ooool2o`00o`Oooooo00?oo`00ooooooooool01_ooool00ol00?oo
ooooooooo`05ooooo`;o003o1oooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool2o`00o`Ko
oooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000Gooooo
00?o003oooooooooool05Oooool00ol00?ooooooo`00o`06ooooo`;o003o1_ooool00ol00?oooooo
o`00o`07ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ooo003ooooo
ooooo`05ooooo`;o003o1_ooool2o`00o`Oooooo00?oo`00ooooooooool01Oooool2o`00o`Kooooo
00?o003oooooool00?l01oooool00ooo003oooooooooo`05ooooo`03o`00oooooooooooo00kooooo
00?oo`00ooooooooool01Oooool2o`00o`oooooo00?oo`00ooooooooool01_ooool00ol00?oooooo
ooooo`05ooooo`;o003o1_ooool2o`00o`Oooooo0_l00?lOooooo`03o`00oooooooooooo00cooooo
0_l00003ooooo`004Oooool00ol0003oooooooooo`0;ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooool00?l01Oooool00ol00?ooooooooooo`06ooooo`;o003o1_ooool00ol00?ooooooo`00
o`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03_ooool00ooo003ooooooooo
o`05ooooo`;o003o1_ooool00ol00?ooooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?o
003oooooool00?l01Oooool00ol00?ooooooooooo`07ooooo`03ool00?oooooooooo00Kooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03ool00?oooooooooo00Gooooo00?o
003oooooooooool03_ooool00ooo003oooooooooo`06ooooo`03o`00oooooooooooo00Gooooo0_l0
0?l6ooooo`;o003o1oooool2o`00o`Kooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00oooool2o`00o`Kooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01_ooool2o`00o`Kooooo0_l00?l7
ooooo`;o003o1oooool00ooo003oooooooooo`06ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01oooool00ooo003oooooooooo`04ooooo`03o`00oooooooo003o00Kooooo0_l00?l7
ooooo`03ool00?oooooooooo00Gooooo00?o003oooooooooool01Oooool2o`00o`Oooooo00?oo`00
ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`06ooooo`;o003o1_ooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`05
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Gooooo00?o003ooooo
ooooool00oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003o
ooooool00?l04?ooool00ol00?ooooooooooo`04ooooo`;o003o1_ooool00ol00?ooooooooooo`06
ooooo`;o003o1oooool00ooo003oooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?oo`00
ooooooooool03Oooool00ol00?ooooooo`00o`07ooooo`03ool00?oooooooooo00Cooooo00?o003o
ooooool00?l01Oooool00ol00?ooooooo`00o`07ooooo`03ool00?oooooooooo00Gooooo00?o003o
ooooool00?l01Oooool2o`00o`Oooooo00?oo`00ooooooooool01Oooool2o`00o`oooooo00?o003o
ooooooooool03Oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Gooooo00Co
003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Gooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01Oooool00ol00?oooooooooo
o`03ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Kooooo0_l00?l7ooooo`03ool00?oooooooooo00Go
oooo0_l00?l8ooooo`03o`00oooooooooooo00Cooooo00?oo`00ooooooooool01Oooool00ol00?oo
ooooo`00o`07ooooo`03o`00oooooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooo003o00Oooooo00?oo`00ooooooooool01oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooo003o00Kooooo00?oo`00ooooooooool01_ooool00ol00?oo
ooooooooo`05ooooo`;o003o2?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Go
oooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`04o`00oooooooooooo
o`00o`Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`000?oooooo
oooo007ooooo000Aooooo`;o00001_ooool00ol00?ooooooooooo`0Cooooo`05o`00oooooooooooo
ooooool00?l01?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Oooooo00?o
003oooooooooool01?ooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00Gooooo00?o
o`00ooooooooool01Oooool2o`00o`Gooooo00Co003ooooooooooooo003o1_ooool00ooo003ooooo
ooooo`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01oooool00ooo003ooooo
ooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01oooool00ooo003ooooo
ooooo`04ooooo`04o`00ooooooooooooo`00o`kooooo00?oo`00ooooooooool01_ooool00ol00?oo
ooooooooo`05ooooo`;o003o1_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o01Ko
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`;o00000oooool0017ooooo
00?o0000ooooooooool02_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Kooooo
00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool03Oooool00ooo003oooooooooo`05ooooo`03o`00oooooooo003o00Co
oooo00Co003ooooooooooooo003o1_ooool00ooo003oooooooooo`05ooooo`03o`00oooooooo003o
00Gooooo00?o003oooooool00?l01oooool00ooo003oooooooooo`07ooooo`03o`00oooooooooooo
00cooooo00?oo`00ooooooooool01?ooool01?l00?ooooooooooool00?l>ooooo`03ool00?oooooo
oooo00Gooooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo
003o00Gooooo00?o003oooooool00?l04Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool02_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`06ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool01Oooool01?l00?ooooooooooool00?l7ooooo`03o`00
oooooooooooo00Cooooo0_l00?l7ooooo`03ool00?oooooooooo00Cooooo00Co003ooooooooooooo
003o1?ooool00ol00?ooooooooooo`07ooooo`03ool00?oooooooooo00Cooooo00Co003ooooooooo
oooo003o1?ooool00ol00?ooooooooooo`08ooooo`03ool00?oooooooooo00Cooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?l6ooooo`03ool00?oooooooooo00Cooooo00?o
003oooooooooool01_ooool00ol00?ooooooo`00o`06ooooo`03ool00?oooooooooo00Gooooo00?o
003oooooooooool01Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Gooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00Oooooo00Go003ooooooooooooooooo
o`00o`08ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Kooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l03?ooool00ol00?ooooooooooo`06oooo
o`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01_ooool2o`00o`Oooooo00?oo`00
ooooooooool03?ooool01?l00?ooooooooooool00?l6ooooo`03ool00?oooooooooo00cooooo00Co
003ooooooooooooo003o1oooool00ooo003oooooooooo`04ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1_ooool00ooo003oooooooooo`04ooooo`05o`00oooooooooooo
ooooool00?l01?ooool00ol00?ooooooo`00o`06ooooo`03ool00?oooooooooo00Gooooo0_l00?l>
ooooo`03o`00oooooooooooo00kooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo00Kooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooooooooooo
o`00o`Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooo
oooooooo00Kooooo0_l00?l7ooooo`03ool00?oooooooooo00Cooooo00Co003ooooooooooooo003o
1oooool00ol00?ooooooooooo`04ooooo`03ool00?oooooooooo00Sooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`05ooooo`03ool00?oooooooooo00Cooooo00Co003ooooooooooooo
003o0oooool01Ol00?oooooooooooooooooo003o00Kooooo00?oo`00ooooooooool02?ooool01Ol0
0?oooooooooooooooooo003o00;ooooo00?o003oooooooooool01?ooool00ooo003oooooooooo`05
ooooo`;o003o1_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l02?ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000Oo
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Kooooo0_l00?l7ooooo`03ool00?oooooo
oooo00Cooooo00?o003oooooooooool01?ooool01Ol00?oooooooooooooooooo003o00Kooooo00?o
o`00ooooooooool01?ooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003oooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
2?ooool00ooo003oooooooooo`08ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oo
ooooooooo`04ooooo`03ool00?oooooooooo00Oooooo00?o003oooooooooool00oooool00ol00?oo
ooooo`00o`08ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`08oooo
o`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00kooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo
00kooooo0_l00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0=ooooo`03ool00?oooooooooo00Cooooo00?o003oooooooooool01?ooool01Ol00?oooooooooo
oooooooo003o00Kooooo00?oo`00ooooooooool01?ooool01Ol00?oooooooooooooooooo003o00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03ool00?oooooooooo00So
oooo00?o003oooooooooool02oooool00ooo003oooooooooo`04ooooo`05o`00oooooooooooooooo
ool00?l03Oooool00ooo003oooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l06Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`04ooooo`;o003o1_ooool0
0ol00?ooooooo`00o`08ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`08ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool2o`00o`Oooooo00?o
o`00ooooooooool01?ooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooooooo00Wooooo
00?oo`00ooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00_ooooo
00?oo`00ooooooooool02?ooool3o`00o`Cooooo00?o003oooooooooool01?ooool00ooo003ooooo
ooooo`04ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o1_ooool00ooo003o
ooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01_ooool00ol00?oooooo
ooooo`05ooooo`?o003o2Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`07ooooo`?o003o1_ooool2o`00o`Kooooo00?o003oooooool00?l01Oooool00ol00?oooooooooo
o`05ooooo`05o`00ooooooooooooooooool00?l02?ooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`Kooooo0_l00?l7ooooo`03ool00?oooooooooo00Sooooo00?o003ooooo
ool00?l02oooool00ooo003oooooooooo`0:ooooo`03o`00oooooooooooo00[ooooo00?oo`00oooo
ooooool00oooool00ol00?ooooooooooo`03ooooo`;o003o1?ooool00ol00?ooooooooooo`04oooo
o`03ool00?oooooooooo00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`03oooo
o`03o`00oooooooooooo00Cooooo00?oo`00ooooooooool01Oooool00ol00?ooooooo`00o`0=oooo
o`03o`00oooooooooooo00[ooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l5ooooo`03o`00oooooooo003o00Kooooo0_l00?l7ooooo`03o`00oooooooooooo00Sooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool06?ooool2o`00o`Kooooo0ol00?l=
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooool00?l01oooool00ooo003oooooooooo`08ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool00oooool00ooo003oooooooooo`0@ooooo`03o`00oooo
oooooooo00Cooooo00?oo`00ooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Cooooo00?oo`00ooooooooool02Oooool3o`00o`?ooooo00?o003oooooooooool01?oo
ool00ooo003oooooooooo`05ooooo`03o`00oooooooo003o01gooooo00?o003oooooooooool00ooo
ool00ol00?ooooooo`00o`06ooooo`;o003o6_ooool00ol0003oooooooooo`01ooooo`004Oooool2
o`0002;ooooo0_l00?l6ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Kooooo00?o003oooooool00?l01oooool0
0ooo003oooooooooo`04ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00oooool0
0ooo003oooooooooo`04ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01?ooool0
0ooo003oooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01?ooool0
0ooo003oooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?oo`00ooooooooool01oooool0
0ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`Sooooo00Go003ooooooooooooooooo
o`00o`0=ooooo`?o003o8Oooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo02Wooooo00?o
003oooooool00?l01Oooool00ol00?ooooooooooo`09ooooo`04o`00ooooooooooooo`00o`oooooo
00?oo`00ooooooooool01?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00?ooooo
00?oo`00ooooooooool01?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Cooooo
00?oo`00ooooooooool05_ooool00ooo003oooooooooo`03ooooo`03o`00oooooooooooo013ooooo
00?oo`00ooooooooool01oooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo0_l00?l/oooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo02Wooooo0ol00?l5ooooo`04
o`00ooooooooooooo`00o`_ooooo00?o003oooooooooool03Oooool00ooo003oooooooooo`04oooo
o`03o`00oooooooooooo00oooooo00?oo`00ooooooooool01?ooool00ol00?ooooooooooo`0@oooo
o`03ool00?oooooooooo013ooooo00?o003oooooooooool00oooool00ooo003oooooooooo`03oooo
o`03o`00oooooooooooo013ooooo00?oo`00ooooooooool01Oooool00ol00?ooooooooooo`05oooo
o`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool0
0?l6ooooo`;o003o:oooool00ol0003oooooooooo`01ooooo`000oooool3o`0000Cooooo0_l00005
ooooo`03o`000?oooooooooo03Cooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`07ooooo`03ool00?oo
oooooooo01Kooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`03ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool00oooool00ooo003oooooooooo`03ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool01?ooool00ooo003oooooooooo`05ooooo`03o`00oooo
oooo003o00Sooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo037ooooo
00?o0000ooooooooool00Oooool000Cooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool01Oooool01Ol00?oooooo
oooooooooooo003o00Sooooo00?o003oooooool00?l01oooool00ooo003oooooooooo`0@ooooo`03
o`00oooooooooooo00?ooooo00?oo`00ooooooooool04?ooool00ol00?ooooooooooo`04ooooo`03
ool00?oooooooooo00?ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`03ooooo`03
ool00?oooooooooo00oooooo00?o003oooooooooool01?ooool00ooo003oooooooooo`05ooooo`03
o`00oooooooo003o00cooooo00?o003oooooooooool0>Oooool00ol0003oooooooooo`01ooooo`00
1?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0<_ooool00ol00?ooooooooooo`04ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol0
0?ooooooo`00o`07ooooo`03ool00?oooooooooo00Cooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`03ooooo`03ool00?oooooooooo00?ooooo0_l00?l;ooooo`03o`00oooooooooooo
00Cooooo00?oo`00ooooooooool00oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00?ooooo00?oo`00ooooooooool03oooool00ol00?ooooooooooo`04ooooo`03ool00?oooooooooo
00Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00Kooooo0_l00?ldooooo`03o`000?oooooooooo007ooooo0004ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001?ooool3o`0003;ooooo0_l00?l5ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`0<ooooo`03ool00?oooooooooo00Cooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?o003o
ooooooooool04?ooool00ooo003oooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?oo`00
ooooooooool01oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Co003o
oooooooooooo003o1Oooool2o`00oc;ooooo0ol00003ooooo`001?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0@Oooool00ol00?oooooooooo
o`0<ooooo`03ool00?oooooooooo00Cooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`03ooooo`03ool00?oooooooooo00?ooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`03ooooo`03ool00?oooooooooo013ooooo00?o003oooooooooool00oooool00ooo003ooooooooo
o`03ooooo`03o`00oooooooooooo013ooooo00?oo`00ooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o>oooool00ol0003ooooo
ooooo`01ooooo`000oooool2o`0000Cooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`0jooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool00ol00?oooooo
o`00o`07ooooo`03ool00?oooooooooo00Cooooo00?o003oooooooooool03oooool00ooo003ooooo
ooooo`03ooooo`03o`00oooooooooooo017ooooo00?oo`00ooooooooool00_ooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo00?ooooo00?oo`00ooooooooool00oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00?ooooo00?oo`00ooooooooool01Oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o>oooool00ol0003o
ooooooooo`01ooooo`001?ooool00ol0003oooooooooo`03ooooo`;o00001Oooool00ol0003ooooo
ooooo`0jooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?oooooo
o`00o`07ooooo`03ool00?oooooooooo017ooooo00?o003oooooooooool00_ooool00ooo003ooooo
ooooo`0Aooooo`03o`00oooooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo00?ooooo00?oo`00ooooooooool00oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00?ooooo00?oo`00ooooooooool01Oooool00ol00?oooooo
o`00o`0;ooooo`03o`00oooooooooooo03[ooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool0>_ooool00ol00?ooooooo`00o`09ooooo`04o`00ooooooooooooo`00o`Kooooo
00?oo`00ooooooooool00oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00;ooooo
00?oo`00ooooooooool00oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00?ooooo
00?oo`00ooooooooool00_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00?ooooo
00?oo`00ooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03ool00?oooooooooo00Gooooo
00?o003oooooool00?l01?ooool00ol00?ooooooooooo`11ooooo`03o`000?oooooooooo007ooooo
000Aooooo`;o0000>oooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co
003ooooooooooooo003o1_ooool00ooo003oooooooooo`03ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool00_ooool00ooo003oooooooooo`03ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool00oooool00ooo003oooooooooo`02ooooo`03o`00oooooooooooo017ooooo
00?oo`00ooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03ool00?oooooooooo00Oooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`;o003o??ooool2o`0000?ooooo
000Aooooo`03o`000?oooooooooo047ooooo00?o003oooooooooool03?ooool00ooo003ooooooooo
o`03ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool00_ooool00ooo003ooooooooo
o`03ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool00oooool00ooo003ooooooooo
o`0Fooooo`03ool00?oooooooooo00;ooooo00?o003oooooooooool04Oooool00ooo003ooooooooo
o`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00oooool2o`00occooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0@Oooool00ol00?ooooooooooo`02
ooooo`04o`00ooooooooooooo`00o`Kooooo00?oo`00ooooooooool00oooool00ol00?oooooooooo
o`0@ooooo`03ool00?oooooooooo00?ooooo00?o003oooooooooool04Oooool00ooo003ooooooooo
o`0@ooooo`03o`00oooooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo047ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool0@Oooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Kooooo00?o
o`00ooooooooool05_ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo00;ooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00Go
003oooooooooooooooooo`00o`17ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo04Gooooo00Go003oooooooooooooooooo`00o`06ooooo`03ool00?oooooooooo017ooooo
00?o003oooooooooool00_ooool00ooo003oooooooooo`0Aooooo`03o`00oooooooooooo00?ooooo
00?oo`00ooooooooool00_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00;ooooo
00?oo`00ooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03ool00?oooooooooo00Cooooo
00Go003oooooooooooooooooo`00o`17ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000
@oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00Cooooo00?oo`00oooooooo
ool00oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00?ooooo00?oo`00oooooooo
ool00_ooool00ol00?ooooooooooo`0Aooooo`03ool00?oooooooooo013ooooo00?o003ooooooooo
ool00oooool00ooo003oooooooooo`08ooooo`04o`00ooooooooooooo`00od?ooooo0_l00003oooo
o`004Oooool00ol0003oooooooooo`12ooooo`03o`00oooooooooooo00_ooooo00?oo`00oooooooo
ool00oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00?ooooo00?oo`00oooooooo
ool05_ooool00ooo003oooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?oo`00oooooooo
ool02?ooool01?l00?ooooooooooool00?m4ooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo04;ooooo00Co003ooooooooooooo003o2_ooool00ooo003oooooooooo`03oooo
o`03o`00oooooooooooo013ooooo00?oo`00ooooooooool00_ooool00ol00?ooooooooooo`0Boooo
o`03ool00?oooooooooo017ooooo00?o003oooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool00oooool00ooo003oooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool0@_ooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`12ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003ooooo
ooooool01?ooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo01Oooooo00?oo`00oooo
ooooool00_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00?ooooo00?oo`00oooo
ooooool01?ooool01Ol00?oooooooooooooooooo003o04Oooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool0AOooool01Ol00?oooooooooooooooooo003o00Kooooo00?oo`00
ooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03ool00?oooooooooo01;ooooo00?o003o
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool00_ooool00ooo003oooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?oo`00
ooooooooool01?ooool01Ol00?oooooooooooooooooo003o04Oooooo00?o0000ooooooooool00Ooo
ool0017ooooo0_l00016ooooo`05o`00ooooooooooooooooool00?l01_ooool00ooo003ooooooooo
o`03ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00_ooool01Ooo003ooooooooo
oooooooo003o00oooooo00?o003oooooooooool00_ooool00ooo003oooooooooo`0@ooooo`03o`00
oooooooooooo00?ooooo00?oo`00ooooooooool02?ooool01?l00?ooooooooooool00?m3ooooo`;o
00000oooool0017ooooo00?o0000ooooooooool0@_ooool00ol00?ooooooooooo`0;ooooo`03ool0
0?oooooooooo00?ooooo00?o003oooooooooool03?ooool01Ol00?ooooooooooooooooooo`0000Co
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`02ooooo`05ool00?oooooooooooooo
ool00?l05?ooool00ooo003oooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?oo`00oooo
ooooool02?ooool01?l00?ooooooooooool00?m4ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo04?ooooo00?o003oooooooooool02_ooool00ooo003oooooooooo`03oooo
o`03o`00oooooooooooo013ooooo00?oo`00ooooooooool00_ooool00ol00?ooooooooooo`0=oooo
o`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool04Oooool00ol00?ooooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?o003oooooooooool04Oooool00ooo003oooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool0@_ooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`13ooooo`;o003o1?ooool00ol00?ooooooooooo`04ooooo`03
ool00?oooooooooo00?ooooo00?o003oooooooooool04?ooool00ooo003oooooooooo`02ooooo`03
o`00oooooooooooo01;ooooo00Goo`00ooooooooooooooooo`00o`0?ooooo`03o`00oooooooooooo
00;ooooo00Goo`00ooooooooooooooooo`00o`0>ooooo`03o`00oooooooooooo00?ooooo00?oo`00
ooooooooool01?ooool00ol00?ooooooooooo`19ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo04Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`04oooo
o`03ool00?oooooooooo01;ooooo00Go003oooooooooooooooooool0000Dooooo`03o`00oooooooo
oooo00;ooooo00Goo`00ooooooooooooooooo`00o`0@ooooo`05o`00oooooooooooooooooooo0000
0oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00?ooooo00?oo`00ooooooooool0
1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo04Cooooo00?o0000ooooooooool0
0Oooool0017ooooo0_l00015ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?oo
ool00ooo003oooooooooo`03ooooo`03o`00oooooooooooo00cooooo00Go003ooooooooooooooooo
ool00004ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00_ooool01Ooo003ooooo
oooooooooooo003o013ooooo00Go003oooooooooooooooooool0000Booooo`03o`00oooooooooooo
00?ooooo00?oo`00ooooooooool01?ooool00ol00?ooooooooooo`02ooooo`;o003oA?ooool2o`00
00?ooooo000Aooooo`03o`000?oooooooooo04Wooooo00?o003oooooooooool01?ooool00ooo003o
ooooooooo`03ooooo`03o`00oooooooooooo00cooooo00Go003oooooooooooooooooool00004oooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool00_ooool01Ooo003ooooooooooooooooo
003o01Cooooo00Goo`00ooooooooooooooooo`00o`0Dooooo`03ool00?oooooooooo053ooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0D?ooool00ooo003oooooooooo`03
ooooo`03o`00oooooooooooo00cooooo00Go003oooooooooooooooooool00003ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool00_ooool00ooo003oooooooooo`0Fooooo`05ool00?oo
ooooooooooooool00?l05?ooool00ooo003oooooooooo`04ooooo`03o`00oooooooooooo04Wooooo
00?o0000ooooooooool00Oooool000;ooooo1Ol00003ooooo`;o00001Oooool00ol0003ooooooooo
o`19ooooo`03o`00oooooooooooo00Cooooo00?oo`00ooooooooool00oooool00ol00?oooooooooo
o`0@ooooo`05ool00?ooooooooooooooool00?l05Oooool00ooo003oooooooooo`0Booooo`05o`00
oooooooooooooooooooo00000oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00;o
oooo00?oo`00ooooooooool01?ooool00ol00?ooooooooooo`19ooooo`03o`000?oooooooooo007o
oooo0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`19ooooo`03o`00oooooooooooo00Cooooo00?oo`00ooooooooool04_ooool01Ol0
0?ooooooooooooooooooo`0001Wooooo00Goo`00ooooooooooooooooo`00o`0@ooooo`05o`00oooo
oooooooooooooooo00000oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo
00?oo`00ooooooooool01?ooool00ol00?ooooooooooo`19ooooo`03o`000?oooooooooo007ooooo
0004ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool3o`0004Wooooo
00?o003oooooooooool01?ooool00ooo003oooooooooo`0Booooo`05o`00oooooooooooooooooooo
00005Oooool01Ol00?ooooooooooooooooooo`0000?ooooo00?o003oooooooooool03_ooool01Ol0
0?ooooooooooooooooooo`0001?ooooo00?o003oooooooooool00_ooool00ooo003oooooooooo`04
ooooo`03o`00oooooooooooo04Oooooo0ol00003ooooo`001Oooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`19ooooo`03o`00oooooooo
oooo00Cooooo00?oo`00ooooooooool00_ooool00ol00?ooooooooooo`0>ooooo`04o`00oooooooo
ooooool000?ooooo00?o003oooooooooool03oooool01Ol00?ooooooooooooooooooo`0000;ooooo
00?o003oooooooooool04oooool00ooo003oooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo
00?oo`00ooooooooool0D?ooool00ol0003oooooooooo`01ooooo`000_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1@ooooo`03
ool00?oooooooooo00;ooooo00?o003oooooooooool03_ooool01?l00?oooooooooooooo0003oooo
o`03o`00oooooooooooo00oooooo00Go003oooooooooooooooooool0000Hooooo`05ool00?oooooo
ooooooooool00?l05?ooool00ooo003oooooooooo`1@ooooo`03o`000?oooooooooo007ooooo0002
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo053ooooo00?oo`00ooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`05ool0
0?ooooooooooooooool00?l05Oooool00ooo003oooooooooo`0Booooo`05o`00oooooooooooooooo
oooo00000oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo00?oo`00oooo
ooooool01?ooool00ol00?ooooooooooo`19ooooo`03o`000?oooooooooo007ooooo0003ooooo`?o
00001?ooool2o`0000Gooooo00?o0000ooooooooool0BOooool00ol00?ooooooooooo`04ooooo`03
ool00?oooooooooo01Kooooo00?oo`00ooooooooool05oooool01?oo003oooooooooool00?lAoooo
o`05o`00oooooooooooooooooooo00000_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooo
oooo00;ooooo00?oo`00ooooooooool01?ooool00ol00?ooooooooooo`19ooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo04Wooooo00?o003oooooooooool01?ooool00ooo
003oooooooooo`0Cooooo`04o`00ooooooooooooool001Gooooo00Go003oooooooooooooooooool0
0002ooooo`03o`00oooooooooooo00oooooo00Go003oooooooooooooooooool0000Cooooo`03o`00
oooooooooooo00;ooooo00?oo`00ooooooooool01?ooool00ol00?ooooooooooo`19ooooo`03o`00
0?oooooooooo007ooooo000Aooooo`;o0000Boooool00ol00?ooooooooooo`03ooooo`03ool00?oo
oooooooo00;ooooo00?o003oooooooooool03_ooool01?l00?oooooooooooooo0003ooooo`03o`00
oooooooooooo00oooooo00Go003oooooooooooooooooool00002ooooo`03o`00oooooooooooo00oo
oooo00Go003oooooooooooooooooool0000Cooooo`03o`00oooooooooooo00;ooooo00?oo`00oooo
ooooool0Coooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo053ooooo00?oo`00oooooooo
ool00_ooool00ol00?ooooooooooo`0>ooooo`04o`00ooooooooooooool000?ooooo00?o003ooooo
ooooool03oooool01Ol00?ooooooooooooooooooo`0000;ooooo00?o003oooooooooool04oooool0
1?oo003oooooooooool00?lEooooo`03ool00?oooooooooo053ooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0D?ooool00ooo003oooooooooo`02ooooo`03o`00oooooooo
oooo017ooooo00Coo`00oooooooooooo003o5_ooool00ooo003oooooooooo`0Cooooo`04o`00oooo
ooooooooool000;ooooo00?o003oooooooooool04oooool00ooo003oooooooooo`04ooooo`03o`00
oooooooooooo04Wooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0B_oo
ool00ol00?ooooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?o003oooooooooool04Ooo
ool01?oo003oooooooooool00?lFooooo`04ool00?ooooooooooo`00oa;ooooo00Co003ooooooooo
ooooo`000_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00;ooooo00?oo`00oooo
ooooool01?ooool00ol00?ooooooooooo`19ooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo04[ooooo00?o003oooooooooool00oooool00ooo003oooooooooo`0Cooooo`04
o`00ooooooooooooool001Kooooo00Co003oooooooooooooo`000_ooool00ol00?ooooooooooo`0@
ooooo`04o`00ooooooooooooool000;ooooo00?o003oooooooooool03_ooool00ol00?oooooooooo
o`02ooooo`03ool00?oooooooooo00?ooooo00?o003oooooooooool0B_ooool00ol0003ooooooooo
o`01ooooo`004Oooool2o`0004_ooooo00?o003oooooooooool00oooool00ooo003oooooooooo`02
ooooo`03o`00oooooooooooo00kooooo00Co003oooooooooooooo`000_ooool00ol00?oooooooooo
o`0Aooooo`06o`00ooooooooooooool00?oooooo003o4oooool01?l00?oooooooooooooo000Coooo
o`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool00oooool00ol00?ooooooooooo`19oooo
o`;o00000oooool0017ooooo00?o0000ooooooooool0B_ooool00ol00?ooooooooooo`03ooooo`03
ool00?oooooooooo00;ooooo00?o003oooooooooool03oooool00ol00?ooooooool00002ooooo`03
o`00oooooooooooo017ooooo00Ko003oooooooooooooo`00ooooool00?lFooooo`04ool00?oooooo
ooooo`00oaGooooo00?oo`00ooooooooool0D?ooool00ol0003oooooooooo`01ooooo`004Oooool0
0ol0003oooooooooo`1@ooooo`03ool00?oooooooooo00;ooooo00?o003oooooooooool03oooool0
0ol00?ooooooool00002ooooo`03o`00oooooooooooo017ooooo00Co003oooooooooooooo`006?oo
ool01?oo003oooooooooool00?lEooooo`03ool00?oooooooooo00?ooooo00?o003oooooooooool0
B_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1:ooooo`03o`00oooo
oooooooo00?ooooo00?oo`00ooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`04ool00?oo
ooooooooo`00oaKooooo00?oo`00ooooooooool04oooool01?l00?oooooooooooooo0002ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool00_ooool00ooo003oooooooooo`03ooooo`03
o`00oooooooooooo04[ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
B_ooool00ol00?ooooooooooo`03ooooo`03ool00?oooooooooo01Cooooo00?o003ooooooooo0000
5_ooool01_l00?oooooooooooooo003oooooo`00oa?ooooo00Ko003oooooooooooooo`00ooooool0
0?lAooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool00oooool00ol00?oooooooooo
o`1:ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000Boooool00ol00?ooooooooooo`03
ooooo`03ool00?oooooooooo01Cooooo00?o003ooooooooo00005_ooool01_l00?oooooooooooooo
003oooooo`00oaCooooo00?o003ooooooooo00004oooool00ol00?ooooooooooo`02ooooo`03ool0
0?oooooooooo00?ooooo00?o003oooooooooool0BOooool2o`0000?ooooo000Aooooo`03o`000?oo
oooooooo04[ooooo00?o003oooooooooool00oooool00ooo003oooooooooo`02ooooo`03o`00oooo
oooooooo00oooooo00Co003ooooooooo003ooooo0_l00?lCooooo`06o`00ooooooooooooool00?oo
oooo003o5_ooool00ooo003oooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?oo`00oooo
ooooool0D?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1@ooooo`03
ool00?oooooooooo00;ooooo00?o003oooooooooool03oooool01Ol00?ooooooool00?oooooo003o
01Cooooo00Co003oooooooooooooo`006?ooool00ooo003oooooo`00o`0Fooooo`03ool00?oooooo
oooo053ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0D?ooool00ooo
003oooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?oo`00ooooool00?l05oooool00ooo
003oooooooooo`0Dooooo`05o`00ooooooooo`00ooooool00?l04_ooool01Ol00?oooooooooooooo
ooooo`0000Gooooo00?o003oooooooooool0B_ooool00ol0003oooooooooo`01ooooo`004Oooool0
0ol0003oooooooooo`1:ooooo`03o`00oooooooooooo00?ooooo00?oo`00ooooooooool05_ooool0
0ooo003oooooooooo`0Gooooo`03ool00?l00?oooooo01Cooooo00Go003ooooooooo003oooooo`00
o`0Booooo`05o`00oooooooooooooooooooo00001Oooool00ol00?ooooooooooo`1:ooooo`03o`00
0?oooooooooo007ooooo000Aooooo`;o0000Boooool00ol00?ooooooooooo`03ooooo`03ool00?oo
oooooooo01Gooooo00?o003oool00?ooool05_ooool01?l00?ooooooool00?l00?lEooooo`03o`00
ooooooooo`0001Cooooo00Go003oooooooooooooooooool00005ooooo`03o`00oooooooooooo04Wo
oooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1:ooooo`03o`00oooooooooooo00?ooooo
00Goo`00ooooooooooooooooo`00o`0Dooooo`03ool00?oooooo003o01Gooooo00Co003ooooooooo
003o003o5Oooool00ol00?ooooooool0000Dooooo`05o`00oooooooooooooooooooo0000D_ooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1@ooooo`05ool00?oooooooooo
ooooool00?l04oooool01?l00?ooo`00ooooool00?lEooooo`03o`00ooooooooo`0001Sooooo00?o
o`00o`00ooooool05_ooool00ooo003oooooooooo`1@ooooo`03o`000?oooooooooo007ooooo0003
ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0D?ooool01Ooo003ooooooooooooo
oooo003o01?ooooo00?o003oool00?l00?l06?ooool00ooo003oooooooooo`0Eooooo`03o`00oooo
003o003o01Oooooo00?oo`00ooooooooool00oooool00ol00?ooooooooooo`1:ooooo`03o`000?oo
oooooooo007ooooo0002ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo04[ooooo00?o003oooooooooool00oooool01Ooo003ooooo
oooooooooooo003o01?ooooo00?o003oool00?ooool06?ooool00ooo003oooooooooo`0Eooooo`03
o`00oooo003o003o01?ooooo00Go003oooooooooooooooooool00005ooooo`03o`00oooooooooooo
04[ooooo00?o0000ooooooooool00Oooool000Kooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`02ooooo`?o0000B_ooool00ol00?ooooooooooo`03ooooo`03ool00?oooooooooo
01Gooooo0ooo000Fooooo`?oo`005oooool3ool001?ooooo00Go003oooooooooooooooooool00005
ooooo`03o`00oooooooooooo04Sooooo0ol00003ooooo`001?ooool2o`0000?ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`1:ooooo`03o`00oooooooooooo00?ooooo00Goo`00
ooooooooooooooooo`00o`0Cooooo`?oo`005_ooool3ool001Oooooo0ooo000Cooooo`05o`00oooo
oooooooooooooooo00001Oooool00ol00?ooooooooooo`1:ooooo`03o`000?oooooooooo007ooooo
0006ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1:ooooo`03o`00oooooooooooo00?ooooo00Goo`00ooooooooooooooooo`00o`0Cooooo`?o
o`005_ooool3ool001Oooooo0ooo000Gooooo`03ool00?oooooooooo053ooooo00?o0000oooooooo
ool00Oooool000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0D?ooool01Ooo003ooooooooooooooooo003o02kooooo00?o0000
ooooooooool0;oooool00ooo003oooooooooo`03ooooo`03o`00oooooooooooo04[ooooo00?o0000
ooooooooool00Oooool000?ooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`1:oooo
o`03o`00oooooooooooo00?ooooo00Goo`00ooooooooooooooooo`00o`0^ooooo`03o`000?oooooo
oooo02_ooooo00Go003oooooooooooooooooool00005ooooo`03o`00oooooooooooo04[ooooo00?o
0000ooooooooool00Oooool0017ooooo0_l0001;ooooo`03o`00oooooooooooo00?ooooo00?oo`00
ooooooooool0<?ooool00ol0003oooooooooo`0[ooooo`05o`00oooooooooooooooooooo00001Ooo
ool00ol00?ooooooooooo`19ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0Boooool0
0ol00?ooooooooooo`02ooooo`03ool00?oooooooooo033ooooo00?o0000ooooooooool0:oooool0
1Ol00?ooooooooooooooooooo`0000Gooooo00?o003oooooooooool0B_ooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`1;ooooo`03o`00oooooooooooo00;ooooo00Goo`00
ooooooooooooooooo`00o`0^ooooo`03o`000?oooooooooo02_ooooo00Go003ooooooooooooooooo
ool0001Booooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo053ooooo00Go
o`00ooooooooooooooooo`00o`0^ooooo`03o`000?oooooooooo02oooooo00?oo`00ooooooooool0
D?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1@ooooo`05ool00?oo
ooooooooooooool00?l0;_ooool00ol0003oooooooooo`0[ooooo`05o`00oooooooooooooooooooo
00001Oooool00ol00?ooooooooooo`1:ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000
C?ooool00ol00?ooooooooooo`02ooooo`03ool00?oooooooooo033ooooo00?o0000ooooooooool0
:oooool01Ol00?ooooooooooooooooooo`0000Gooooo00?o003oooooooooool0BOooool2o`0000?o
oooo000Aooooo`03o`000?oooooooooo04_ooooo00?o003oooooooooool00_ooool00ooo003ooooo
ooooo`0`ooooo`03o`000?oooooooooo02_ooooo00Go003oooooooooooooooooool00004ooooo`03
o`00oooooooooooo04_ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
Boooool00ol00?ooooooooooo`02ooooo`05ool00?ooooooooooooooool00?l0;_ooool00ol0003o
ooooooooo`0[ooooo`05o`00oooooooooooooooooooo0000D_ooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`1@ooooo`05ool00?ooooooooooooooool00?l0;_ooool00ol0
003oooooooooo`0_ooooo`03ool00?oooooooooo053ooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool0D?ooool01Ooo003ooooooooooooooooo003o02kooooo00?o0000oooo
ooooool0;oooool00ooo003oooooooooo`02ooooo`03o`00oooooooooooo04_ooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool0Boooool00ol00?ooooooooooo`02ooooo`05
ool00?ooooooooooooooool00?l0;_ooool00ol0003oooooooooo`0[ooooo`05o`00oooooooooooo
oooooooo00001?ooool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`;o0000C?ooool00ol00?ooooooooooo`02ooooo`03ool00?oooooooooo033ooooo00?o0000oooo
ooooool0:oooool01Ol00?ooooooooooooooooooo`0000Cooooo00?o003oooooooooool0B_ooool2
o`0000?ooooo000Aooooo`03o`000?oooooooooo04_ooooo00?o003oooooooooool00_ooool01Ooo
003ooooooooooooooooo003o02kooooo00?o0000ooooooooool0;?ooool01?l00?oooooooooooooo
0004ooooo`03o`00oooooooooooo04_ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool0Boooool00ol00?ooooooooooo`02ooooo`05ool00?ooooooooooooooool00?l0;_oo
ool00ol0003oooooooooo`0_ooooo`03ool00?oooooooooo053ooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0D?ooool01?oo003oooooooooool00?l_ooooo`03o`000?oo
oooooooo02oooooo00?oo`00ooooooooool00_ooool00ol00?ooooooooooo`1;ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo04_ooooo00?o003oooooooooool00_ooool0
1?oo003oooooooooool00?l_ooooo`03o`000?oooooooooo02cooooo00Co003oooooooooooooo`00
1?ooool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000C?oo
ool00ol00?ooooooooooo`02ooooo`03ool00?oooooooooo033ooooo00?o0000ooooooooool0;?oo
ool01?l00?oooooooooooooo0004ooooo`03o`00oooooooooooo04[ooooo0_l00003ooooo`004Ooo
ool00ol0003oooooooooo`1;ooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool0<?oo
ool00ol0003oooooooooo`0/ooooo`04o`00ooooooooooooool000Cooooo00?o003oooooooooool0
Boooool00ol0003oooooooooo`01ooooo`001?ooool3o`0000?ooooo0_l00005ooooo`03o`000?oo
oooooooo04_ooooo00?o003oooooooooool00_ooool01?oo003oooooooooool00?l_ooooo`03o`00
0?oooooooooo02cooooo00Co003oooooooooooooo`00D_ooool00ol0003oooooooooo`01ooooo`00
1Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1@ooooo`04ool00?ooooooooooo`00oboooooo00?o0000ooooooooool0;oooool00ooo
003oooooooooo`1@ooooo`03o`000?oooooooooo007ooooo0002ooooo`Go00000_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo053ooooo00Coo`00oooooooooooo003o;oooool0
0ol0003oooooooooo`0/ooooo`04o`00ooooooooooooool000Cooooo00?o003oooooooooool0Booo
ool00ol0003oooooooooo`01ooooo`000_ooool01?l0003oooooooooool00003ooooo`04o`000?oo
ooooooooo`0000Cooooo0ol0001;ooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool0
<?ooool00ol0003oooooooooo`0/ooooo`04o`00ooooooooooooool000Cooooo00?o003ooooooooo
ool0BOooool3o`0000?ooooo0003ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`1;ooooo`03o`00oooooooooooo00;ooooo00?oo`00oooooooo
ool0<?ooool00ol0003oooooooooo`0/ooooo`04o`00ooooooooooooool000Cooooo00?o003ooooo
ooooool0Boooool00ol0003oooooooooo`01ooooo`001?ooool2o`0000?ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`1;ooooo`03o`00oooooooooooo00;ooooo00Coo`00oooo
oooooooo003o;oooool00ol0003oooooooooo`0/ooooo`04o`00ooooooooooooool005;ooooo00?o
0000ooooooooool00Oooool000Gooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000
ooooooooool0D?ooool01?oo003oooooooooool00?l_ooooo`03o`000?oooooooooo02oooooo00?o
o`00ooooooooool0D?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1@
ooooo`04ool00?ooooooooooo`00oboooooo00?o0000ooooooooool0;oooool00ooo003ooooooooo
o`02ooooo`03o`00oooooooooooo04_ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001<
ooooo`03o`00oooooooooooo00;ooooo00Coo`00oooooooooooo003o;oooool00ol0003ooooooooo
o`0/ooooo`04o`00ooooooooooooool000Cooooo00?o003oooooooooool0B_ooool2o`0000?ooooo
000Aooooo`03o`000?oooooooooo04_ooooo00?o003oooooooooool00_ooool00ooo003ooooooooo
o`0`ooooo`03o`000?oooooooooo02cooooo00Co003oooooooooooooo`001?ooool00ol00?oooooo
ooooo`1;ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04cooooo00Go
003oooooooooooooooooool00002ooooo`03o`00oooooooooooo02gooooo00?o0000ooooooooool0
;?ooool01?l00?oooooooooooooo0004ooooo`03o`00oooooooooooo04_ooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool0C?ooool01Ol00?ooooooooooooooooooo`0000;o
oooo00?o003oooooooooool0;Oooool00ol0003oooooooooo`0_ooooo`03ool00?oooooooooo053o
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0C?ooool01Ol00?oooooo
ooooooooooooo`0000;ooooo00?o003oooooooooool0;Oooool00ol0003oooooooooo`0_ooooo`05
ool00?ooooooooooooooool00?l0C_ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0004go
oooo00Go003oooooooooooooooooool00002ooooo`03o`00oooooooooooo02gooooo00?o0000oooo
ooooool0;?ooool01?l00?oooooooooooooo0003ooooo`03o`00oooooooooooo04_ooooo0_l00003
ooooo`004Oooool00ol0003oooooooooo`1@ooooo`03ool00?oooooooooo033ooooo00?o0000oooo
ooooool0;?ooool01?l00?oooooooooooooo0003ooooo`03o`00oooooooooooo04cooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0D?ooool00ooo003oooooooooo`0`oooo
o`03o`000?oooooooooo02gooooo00?o003ooooooooo00000oooool00ol00?ooooooooooo`1<oooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04cooooo00Go003ooooooooo
ooooooooool00002ooooo`03o`00oooooooooooo02gooooo00?o0000ooooooooool0;Oooool00ol0
0?ooooooool0001Booooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04co
oooo00Go003oooooooooooooooooool00002ooooo`03o`00oooooooooooo02gooooo00?o0000oooo
ooooool0;oooool00ooo003oooooooooo`1@ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o
0000COooool01ol00?ooooooooooooooooooo`00ooooool00?l0<?ooool00ol0003oooooooooo`0]
ooooo`03o`00ooooooooo`0000?ooooo00?o003oooooooooool0Boooool2o`0000?ooooo000Aoooo
o`03o`000?oooooooooo053ooooo00?oo`00ooooooooool0<?ooool00ol0003oooooooooo`0]oooo
o`03o`00ooooooooo`0000?ooooo00?o003oooooooooool0C?ooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`1@ooooo`03ool00?oooooooooo033ooooo00?o0000oooooooo
ool0;Oooool00ol00?ooooooool00003ooooo`03o`00oooooooooooo04cooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool0C?ooool01ol00?ooooooooooooooooooo`00oooo
ool00?l0<?ooool00ol0003oooooooooo`0]ooooo`03o`00ooooooooo`0005;ooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool0C?ooool01ol00?ooooooooooooooooooo`00
ooooool00?l0<?ooool00ol0003oooooooooo`0_ooooo`03ool00?oooooooooo053ooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0C?ooool01ol00?oooooooooooooooooo
o`00ooooool00?l0<?ooool00ol0003oooooooooo`0_ooooo`05ool00?ooooooooooooooool00?l0
C_ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0004gooooo00Go003ooooooooooooooooo
ool0000booooo`03o`000?oooooooooo02gooooo00?o003ooooooooo00000oooool00ol00?oooooo
ooooo`1;ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0D?ooool00ooo003ooooooooo
o`0`ooooo`03o`000?oooooooooo02gooooo00?o003ooooooooo00000oooool00ol00?oooooooooo
o`1<ooooo`03o`000?oooooooooo007ooooo0003ooooo`?o00001?ooool2o`0000Gooooo00?o0000
ooooooooool0C?ooool01ol00?ooooooooooooooooooo`00ooooool00?l0<?ooool00ol0003ooooo
ooooo`0]ooooo`03o`00ooooooooo`0000?ooooo00?o003oooooooooool0C?ooool00ol0003ooooo
ooooo`01ooooo`000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`1<ooooo`07o`00oooooooooooooooooooo003oooooo`00o`0`
ooooo`03o`000?oooooooooo02oooooo00?oo`00ooooooooool0D?ooool00ol0003oooooooooo`01
ooooo`001_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0C?ooool01ol00?ooooooooooooooooooo`00ooooool00?l0<?ooool00ol0003ooooo
ooooo`0_ooooo`05ool00?ooooooooooooooool00?l0C_ooool00ol0003oooooooooo`01ooooo`00
1_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo0ol0001<ooooo`07
o`00oooooooooooooooooooo003oooooo`00o`0`ooooo`03o`000?oooooooooo02gooooo00?o003o
oooooooo00000oooool00ol00?ooooooooooo`1:ooooo`?o00000oooool000;ooooo1?l00003oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0D?ooool00ooo003oooooooooo`0`
ooooo`03o`000?oooooooooo02gooooo00?o003ooooooooo00000oooool00ol00?ooooooooooo`1<
ooooo`03o`000?oooooooooo007ooooo0002ooooo`03o`000?oooooooooo00Cooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`1@ooooo`03ool00?oooooo003o033ooooo00?o0000
ooooooooool0;Oooool00ol00?ooooooool00003ooooo`03o`00oooooooooooo04cooooo00?o0000
ooooooooool00Oooool000;ooooo1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`1=oooo
o`06o`00ooooooooooooool00?oooooo003o<?ooool00ol0003oooooooooo`0]ooooo`03o`00oooo
ooooo`0005;ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0COooool0
1_l00?oooooooooooooo003oooooo`00oc3ooooo00?o0000ooooooooool0;oooool00ooo003ooooo
ooooo`1@ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000C_ooool01_l00?oooooooooo
oooo003oooooo`00oc3ooooo00?o0000ooooooooool0;_ooool00ol00?ooo`00ooooo`02ooooo`03
o`00oooooooooooo04_ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1@ooooo`03ool0
0?oooooooooo033ooooo00?o0000ooooooooool0;_ooool00ol00?ooo`00ooooo`02ooooo`03o`00
oooooooooooo04cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0D?oo
ool00ooo003oooooooooo`0`ooooo`03o`000?oooooooooo02kooooo00Go003oool00?oooooooooo
o`00o`1?ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04gooooo00Go
003oooooooooooooo`00o`00o`0aooooo`03o`000?oooooooooo02kooooo00?o003oool00?ooool0
DOooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1=ooooo`05o`00oooo
ooooooooool00?l00?l0<Oooool00ol0003oooooooooo`0_ooooo`03ool00?oooooooooo053ooooo
00?o0000ooooooooool00Oooool0017ooooo0_l0001>ooooo`05o`00ooooooooooooool00?l00?l0
<Oooool00ol0003oooooooooo`0_ooooo`04ool00?ooooooooooo`00odkooooo0_l00003ooooo`00
4Oooool00ol0003oooooooooo`1=ooooo`04o`00ooooooooooooool003;ooooo00?o0000oooooooo
ool0;_ooool01Ol00?ooo`00oooooooooooo003o04oooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool0D?ooool00ooo003oooooooooo`0`ooooo`03o`000?oooooooooo02ko
oooo00Go003oool00?ooooooooooo`00o`1?ooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo04gooooo00Go003oooooooooooooo`00o`00o`0aooooo`03o`000?oooooooooo
02kooooo00?o003oool00?ooool0DOooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`1=ooooo`05o`00ooooooooooooool00?l00?l0<Oooool00ol0003oooooooooo`0_oooo
o`03ool00?oooooooooo053ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001>ooooo`05
o`00ooooooooooooool00?l00?l0<Oooool00ol0003oooooooooo`0_ooooo`04ool00?oooooooooo
o`00odkooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1=ooooo`05o`00oooooooooooo
ool00?l00?l0<Oooool00ol0003oooooooooo`0^ooooo`05o`00oooo003oooooooooool00?l0Cooo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1@ooooo`03ool00?oooooo
oooo033ooooo00?o0000ooooooooool0;_ooool01Ol00?ooo`00oooooooooooo003o04oooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0D?ooool00ooo003o003oooooo`0`
ooooo`03o`000?oooooooooo02kooooo00Go003oool00?ooooooooooo`00o`1?ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo04kooooo00Co003ooooooooo003o003o<Ooo
ool00ol0003oooooooooo`0^ooooo`03o`00oooo003ooooo057ooooo00?o0000ooooooooool00Ooo
ool0017ooooo0_l0001?ooooo`04o`00ooooooooo`00o`00oc7ooooo00?o0000ooooooooool0;ooo
ool00ooo003oooooo`00o`1?ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0C_ooool0
0ol00?ooooooool0000booooo`03o`000?oooooooooo02oooooo00?oo`00ooooool00?l0D?ooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1@ooooo`03ool00?oooooooooo
033ooooo00?o0000ooooooooool0;oooool00ooo003oooooo`00o`1@ooooo`03o`000?oooooooooo
007ooooo0003ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0D?ooool00ooo003o
ooooooooo`0`ooooo`03o`000?oooooooooo02oooooo00?oo`00ooooool00?l0D?ooool00ol0003o
ooooooooo`01ooooo`000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`1>ooooo`03o`00ooooooooo`0003;ooooo00?o0000oooo
ooooool0;oooool00ooo003oooooooooo`1@ooooo`03o`000?oooooooooo007ooooo0002ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`?o0000C_ooool3
ool003;ooooo00?o0000ooooooooool0;_ooool3ool00003o`00oooooooooooo04cooooo0ol00003
ooooo`000_ooool4o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1>
ooooo`?oo`00<_ooool00ol0003oooooooooo`0^ooooo`?oo`0000?o003oooooooooool0C_ooool0
0ol0003oooooooooo`01ooooo`000_ooool00ol0003oooooooooo`04ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0C_ooool3ool003;ooooo00?o0000ooooooooool0;_ooool3
ool0057ooooo00?o0000ooooooooool00Oooool000?ooooo00?o0000ooooooooool00oooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0<?ooool0
0ol00?ooooooooooo`1?ooooo`03o`000?oooooooooo007ooooo0004ooooo`;o00001?ooool2o`00
00Gooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00Oooool0017ooooo
ool0000=o`0000?ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.95693, -6.30366, \
0.0394232, 0.387934}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g7 = 
        DiscreteListPlot[
          FourierRearrange[Arg[\(\((Last[#] +  .0000001)\) &\)\  /@ \ fft], 
            fs], Red, PlotRange \[Rule] All, ImageSize \[Rule] 504, \ 
          Frame \[Rule] True, \ Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g8 = \ Show[g2, g7];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309069 0.103352 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .10236 -12 -4.5 ]
[-0.0125 .10236 0 4.5 ]
[-0.0125 .20572 -12 -4.5 ]
[-0.0125 .20572 0 4.5 ]
[-0.0125 .30907 -6 -4.5 ]
[-0.0125 .30907 0 4.5 ]
[-0.0125 .41242 -6 -4.5 ]
[-0.0125 .41242 0 4.5 ]
[-0.0125 .51577 -6 -4.5 ]
[-0.0125 .51577 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10236 m
.00625 .10236 L
s
[(-2)] -0.0125 .10236 1 0 Mshowa
0 .20572 m
.00625 .20572 L
s
[(-1)] -0.0125 .20572 1 0 Mshowa
0 .30907 m
.00625 .30907 L
s
[(0)] -0.0125 .30907 1 0 Mshowa
0 .41242 m
.00625 .41242 L
s
[(1)] -0.0125 .41242 1 0 Mshowa
0 .51577 m
.00625 .51577 L
s
[(2)] -0.0125 .51577 1 0 Mshowa
.125 Mabswid
0 .01968 m
.00375 .01968 L
s
0 .04035 m
.00375 .04035 L
s
0 .06102 m
.00375 .06102 L
s
0 .08169 m
.00375 .08169 L
s
0 .12304 m
.00375 .12304 L
s
0 .14371 m
.00375 .14371 L
s
0 .16438 m
.00375 .16438 L
s
0 .18505 m
.00375 .18505 L
s
0 .22639 m
.00375 .22639 L
s
0 .24706 m
.00375 .24706 L
s
0 .26773 m
.00375 .26773 L
s
0 .2884 m
.00375 .2884 L
s
0 .32974 m
.00375 .32974 L
s
0 .35041 m
.00375 .35041 L
s
0 .37108 m
.00375 .37108 L
s
0 .39175 m
.00375 .39175 L
s
0 .43309 m
.00375 .43309 L
s
0 .45376 m
.00375 .45376 L
s
0 .47443 m
.00375 .47443 L
s
0 .4951 m
.00375 .4951 L
s
0 .53644 m
.00375 .53644 L
s
0 .55711 m
.00375 .55711 L
s
0 .57778 m
.00375 .57778 L
s
0 .59845 m
.00375 .59845 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .10236 m
1 .10236 L
s
.99375 .20572 m
1 .20572 L
s
.99375 .30907 m
1 .30907 L
s
.99375 .41242 m
1 .41242 L
s
.99375 .51577 m
1 .51577 L
s
.125 Mabswid
.99625 .01968 m
1 .01968 L
s
.99625 .04035 m
1 .04035 L
s
.99625 .06102 m
1 .06102 L
s
.99625 .08169 m
1 .08169 L
s
.99625 .12304 m
1 .12304 L
s
.99625 .14371 m
1 .14371 L
s
.99625 .16438 m
1 .16438 L
s
.99625 .18505 m
1 .18505 L
s
.99625 .22639 m
1 .22639 L
s
.99625 .24706 m
1 .24706 L
s
.99625 .26773 m
1 .26773 L
s
.99625 .2884 m
1 .2884 L
s
.99625 .32974 m
1 .32974 L
s
.99625 .35041 m
1 .35041 L
s
.99625 .37108 m
1 .37108 L
s
.99625 .39175 m
1 .39175 L
s
.99625 .43309 m
1 .43309 L
s
.99625 .45376 m
1 .45376 L
s
.99625 .47443 m
1 .47443 L
s
.99625 .4951 m
1 .4951 L
s
.99625 .53644 m
1 .53644 L
s
.99625 .55711 m
1 .55711 L
s
.99625 .57778 m
1 .57778 L
s
.99625 .59845 m
1 .59845 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30907 m
1 .30907 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .47141 m
.02847 .42587 L
.03355 .37621 L
.03832 .32956 L
.04291 .28471 L
.0478 .23696 L
.0525 .19101 L
.05373 .17897 L
.05438 .17262 L
.05474 .16915 L
.05507 .1659 L
.05536 .16307 L
.05544 .16225 L
.05552 .16148 L
.05567 .48471 L
.05575 .48394 L
.05584 .48311 L
.05599 .48162 L
.05633 .47824 L
.0575 .46685 L
.06251 .41785 L
.06735 .37063 L
.072 .32521 L
.07694 .2769 L
.0817 .23038 L
.0841 .20698 L
.08514 .19676 L
.08628 .18565 L
.08659 .18268 L
.08691 .17952 L
.08704 .17822 L
.08719 .17682 L
.08734 .49998 L
.08749 .49854 L
.08864 .48736 L
.09116 .46273 L
.09612 .41428 L
.1009 .36762 L
.10549 .32275 L
.11039 .275 L
.1151 .22905 L
.11633 .21699 L
.11767 .20393 L
.11828 .19793 L
.11862 .19465 L
.11878 .19305 L
.11893 .19159 L
.11907 .51494 L
.1192 .51367 L
.11949 .51086 L
Mistroke
.1201 .5049 L
.12471 .45991 L
.12962 .41203 L
.13435 .36596 L
.13937 .31701 L
.14421 .26985 L
.14643 .24821 L
.14769 .23593 L
.14886 .22449 L
.15003 .21315 L
.15036 .20989 L
.15052 .20828 L
.15068 .2068 L
.15082 .53015 L
.15096 .52872 L
.15127 .52571 L
.15381 .50095 L
.15837 .45655 L
.16323 .4093 L
.1679 .36383 L
.17287 .31551 L
.17765 .26899 L
.18006 .24554 L
.18112 .23533 L
.18167 .22995 L
.18197 .22701 L
.18225 .22427 L
.1824 .22285 L
.18256 .54602 L
.18265 .54515 L
.18273 .54433 L
.18289 .54279 L
.18347 .53711 L
.18462 .52594 L
.18715 .50138 L
.19177 .45654 L
.19669 .40886 L
.20142 .36298 L
.20597 .3189 L
.20849 .29443 L
.21081 .27198 L
.21308 .25001 L
.21363 .24468 L
.21394 .24174 L
.21409 .2403 L
.21422 .23897 L
.2143 .56289 L
.21439 .56208 L
.21456 .56038 L
.21487 .5574 L
Mistroke
.21547 .55157 L
.22004 .50743 L
.2249 .46047 L
.22958 .41533 L
.23455 .36739 L
.23934 .32127 L
.24176 .29802 L
.24395 .27697 L
.24454 .27132 L
.24518 .26522 L
.24547 .26242 L
.24563 .26089 L
.24578 .25946 L
.2459 .25824 L
.24604 .58162 L
.24619 .58017 L
.24633 .57885 L
.24886 .55458 L
.25366 .50851 L
.25829 .46427 L
.26321 .41731 L
.26795 .37219 L
.2725 .32894 L
.27503 .30495 L
.27614 .29447 L
.27673 .28892 L
.27705 .28588 L
.27735 .28301 L
.2775 .28165 L
.27765 .28021 L
.27773 .27946 L
.27782 .60332 L
.27797 .60186 L
.27853 .59657 L
.27963 .58622 L
.28202 .56366 L
.28689 .51793 L
.29158 .47414 L
.29656 .42784 L
.30135 .38357 L
.30597 .34133 L
.31088 .29685 L
.31561 .25458 L
.32063 .21043 L
.32547 .16882 L
.33013 .12994 L
.33508 .0902 L
.33755 .07119 L
.33876 .06214 L
.33985 .05404 L
Mistroke
.3404 .05007 L
.34069 .04798 L
.34099 .04579 L
.34112 .04487 L
.34126 .04388 L
.34141 .36749 L
.34155 .36648 L
.34207 .36282 L
.34444 .34655 L
.34941 .31536 L
.3542 .2896 L
.3588 .26863 L
.36371 .24871 L
.36842 .22899 L
.36966 .22338 L
.371 .21705 L
.37162 .21404 L
.37227 .21079 L
.37254 .20943 L
.37283 .20796 L
.37291 .20752 L
.37299 .20711 L
.37314 .53102 L
.37328 .53028 L
.37344 .52948 L
.37835 .50158 L
.38309 .47122 L
.38764 .43955 L
.39249 .40391 L
.39715 .36838 L
.40211 .32984 L
.40689 .2924 L
.41148 .25645 L
.41637 .2186 L
.42108 .18292 L
.42608 .1462 L
.4309 .11239 L
.43311 .09751 L
.43437 .08925 L
.43498 .08526 L
.43554 .08165 L
.43582 .07983 L
.43613 .07786 L
.43628 .07696 L
.43643 .07601 L
.43657 .3998 L
.4367 .39898 L
.43794 .39122 L
.44047 .37579 L
.44531 .34793 L
Mistroke
.44997 .32254 L
.45492 .29603 L
.45968 .26981 L
.46427 .24309 L
.46662 .22864 L
.4673 .22439 L
.46764 .22228 L
.46794 .22032 L
.46809 .2194 L
.46822 .21854 L
.46837 .54233 L
.46852 .54133 L
.46915 .53729 L
.47382 .50613 L
.47878 .47113 L
.48357 .43595 L
.48817 .40112 L
.49307 .3633 L
.49778 .32648 L
.50279 .28721 L
.50762 .24954 L
.51226 .21374 L
.5172 .17646 L
.52196 .14168 L
.52653 .10962 L
.52908 .09248 L
.53028 .08455 L
.53081 .0811 L
.53112 .07914 L
.5314 .07732 L
.53153 .07648 L
.53167 .0756 L
.53182 .39932 L
.53196 .39844 L
.53255 .39467 L
.53381 .38682 L
.53609 .37292 L
.54068 .3463 L
.54556 .31952 L
.55027 .29434 L
.55527 .26697 L
.55777 .25266 L
.56008 .239 L
.56233 .22524 L
.56288 .22182 L
.56318 .21992 L
.56333 .21899 L
.56347 .21812 L
.56355 .54231 L
.56363 .54178 L
Mistroke
.5638 .54067 L
.56411 .5387 L
.56472 .53482 L
.56973 .50138 L
.57457 .46725 L
.57922 .43299 L
.58416 .39542 L
.58893 .3585 L
.59351 .32265 L
.59838 .28445 L
.60308 .24801 L
.60807 .2101 L
.61287 .17494 L
.6175 .14302 L
.61983 .12782 L
.62241 .11194 L
.62359 .10505 L
.62486 .09788 L
.62544 .09467 L
.62605 .09136 L
.62658 .08858 L
.62672 .08783 L
.62687 .08703 L
.62702 .41097 L
.62715 .41029 L
.63197 .3874 L
.63661 .36815 L
.64155 .348 L
.6463 .32604 L
.65087 .3011 L
.65342 .28555 L
.65574 .27038 L
.65689 .26256 L
.6575 .25835 L
.65783 .25602 L
.65814 .25382 L
.65844 .2517 L
.65852 .25112 L
.65861 .25051 L
.65876 .57409 L
.6589 .5731 L
.65903 .57217 L
.65933 .57006 L
.66042 .56207 L
.66512 .52633 L
.67012 .48617 L
.67493 .44591 L
.67956 .40605 L
.68449 .36274 L
.68923 .32032 L
Mistroke
.69379 .27902 L
.69864 .23459 L
.70332 .19147 L
.70829 .14529 L
.71307 .10055 L
.71768 .05731 L
.72005 .03498 L
.72073 .02854 L
.72137 .02247 L
.72165 .01982 L
.72195 .01701 L
.7221 .01555 L
.72219 .01472 L
.72227 .33863 L
.72242 .33726 L
.72257 .3358 L
.72756 .2886 L
.73236 .24299 L
.73698 .199 L
.7419 .15208 L
.74663 .10681 L
.75118 .06321 L
.75232 .05232 L
.75293 .04637 L
.75351 .04084 L
.75367 .03935 L
.75381 .03794 L
.7539 .03715 L
.75398 .361 L
.75414 .35952 L
.75482 .35294 L
.75603 .34138 L
.76096 .29397 L
.76571 .24825 L
.77027 .20424 L
.77514 .15733 L
.77981 .11213 L
.78219 .08913 L
.78345 .07698 L
.78414 .07031 L
.78479 .06403 L
.78509 .06108 L
.78542 .05797 L
.78558 .05634 L
.78568 .05542 L
.78577 .37924 L
.78593 .37773 L
.78609 .3761 L
.78728 .36467 L
.78958 .34235 L
Mistroke
.79457 .29401 L
.79938 .24741 L
.80401 .20255 L
.80893 .15479 L
.81138 .13105 L
.81367 .10878 L
.81586 .08748 L
.81646 .08164 L
.81679 .07846 L
.8171 .0755 L
.81723 .07419 L
.81736 .07296 L
.8175 .39623 L
.81764 .39494 L
.81823 .38921 L
.82287 .34409 L
.82781 .29608 L
.83256 .24982 L
.83713 .20533 L
.842 .15794 L
.84425 .1361 L
.84669 .11231 L
.84733 .10605 L
.84802 .09939 L
.84835 .09615 L
.84866 .0931 L
.84894 .09036 L
.8491 .08882 L
.84924 .4121 L
.84939 .41073 L
.84954 .40926 L
.84981 .40661 L
.85042 .4006 L
.85167 .38848 L
.85667 .33978 L
.86148 .29285 L
.86611 .24769 L
.87104 .19963 L
.87579 .15335 L
.87817 .13011 L
.87921 .11994 L
.87976 .11457 L
.88035 .10884 L
.88052 .1072 L
.88068 .10566 L
.88082 .10427 L
.88097 .42746 L
.88112 .42603 L
.88127 .42452 L
.88155 .42182 L
Mistroke
.88269 .41069 L
.88521 .38612 L
.88979 .34144 L
.89466 .29386 L
.89935 .24805 L
.90434 .19935 L
.90684 .17498 L
.90915 .15243 L
.91139 .13055 L
.91193 .12523 L
.91222 .12243 L
.91252 .11949 L
.9126 .11874 L
.91268 .11793 L
.91277 .44173 L
.91286 .4409 L
.91316 .43789 L
.91377 .43198 L
.91877 .3831 L
.92359 .33601 L
.92823 .29069 L
.93317 .24248 L
.93792 .19605 L
.94031 .17273 L
.94249 .15141 L
.94306 .14579 L
.94369 .13966 L
.94398 .13685 L
.94414 .13531 L
.94428 .13387 L
.94442 .13251 L
.94457 .45574 L
.94471 .45441 L
.94483 .45319 L
.94735 .42856 L
.95212 .38197 L
.95671 .33716 L
.96159 .28945 L
.96628 .24354 L
.97128 .19473 L
.97609 .1477 L
.97619 .14672 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.05556 .30907 m
.05556 .30907 L
s
.0873 .30907 m
.0873 .30907 L
s
.11905 .30907 m
.11905 .30907 L
s
.15079 .30907 m
.15079 .30907 L
s
.18254 .30907 m
.18254 .30907 L
s
.21429 .30907 m
.21429 .30907 L
s
.24603 .30907 m
.24603 .30907 L
s
.27778 .30907 m
.27778 .30907 L
s
.30952 .30907 m
.30952 .30907 L
s
.34127 .30907 m
.34127 .30907 L
s
.37302 .30907 m
.37302 .30907 L
s
.40476 .30907 m
.40476 .30907 L
s
.43651 .30907 m
.43651 .30907 L
s
.46825 .30907 m
.46825 .30907 L
s
.5 .30907 m
.5 .30907 L
s
.53175 .30907 m
.53175 .30907 L
s
.56349 .30907 m
.56349 .30907 L
s
.59524 .30907 m
.59524 .30907 L
s
.62698 .30907 m
.62698 .30907 L
s
.65873 .30907 m
.65873 .30907 L
s
.69048 .30907 m
.69048 .30907 L
s
.72222 .30907 m
.72222 .30907 L
s
.75397 .30907 m
.75397 .30907 L
s
.78571 .30907 m
.78571 .30907 L
s
.81746 .30907 m
.81746 .30907 L
s
.84921 .30907 m
.84921 .30907 L
s
.88095 .30907 m
.88095 .30907 L
s
.9127 .30907 m
.9127 .30907 L
s
.94444 .30907 m
.94444 .30907 L
s
.97619 .30907 m
.97619 .30907 L
s
.015 w
.05556 .30907 Mdot
.0873 .30907 Mdot
.11905 .30907 Mdot
.15079 .30907 Mdot
.18254 .30907 Mdot
.21429 .30907 Mdot
.24603 .30907 Mdot
.27778 .30907 Mdot
.30952 .30907 Mdot
.34127 .30907 Mdot
.37302 .30907 Mdot
.40476 .30907 Mdot
.43651 .30907 Mdot
.46825 .30907 Mdot
.5 .30907 Mdot
.53175 .30907 Mdot
.56349 .30907 Mdot
.59524 .30907 Mdot
.62698 .30907 Mdot
.65873 .30907 Mdot
.69048 .30907 Mdot
.72222 .30907 Mdot
.75397 .30907 Mdot
.78571 .30907 Mdot
.81746 .30907 Mdot
.84921 .30907 Mdot
.88095 .30907 Mdot
.9127 .30907 Mdot
.94444 .30907 Mdot
.97619 .30907 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<oooool3o`0002kooooo1Ol0000]ooooo`;o0000;_ooool5o`00033ooooo0ol0000Roooo
o`00=?ooool00ol0003oooooooooo`0^ooooo`04o`000?ooooooooooo`0002cooooo00Co0000oooo
oooooooo0000;_ooool01?l0003oooooooooool0000aooooo`03o`000?oooooooooo027ooooo000[
ooooo`Go000000?oooooo`000?l000000ol0000Xooooo`Go00000oooool00ol0003oooooooooo`0/
ooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool0;_ooool5o`0002;ooooo000a
ooooo`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool0:oooool01?l0003ooooooooo
ool0000`ooooo`03o`000?oooooooooo02gooooo00Co0000oooooooooooo00008oooool003;ooooo
00?o0000ooooool00000;oooool01Ol0003ooooooooooooooooo000002cooooo00Co0000oooooooo
oooo0000;Oooool01Ol0003ooooooooooooooooo000002oooooo00?o0000ooooool000008oooool0
03?ooooo0_l0000_ooooo`05o`000?ooooooooooooooool00000;?ooool01?l0003oooooooooool0
000]ooooo`05o`000?ooooooooooooooool00000<?ooool2o`0002?ooooo000dooooo`03o`000?oo
oooooooo02kooooo0ol0000^ooooo`;o0000;oooool3o`0003;ooooo00?o0000ooooooooool08Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0017oooooool0
000=o`0000?ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Poooool00ol0003o
ooooooooo`22ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo08?ooooo
00?o0000ooooooooool0>?ooool00ol00?ooooooooooo`17ooooo`03o`000?oooooooooo007ooooo
000Aooooo`;o0000Q?ooool00ol0003oooooooooo`0hooooo`03o`00oooooooooooo04Kooooo0_l0
0003ooooo`004Oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo08;ooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo08?ooooo00?o0000oooooooo
ool0=oooool2o`00odWooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
Poooool00ol0003oooooooooo`0gooooo`;o003oBOooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo03Oooooo0_l00?l7ooooo`03o`00oooo
oooooooo03oooooo00?o0000ooooooooool00Oooool0017ooooo0_l00024ooooo`03o`000?oooooo
oooo043ooooo00?o003oooooooooool0?_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo
08?ooooo00?o0000ooooooooool0@?ooool00ol00?ooooooooooo`0oooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo05Sooooo00?o003oooooooooool0:?ooool00ol0003o
ooooooooo`0gooooo`;o003o1oooool00ol00?ooooooooooo`0oooooo`03o`000?oooooooooo007o
oooo000Aooooo`03o`000?oooooooooo05Sooooo00?o003oooooooooool0:?ooool00ol0003ooooo
ooooo`0gooooo`;o003o1oooool00ol00?ooooooooooo`0oooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo05Sooooo00?o003oooooooooool0:?ooool00ol0003ooooooooo
o`0gooooo`;o003o1oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo03Kooooo00?o
0000ooooooooool00Oooool0017ooooo0_l0001Iooooo`03o`00oooooooooooo02Sooooo00?o0000
ooooooooool0=oooool2o`00o`Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0e
ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0F?ooool00ol00?ooooooooooo`0Xoooo
o`03o`000?oooooooooo043ooooo00?o003oooooooooool0?oooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`1Gooooo`;o003o:_ooool00ol0003oooooooooo`0fooooo`03
o`00oooooooo003o00Kooooo0_l00?l7ooooo`03o`00oooooooooooo03Oooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool0F?ooool00ol00?ooooooooooo`0Xooooo`03o`00
0?oooooooooo03Kooooo00?o003oooooool00?l01oooool00ol00?ooooooooooo`05ooooo`;o003o
>?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Hooooo`03o`00oooo
oooooooo01Oooooo00?o003oooooooooool03_ooool00ol0003oooooooooo`05ooooo`03o`00oooo
oooooooo02kooooo00?o003oooooool00?l01oooool00ol00?ooooooooooo`05ooooo`;o003o1ooo
ool00ol00?ooooooooooo`0^ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo05Oooooo0_l00?lIooooo`03o`00oooooooooooo00kooooo00?o0000ooooooooool01Oooool0
0ol00?ooooooooooo`0^ooooo`03o`00oooooooo003o00Kooooo00?o003oooooooooool01_ooool2
o`00o`Oooooo00?o003oooooooooool0;_ooool00ol0003oooooooooo`01ooooo`004Oooool2o`00
05Sooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooooooo
00Gooooo00?o003oooooooooool0=oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool0;Oooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo05Oo
oooo0_l00?lZooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool05_ooool00ol00?oo
ooooooooo`0Nooooo`;o003o1oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02ko
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0F?ooool00ol00?oooooo
ooooo`0Gooooo`03o`00oooooooooooo00kooooo00?o0000ooooooooool01Oooool00ol00?oooooo
ooooo`0Fooooo`03o`00oooooooooooo01Gooooo00?o003oooooool00?l01_ooool2o`00o`Oooooo
0_l00?l7ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool09Oooool00ol0003ooooo
ooooo`01ooooo`002?ooool5o`0000Cooooo00?o0000ooooooooool0F?ooool00ol00?oooooooooo
o`0Fooooo`;o003o4?ooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo01Kooooo00?o
003oooooooooool05Oooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00Gooooo0_l0
0?l6ooooo`03o`00oooooooooooo00Kooooo0_l00?lWooooo`03o`000?oooooooooo007ooooo0009
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0E_ooool00ol00?ooooooo`00
o`0Hooooo`;o003o4?ooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo01Oooooo00?o
003oooooooooool05?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00Oooooo
0_l00?l6ooooo`03o`00oooooooooooo02oooooo00?o0000ooooooooool00Oooool000;ooooo1Ol0
0003ooooo`03o`000?oooooooooo00Cooooo0ol0001Fooooo`03o`00oooooooooooo01Sooooo00?o
003oooooooooool03oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo01Oooooo00?o
003oooooooooool07Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo0_l0
0?l^ooooo`?o00000oooool000_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1F
ooooo`03o`00oooooooooooo02[ooooo00?o0000ooooooooool01?ooool2o`00oaOooooo0_l00?lO
ooooo`03o`00oooooooo003o00oooooo0_l00?l7ooooo`;o003o1oooool00ol00?ooooooooooo`0M
ooooo`03o`000?oooooooooo007ooooo0008ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`1Hooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool03_ooool0
0ol0003oooooooooo`05ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool0
1?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Kooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`05ooooo`;o003o1oooool00ol00?ooooooooooo`0Mooooo`03o`000?oo
oooooooo007ooooo0008ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`1Hooooo`03o`00oooooooooooo01Gooooo00?o003oooooool00?l04?ooool00ol0003ooooooooo
o`05ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool01?l00?oooooooooo
ool00?l7ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l03oooool2o`00o`Oooooo
00?o003oooooooooool07Oooool00ol0003oooooooooo`01ooooo`002Oooool3o`0000Gooooo00?o
0000ooooooooool0E_ooool00ol00?ooooooo`00o`0Gooooo`03o`00oooooooo003o013ooooo00?o
0000ooooooooool00oooool00ol00?ooooooooooo`0Gooooo`;o003o5_ooool01?l00?oooooooooo
ool00?l7ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01_ooool00ol00?oooooo
ooooo`0?ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05?ooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`1Fooooo`03o`00oooooooooooo01Oooooo00?o
003oooooool00?l04?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo01Sooooo00?o
003oooooooooool05?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool01?ooool2o`00oa3ooooo00?o003oooooooooool01Oooool2o`00oaKooooo
00?o0000ooooooooool00Oooool0017ooooo0_l0001Fooooo`03o`00oooooooooooo01Sooooo00?o
003oooooooooool04?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooo003o01Sooooo00?o
003oooooooooool07Oooool00ol00?ooooooo`00o`0?ooooo`;o003o1oooool2o`00o`oooooo00?o
003oooooooooool05?ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo05Gooooo00Co003o
oooooooooooo003o6Oooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo00?o
003oooooooooool05Oooool2o`00oaKooooo00Co003ooooooooooooo003o1Oooool00ol00?oooooo
o`00o`06ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool2o`00o`Oooooo
00?o003oooooooooool07Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`1Hooooo`03o`00oooooooooooo01Cooooo00Co003ooooooooooooo003o4?ooool00ol0003ooooo
ooooo`05ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool01?l00?oooooo
ooooool00?l7ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooo003o00Kooooo0_l00?l8ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool03?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`1Eooooo`04o`00ooooooooooooo`00oaKooooo00Co003ooooooooooooo003o4?ooool00ol0
003oooooooooo`03ooooo`03o`00oooooooo003o01Kooooo00?o003oooooool00?l05Oooool01Ol0
0?oooooooooooooooooo003o00Oooooo00?o003oooooooooool00oooool01?l00?ooooooooooool0
0?l5ooooo`03o`00oooooooooooo00Kooooo00?o003oooooool00?l01_ooool2o`00o`Oooooo0_l0
0?l7ooooo`03o`00oooooooooooo00cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool0EOooool01?l00?ooooooooooool00?lFooooo`04o`00ooooooooooooo`00oa3ooooo
00?o0000ooooooooool00oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo01?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooo
oooo003o1Oooool00ol00?ooooooo`00o`0?ooooo`03o`00oooooooooooo00Kooooo0_l00?l7oooo
o`03o`00oooooooooooo00cooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001Fooooo`03
o`00oooooooooooo01Oooooo00?o003oooooooooool04Oooool00ol0003oooooooooo`02ooooo`04
o`00ooooooooooooo`00oaSooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0;oooo
o`;o00000oooool0017ooooo00?o0000ooooooooool0EOooool01?l00?ooooooooooool00?lZoooo
o`03o`000?oooooooooo00;ooooo00Co003ooooooooooooo003o5_ooool00ol00?ooooooo`00o`0N
ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool01_ooool00ol00?ooooooo`00
o`06ooooo`03o`00oooooooo003o00Oooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool0F?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00kooooo00?o0000
ooooooooool01Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00Go003o
ooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo
003o1oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Kooooo0_l00?l8ooooo`03
o`00oooooooooooo00Cooooo0_l00?l>ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo05Sooooo00?o003oooooooooool05?ooool01?l00?ooooooooooool00?l@ooooo`03
o`000?oooooooooo00;ooooo00Co003ooooooooooooo003o5Oooool00ol00?ooooooooooo`0Foooo
o`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`03ooooo`04o`00oooooooo
ooooo`00o`Gooooo00?o003oooooooooool01_ooool00ol00?ooooooo`00o`06ooooo`;o003o1_oo
ool00ol00?ooooooo`00o`06ooooo`;o003o1oooool00ol00?ooooooooooo`04ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo05Cooooo00Go003oooooooooooooooooo`00
o`0Fooooo`04o`00ooooooooooooo`00oa3ooooo00?o0000ooooooooool00_ooool00ol00?oooooo
ooooo`0Iooooo`03o`00oooooooooooo01?ooooo00Go003oooooooooooooooooo`00o`04ooooo`03
o`00oooooooooooo00Kooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooooooo`0?oooo
o`;o003o1_ooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Dooooo`03
o`00oooooooooooo01Oooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`02ooooo`03
o`00oooooooooooo01Wooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`05ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooool00?l01oooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Cooooo00?o0000ooooooooool00Oooool0017ooooo0_l0000=ooooo`03o`00
oooooooooooo04Gooooo00?o003oooooooooool0;?ooool00ol0003oooooooooo`02ooooo`04o`00
ooooooooooooo`00oaGooooo00Co003ooooooooooooo003o7_ooool01?l00?ooooooooooool00?l>
ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l01oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool2o`0000?ooooo000Aoooo
o`03o`000?oooooooooo00cooooo00?o003oooooooooool0BOooool00ol00?ooooooooooo`0Goooo
o`03o`00oooooooooooo00kooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`0Coooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`03
ooooo`04o`00ooooooooooooo`00o`Oooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`04ooooo`;o003o3_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0<
ooooo`03o`00oooooooooooo04Wooooo00?o003oooooooooool04oooool01Ol00?oooooooooooooo
oooo003o013ooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`0Cooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00?ooooo00Co003ooooooooooooo003o3Oooool01?l00?ooooooooooool00?l5ooooo`03
o`00oooooooo003o00Sooooo00?o003oooooooooool01?ooool2o`00o`Oooooo00?o003ooooooooo
ool01?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0<ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool0??ooool01Ol00?oooooooooooooooooo003o01Go
oooo00Go003oooooooooooooooooo`00o`0@ooooo`05o`000?ooooooooooooooool00?l06Oooool0
1?l00?ooooooooooool00?lDooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03
o`00oooooooooooo00oooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`07ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo03cooooo00?o003oooooooooool0
5oooool01Ol00?oooooooooooooooooo003o013ooooo00Go0000ooooooooooooooooo`00o`0Loooo
o`03o`00oooooooooooo01Oooooo00Go003oooooooooooooooooo`00o`0<ooooo`03o`00oooooooo
oooo00;ooooo00Co003ooooooooooooo003o3_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooo003o00Oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`;o00003Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo03gooooo00?o003oooooooooool0;?ooool01Ol0003ooooooooooooooooo003o00?ooooo00?o
003oooooooooool04_ooool01Ol00?oooooooooooooooooo003o01gooooo00Go003ooooooooooooo
ooooo`00o`0=ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o3_ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool2
o`0000?ooooo000Aooooo`03o`000?oooooooooo00_ooooo0_l00?l8ooooo`03o`00oooooooooooo
03cooooo00Go003oooooooooooooooooo`00o`0Iooooo`03o`00oooooooooooo00kooooo00?o0000
ooooooooool01Oooool00ol00?ooooooooooo`0Booooo`05o`00ooooooooooooooooool00?l05?oo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00oooool01?l00?oooooo
ooooool00?l7ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03Oooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0;ooooo`;o003o2?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo03Sooooo00?o003oooooooooool04_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00kooooo00?o0000ooooooooool01Oooool00ol00?oooooo
ooooo`0Booooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`07ooooo`03
o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`08oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`05oooo
o`03o`000?oooooooooo007ooooo0009ooooo`?o00001Oooool00ol0003oooooooooo`0;ooooo`;o
003o1oooool2o`00o`Oooooo00?o003oooooooooool0<oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0>ooooo`04
o`000?ooooooooooo`00o`Cooooo00?o003oooooooooool04_ooool01Ol00?oooooooooooooooooo
003o01Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00oooooo00?o
003oooooool00?l01Oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Kooooo
00?o003oooooooooool01Oooool00ol0003oooooooooo`01ooooo`002_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool01_ooool2o`00o`Oooooo00?o
003oooooooooool0<oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0>ooooo`04o`000?ooooooooooo`00oagooooo
00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l02?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o3Oooool0
0ol00?ooooooooooo`06ooooo`04o`00ooooooooooooo`00o`Oooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo007ooooo0002ooooo`Go00000oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0cooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool04oooool0
1?l0003oooooooooool00?l4ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool06ooo
ool01Ol00?oooooooooooooooooo003o00Sooooo00?o003oooooooooool00_ooool01?l00?oooooo
ooooool00?l4ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05oooo
o`03o`000?oooooooooo007ooooo000:ooooo`03o`000?oooooooooo00Cooooo0ol0000;ooooo`;o
003o1oooool2o`00o`Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Zooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Oooooo`04
o`000?ooooooooooo`00o`Cooooo00?o003oooooooooool04_ooool01Ol00?oooooooooooooooooo
003o01?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l02?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooo
ooooo`00o`07ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0<ooooo`?o00000oooool000[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0;ooooo`;o003o2?ooool00ol00?ooooooooooo`04ooooo`;o003o1oooool00ol00?oooooo
ooooo`0`ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00kooooo00?o0000ooooooooool01Oooool00ol00?oooooo
ooooo`0Aooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`05ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooooooooooo
o`00o`Sooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`0>ooooo`03o`000?oooooo
oooo007ooooo0009ooooo`;o00001_ooool00ol0003oooooooooo`0;ooooo`;o003o1oooool2o`00
o`Kooooo0_l00?l7ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03_ooool01?l0
003oooooooooool00?l4ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool05_ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00Go003oooooooooooooooooo`00
o`04ooooo`05o`00ooooooooooooooooool00?l02?ooool01Ol00?oooooooooooooooooo003o00Co
oooo00Co003ooooooooooooo003o1Oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo
003o00Kooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`01ooooo`002_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool01_ooool2o`00
o`Oooooo00?o003oooooooooool01Oooool2o`00obcooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03_ooool01?l0
003oooooooooool00?l=ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool04Oooool0
0ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o017ooooo00Co003ooooooooooooo003o1Oooool01?l00?oo
ooooooooool00?l7ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02;o
oooo00?o003oooooooooool02_ooool2o`00o`[ooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`06ooooo`03o`000?oooooo003o00kooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`0Jooooo`03o`00oooooooooooo00_ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooo
oooo00Kooooo00Co003ooooooooooooo003o1oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00Kooooo00?o0000ooooooooool00Oooool0017ooooo0_l0000=ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`;o003o1oooool0
0ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00_ooooo0_l00?lHooooo`03o`00oooooooo
oooo00Kooooo00?o0000ooooool00?l01Oooool00ol00?ooooooooooo`05ooooo`;o003o2_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0:ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooo
oooooooo003o00Oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00kooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`0:ooooo`03o`00oooo
oooo003o00Sooooo00?o003oooooooooool01?ooool2o`00o`Oooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo00Cooooo0ol00?l@ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00oooo
oooooooo00Gooooo0_l00?l:ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool00ooo
ool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l03?ooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o3_ooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooo003o00Sooooo00?o003ooooo
ooooool01?ooool2o`00o`Oooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04oooo
o`;o003o2?ooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool01Oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool02_ooool0
1Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooooooo`06oooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00[ooooo00?o003oooooool0
0?l01_ooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00Gooooo0_l00?l7ooooo`03
o`00oooooooooooo027ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Aooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool03_ooool00ol0003oooooo`00o`0=ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03
o`00oooooooooooo00Cooooo00Co003ooooooooooooo003o2?ooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l04Oooool01?l00?ooooooooooool00?l4ooooo`05o`00oooo
ooooooooooooool00?l01oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Kooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool04oooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`0Qooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol0003oooooo`00
o`0>ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool05oooool01?l00?oooooooooo
ool00?l=ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Kooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00Cooooo0_l00?l7ooooo`03o`00oooooooooooo01Wo
oooo00?o003oooooooooool02_ooool00ol00?ooooooo`00o`0Gooooo`;o003o2?ooool00ol0003o
ooooo`00o`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l02Oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`01oooo
o`004Oooool2o`0000_ooooo00?o003oooooool00?l02?ooool00ol00?ooooooooooo`04ooooo`;o
003o1_ooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool07oooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00oa3ooooo00?o003ooooo
ooooool01?ooool2o`00o`Sooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooo003o00Wooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l=
ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool03_ooool2o`0000?ooooo000Aooooo`03o`000?oooooo
oooo00[ooooo00?o003oooooool00?l02?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
003o00Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo01oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01?ooool2o`00o`Sooooo00?o0000ooooooooool01Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool0
1?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00Gooooo00Go003ooooooooooooooooo
o`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooooooo`06oooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00[ooooo00?o003oooooool0
0?l01Oooool01?l00?ooooooooooool00?l7ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ool00?l01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Sooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`07ooooo`03o`000?l00?oooooo00Gooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool01Oooool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00oa7ooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?oo
ooooooooool00?l5ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool04_ooool01?l00?ooooooooooool00?l7ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01?ooool2o`00oa3ooooo00?o003oooooooooool03oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o0000o`00ooooool03_ooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooo003o00Sooooo00?o003oooooooooool00oooool01?l0
0?ooooooooooool00?l4ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool0
1Ol00?oooooooooooooooooo003o00Oooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`07ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01;ooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo0_l00?l7
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0:
ooooo`04o`00ooooooooooooo`00o`Wooooo00?o003oooooooooool02_ooool00ol00?ooooooo`00
o`08ooooo`03o`000?l00?oooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00Gooooo0_l00?lBooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool01_ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool00Oooool0017o
oooo0_l0000:ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o1Oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooo003o00Oooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l05_ooool00ol00?ooooooo`00
o`08ooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool00oooool01?l00?oooooooooo
ool00?l8ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00oooool01?l00?oooooo
ooooool00?l=ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool03oooool2o`0000?ooooo000Aooooo`03
o`000?oooooooooo00Wooooo00Co003ooooooooooooo003o2?ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooo003o00Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooool00?l02?ooool00ol0003oooooooooo`05ooooo`03o`00oooooooo
oooo00?ooooo00Co003ooooooooooooo003o2?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01Oooool01?l00?ooooooooooool00?l5ooooo`03o`00
oooooooooooo00Gooooo00Co003ooooooooooooo003o1Oooool01?l00?ooooooooooool00?l4oooo
o`03o`00oooooooooooo00Kooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool01oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`09ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o1Ooo
ool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Sooooo00?o0000o`00ooooool01Ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Ooo
ool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Oooooo00?o003ooooooooo
ool00oooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l01?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`07ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Wooooo00?o003o
ooooooooool01_ooool01?l00?ooooooooooool00?l7ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooool00?l01_ooool00ol00?ooooooooooo`0>ooooo`;o003o4Oooool00ol00?oooooooooo
o`04ooooo`05o`00ooooooooooooooooool00?l03Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00kooooo00?o0000o`00ooooool03_ooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Gooooo0_l00?l8ooooo`03o`00oooooooooooo00Gooooo0_l00?l9ooooo`03o`00
oooooooooooo00?ooooo00Co003ooooooooooooo003o4?ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00Oooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
4_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
0oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00Co003ooooooooooooo
003o2?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool01Oooool2o`00oa7ooooo00?o003oooooooooool03Oooool00ol00?ooooooo`00o`05ooooo`04
o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o2?ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01oooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`09ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`05ooooo`04o`00ooooooooooooo`00o`Gooooo00?o
003oooooool00?l01_ooool2o`00o`Oooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0Cooooo`04o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooo003o00Sooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l5oooo
o`03o`00oooooooooooo00Gooooo00Go003oooooooooooooooooo`00o`08ooooo`03o`00oooooooo
oooo013ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0000:ooooo`04o`00oooooooooooo
o`00o`Sooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool01?ooool2o`00o`Oooooo0_l00?l7ooooo`03o`00oooo
oooooooo00kooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`So
oooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l02?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Gooooo0_l00?l6oooo
o`03o`00oooooooo003o00kooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Kooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00_ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`08ooooo`05o`00oooooooo
ooooooooool00?l02?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Gooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`;o003o2?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool01?l00?oooooo
ooooool00?l8ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l01_ooool00ol00?oo
ooooo`00o`08ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o1?ooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l02_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`08ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00Oo
oooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo
00oooooo0_l00?l7ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool01?l0
0?ooooooooooool00?l>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool01?ooool0
0ol00?ooooooo`00o`08ooooo`03o`00oooooooooooo00Gooooo0_l00?l8ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooool00?l04Oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l01?ooool00ol00?ooooooooooo`05ooooo`05o`00ooooooooooooooooool00?l0
2_ooool00ol0003oooooooooo`01ooooo`002_ooool2o`0000Gooooo00?o0000ooooooooool04Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00ooo
ool00ol00?ooooooo`00o`0?ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o013ooooo0_l00?l?ooooo`03o`00oooo
oooo003o00Gooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool01Oooool01Ol00?oooooooooooooooooo003o00[ooooo
00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`0<ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01_ooool2o`00o`Oooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0Booooo`05o`00ooooooooooooooooool0
0?l02?ooool00ol00?ooooooooooo`05ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooo`00o`0Aooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool01Oooool0
1?l00?ooooooooooool00?l8ooooo`03o`00oooooooooooo017ooooo00?o0000ooooooooool00Ooo
ool000Wooooo00Co0000oooooooooooo00001?ooool;o`000003o`00ool0003o000000?oo`001Ol0
0003ool000Co000000?o003oo`000?oo00000_oo0004o`000004o`00oooo003oo`00ool000Ko0000
0ooo0005o`0000?oo`001_l00003ool000Go00000ooo0005o`0000?oo`001_l00003ool00003o`00
0?l00?oo000000;o00000ooo0006o`0000?oo`001Ol00003ool000?o000000?o003oo`000?l00000
0ooo0005o`0000?oo`001_l00003ool000;o000000?o003oo`000?l000000ooo0006o`0000?oo`00
1Ol00003ool000Co000000Co003oool00?oo003oo`001_l00003ool000Go00000ooo00000ol00?oo
0000o`000003o`0000?oo`0000?o003oo`000?l000000_l00003ool000Ko00000ooo00000ol0003o
003oo`000002o`0000?oo`001_l00003ool000Go00000ooo0002o`000004o`00ool0003o0000o`00
00?oo`001Ol00003ool000Ko00000oooool000Wooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`08ooooo`03o`00oooooooooooo00?oo`001Oooool3ool000Cooooo00?o003ooooo
oooo00000_oo0004ooooo`04o`00oooo003oo`00ool000Kooooo0ooo0004ooooo`04o`00oooo003o
o`00ool000Kooooo0ooo0005ooooo`?oo`001Oooool3ool000Kooooo0ooo0005ooooo`?oo`001_oo
ool3ool000Gooooo0ooo0003ooooo`03o`00oooooooooooo00?oo`001Oooool3ool000Kooooo0ooo
0002ooooo`03o`00oooooooooooo00?oo`001_ooool3ool000Gooooo0ooo0005ooooo`?oo`001_oo
ool3ool000Gooooo0ooo0006ooooo`?oo`0000?o003oooooooooool00_ooool3ool000Kooooo0ooo
00000ol00?ooooooooooo`02ooooo`?oo`0000?oooooo`00ooooool00oooool3ool000Gooooo0ooo
0002ooooo`04o`00ooooooooooooooooo`?oo`000_ooool00ol00?ooooooooooo`03ool000Gooooo
00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`08ooooo`03o`00oooooooooooo00?oo`000oooool00ol00?ooooooool00002ool000Kooooo
0ooo0004ooooo`04o`00oooo003oo`00ool000Cooooo00?o003ooooooooo00000_oo0005ooooo`?o
o`001_ooool3ool000Gooooo0ooo0005ooooo`?oo`001_ooool3ool000Gooooo0ooo0006ooooo`?o
o`001Oooool3ool000Kooooo0ooo0005ooooo`?oo`001_ooool3ool000;ooooo00?o003ooooooooo
ool00ooo0006ooooo`?oo`001Oooool3ool000Cooooo00Co003oool00?oo003oo`001_ooool3ool0
00Gooooo0ooo0006ooooo`?oo`001Oooool3ool00003o`00oooooooooooo00?ooooo0ooo0005oooo
o`?oo`0000?oooooo`00ooooool00oooool3ool00003ooooool00?oooooo00;ooooo0ooo0002oooo
o`04o`00ooooooooooooooooo`?oo`000_ooool00ol00?ooooooooooo`03ool000Gooooo00?o0000
ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0A
ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00;ooooo00Co003ooooooooooooo003o3_ooool00ol00?ooooooo`00o`0@ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00gooooo00?o003oo`000?ooool03oooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00?ooooo00Co003ooooooooooooo003o1oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00kooooo0_l00?l6ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00Go003ooooooooo
ooooooooo`00o`0:ooooo`03o`000?oooooooooo007ooooo000:ooooo`;o00001Oooool00ol0003o
ooooooooo`0Aooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`02ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01_ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`05ooooo`03o`00ool0003ooooo00Kooooo00Co003ooooooooooooo003o1Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00oooool0
1?l00?ooooooooooool00?l@ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_oo
ool2o`00o`Kooooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`08ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo00Sooooo00Go003oooooooooooooooooo`00
o`08ooooo`05o`00ooooooooooooooooool00?l02?ooool01Ol00?oooooooooooooooooo003o00Oo
oooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Ko
oooo0_l00?l7ooooo`03o`00oooooooooooo00Kooooo00?o003oooooool00?l01_ooool00ol00?oo
ooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo0_l00?l?ooooo`03o`00oooooooo003o
00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
017ooooo00?o0000ooooooooool00Oooool0017ooooo0_l00009ooooo`05o`00oooooooooooooooo
ool00?l02?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l02?ooool0
0ol00?ooooooooooo`04ooooo`;o003o4?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01oooool01?l00?ooooooooooool00?l4ooooo`03o`00oooo
oooooooo00Kooooo00?o0000ooooooooool01Oooool01?l00?ooooooooooool00?l5ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00Gooooo0_l00?l7ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l0
1_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooool00?l0
1Oooool01?l00?ooooooooooool00?l:ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0
2?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooool00?l02?ooool00ol00?ooooooooooo`04oooo
o`;o003o1oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`07ooooo`04o`00ooooooooooooo`00o`cooooo00?o003o
o`000?ooool01_ooool01?l00?ooooooooooool00?l<ooooo`03o`00oooooooooooo00oooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Gooooo0_l0
0?l7ooooo`;o003o2?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Gooooo00Co
003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`_o
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03oooool00ol00?oooooo
o`00o`0?ooooo`03o`00oooooooooooo00Kooooo0_l00?l>ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool03Oooool00ol00?oo0000ooooo`0?ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Kooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo0_l00?l6ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o2oooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ool000004?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`0Qooooo`;o003o1_ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo
003o00Oooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`08ooooo`03o`00oooooooo
oooo00Wooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol00?ooooooooooo`06
ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l5ooooo`03o`00
oooooooo003o00Gooooo00?o003oooooooooool01oooool2o`00o`Oooooo00?o003oooooooooool0
1_ooool2o`00o`Oooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooool000001oooool01?l00?ooooooo`00ool00?l5ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01_ooool01Ol00?oooooooooooooooooo003o
00_ooooo00?o003oooooooooool03oooool2o`00o`Sooooo00?o003oooooooooool01?ooool00ol0
0?ooooooo`00o`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l02?ooool00ol0
0?ooooooooooo`0Booooo`03o`000?oooooooooo007ooooo000Aooooo`;o00002?ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00Kooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`02oooo
o`04o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool01?ooool2o`00oa3ooooo0_l00?l7
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01oooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol00?ooooooo`00o`06
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0?
ooooo`;o003o3oooool00ol00?ooooooo`00o`06ooooo`;o003o1_ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool02oooool2o`0000?ooooo000Aoooo
o`03o`000?oooooooooo00Oooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
2?ooool00ol00?ooooooooooo`06ooooo`04o`00ooooooooooooo`00o`Sooooo00?o003ooooooooo
ool00oooool00ol00?ooooooo`00o`0@ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooo`000007ooooo`03o`00oooooooo003o00cooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo0_l00?l6ooooo`03
o`00oooooooo003o00Kooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l;oooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Oooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool01Oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0Aooooo`04o`00oooo
ooooooooo`00o`Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07ooooo`;o003o
3Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00cooooo00?o003oooooool00000
8?ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`0?ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooo003o00Kooooo00?o003oooooooooool01Oooool01?l00?oo
ooooooooool00?l;ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00oo
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`06ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool03oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool02?ooool2o`00o`Kooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00000@oooo
o`03o`00oooooooooooo00gooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooo
oooo01oooooo00?o003oooooooooool01Oooool2o`00o`Sooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o2ooo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0<ooooo`04o`00oooooooo
ooooo`00o`Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Go
oooo00?o003oooooooooool01_ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00Oo
oooo0_l00?l7ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooo000000Oooooo00?o003oooooool00?l01_ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00Oooooo00Co003ooooooooooooo003o1Oooool00ol0
0?ooooooooooo`0Oooooo`03o`00oooooooooooo00Gooooo0_l00?l7ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooool00?l02?ooool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`06ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`04
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool0
0?l5ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l04?ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00kooooo0_l00?l6ooooo`03o`00oooooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01Sooooo
00?o003oooooooooool01Oooool2o`00o`Oooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03?ooool00ol0003ooooo
ooooo`01ooooo`004Oooool2o`0000Sooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`06ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`0<ooooo`03
o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o2?ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooo003o01Wooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`08oooo
o`;o003o1_ooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0_l00?l=oooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Hoooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool2o`00o`Kooooo00?o003ooooo
ooooool01_ooool2o`00o`Kooooo00?o003oooooool00?l02oooool2o`0000?ooooo000Aooooo`03
o`000?oooooooooo00Kooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l5oooo
o`03o`00oooooooooooo00Gooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l02oooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`Gooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool02oooool01?l00?ooooooooooool00007ooooo`;o003o3Oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooo003o00Kooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0Iooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?oo
ooooo`00o`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l03?ooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`0;ooooo`04o`00ooooooooooooo`00o`kooooo00?o003ooooo
ooooool05_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00Co003ooooo
oooooooo00004?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo003o00Kooooo00?o003o
ooooooooool07oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooool00?l03?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0<oooo
o`04o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool02oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`03ooooo`04o`00
ooooooooooooo`0000Oooooo0_l00?l7ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo02Oooooo0_l00?l7ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00[ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
1_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooooooo
003o2?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool00_ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l01?ooool0
1?l00?ooooooooooool00?l6ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool2o`00o`Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooo003o00cooooo00?o003oooooooooool08Oooool2o`00o`Oooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o0000ooooooooool00Ooo
ool0017ooooo0_l00007ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01_ooool0
1?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l03?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`04
o`00ooooooooooooo`00oaWooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`05oooo
o`;o003o1oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Oooooo00?o003ooooo
ooooool08Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01_ooool2o`00o`Kooooo00?o003oooooool00?l02oooool2o`0000?ooooo000Aooooo`03
o`000?oooooooooo00Kooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l5oooo
o`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o2?ooool00ol00?ooooooooooo`06
ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol00?ooooooooooo`02ooooo`04o`00oooo
ooooooooo`00o`Gooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02oooool01?l00?ooooooooooool00007ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`05ooooo`;o
003o1oooool2o`00o`Kooooo00?o003oooooool00?l03?ooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooooooo
003o4Oooool01Ol00?oooooooooooooooooo003o00gooooo00?o003oooooooooool05_ooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00_ooooo00Co003ooooooooooooo00004?ooool0
0ol00?ooooooooooo`0=ooooo`;o003o1oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo02[ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Gooooo0_l00?l=ooooo`03o`000?oooooooooo007ooooo0009ooooo`?o00001Oooool00ol0
003oooooooooo`0>ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool01?l0
0?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04Oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo0000013ooooo00?o003oooooooooool03Oooool2o`00o`Oooooo00?o003oooooooooool0
<?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo0_l00?l7ooooo`03o`00
oooooooooooo00_ooooo00?o0000ooooooooool00Oooool000[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l02?oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o
1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`06ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool04Oooool00ol0
0?ooooooooooo`0Fooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00Sooooo0_l00?l<ooooo`03o`00oooooooooooo
02_ooooo00?o003oooooooooool01Oooool2o`00o`Sooooo00?o003oooooooooool04oooool00ol0
003oooooooooo`01ooooo`002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Ko
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo003o00Go
oooo00Co003ooooooooooooo003o3Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00oaWooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Kooooo00?o
0000ooooooooool03_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Kooooo00?o
003oooooooooool0:oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0<ooooo`03o`000?oooooooooo007ooooo000:
ooooo`03o`000?oooooooooo00Cooooo0ol00005ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooool00?l01_ooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Sooooo00?o
003oooooooooool01_ooool01Ol00?oooooooooooooooooo003o00Sooooo00?o003oooooooooool0
0_ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo017ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00000Dooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0[ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`05ooooo`;o003o2oooool3o`0000?ooooo000:ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01Oooool01?l00?ooooooooooool00?l5ooooo`04o`00oooooooooooo
o`00oa7ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool05Oooool00ol00?ooooooooooo`0Gooooo`05o`00ooooooooooooooooool00000
:Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo03?ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`05ooooo`;o003o3Oooool00ol0003oooooooooo`01ooooo`002Ooo
ool2o`0000Kooooo00?o0000ooooooooool03_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool01_ooool00ol00?ooooooo`00o`05ooooo`04o`00oooo
ooooooooo`00o`Wooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Fooooo`03o`00
oooooooooooo01;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo0000013o
oooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0hooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool01Oooool2o`00o`gooooo00?o0000ooooooooool00Oooool000[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`00oooooooo003o00Sooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Gooooo
00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00Sooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool05_ooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool000004?ooool01Ol00?oooooooooo
oooooooo003o01Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0cooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool05?ooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01_oo
ool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool0
1Oooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool05oooool01Ol00?oooooooooooooo
oooo003o01Cooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`0>ooooo`05o`00oooo
ooooooooooooool00?l06Oooool00ol00?ooooooooooo`0cooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0<ooooo`03o`000?oooooooooo007ooooo
000Aooooo`;o00001_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`04o`00ooooooooooooo`00o`Cooooo
00?o003oooooooooool01_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool05oooool01Ol00?oooooooooooooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`04
ooooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool04_ooool01Ol00?oooooooooooooo
oooo003o03oooooo00?o003oooooooooool01Oooool2o`00o`cooooo0_l00003ooooo`004Oooool0
0ol0003oooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l03Oooool0
1Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`08ooooo`03o`00
oooooooooooo01Kooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`02ooooo`03o`00
0?oooooooooo02Oooooo00Go003oooooooooooooooooo`00o`0oooooo`03o`00oooooooooooo00Go
oooo0_l00?l=ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00kooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooool00?l01Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo01Kooooo
00?o003oooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo01Kooooo
00?o003oooooooooool0@Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00cooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool03?ooool2o`00o`Sooooo00?o
003oooooooooool03Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo
00Go003oooooooooooooooooo`00o`0<ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool04_ooool00ol00?ooooooooooo`0Fooooo`05o`00ooooooooooooooooool00?l01?ooool00ol0
003oooooooooo`0>ooooo`04o`00ooooooooooooo`00oaGooooo00?o003oooooooooool0BOooool0
0ol00?ooooooooooo`0<ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`;o003o2?ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o1?ooool0
1Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo01Oooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`06ooooo`03o`00
0?oooooooooo00kooooo00Co003ooooooooooooo003o6Oooool00ol00?ooooooooooo`1Dooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`06ooooo`;o003o1_ooool00ol00?ooooooo`00o`0>ooooo`04o`00
ooooooooooooo`00o`Cooooo00?o003oooooooooool01_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool05oooool01?l00?ooooooooooool00?lEooooo`03o`00oooooooo
oooo00Kooooo00?o0000ooooooooool03_ooool01?l00?ooooooooooool00?lIooooo`03o`00oooo
oooooooo04Gooooo00?o003oooooooooool03?ooool00ol0003oooooooooo`01ooooo`004Oooool2
o`0000Gooooo00?o003oooooooooool01Oooool2o`00o`Oooooo00?o003oooooooooool01Oooool0
0ol00?ooooooo`00o`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01_ooool0
1?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_oo
ool01?l00?ooooooooooool00?lIooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool0
4Oooool00ol00?ooooooooooo`0Cooooo`05o`00ooooooooooooooooool00?l0Aoooool00ol00?oo
ooooooooo`0;ooooo`;o00000oooool0017ooooo00?o0000ooooooooool03Oooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oooooo
o`00o`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`0Eooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool00_ooool00ol0003ooooo
ooooo`0>ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0F?ooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool03Oooool2o`00o`Kooooo00?o003oooooool00?l02?ooool00ol00?oooooooooo
o`0;ooooo`05o`00ooooooooooooooooool00?l05Oooool00ol00?ooooooooooo`0Fooooo`04o`00
ooooooooooooo`00o`Gooooo00?o0000ooooooooool03_ooool01?l00?ooooooooooool00?lEoooo
o`03o`00oooooooooooo05Sooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool01?ooool00ol00?ooooooooooo`05ooooo`;o003o2?ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`05ooooo`04
o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o01Gooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`06ooooo`03o`000?oooooo
oooo00kooooo00?o003oooooool00?l06_ooool00ol00?ooooooooooo`1Dooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo0_l00?l?ooooo`03o`00oooooooo003o
00Gooooo00?o003oooooooooool01_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooo
oooo01Oooooo00?o003oooooool00?l05_ooool00ol00?ooooooooooo`06ooooo`03o`000?oooooo
oooo00kooooo00?o003oooooool00?l06_ooool00ol00?ooooooooooo`1Dooooo`03o`000?oooooo
oooo007ooooo000Aooooo`;o00003Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Gooooo0_l00?l8ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`06ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00
o`0Eooooo`03o`00oooooooo003o01Kooooo00Co003ooooooooooooo003o1Oooool00ol0003ooooo
ooooo`0@ooooo`03o`00oooooooooooo01Cooooo00Co003ooooooooooooo003oE_ooool2o`0000?o
oooo000Aooooo`03o`000?oooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`05ooooo`;o003o1oooool2o`00oa7ooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05oooool00ol00?oooooo
ooooo`03ooooo`03o`000?oooooooooo02Oooooo00Co003ooooooooooooo003oEoooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`;o003o1_ooool00ol00?oooooo
o`00o`08ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool05Oooool00ol00?oooooo
ooooo`0Dooooo`03o`00oooooooo003o00Kooooo00?o0000ooooooooool03_ooool00ol00?oooooo
ooooo`0Fooooo`03o`00oooooooooooo05Sooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01Oooool2o`00o`Kooooo00?o003oooooool00?l01Oooool01?l00?oooooooooo
ool00?l8ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0Eooooo`03
o`00oooooooooooo01Kooooo00?o003oooooool00?l01_ooool00ol0003oooooooooo`0>ooooo`03
o`00oooooooo003o01Kooooo00Co003ooooooooooooo003oEoooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00Gooooo0_l00?l7ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l5oooo
o`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool05oooool00ol00?ooooooo`00o`0F
ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol00?ooooooo`00o`0I
ooooo`03o`00oooooooooooo05Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool05Oooool00ol00?ooooooooooo`05ooooo`;o003o2?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooo003o00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooo`00o`05oooo
o`03o`00oooooooooooo01Oooooo00?o003oooooool00?l05_ooool00ol00?ooooooo`00o`06oooo
o`03o`000?oooooooooo00oooooo00?o003oooooooooool05Oooool01?l00?ooooooooooool00?mG
ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00005_ooool00ol00?ooooooooooo`05oooo
o`;o003o1oooool2o`00o`kooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`08oooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`04oooo
o`03o`000?oooooooooo02Oooooo00Co003ooooooooooooo003oE_ooool2o`0000?ooooo000Aoooo
o`03o`000?oooooooooo01gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`04oooo
o`03o`000?oooooooooo00kooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`1Hoooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01gooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool00ol00?ooooooo`00o`08ooooo`03
o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o5_ooool00ol00?ooooooooooo`0Foooo
o`03o`00oooooooo003o00Kooooo00?o0000ooooooooool03_ooool2o`00oaOooooo00?o003ooooo
ooooool0F?ooool00ol0003oooooooooo`01ooooo`002?ooool5o`0000Cooooo00?o0000oooooooo
ool07Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo0_l00?l6ooooo`03
o`00oooooooo003o00Kooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`0Gooooo`03
o`00oooooooooooo01Kooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`0>ooooo`;o
003o6Oooool00ol00?ooooooooooo`1Fooooo`03o`000?oooooooooo007ooooo0009ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool07Oooool00ol00?ooooooooooo`0>ooooo`;o
003o1_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo003o00Gooooo00?o003ooooooooo
ool05oooool2o`00oaOooooo0_l00?l7ooooo`03o`000?oooooooooo00kooooo0_l00?lIooooo`03
o`00oooooooooooo05Kooooo00?o0000ooooooooool00Oooool000[ooooo00?o0000ooooooooool0
1?ooool3o`0001gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooo003o00Kooooo00?o003oooooool00?l02?ooool00ol00?ooooooooooo`0Dooooo`;o003o
6?ooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo00oooooo00?o003oooooooooool0
5Oooool00ol00?ooooooo`00o`1Fooooo`?o00000oooool000_ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Vooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool05?oo
ool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00Gooooo00?o0000ooooooooool03_oo
ool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo05Sooooo00?o0000ooooooooool00Ooo
ool000Sooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo02Kooooo00?o
003oooooooooool01Oooool2o`00o`Oooooo00?o003oooooooooool03Oooool01?l00?oooooooooo
ool00?lFooooo`03o`00oooooooooooo01Kooooo0_l00?l7ooooo`03o`000?oooooooooo00kooooo
00?o003oooooooooool05_ooool00ol00?ooooooooooo`1Hooooo`03o`000?oooooooooo007ooooo
0008ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Vooooo`03o`00
oooooooooooo00Gooooo0_l00?l6ooooo`;o003o2?ooool00ol00?ooooooooooo`04ooooo`04o`00
ooooooooooooo`00oaKooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`06ooooo`03
o`000?oooooooooo00kooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`1Fooooo`03
o`000?oooooooooo007ooooo0009ooooo`?o00001Oooool00ol0003oooooooooo`0^ooooo`;o003o
1_ooool00ol00?ooooooooooo`06ooooo`;o003o1_ooool00ol00?ooooooooooo`0Gooooo`03o`00
oooooooooooo01Kooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`0>ooooo`03o`00
oooooooooooo01Sooooo00?o003oooooooooool0E_ooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`0^ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_oo
ool2o`00o`Kooooo00?o003oooooool00?l0<?ooool2o`00o`Oooooo00?o0000ooooooooool03_oo
ool00ol00?ooooooooooo`0Fooooo`;o003oFOooool00ol0003oooooooooo`01ooooo`004Oooool2
o`0003Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo02kooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`0Wooooo`;o003oF?ooool2
o`0000?ooooo000Aooooo`03o`000?oooooooooo02kooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooo003o033ooooo00?o003oooooooooool01_ooool00ol0
003oooooooooo`0>ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0F?ooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0^ooooo`03o`00oooooooooooo00Go
oooo0_l00?l8ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l0>Oooool00ol0003o
ooooooooo`0Wooooo`;o003oFOooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`0fooooo`03o`00oooooooooooo00Kooooo0_l00?l6ooooo`03o`00oooooooooooo03Wooooo
00?o0000ooooooooool0:?ooool00ol00?ooooooooooo`1Gooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo03Oooooo00?o003oooooooooool01Oooool2o`00o`Kooooo00?o
003oooooooooool0>Oooool00ol0003oooooooooo`0Wooooo`;o003oFOooool00ol0003ooooooooo
o`01ooooo`004Oooool2o`0003Sooooo00?o003oooooooooool01Oooool2o`00o`Sooooo00?o003o
ooooooooool0=oooool00ol0003oooooooooo`0Wooooo`;o003oF?ooool2o`0000?ooooo000Aoooo
o`03o`000?oooooooooo03Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo03Oooooo00?o0000ooooooooool09oooool00ol00?ooooooooooo`1Hoooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo03oooooo00?o003ooooooooo
ool01Oooool3o`00ocWooooo00?o0000ooooooooool09oooool00ol00?ooooooooooo`1Hooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo03oooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`0iooooo`03o`000?oooooooooo02Oooooo00?o003oooooooooool0
F?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0oooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool0>Oooool00ol0003oooooooooo`0Wooooo`03o`00oooo
oooooooo05Sooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0?oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo03Sooooo00?o0000ooooooooool09oooool0
0ol00?ooooooooooo`1Hooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000@?ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo03Sooooo00?o0000ooooooooool0POooool2o`00
00?ooooo000Aooooo`03o`000?oooooooooo04Oooooo0_l00?ljooooo`03o`000?oooooooooo08;o
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Aoooool00ol00?oooooo
ooooo`0iooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool0Aoooool00ol00?ooooooooooo`0iooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Aoooool2o`00oc[ooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0004Wooooo00?o003ooooo
ooooool0>?ooool00ol0003oooooooooo`21ooooo`;o00000oooool0017ooooo00?o0000oooooooo
ool0Aoooool00ol00?ooooooooooo`0iooooo`03o`000?oooooooooo08;ooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool0Aoooool00ol00?ooooooooooo`0iooooo`03o`00
0?oooooooooo08;ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Pooo
ool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00Oooool0017oooooool0000=o`0000?ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.95693, -3.43838, \
0.0394232, 0.0363282}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Show all", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{{g3, g4}, {g6, g8}}], \ 
        ImageSize \[Rule] 504];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 504 311.489 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.0147151 0.00967843 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1115 -12 -4.5 ]
[-0.0125 .1115 0 4.5 ]
[-0.0125 .20828 -12 -4.5 ]
[-0.0125 .20828 0 4.5 ]
[-0.0125 .30507 -12 -4.5 ]
[-0.0125 .30507 0 4.5 ]
[-0.0125 .40185 -12 -4.5 ]
[-0.0125 .40185 0 4.5 ]
[-0.0125 .49864 -12 -4.5 ]
[-0.0125 .49864 0 4.5 ]
[-0.0125 .59542 -12 -4.5 ]
[-0.0125 .59542 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1115 m
.00625 .1115 L
s
[(10)] -0.0125 .1115 1 0 Mshowa
0 .20828 m
.00625 .20828 L
s
[(20)] -0.0125 .20828 1 0 Mshowa
0 .30507 m
.00625 .30507 L
s
[(30)] -0.0125 .30507 1 0 Mshowa
0 .40185 m
.00625 .40185 L
s
[(40)] -0.0125 .40185 1 0 Mshowa
0 .49864 m
.00625 .49864 L
s
[(50)] -0.0125 .49864 1 0 Mshowa
0 .59542 m
.00625 .59542 L
s
[(60)] -0.0125 .59542 1 0 Mshowa
.125 Mabswid
0 .03407 m
.00375 .03407 L
s
0 .05343 m
.00375 .05343 L
s
0 .07279 m
.00375 .07279 L
s
0 .09214 m
.00375 .09214 L
s
0 .13086 m
.00375 .13086 L
s
0 .15021 m
.00375 .15021 L
s
0 .16957 m
.00375 .16957 L
s
0 .18893 m
.00375 .18893 L
s
0 .22764 m
.00375 .22764 L
s
0 .247 m
.00375 .247 L
s
0 .26635 m
.00375 .26635 L
s
0 .28571 m
.00375 .28571 L
s
0 .32442 m
.00375 .32442 L
s
0 .34378 m
.00375 .34378 L
s
0 .36314 m
.00375 .36314 L
s
0 .3825 m
.00375 .3825 L
s
0 .42121 m
.00375 .42121 L
s
0 .44057 m
.00375 .44057 L
s
0 .45992 m
.00375 .45992 L
s
0 .47928 m
.00375 .47928 L
s
0 .51799 m
.00375 .51799 L
s
0 .53735 m
.00375 .53735 L
s
0 .55671 m
.00375 .55671 L
s
0 .57606 m
.00375 .57606 L
s
0 .61478 m
.00375 .61478 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1115 m
1 .1115 L
s
.99375 .20828 m
1 .20828 L
s
.99375 .30507 m
1 .30507 L
s
.99375 .40185 m
1 .40185 L
s
.99375 .49864 m
1 .49864 L
s
.99375 .59542 m
1 .59542 L
s
.125 Mabswid
.99625 .03407 m
1 .03407 L
s
.99625 .05343 m
1 .05343 L
s
.99625 .07279 m
1 .07279 L
s
.99625 .09214 m
1 .09214 L
s
.99625 .13086 m
1 .13086 L
s
.99625 .15021 m
1 .15021 L
s
.99625 .16957 m
1 .16957 L
s
.99625 .18893 m
1 .18893 L
s
.99625 .22764 m
1 .22764 L
s
.99625 .247 m
1 .247 L
s
.99625 .26635 m
1 .26635 L
s
.99625 .28571 m
1 .28571 L
s
.99625 .32442 m
1 .32442 L
s
.99625 .34378 m
1 .34378 L
s
.99625 .36314 m
1 .36314 L
s
.99625 .3825 m
1 .3825 L
s
.99625 .42121 m
1 .42121 L
s
.99625 .44057 m
1 .44057 L
s
.99625 .45992 m
1 .45992 L
s
.99625 .47928 m
1 .47928 L
s
.99625 .51799 m
1 .51799 L
s
.99625 .53735 m
1 .53735 L
s
.99625 .55671 m
1 .55671 L
s
.99625 .57606 m
1 .57606 L
s
.99625 .61478 m
1 .61478 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .01472 m
.02847 .04487 L
.03089 .05844 L
.03218 .06466 L
.03355 .07042 L
.03484 .07492 L
.03602 .07816 L
.03659 .07942 L
.0372 .08055 L
.03779 .0814 L
.03832 .08199 L
.03862 .08223 L
.03888 .0824 L
.03903 .08248 L
.03919 .08254 L
.03935 .08258 L
.03949 .08261 L
.03963 .08263 L
.03977 .08263 L
.03989 .08262 L
.04002 .0826 L
.04016 .08256 L
.04031 .08251 L
.04058 .08238 L
.04088 .08218 L
.04119 .0819 L
.04177 .08123 L
.04245 .08016 L
.04307 .07893 L
.04426 .07586 L
.04537 .07227 L
.04787 .06166 L
.05032 .04851 L
.05261 .03434 L
.05368 .02734 L
.0548 .01982 L
.05509 .0179 L
.05539 .01584 L
.05548 .01523 L
.05556 .01477 L
.05572 .01585 L
.05603 .01795 L
.05716 .02556 L
.0618 .05453 L
.06415 .06646 L
.0654 .07171 L
.06674 .07639 L
.06802 .07988 L
.06919 .08215 L
.06976 .08293 L
Mistroke
.07005 .08325 L
.07037 .08354 L
.07068 .08374 L
.07095 .08387 L
.07108 .08392 L
.07123 .08396 L
.07136 .08398 L
.07149 .08399 L
.07164 .08398 L
.07179 .08396 L
.07192 .08393 L
.07206 .08389 L
.07221 .08383 L
.07237 .08374 L
.07267 .08355 L
.07319 .08305 L
.07376 .08229 L
.07438 .08123 L
.07505 .07981 L
.07626 .07652 L
.07868 .06729 L
.08123 .0543 L
.08364 .0396 L
.08583 .02494 L
.08641 .0209 L
.08672 .01875 L
.08705 .01649 L
.08719 .01553 L
.08733 .01493 L
.08742 .01553 L
.08749 .01606 L
.08765 .01712 L
.0882 .02097 L
.09073 .03826 L
.09322 .05399 L
.09553 .06656 L
.09777 .07625 L
.0989 .08006 L
.09951 .08177 L
.10015 .08332 L
.10073 .08449 L
.10136 .08551 L
.10164 .08587 L
.10194 .08619 L
.10222 .08644 L
.10248 .08662 L
.10263 .08671 L
.1028 .08678 L
.10297 .08684 L
.10307 .08686 L
Mistroke
.10315 .08687 L
.10324 .08688 L
.10331 .08689 L
.10346 .08688 L
.10362 .08686 L
.10371 .08684 L
.10379 .08681 L
.10395 .08676 L
.1041 .08669 L
.10437 .08651 L
.10467 .08627 L
.10499 .08593 L
.10558 .08512 L
.10614 .08414 L
.1074 .08114 L
.10862 .07722 L
.10994 .07197 L
.11493 .04393 L
.11614 .03567 L
.11743 .02654 L
.11796 .02271 L
.11853 .01855 L
.11868 .01738 L
.11885 .01616 L
.11899 .01511 L
.11915 .01547 L
.1193 .01655 L
.11945 .01771 L
.11974 .01979 L
.12436 .05244 L
.12677 .06697 L
.12803 .07355 L
.12937 .07954 L
.13057 .08397 L
.1312 .08594 L
.13188 .08775 L
.1325 .08912 L
.13308 .09013 L
.13335 .09053 L
.13365 .09091 L
.13393 .0912 L
.13419 .09142 L
.1345 .09161 L
.13467 .09168 L
.13475 .09171 L
.13484 .09174 L
.13499 .09177 L
.13513 .09178 L
.13521 .09178 L
.13529 .09178 L
Mistroke
.13544 .09175 L
.13558 .09172 L
.13572 .09167 L
.13585 .09161 L
.13598 .09154 L
.13629 .09132 L
.13657 .09105 L
.13721 .09023 L
.13779 .08921 L
.1391 .08601 L
.14029 .08206 L
.14139 .07754 L
.14389 .0645 L
.14861 .03186 L
.14985 .02221 L
.15019 .01952 L
.15037 .01805 L
.15055 .01667 L
.1507 .0155 L
.15085 .0152 L
.15094 .01592 L
.15103 .0166 L
.15119 .01788 L
.15362 .03715 L
.15824 .07011 L
.16063 .08338 L
.16185 .08881 L
.16316 .09351 L
.16376 .09522 L
.16439 .09673 L
.16497 .09785 L
.16551 .09865 L
.16577 .09895 L
.16602 .09918 L
.16615 .09929 L
.1663 .09939 L
.16644 .09946 L
.16656 .09952 L
.1667 .09956 L
.16685 .0996 L
.167 .09961 L
.16708 .09961 L
.16716 .09961 L
.1673 .09958 L
.16744 .09954 L
.16758 .09949 L
.16771 .09942 L
.16803 .0992 L
.16833 .09892 L
.16899 .09803 L
Mistroke
.16957 .09695 L
.17019 .0955 L
.17126 .09225 L
.17244 .08766 L
.17479 .07542 L
.17732 .0584 L
.17971 .0394 L
.18097 .0286 L
.18166 .02253 L
.182 .01953 L
.18215 .01821 L
.18231 .01677 L
.18245 .01548 L
.18259 .01515 L
.18273 .01642 L
.18288 .01778 L
.1835 .02331 L
.18481 .03505 L
.18712 .05512 L
.18952 .07421 L
.19213 .09153 L
.19335 .09811 L
.19464 .10383 L
.19574 .10762 L
.19632 .10919 L
.19696 .11055 L
.19728 .11112 L
.19759 .11156 L
.19787 .11189 L
.19802 .11203 L
.19818 .11216 L
.19833 .11226 L
.19846 .11233 L
.19859 .11238 L
.19873 .11242 L
.19887 .11244 L
.199 .11245 L
.19915 .11243 L
.19931 .11239 L
.19939 .11236 L
.19947 .11232 L
.19963 .11223 L
.1998 .11211 L
.19998 .11195 L
.20032 .11157 L
.20063 .11112 L
.2012 .11004 L
.20183 .10852 L
.20305 .10448 L
.20438 .09852 L
Mistroke
.2068 .08376 L
.20937 .06328 L
.2117 .04138 L
.21287 .02955 L
.21348 .02317 L
.21382 .01965 L
.21398 .01792 L
.21413 .01634 L
.21427 .01485 L
.21441 .016 L
.2147 .01913 L
.21532 .02579 L
.21642 .03753 L
.22105 .08437 L
.22338 .10425 L
.22463 .1132 L
.22596 .12136 L
.22724 .12756 L
.2278 .12975 L
.22841 .13176 L
.22895 .13321 L
.22953 .1344 L
.22984 .13489 L
.23013 .13524 L
.23027 .13537 L
.23043 .13549 L
.23057 .13558 L
.2307 .13564 L
.23085 .13568 L
.231 .1357 L
.23112 .13569 L
.23127 .13566 L
.23142 .13561 L
.2315 .13556 L
.23158 .13551 L
.23187 .13527 L
.23214 .13495 L
.23243 .13451 L
.23296 .13345 L
.2336 .13175 L
.23426 .12945 L
.23545 .12401 L
.2366 .11723 L
.23783 .10835 L
.24004 .08838 L
.24244 .06177 L
.2437 .04604 L
.24439 .03703 L
.24504 .02836 L
.24561 .02055 L
Mistroke
.24577 .01827 L
.24593 .0161 L
.24607 .01528 L
.24623 .01743 L
.24754 .03591 L
.24985 .06879 L
.25242 .10407 L
.25475 .1331 L
.2572 .15874 L
.25946 .17634 L
.26059 .18256 L
.26116 .185 L
.26178 .1871 L
.2621 .18795 L
.26241 .1886 L
.26258 .1889 L
.26276 .18916 L
.26291 .18935 L
.26308 .1895 L
.26324 .18961 L
.26339 .18967 L
.26354 .18969 L
.26363 .18969 L
.26371 .18967 L
.26385 .18962 L
.26399 .18953 L
.26415 .18939 L
.26429 .18923 L
.26461 .18874 L
.2649 .18814 L
.26556 .18623 L
.26614 .18391 L
.26676 .18079 L
.26783 .17378 L
.269 .16369 L
.27134 .1362 L
.27386 .09614 L
.27624 .04918 L
.27689 .03493 L
.27725 .02687 L
.27743 .02286 L
.27759 .01914 L
.27774 .01558 L
.27782 .01566 L
.2779 .01764 L
.27824 .02572 L
.27884 .04011 L
.28363 .16731 L
.28851 .30479 L
.2932 .42755 L
Mistroke
.2956 .4813 L
.2982 .53027 L
.29941 .54921 L
.30069 .56639 L
.3019 .57961 L
.303 .58921 L
.30414 .5965 L
.30473 .59928 L
.30503 .60041 L
.30535 .60142 L
.30564 .60213 L
.3059 .60264 L
.30603 .60283 L
.30616 .603 L
.30629 .60313 L
.30641 .60322 L
.30655 .60329 L
.30667 .60332 L
.30682 .60331 L
.30697 .60326 L
.30713 .60315 L
.30728 .603 L
.30741 .60283 L
.30756 .6026 L
.30787 .60198 L
.3082 .60109 L
.30881 .59891 L
.3094 .5961 L
.30994 .59293 L
.31117 .58364 L
.31247 .57084 L
.31485 .54008 L
.31706 .50386 L
.32176 .40868 L
.32676 .29324 L
.33158 .18349 L
.33621 .09135 L
.33855 .05237 L
.3398 .0341 L
.34048 .02476 L
.34082 .02035 L
.34099 .01825 L
.34114 .01637 L
.34129 .01495 L
.34143 .0167 L
.34175 .02048 L
.34242 .02809 L
.34359 .04023 L
.34588 .05961 L
.34706 .06739 L
Mistroke
.3483 .07409 L
.34936 .07865 L
.35053 .08252 L
.35116 .08414 L
.35176 .0854 L
.3523 .08629 L
.35288 .08703 L
.35318 .08732 L
.35352 .08757 L
.35369 .08767 L
.35387 .08776 L
.35404 .08782 L
.35419 .08786 L
.35434 .08789 L
.35447 .0879 L
.35462 .0879 L
.35478 .08789 L
.35486 .08788 L
.35495 .08786 L
.35511 .08782 L
.35526 .08777 L
.3554 .08771 L
.3557 .08755 L
.35597 .08736 L
.35657 .08681 L
.35713 .08614 L
.35767 .08536 L
.35886 .0832 L
.36016 .08018 L
.36253 .07305 L
.36506 .06321 L
.36748 .05153 L
.37008 .03606 L
.37131 .02766 L
.37198 .02275 L
.37231 .02027 L
.37261 .01796 L
.37274 .01693 L
.37288 .0158 L
.37302 .01472 L
.37314 .01571 L
.37371 .02042 L
.37492 .03097 L
.37966 .07907 L
.38422 .13306 L
.38908 .19273 L
.39375 .24458 L
.39612 .26634 L
.39738 .27618 L
.39872 .28523 L
Mistroke
.40002 .2925 L
.4012 .29772 L
.40177 .29976 L
.40238 .30159 L
.40292 .30289 L
.4035 .30395 L
.40381 .30437 L
.40409 .30468 L
.40423 .30479 L
.40438 .3049 L
.40452 .30498 L
.40464 .30503 L
.40479 .30507 L
.40493 .30509 L
.40509 .30509 L
.40517 .30508 L
.40525 .30506 L
.4054 .30501 L
.40549 .30497 L
.40557 .30492 L
.40573 .30482 L
.4059 .30467 L
.40623 .3043 L
.40654 .30386 L
.40713 .30275 L
.40781 .30102 L
.40844 .29901 L
.40961 .29426 L
.4107 .28864 L
.41319 .27187 L
.41787 .22783 L
.42284 .16938 L
.42763 .10982 L
.43224 .05643 L
.43461 .03213 L
.4353 .02563 L
.43594 .01974 L
.43622 .01723 L
.43637 .01588 L
.43652 .0148 L
.43667 .01614 L
.43684 .0176 L
.43714 .02012 L
.44184 .05307 L
.4444 .06576 L
.44558 .07036 L
.44683 .07441 L
.44797 .07738 L
.44858 .07868 L
.44923 .07986 L
Mistroke
.44983 .08075 L
.45038 .0814 L
.4509 .08188 L
.45116 .08206 L
.45145 .08223 L
.45176 .08236 L
.45193 .08241 L
.45209 .08244 L
.45223 .08246 L
.45238 .08247 L
.45246 .08246 L
.45254 .08246 L
.45269 .08245 L
.45284 .08242 L
.45299 .08238 L
.45314 .08233 L
.45328 .08227 L
.45354 .08214 L
.45382 .08196 L
.4545 .08135 L
.45514 .08055 L
.45635 .07848 L
.45753 .0757 L
.45877 .07195 L
.461 .06309 L
.46338 .05057 L
.46559 .03597 L
.46686 .02637 L
.46748 .02132 L
.46775 .01904 L
.4679 .01781 L
.46805 .01647 L
.46819 .01526 L
.46832 .01529 L
.46845 .01643 L
.46857 .01752 L
.46913 .02251 L
.47029 .03355 L
.4749 .08314 L
.4798 .1427 L
.48451 .20027 L
.48692 .22737 L
.48953 .25348 L
.49183 .27289 L
.49313 .28211 L
.49436 .28941 L
.49561 .29554 L
.49676 .29984 L
.49739 .30167 L
.49798 .30304 L
Mistroke
.49861 .30411 L
.49897 .30454 L
.49913 .30469 L
.4993 .30482 L
.49944 .30491 L
.49959 .30498 L
.49973 .30503 L
.49986 .30506 L
.50001 .30507 L
.50015 .30506 L
.50022 .30504 L
.50031 .30502 L
.50046 .30496 L
.50059 .30489 L
.50073 .3048 L
.50102 .30454 L
.50129 .30423 L
.50155 .30387 L
.50217 .30271 L
.50275 .30131 L
.50403 .29701 L
.50522 .29164 L
.50632 .28551 L
.50883 .26779 L
.51355 .22229 L
.51857 .16302 L
.5234 .10332 L
.52806 .05032 L
.53047 .02631 L
.53105 .0209 L
.53137 .01801 L
.53153 .0166 L
.53168 .01531 L
.53176 .01485 L
.53185 .01562 L
.53204 .01723 L
.53237 .02001 L
.53301 .02527 L
.53756 .05592 L
.5399 .06702 L
.5411 .07153 L
.54242 .07555 L
.54367 .07851 L
.54484 .08052 L
.54548 .08133 L
.54607 .08187 L
.54639 .0821 L
.54656 .0822 L
.54674 .08228 L
.5469 .08235 L
Mistroke
.54708 .0824 L
.54723 .08243 L
.54738 .08245 L
.54753 .08246 L
.54761 .08247 L
.5477 .08246 L
.54784 .08245 L
.54798 .08242 L
.54806 .08241 L
.54815 .08238 L
.5483 .08233 L
.54864 .08218 L
.54893 .082 L
.54921 .08179 L
.54983 .08117 L
.5504 .08044 L
.55091 .07962 L
.55207 .07729 L
.55327 .07413 L
.55438 .07052 L
.55689 .05986 L
.55914 .04722 L
.56044 .03863 L
.56163 .02993 L
.56221 .02544 L
.56283 .02033 L
.56312 .01793 L
.56328 .01659 L
.56342 .01531 L
.56356 .01532 L
.56371 .01663 L
.56397 .01895 L
.56649 .0431 L
.57144 .09851 L
.5762 .15742 L
.58078 .21275 L
.58333 .24039 L
.58565 .26236 L
.58809 .28116 L
.59035 .29405 L
.59146 .29867 L
.59203 .30056 L
.59265 .30224 L
.59326 .30353 L
.59354 .30398 L
.59384 .30439 L
.59417 .30474 L
.59436 .30488 L
.59452 .30498 L
.59468 .30504 L
Mistroke
.59483 .30508 L
.59491 .30509 L
.595 .3051 L
.59515 .30508 L
.5953 .30505 L
.59544 .305 L
.59559 .30492 L
.59574 .30482 L
.59601 .30458 L
.59629 .30424 L
.59695 .30316 L
.59755 .30177 L
.59878 .29782 L
.60009 .29198 L
.60268 .27579 L
.60511 .25553 L
.60977 .20639 L
.61472 .14615 L
.61949 .08869 L
.62407 .04028 L
.62528 .02911 L
.62643 .01924 L
.62674 .01671 L
.62689 .01545 L
.62698 .01474 L
.62706 .01535 L
.62742 .01818 L
.62775 .02073 L
.62895 .02954 L
.63363 .05717 L
.63605 .06783 L
.6386 .07669 L
.63975 .07994 L
.64098 .08286 L
.64214 .08506 L
.6432 .08655 L
.64378 .08716 L
.64411 .08742 L
.64441 .08761 L
.64466 .08774 L
.64479 .08779 L
.64493 .08784 L
.64509 .08787 L
.64524 .08789 L
.64538 .0879 L
.64552 .0879 L
.64566 .08789 L
.64581 .08786 L
.64596 .08782 L
.64609 .08777 L
Mistroke
.64641 .08762 L
.64673 .08739 L
.64705 .0871 L
.64735 .08676 L
.64803 .08577 L
.64863 .0846 L
.64929 .083 L
.65049 .0792 L
.65166 .07428 L
.65273 .06862 L
.65499 .05291 L
.65629 .0414 L
.65748 .02923 L
.65806 .02278 L
.65836 .01922 L
.65853 .01722 L
.65868 .01531 L
.65883 .01597 L
.65892 .01702 L
.65899 .01799 L
.65927 .02159 L
.65982 .02887 L
.66234 .06657 L
.66711 .15553 L
.67169 .25706 L
.67657 .37093 L
.68126 .47234 L
.68365 .51628 L
.68625 .55547 L
.68747 .57014 L
.68875 .58297 L
.68985 .59155 L
.69043 .59516 L
.69106 .59836 L
.69166 .60065 L
.69198 .60161 L
.69228 .60231 L
.69243 .60258 L
.69256 .6028 L
.69269 .60296 L
.69282 .60311 L
.69296 .60322 L
.6931 .60329 L
.69324 .60332 L
.6934 .60331 L
.69348 .60328 L
.69357 .60324 L
.69365 .60318 L
.69372 .60312 L
.69387 .60297 L
Mistroke
.69402 .60276 L
.69438 .60209 L
.6947 .60127 L
.69532 .59905 L
.69591 .59624 L
.6971 .58845 L
.69834 .5772 L
.70057 .54952 L
.70295 .5101 L
.70516 .46514 L
.70986 .34934 L
.71486 .2099 L
.71736 .13979 L
.71967 .07779 L
.72083 .04825 L
.7214 .03428 L
.72192 .0218 L
.72206 .01863 L
.7222 .0152 L
.72234 .01745 L
.72247 .02042 L
.72306 .03378 L
.72431 .06069 L
.72657 .10377 L
.72902 .14113 L
.73037 .15722 L
.7316 .16919 L
.73279 .17806 L
.73344 .18188 L
.73404 .18469 L
.73462 .18684 L
.73518 .18832 L
.73548 .1889 L
.73577 .1893 L
.73591 .18945 L
.73608 .18957 L
.73616 .18962 L
.73625 .18966 L
.7364 .18969 L
.73654 .18968 L
.73667 .18965 L
.73681 .18958 L
.73697 .18946 L
.73713 .1893 L
.73728 .18911 L
.73756 .18866 L
.73807 .18752 L
.73862 .18583 L
.73976 .18084 L
.74101 .17318 L
Mistroke
.74355 .15152 L
.74841 .09293 L
.75065 .06168 L
.75184 .04483 L
.75309 .02695 L
.75345 .02192 L
.75363 .01946 L
.75379 .0172 L
.75394 .01515 L
.75409 .01643 L
.75425 .01859 L
.75442 .02094 L
.75565 .03751 L
.75807 .06778 L
.76063 .0949 L
.76295 .11418 L
.76411 .1216 L
.76537 .12793 L
.76594 .13021 L
.76655 .1322 L
.76707 .13354 L
.76765 .13465 L
.76793 .13505 L
.76824 .13538 L
.7684 .1355 L
.76849 .13555 L
.76857 .1356 L
.76873 .13566 L
.76887 .13569 L
.76901 .1357 L
.76915 .13568 L
.76927 .13565 L
.76941 .13559 L
.76955 .13551 L
.76971 .13539 L
.76999 .13511 L
.77031 .13467 L
.77066 .13405 L
.7713 .13258 L
.77193 .13071 L
.7725 .12861 L
.77475 .1172 L
.77723 .09935 L
.77976 .07677 L
.78208 .0534 L
.78435 .02931 L
.7849 .02341 L
.7852 .02017 L
.78549 .01712 L
.78557 .01628 L
Mistroke
.78565 .01539 L
.78574 .01501 L
.78583 .01591 L
.78614 .01917 L
.78674 .02549 L
.7913 .06907 L
.79364 .08682 L
.79616 .10112 L
.79738 .10605 L
.79803 .1081 L
.79871 .10985 L
.79905 .11056 L
.79937 .11111 L
.79968 .11157 L
.79997 .1119 L
.80024 .11214 L
.80038 .11224 L
.80053 .11232 L
.80068 .11239 L
.80077 .11241 L
.80084 .11243 L
.80099 .11245 L
.80114 .11244 L
.80127 .11242 L
.80142 .11238 L
.80156 .11232 L
.80169 .11225 L
.80199 .11202 L
.8023 .1117 L
.80289 .11083 L
.80354 .10952 L
.80469 .10625 L
.80576 .10219 L
.80823 .08941 L
.81047 .07425 L
.81298 .05428 L
.81529 .03414 L
.81646 .02371 L
.81675 .02108 L
.81703 .01859 L
.81728 .01636 L
.81742 .0151 L
.81755 .01549 L
.81769 .01674 L
.81781 .01786 L
.8181 .02038 L
.81868 .02557 L
.81993 .03638 L
.82246 .0567 L
.82477 .07276 L
Mistroke
.82704 .08528 L
.82818 .0902 L
.82943 .09445 L
.83006 .09613 L
.83066 .09742 L
.8312 .09833 L
.83151 .09873 L
.83179 .09904 L
.83209 .0993 L
.83225 .0994 L
.83243 .09949 L
.83251 .09953 L
.83261 .09956 L
.8327 .09958 L
.83278 .0996 L
.83293 .09961 L
.83302 .09961 L
.8331 .0996 L
.83326 .09958 L
.8334 .09953 L
.83356 .09946 L
.83372 .09937 L
.83401 .09916 L
.83431 .09886 L
.83494 .09799 L
.83554 .09688 L
.83666 .09404 L
.83787 .08992 L
.83919 .08428 L
.8441 .05429 L
.84654 .03586 L
.84774 .02642 L
.84826 .02225 L
.84854 .02004 L
.84883 .01768 L
.84898 .01649 L
.84912 .01537 L
.84925 .01506 L
.84939 .01615 L
.8499 .02023 L
.85102 .02903 L
.85338 .04666 L
.85573 .06225 L
.85832 .07621 L
.8595 .08126 L
.86077 .08564 L
.86139 .08735 L
.86197 .08872 L
.86253 .08981 L
.86307 .09062 L
Mistroke
.86336 .09097 L
.86367 .09128 L
.86396 .0915 L
.86422 .09165 L
.86437 .0917 L
.86451 .09174 L
.86466 .09177 L
.86475 .09178 L
.86482 .09178 L
.86498 .09177 L
.86507 .09176 L
.86515 .09174 L
.8653 .0917 L
.86546 .09163 L
.86572 .09148 L
.866 .09126 L
.86651 .09071 L
.86712 .08981 L
.86768 .08875 L
.86886 .08577 L
.86996 .08213 L
.87246 .07111 L
.87717 .04209 L
.87841 .03332 L
.87975 .02357 L
.88036 .01905 L
.88053 .01785 L
.8807 .01657 L
.88078 .01595 L
.88086 .01536 L
.88101 .01517 L
.88115 .01618 L
.88128 .01712 L
.88157 .01924 L
.88218 .0237 L
.88691 .05554 L
.8895 .06942 L
.89068 .07459 L
.89193 .07912 L
.89309 .08244 L
.89371 .08383 L
.89436 .08503 L
.89497 .08588 L
.89552 .08643 L
.89578 .08662 L
.89592 .0867 L
.89607 .08676 L
.8962 .08681 L
.89634 .08685 L
.89647 .08687 L
Mistroke
.89659 .08688 L
.89674 .08688 L
.89683 .08688 L
.8969 .08686 L
.89705 .08683 L
.89719 .08679 L
.89736 .08671 L
.89751 .08663 L
.89784 .08639 L
.89812 .08613 L
.89842 .08579 L
.89903 .08491 L
.90019 .08254 L
.90127 .07955 L
.90372 .0701 L
.90596 .05871 L
.90846 .04361 L
.91077 .02815 L
.91132 .0243 L
.91192 .02013 L
.9122 .01821 L
.91235 .01716 L
.91249 .01618 L
.91261 .01534 L
.91274 .01498 L
.91288 .01597 L
.91301 .01687 L
.91414 .02472 L
.91539 .0332 L
.9179 .04919 L
.92021 .062 L
.92246 .07206 L
.92361 .07612 L
.92485 .07957 L
.92548 .08097 L
.92608 .08206 L
.92662 .08283 L
.92693 .08318 L
.92721 .08344 L
.9275 .08366 L
.92777 .08382 L
.92791 .08388 L
.92805 .08392 L
.9282 .08396 L
.92836 .08398 L
.92848 .08399 L
.92862 .08398 L
.92875 .08396 L
.92886 .08394 L
.929 .08389 L
Mistroke
.92915 .08383 L
.92942 .08368 L
.9297 .08348 L
.93001 .0832 L
.93056 .08253 L
.93121 .08147 L
.93181 .08027 L
.93304 .07706 L
.93434 .07269 L
.93673 .06228 L
.93895 .05027 L
.94121 .03629 L
.9424 .02848 L
.94366 .02002 L
.94397 .01793 L
.94414 .01678 L
.9443 .01569 L
.94439 .01508 L
.94449 .01502 L
.94458 .01563 L
.94466 .0162 L
.945 .01849 L
.94624 .02679 L
.94867 .04244 L
.95111 .05649 L
.9534 .06748 L
.95559 .07544 L
.95682 .07868 L
.95795 .08083 L
.95852 .0816 L
.95884 .08193 L
.95913 .08219 L
.95941 .08237 L
.95955 .08245 L
.95971 .08252 L
.95984 .08256 L
.95998 .0826 L
.96011 .08262 L
.96023 .08263 L
.96038 .08263 L
.96047 .08262 L
.96055 .08261 L
.9607 .08257 L
.96086 .08252 L
.96101 .08245 L
.96116 .08238 L
.96143 .08219 L
.96176 .08191 L
.96205 .08159 L
.96273 .08066 L
Mistroke
.96329 .07965 L
.9639 .07834 L
.965 .0754 L
.96749 .06614 L
.97005 .05339 L
.97248 .03903 L
.97619 .01472 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.05556 .01472 m
.05556 .01472 L
s
.0873 .01472 m
.0873 .01472 L
s
.11905 .01472 m
.11905 .01472 L
s
.15079 .01472 m
.15079 .01472 L
s
.18254 .01472 m
.18254 .01472 L
s
.21429 .01472 m
.21429 .01472 L
s
.24603 .01472 m
.24603 .01472 L
s
.27778 .01472 m
.27778 .01472 L
s
.30952 .01472 m
.30952 .59542 L
s
.34127 .01472 m
.34127 .01472 L
s
.37302 .01472 m
.37302 .01472 L
s
.40476 .01472 m
.40476 .30507 L
s
.43651 .01472 m
.43651 .01472 L
s
.46825 .01472 m
.46825 .01472 L
s
.5 .01472 m
.5 .30507 L
s
.53175 .01472 m
.53175 .01472 L
s
.56349 .01472 m
.56349 .01472 L
s
.59524 .01472 m
.59524 .30507 L
s
.62698 .01472 m
.62698 .01472 L
s
.65873 .01472 m
.65873 .01472 L
s
.69048 .01472 m
.69048 .59542 L
s
.72222 .01472 m
.72222 .01472 L
s
.75397 .01472 m
.75397 .01472 L
s
.78571 .01472 m
.78571 .01472 L
s
.81746 .01472 m
.81746 .01472 L
s
.84921 .01472 m
.84921 .01472 L
s
.88095 .01472 m
.88095 .01472 L
s
.9127 .01472 m
.9127 .01472 L
s
.94444 .01472 m
.94444 .01472 L
s
.97619 .01472 m
.97619 .01472 L
s
.015 w
.05556 .01472 Mdot
.0873 .01472 Mdot
.11905 .01472 Mdot
.15079 .01472 Mdot
.18254 .01472 Mdot
.21429 .01472 Mdot
.24603 .01472 Mdot
.27778 .01472 Mdot
.30952 .59542 Mdot
.34127 .01472 Mdot
.37302 .01472 Mdot
.40476 .30507 Mdot
.43651 .01472 Mdot
.46825 .01472 Mdot
.5 .30507 Mdot
.53175 .01472 Mdot
.56349 .01472 Mdot
.59524 .30507 Mdot
.62698 .01472 Mdot
.65873 .01472 Mdot
.69048 .59542 Mdot
.72222 .01472 Mdot
.75397 .01472 Mdot
.78571 .01472 Mdot
.81746 .01472 Mdot
.84921 .01472 Mdot
.88095 .01472 Mdot
.9127 .01472 Mdot
.94444 .01472 Mdot
.97619 .01472 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309069 0.103352 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .10236 -12 -4.5 ]
[-0.0125 .10236 0 4.5 ]
[-0.0125 .20572 -12 -4.5 ]
[-0.0125 .20572 0 4.5 ]
[-0.0125 .30907 -6 -4.5 ]
[-0.0125 .30907 0 4.5 ]
[-0.0125 .41242 -6 -4.5 ]
[-0.0125 .41242 0 4.5 ]
[-0.0125 .51577 -6 -4.5 ]
[-0.0125 .51577 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10236 m
.00625 .10236 L
s
[(-2)] -0.0125 .10236 1 0 Mshowa
0 .20572 m
.00625 .20572 L
s
[(-1)] -0.0125 .20572 1 0 Mshowa
0 .30907 m
.00625 .30907 L
s
[(0)] -0.0125 .30907 1 0 Mshowa
0 .41242 m
.00625 .41242 L
s
[(1)] -0.0125 .41242 1 0 Mshowa
0 .51577 m
.00625 .51577 L
s
[(2)] -0.0125 .51577 1 0 Mshowa
.125 Mabswid
0 .01968 m
.00375 .01968 L
s
0 .04035 m
.00375 .04035 L
s
0 .06102 m
.00375 .06102 L
s
0 .08169 m
.00375 .08169 L
s
0 .12304 m
.00375 .12304 L
s
0 .14371 m
.00375 .14371 L
s
0 .16438 m
.00375 .16438 L
s
0 .18505 m
.00375 .18505 L
s
0 .22639 m
.00375 .22639 L
s
0 .24706 m
.00375 .24706 L
s
0 .26773 m
.00375 .26773 L
s
0 .2884 m
.00375 .2884 L
s
0 .32974 m
.00375 .32974 L
s
0 .35041 m
.00375 .35041 L
s
0 .37108 m
.00375 .37108 L
s
0 .39175 m
.00375 .39175 L
s
0 .43309 m
.00375 .43309 L
s
0 .45376 m
.00375 .45376 L
s
0 .47443 m
.00375 .47443 L
s
0 .4951 m
.00375 .4951 L
s
0 .53644 m
.00375 .53644 L
s
0 .55711 m
.00375 .55711 L
s
0 .57778 m
.00375 .57778 L
s
0 .59845 m
.00375 .59845 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .10236 m
1 .10236 L
s
.99375 .20572 m
1 .20572 L
s
.99375 .30907 m
1 .30907 L
s
.99375 .41242 m
1 .41242 L
s
.99375 .51577 m
1 .51577 L
s
.125 Mabswid
.99625 .01968 m
1 .01968 L
s
.99625 .04035 m
1 .04035 L
s
.99625 .06102 m
1 .06102 L
s
.99625 .08169 m
1 .08169 L
s
.99625 .12304 m
1 .12304 L
s
.99625 .14371 m
1 .14371 L
s
.99625 .16438 m
1 .16438 L
s
.99625 .18505 m
1 .18505 L
s
.99625 .22639 m
1 .22639 L
s
.99625 .24706 m
1 .24706 L
s
.99625 .26773 m
1 .26773 L
s
.99625 .2884 m
1 .2884 L
s
.99625 .32974 m
1 .32974 L
s
.99625 .35041 m
1 .35041 L
s
.99625 .37108 m
1 .37108 L
s
.99625 .39175 m
1 .39175 L
s
.99625 .43309 m
1 .43309 L
s
.99625 .45376 m
1 .45376 L
s
.99625 .47443 m
1 .47443 L
s
.99625 .4951 m
1 .4951 L
s
.99625 .53644 m
1 .53644 L
s
.99625 .55711 m
1 .55711 L
s
.99625 .57778 m
1 .57778 L
s
.99625 .59845 m
1 .59845 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30907 m
1 .30907 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .47141 m
.02847 .42587 L
.03355 .37621 L
.03832 .32956 L
.04291 .28471 L
.0478 .23696 L
.0525 .19101 L
.05373 .17897 L
.05438 .17262 L
.05474 .16915 L
.05507 .1659 L
.05536 .16307 L
.05544 .16225 L
.05552 .16148 L
.05567 .48471 L
.05575 .48394 L
.05584 .48311 L
.05599 .48162 L
.05633 .47824 L
.0575 .46685 L
.06251 .41785 L
.06735 .37063 L
.072 .32521 L
.07694 .2769 L
.0817 .23038 L
.0841 .20698 L
.08514 .19676 L
.08628 .18565 L
.08659 .18268 L
.08691 .17952 L
.08704 .17822 L
.08719 .17682 L
.08734 .49998 L
.08749 .49854 L
.08864 .48736 L
.09116 .46273 L
.09612 .41428 L
.1009 .36762 L
.10549 .32275 L
.11039 .275 L
.1151 .22905 L
.11633 .21699 L
.11767 .20393 L
.11828 .19793 L
.11862 .19465 L
.11878 .19305 L
.11893 .19159 L
.11907 .51494 L
.1192 .51367 L
.11949 .51086 L
Mistroke
.1201 .5049 L
.12471 .45991 L
.12962 .41203 L
.13435 .36596 L
.13937 .31701 L
.14421 .26985 L
.14643 .24821 L
.14769 .23593 L
.14886 .22449 L
.15003 .21315 L
.15036 .20989 L
.15052 .20828 L
.15068 .2068 L
.15082 .53015 L
.15096 .52872 L
.15127 .52571 L
.15381 .50095 L
.15837 .45655 L
.16323 .4093 L
.1679 .36383 L
.17287 .31551 L
.17765 .26899 L
.18006 .24554 L
.18112 .23533 L
.18167 .22995 L
.18197 .22701 L
.18225 .22427 L
.1824 .22285 L
.18256 .54602 L
.18265 .54515 L
.18273 .54433 L
.18289 .54279 L
.18347 .53711 L
.18462 .52594 L
.18715 .50138 L
.19177 .45654 L
.19669 .40886 L
.20142 .36298 L
.20597 .3189 L
.20849 .29443 L
.21081 .27198 L
.21308 .25001 L
.21363 .24468 L
.21394 .24174 L
.21409 .2403 L
.21422 .23897 L
.2143 .56289 L
.21439 .56208 L
.21456 .56038 L
.21487 .5574 L
Mistroke
.21547 .55157 L
.22004 .50743 L
.2249 .46047 L
.22958 .41533 L
.23455 .36739 L
.23934 .32127 L
.24176 .29802 L
.24395 .27697 L
.24454 .27132 L
.24518 .26522 L
.24547 .26242 L
.24563 .26089 L
.24578 .25946 L
.2459 .25824 L
.24604 .58162 L
.24619 .58017 L
.24633 .57885 L
.24886 .55458 L
.25366 .50851 L
.25829 .46427 L
.26321 .41731 L
.26795 .37219 L
.2725 .32894 L
.27503 .30495 L
.27614 .29447 L
.27673 .28892 L
.27705 .28588 L
.27735 .28301 L
.2775 .28165 L
.27765 .28021 L
.27773 .27946 L
.27782 .60332 L
.27797 .60186 L
.27853 .59657 L
.27963 .58622 L
.28202 .56366 L
.28689 .51793 L
.29158 .47414 L
.29656 .42784 L
.30135 .38357 L
.30597 .34133 L
.31088 .29685 L
.31561 .25458 L
.32063 .21043 L
.32547 .16882 L
.33013 .12994 L
.33508 .0902 L
.33755 .07119 L
.33876 .06214 L
.33985 .05404 L
Mistroke
.3404 .05007 L
.34069 .04798 L
.34099 .04579 L
.34112 .04487 L
.34126 .04388 L
.34141 .36749 L
.34155 .36648 L
.34207 .36282 L
.34444 .34655 L
.34941 .31536 L
.3542 .2896 L
.3588 .26863 L
.36371 .24871 L
.36842 .22899 L
.36966 .22338 L
.371 .21705 L
.37162 .21404 L
.37227 .21079 L
.37254 .20943 L
.37283 .20796 L
.37291 .20752 L
.37299 .20711 L
.37314 .53102 L
.37328 .53028 L
.37344 .52948 L
.37835 .50158 L
.38309 .47122 L
.38764 .43955 L
.39249 .40391 L
.39715 .36838 L
.40211 .32984 L
.40689 .2924 L
.41148 .25645 L
.41637 .2186 L
.42108 .18292 L
.42608 .1462 L
.4309 .11239 L
.43311 .09751 L
.43437 .08925 L
.43498 .08526 L
.43554 .08165 L
.43582 .07983 L
.43613 .07786 L
.43628 .07696 L
.43643 .07601 L
.43657 .3998 L
.4367 .39898 L
.43794 .39122 L
.44047 .37579 L
.44531 .34793 L
Mistroke
.44997 .32254 L
.45492 .29603 L
.45968 .26981 L
.46427 .24309 L
.46662 .22864 L
.4673 .22439 L
.46764 .22228 L
.46794 .22032 L
.46809 .2194 L
.46822 .21854 L
.46837 .54233 L
.46852 .54133 L
.46915 .53729 L
.47382 .50613 L
.47878 .47113 L
.48357 .43595 L
.48817 .40112 L
.49307 .3633 L
.49778 .32648 L
.50279 .28721 L
.50762 .24954 L
.51226 .21374 L
.5172 .17646 L
.52196 .14168 L
.52653 .10962 L
.52908 .09248 L
.53028 .08455 L
.53081 .0811 L
.53112 .07914 L
.5314 .07732 L
.53153 .07648 L
.53167 .0756 L
.53182 .39932 L
.53196 .39844 L
.53255 .39467 L
.53381 .38682 L
.53609 .37292 L
.54068 .3463 L
.54556 .31952 L
.55027 .29434 L
.55527 .26697 L
.55777 .25266 L
.56008 .239 L
.56233 .22524 L
.56288 .22182 L
.56318 .21992 L
.56333 .21899 L
.56347 .21812 L
.56355 .54231 L
.56363 .54178 L
Mistroke
.5638 .54067 L
.56411 .5387 L
.56472 .53482 L
.56973 .50138 L
.57457 .46725 L
.57922 .43299 L
.58416 .39542 L
.58893 .3585 L
.59351 .32265 L
.59838 .28445 L
.60308 .24801 L
.60807 .2101 L
.61287 .17494 L
.6175 .14302 L
.61983 .12782 L
.62241 .11194 L
.62359 .10505 L
.62486 .09788 L
.62544 .09467 L
.62605 .09136 L
.62658 .08858 L
.62672 .08783 L
.62687 .08703 L
.62702 .41097 L
.62715 .41029 L
.63197 .3874 L
.63661 .36815 L
.64155 .348 L
.6463 .32604 L
.65087 .3011 L
.65342 .28555 L
.65574 .27038 L
.65689 .26256 L
.6575 .25835 L
.65783 .25602 L
.65814 .25382 L
.65844 .2517 L
.65852 .25112 L
.65861 .25051 L
.65876 .57409 L
.6589 .5731 L
.65903 .57217 L
.65933 .57006 L
.66042 .56207 L
.66512 .52633 L
.67012 .48617 L
.67493 .44591 L
.67956 .40605 L
.68449 .36274 L
.68923 .32032 L
Mistroke
.69379 .27902 L
.69864 .23459 L
.70332 .19147 L
.70829 .14529 L
.71307 .10055 L
.71768 .05731 L
.72005 .03498 L
.72073 .02854 L
.72137 .02247 L
.72165 .01982 L
.72195 .01701 L
.7221 .01555 L
.72219 .01472 L
.72227 .33863 L
.72242 .33726 L
.72257 .3358 L
.72756 .2886 L
.73236 .24299 L
.73698 .199 L
.7419 .15208 L
.74663 .10681 L
.75118 .06321 L
.75232 .05232 L
.75293 .04637 L
.75351 .04084 L
.75367 .03935 L
.75381 .03794 L
.7539 .03715 L
.75398 .361 L
.75414 .35952 L
.75482 .35294 L
.75603 .34138 L
.76096 .29397 L
.76571 .24825 L
.77027 .20424 L
.77514 .15733 L
.77981 .11213 L
.78219 .08913 L
.78345 .07698 L
.78414 .07031 L
.78479 .06403 L
.78509 .06108 L
.78542 .05797 L
.78558 .05634 L
.78568 .05542 L
.78577 .37924 L
.78593 .37773 L
.78609 .3761 L
.78728 .36467 L
.78958 .34235 L
Mistroke
.79457 .29401 L
.79938 .24741 L
.80401 .20255 L
.80893 .15479 L
.81138 .13105 L
.81367 .10878 L
.81586 .08748 L
.81646 .08164 L
.81679 .07846 L
.8171 .0755 L
.81723 .07419 L
.81736 .07296 L
.8175 .39623 L
.81764 .39494 L
.81823 .38921 L
.82287 .34409 L
.82781 .29608 L
.83256 .24982 L
.83713 .20533 L
.842 .15794 L
.84425 .1361 L
.84669 .11231 L
.84733 .10605 L
.84802 .09939 L
.84835 .09615 L
.84866 .0931 L
.84894 .09036 L
.8491 .08882 L
.84924 .4121 L
.84939 .41073 L
.84954 .40926 L
.84981 .40661 L
.85042 .4006 L
.85167 .38848 L
.85667 .33978 L
.86148 .29285 L
.86611 .24769 L
.87104 .19963 L
.87579 .15335 L
.87817 .13011 L
.87921 .11994 L
.87976 .11457 L
.88035 .10884 L
.88052 .1072 L
.88068 .10566 L
.88082 .10427 L
.88097 .42746 L
.88112 .42603 L
.88127 .42452 L
.88155 .42182 L
Mistroke
.88269 .41069 L
.88521 .38612 L
.88979 .34144 L
.89466 .29386 L
.89935 .24805 L
.90434 .19935 L
.90684 .17498 L
.90915 .15243 L
.91139 .13055 L
.91193 .12523 L
.91222 .12243 L
.91252 .11949 L
.9126 .11874 L
.91268 .11793 L
.91277 .44173 L
.91286 .4409 L
.91316 .43789 L
.91377 .43198 L
.91877 .3831 L
.92359 .33601 L
.92823 .29069 L
.93317 .24248 L
.93792 .19605 L
.94031 .17273 L
.94249 .15141 L
.94306 .14579 L
.94369 .13966 L
.94398 .13685 L
.94414 .13531 L
.94428 .13387 L
.94442 .13251 L
.94457 .45574 L
.94471 .45441 L
.94483 .45319 L
.94735 .42856 L
.95212 .38197 L
.95671 .33716 L
.96159 .28945 L
.96628 .24354 L
.97128 .19473 L
.97609 .1477 L
.97619 .14672 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.05556 .30907 m
.05556 .30907 L
s
.0873 .30907 m
.0873 .30907 L
s
.11905 .30907 m
.11905 .30907 L
s
.15079 .30907 m
.15079 .30907 L
s
.18254 .30907 m
.18254 .30907 L
s
.21429 .30907 m
.21429 .30907 L
s
.24603 .30907 m
.24603 .30907 L
s
.27778 .30907 m
.27778 .30907 L
s
.30952 .30907 m
.30952 .30907 L
s
.34127 .30907 m
.34127 .30907 L
s
.37302 .30907 m
.37302 .30907 L
s
.40476 .30907 m
.40476 .30907 L
s
.43651 .30907 m
.43651 .30907 L
s
.46825 .30907 m
.46825 .30907 L
s
.5 .30907 m
.5 .30907 L
s
.53175 .30907 m
.53175 .30907 L
s
.56349 .30907 m
.56349 .30907 L
s
.59524 .30907 m
.59524 .30907 L
s
.62698 .30907 m
.62698 .30907 L
s
.65873 .30907 m
.65873 .30907 L
s
.69048 .30907 m
.69048 .30907 L
s
.72222 .30907 m
.72222 .30907 L
s
.75397 .30907 m
.75397 .30907 L
s
.78571 .30907 m
.78571 .30907 L
s
.81746 .30907 m
.81746 .30907 L
s
.84921 .30907 m
.84921 .30907 L
s
.88095 .30907 m
.88095 .30907 L
s
.9127 .30907 m
.9127 .30907 L
s
.94444 .30907 m
.94444 .30907 L
s
.97619 .30907 m
.97619 .30907 L
s
.015 w
.05556 .30907 Mdot
.0873 .30907 Mdot
.11905 .30907 Mdot
.15079 .30907 Mdot
.18254 .30907 Mdot
.21429 .30907 Mdot
.24603 .30907 Mdot
.27778 .30907 Mdot
.30952 .30907 Mdot
.34127 .30907 Mdot
.37302 .30907 Mdot
.40476 .30907 Mdot
.43651 .30907 Mdot
.46825 .30907 Mdot
.5 .30907 Mdot
.53175 .30907 Mdot
.56349 .30907 Mdot
.59524 .30907 Mdot
.62698 .30907 Mdot
.65873 .30907 Mdot
.69048 .30907 Mdot
.72222 .30907 Mdot
.75397 .30907 Mdot
.78571 .30907 Mdot
.81746 .30907 Mdot
.84921 .30907 Mdot
.88095 .30907 Mdot
.9127 .30907 Mdot
.94444 .30907 Mdot
.97619 .30907 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0328407 0.0147151 0.00981006 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18801 -0.0125 -3 -9 ]
[.18801 -0.0125 3 0 ]
[.35222 -0.0125 -6 -9 ]
[.35222 -0.0125 6 0 ]
[.51642 -0.0125 -6 -9 ]
[.51642 -0.0125 6 0 ]
[.68062 -0.0125 -6 -9 ]
[.68062 -0.0125 6 0 ]
[.84483 -0.0125 -6 -9 ]
[.84483 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11282 -12 -4.5 ]
[-0.0125 .11282 0 4.5 ]
[-0.0125 .21092 -12 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18801 0 m
.18801 .00625 L
s
[(5)] .18801 -0.0125 0 1 Mshowa
.35222 0 m
.35222 .00625 L
s
[(10)] .35222 -0.0125 0 1 Mshowa
.51642 0 m
.51642 .00625 L
s
[(15)] .51642 -0.0125 0 1 Mshowa
.68062 0 m
.68062 .00625 L
s
[(20)] .68062 -0.0125 0 1 Mshowa
.84483 0 m
.84483 .00625 L
s
[(25)] .84483 -0.0125 0 1 Mshowa
.125 Mabswid
.05665 0 m
.05665 .00375 L
s
.08949 0 m
.08949 .00375 L
s
.12233 0 m
.12233 .00375 L
s
.15517 0 m
.15517 .00375 L
s
.22085 0 m
.22085 .00375 L
s
.25369 0 m
.25369 .00375 L
s
.28654 0 m
.28654 .00375 L
s
.31938 0 m
.31938 .00375 L
s
.38506 0 m
.38506 .00375 L
s
.4179 0 m
.4179 .00375 L
s
.45074 0 m
.45074 .00375 L
s
.48358 0 m
.48358 .00375 L
s
.54926 0 m
.54926 .00375 L
s
.5821 0 m
.5821 .00375 L
s
.61494 0 m
.61494 .00375 L
s
.64778 0 m
.64778 .00375 L
s
.71346 0 m
.71346 .00375 L
s
.74631 0 m
.74631 .00375 L
s
.77915 0 m
.77915 .00375 L
s
.81199 0 m
.81199 .00375 L
s
.87767 0 m
.87767 .00375 L
s
.91051 0 m
.91051 .00375 L
s
.94335 0 m
.94335 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11282 m
.00625 .11282 L
s
[(10)] -0.0125 .11282 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(20)] -0.0125 .21092 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(30)] -0.0125 .30902 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(40)] -0.0125 .40712 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(50)] -0.0125 .50522 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(60)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .0932 m
.00375 .0932 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .17168 m
.00375 .17168 L
s
0 .1913 m
.00375 .1913 L
s
0 .23054 m
.00375 .23054 L
s
0 .25016 m
.00375 .25016 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .32864 m
.00375 .32864 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .4856 m
.00375 .4856 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .56408 m
.00375 .56408 L
s
0 .5837 m
.00375 .5837 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18801 .61178 m
.18801 .61803 L
s
.35222 .61178 m
.35222 .61803 L
s
.51642 .61178 m
.51642 .61803 L
s
.68062 .61178 m
.68062 .61803 L
s
.84483 .61178 m
.84483 .61803 L
s
.125 Mabswid
.05665 .61428 m
.05665 .61803 L
s
.08949 .61428 m
.08949 .61803 L
s
.12233 .61428 m
.12233 .61803 L
s
.15517 .61428 m
.15517 .61803 L
s
.22085 .61428 m
.22085 .61803 L
s
.25369 .61428 m
.25369 .61803 L
s
.28654 .61428 m
.28654 .61803 L
s
.31938 .61428 m
.31938 .61803 L
s
.38506 .61428 m
.38506 .61803 L
s
.4179 .61428 m
.4179 .61803 L
s
.45074 .61428 m
.45074 .61803 L
s
.48358 .61428 m
.48358 .61803 L
s
.54926 .61428 m
.54926 .61803 L
s
.5821 .61428 m
.5821 .61803 L
s
.61494 .61428 m
.61494 .61803 L
s
.64778 .61428 m
.64778 .61803 L
s
.71346 .61428 m
.71346 .61803 L
s
.74631 .61428 m
.74631 .61803 L
s
.77915 .61428 m
.77915 .61803 L
s
.81199 .61428 m
.81199 .61803 L
s
.87767 .61428 m
.87767 .61803 L
s
.91051 .61428 m
.91051 .61803 L
s
.94335 .61428 m
.94335 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11282 m
1 .11282 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .50522 m
1 .50522 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03434 m
1 .03434 L
s
.99625 .05396 m
1 .05396 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .0932 m
1 .0932 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .15206 m
1 .15206 L
s
.99625 .17168 m
1 .17168 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .23054 m
1 .23054 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .26978 m
1 .26978 L
s
.99625 .2894 m
1 .2894 L
s
.99625 .32864 m
1 .32864 L
s
.99625 .34826 m
1 .34826 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .44636 m
1 .44636 L
s
.99625 .46598 m
1 .46598 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .52484 m
1 .52484 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .56408 m
1 .56408 L
s
.99625 .5837 m
1 .5837 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .30902 L
s
.05665 .01472 m
.05665 .01472 L
s
.08949 .01472 m
.08949 .01472 L
s
.12233 .01472 m
.12233 .30902 L
s
.15517 .01472 m
.15517 .01472 L
s
.18801 .01472 m
.18801 .01472 L
s
.22085 .01472 m
.22085 .60332 L
s
.25369 .01472 m
.25369 .01472 L
s
.28654 .01472 m
.28654 .01472 L
s
.31938 .01472 m
.31938 .01472 L
s
.35222 .01472 m
.35222 .01472 L
s
.38506 .01472 m
.38506 .01472 L
s
.4179 .01472 m
.4179 .01472 L
s
.45074 .01472 m
.45074 .01472 L
s
.48358 .01472 m
.48358 .01472 L
s
.51642 .01472 m
.51642 .01472 L
s
.54926 .01472 m
.54926 .01472 L
s
.5821 .01472 m
.5821 .01472 L
s
.61494 .01472 m
.61494 .01472 L
s
.64778 .01472 m
.64778 .01472 L
s
.68062 .01472 m
.68062 .01472 L
s
.71346 .01472 m
.71346 .01472 L
s
.74631 .01472 m
.74631 .01472 L
s
.77915 .01472 m
.77915 .01472 L
s
.81199 .01472 m
.81199 .60332 L
s
.84483 .01472 m
.84483 .01472 L
s
.87767 .01472 m
.87767 .01472 L
s
.91051 .01472 m
.91051 .30902 L
s
.94335 .01472 m
.94335 .01472 L
s
.97619 .01472 m
.97619 .01472 L
s
.015 w
.02381 .30902 Mdot
.05665 .01472 Mdot
.08949 .01472 Mdot
.12233 .30902 Mdot
.15517 .01472 Mdot
.18801 .01472 Mdot
.22085 .60332 Mdot
.25369 .01472 Mdot
.28654 .01472 Mdot
.31938 .01472 Mdot
.35222 .01472 Mdot
.38506 .01472 Mdot
.4179 .01472 Mdot
.45074 .01472 Mdot
.48358 .01472 Mdot
.51642 .01472 Mdot
.54926 .01472 Mdot
.5821 .01472 Mdot
.61494 .01472 Mdot
.64778 .01472 Mdot
.68062 .01472 Mdot
.71346 .01472 Mdot
.74631 .01472 Mdot
.77915 .01472 Mdot
.81199 .60332 Mdot
.84483 .01472 Mdot
.87767 .01472 Mdot
.91051 .30902 Mdot
.94335 .01472 Mdot
.97619 .01472 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0328407 0.309017 0.0983632 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18801 -0.0125 -3 -9 ]
[.18801 -0.0125 3 0 ]
[.35222 -0.0125 -6 -9 ]
[.35222 -0.0125 6 0 ]
[.51642 -0.0125 -6 -9 ]
[.51642 -0.0125 6 0 ]
[.68062 -0.0125 -6 -9 ]
[.68062 -0.0125 6 0 ]
[.84483 -0.0125 -6 -9 ]
[.84483 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01393 -12 -4.5 ]
[-0.0125 .01393 0 4.5 ]
[-0.0125 .11229 -12 -4.5 ]
[-0.0125 .11229 0 4.5 ]
[-0.0125 .21065 -12 -4.5 ]
[-0.0125 .21065 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40738 -6 -4.5 ]
[-0.0125 .40738 0 4.5 ]
[-0.0125 .50574 -6 -4.5 ]
[-0.0125 .50574 0 4.5 ]
[-0.0125 .60411 -6 -4.5 ]
[-0.0125 .60411 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18801 0 m
.18801 .00625 L
s
[(5)] .18801 -0.0125 0 1 Mshowa
.35222 0 m
.35222 .00625 L
s
[(10)] .35222 -0.0125 0 1 Mshowa
.51642 0 m
.51642 .00625 L
s
[(15)] .51642 -0.0125 0 1 Mshowa
.68062 0 m
.68062 .00625 L
s
[(20)] .68062 -0.0125 0 1 Mshowa
.84483 0 m
.84483 .00625 L
s
[(25)] .84483 -0.0125 0 1 Mshowa
.125 Mabswid
.05665 0 m
.05665 .00375 L
s
.08949 0 m
.08949 .00375 L
s
.12233 0 m
.12233 .00375 L
s
.15517 0 m
.15517 .00375 L
s
.22085 0 m
.22085 .00375 L
s
.25369 0 m
.25369 .00375 L
s
.28654 0 m
.28654 .00375 L
s
.31938 0 m
.31938 .00375 L
s
.38506 0 m
.38506 .00375 L
s
.4179 0 m
.4179 .00375 L
s
.45074 0 m
.45074 .00375 L
s
.48358 0 m
.48358 .00375 L
s
.54926 0 m
.54926 .00375 L
s
.5821 0 m
.5821 .00375 L
s
.61494 0 m
.61494 .00375 L
s
.64778 0 m
.64778 .00375 L
s
.71346 0 m
.71346 .00375 L
s
.74631 0 m
.74631 .00375 L
s
.77915 0 m
.77915 .00375 L
s
.81199 0 m
.81199 .00375 L
s
.87767 0 m
.87767 .00375 L
s
.91051 0 m
.91051 .00375 L
s
.94335 0 m
.94335 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01393 m
.00625 .01393 L
s
[(-3)] -0.0125 .01393 1 0 Mshowa
0 .11229 m
.00625 .11229 L
s
[(-2)] -0.0125 .11229 1 0 Mshowa
0 .21065 m
.00625 .21065 L
s
[(-1)] -0.0125 .21065 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .40738 m
.00625 .40738 L
s
[(1)] -0.0125 .40738 1 0 Mshowa
0 .50574 m
.00625 .50574 L
s
[(2)] -0.0125 .50574 1 0 Mshowa
0 .60411 m
.00625 .60411 L
s
[(3)] -0.0125 .60411 1 0 Mshowa
.125 Mabswid
0 .0336 m
.00375 .0336 L
s
0 .05327 m
.00375 .05327 L
s
0 .07295 m
.00375 .07295 L
s
0 .09262 m
.00375 .09262 L
s
0 .13196 m
.00375 .13196 L
s
0 .15164 m
.00375 .15164 L
s
0 .17131 m
.00375 .17131 L
s
0 .19098 m
.00375 .19098 L
s
0 .23033 m
.00375 .23033 L
s
0 .25 m
.00375 .25 L
s
0 .26967 m
.00375 .26967 L
s
0 .28934 m
.00375 .28934 L
s
0 .32869 m
.00375 .32869 L
s
0 .34836 m
.00375 .34836 L
s
0 .36803 m
.00375 .36803 L
s
0 .38771 m
.00375 .38771 L
s
0 .42705 m
.00375 .42705 L
s
0 .44673 m
.00375 .44673 L
s
0 .4664 m
.00375 .4664 L
s
0 .48607 m
.00375 .48607 L
s
0 .52542 m
.00375 .52542 L
s
0 .54509 m
.00375 .54509 L
s
0 .56476 m
.00375 .56476 L
s
0 .58443 m
.00375 .58443 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18801 .61178 m
.18801 .61803 L
s
.35222 .61178 m
.35222 .61803 L
s
.51642 .61178 m
.51642 .61803 L
s
.68062 .61178 m
.68062 .61803 L
s
.84483 .61178 m
.84483 .61803 L
s
.125 Mabswid
.05665 .61428 m
.05665 .61803 L
s
.08949 .61428 m
.08949 .61803 L
s
.12233 .61428 m
.12233 .61803 L
s
.15517 .61428 m
.15517 .61803 L
s
.22085 .61428 m
.22085 .61803 L
s
.25369 .61428 m
.25369 .61803 L
s
.28654 .61428 m
.28654 .61803 L
s
.31938 .61428 m
.31938 .61803 L
s
.38506 .61428 m
.38506 .61803 L
s
.4179 .61428 m
.4179 .61803 L
s
.45074 .61428 m
.45074 .61803 L
s
.48358 .61428 m
.48358 .61803 L
s
.54926 .61428 m
.54926 .61803 L
s
.5821 .61428 m
.5821 .61803 L
s
.61494 .61428 m
.61494 .61803 L
s
.64778 .61428 m
.64778 .61803 L
s
.71346 .61428 m
.71346 .61803 L
s
.74631 .61428 m
.74631 .61803 L
s
.77915 .61428 m
.77915 .61803 L
s
.81199 .61428 m
.81199 .61803 L
s
.87767 .61428 m
.87767 .61803 L
s
.91051 .61428 m
.91051 .61803 L
s
.94335 .61428 m
.94335 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01393 m
1 .01393 L
s
.99375 .11229 m
1 .11229 L
s
.99375 .21065 m
1 .21065 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .40738 m
1 .40738 L
s
.99375 .50574 m
1 .50574 L
s
.99375 .60411 m
1 .60411 L
s
.125 Mabswid
.99625 .0336 m
1 .0336 L
s
.99625 .05327 m
1 .05327 L
s
.99625 .07295 m
1 .07295 L
s
.99625 .09262 m
1 .09262 L
s
.99625 .13196 m
1 .13196 L
s
.99625 .15164 m
1 .15164 L
s
.99625 .17131 m
1 .17131 L
s
.99625 .19098 m
1 .19098 L
s
.99625 .23033 m
1 .23033 L
s
.99625 .25 m
1 .25 L
s
.99625 .26967 m
1 .26967 L
s
.99625 .28934 m
1 .28934 L
s
.99625 .32869 m
1 .32869 L
s
.99625 .34836 m
1 .34836 L
s
.99625 .36803 m
1 .36803 L
s
.99625 .38771 m
1 .38771 L
s
.99625 .42705 m
1 .42705 L
s
.99625 .44673 m
1 .44673 L
s
.99625 .4664 m
1 .4664 L
s
.99625 .48607 m
1 .48607 L
s
.99625 .52542 m
1 .52542 L
s
.99625 .54509 m
1 .54509 L
s
.99625 .56476 m
1 .56476 L
s
.99625 .58443 m
1 .58443 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .30902 m
.02381 .30902 L
s
.05665 .30902 m
.05665 .30902 L
s
.08949 .30902 m
.08949 .30902 L
s
.12233 .30902 m
.12233 .30902 L
s
.15517 .30902 m
.15517 .30902 L
s
.18801 .30902 m
.18801 .30902 L
s
.22085 .30902 m
.22085 .30902 L
s
.25369 .30902 m
.25369 .30902 L
s
.28654 .30902 m
.28654 .30902 L
s
.31938 .30902 m
.31938 .30902 L
s
.35222 .30902 m
.35222 .30902 L
s
.38506 .30902 m
.38506 .30902 L
s
.4179 .30902 m
.4179 .30902 L
s
.45074 .30902 m
.45074 .30902 L
s
.48358 .30902 m
.48358 .30902 L
s
.51642 .30902 m
.51642 .30902 L
s
.54926 .30902 m
.54926 .30902 L
s
.5821 .30902 m
.5821 .30902 L
s
.61494 .30902 m
.61494 .30902 L
s
.64778 .30902 m
.64778 .30902 L
s
.68062 .30902 m
.68062 .30902 L
s
.71346 .30902 m
.71346 .30902 L
s
.74631 .30902 m
.74631 .30902 L
s
.77915 .30902 m
.77915 .30902 L
s
.81199 .30902 m
.81199 .30902 L
s
.84483 .30902 m
.84483 .30902 L
s
.87767 .30902 m
.87767 .30902 L
s
.91051 .30902 m
.91051 .30902 L
s
.94335 .30902 m
.94335 .30902 L
s
.97619 .30902 m
.97619 .30902 L
s
.015 w
.02381 .30902 Mdot
.05665 .30902 Mdot
.08949 .30902 Mdot
.12233 .30902 Mdot
.15517 .30902 Mdot
.18801 .30902 Mdot
.22085 .30902 Mdot
.25369 .30902 Mdot
.28654 .30902 Mdot
.31938 .30902 Mdot
.35222 .30902 Mdot
.38506 .30902 Mdot
.4179 .30902 Mdot
.45074 .30902 Mdot
.48358 .30902 Mdot
.51642 .30902 Mdot
.54926 .30902 Mdot
.5821 .30902 Mdot
.61494 .30902 Mdot
.64778 .30902 Mdot
.68062 .30902 Mdot
.71346 .30902 Mdot
.74631 .30902 Mdot
.77915 .30902 Mdot
.81199 .30902 Mdot
.84483 .30902 Mdot
.87767 .30902 Mdot
.91051 .30902 Mdot
.94335 .30902 Mdot
.97619 .30902 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 311.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0001=b000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00=oooool3o`0002?ooooo1Ol0000Rooooo`;o0000
9?ooool5o`0002Gooooo0ol0001Kooooo`?o00008oooool5o`0002;ooooo0_l0000Sooooo`Go0000
9Oooool3o`0002Oooooo000hooooo`03o`000?oooooooooo02?ooooo00Co0000oooooooooooo0000
8Oooool01?l0003oooooooooool0000Tooooo`04o`000?ooooooooooo`0002Kooooo00?o0000oooo
ooooool0Foooool00ol0003oooooooooo`0Sooooo`04o`000?ooooooooooo`00027ooooo00Co0000
oooooooooooo00008oooool01?l0003oooooooooool0000Vooooo`03o`000?oooooooooo02Kooooo
000_ooooo`Go000000?oooooo`000?l000000ol0000Mooooo`Go00000oooool00ol0003ooooooooo
o`0Qooooo`04o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool08oooool5o`0005?ooooo
1Ol000000ooooooo0000o`000003o`0001gooooo1Ol00003ooooo`03o`000?oooooooooo027ooooo
00Co0000oooooooooooo00009?ooool00ol0003oooooooooo`0Sooooo`Go00009oooool003Gooooo
00Co0000oooooooooooo00009oooool00ol0003oooooooooo`0Pooooo`04o`000?ooooooooooo`00
02Kooooo00?o0000ooooooooool08_ooool01?l0003oooooooooool0001Jooooo`04o`000?oooooo
ooooo`0002Oooooo00?o0000ooooooooool08?ooool01?l0003oooooooooool0000Uooooo`03o`00
0?oooooooooo02;ooooo00Co0000oooooooooooo0000:?ooool003Kooooo00?o0000ooooool00000
9?ooool01Ol0003ooooooooooooooooo0000027ooooo00Co0000oooooooooooo00008oooool01Ol0
003ooooooooooooooooo000002Cooooo00?o0000ooooool00000Foooool00ol0003oooooo`00000T
ooooo`05o`000?ooooooooooooooool000008Oooool01?l0003oooooooooool0000Rooooo`05o`00
0?ooooooooooooooool000009?ooool00ol0003oooooo`00000Xooooo`00=oooool2o`0002Cooooo
00Go0000ooooooooooooooooo`00000Qooooo`04o`000?ooooooooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000Uooooo`;o0000G?ooool2o`0002Cooooo00Go0000ooooooooooooooooo`00
000Qooooo`04o`000?ooooooooooo`0002;ooooo00Go0000ooooooooooooooooo`00000Uooooo`;o
0000:?ooool003Sooooo00?o0000ooooooooool08oooool3o`0002?ooooo0_l0000Uooooo`?o0000
9oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo02?ooooo0ol0000Sooooo`;o0000
9?ooool3o`0002Oooooo00?o0000ooooooooool09_ooool00?oooooonOooool00?oooooonOooool0
0?oooooonOooool00?oooooonOooool001coooood_l0000Yooooom;o00003oooool001Kooooo0_l0
0004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00gooooo000Eooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool02?ooool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000Cooooo0ooo
0003ooooo`?oo`001?ooool3ool000?ooooo0ooo000;ooooo`?oo`000oooool3ool000_ooooo0ooo
0003ooooo`?oo`001Oooool00ol0003oooooooooo`03ooooo`?oo`000oooool3ool000[ooooo0ooo
0004ooooo`?oo`002_ooool3ool000Cooooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo
0003ooooo`?oo`001?ooool3ool000Cooooo0ooo0003ooooo`?oo`000oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0IOooool00ol0003ooooooooo
o`0=ooooo`005Oooool01?l0003oooooooooool00003ooooo`?o00002?ooool3ool000Cooooo0ooo
0003ooooo`?oo`001?ooool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000?ooooo0ooo
0005ooooo`03ool00?oooooooooo00?ooooo0ooo0003ooooo`?oo`001Oooool00ooo003ooooooooo
o`03ooooo`?oo`000oooool3ool000Gooooo00?oo`00ooooooooool00oooool3ool000?ooooo0ooo
0005ooooo`03ool00?oooooooooo00;ooooo0ooo0004ooooo`?oo`001Oooool00ooo003ooooooooo
o`02ooooo`?oo`001?ooool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000?ooooo0ooo
0004ooooo`?oo`001?ooool3ool000?ooooo0ooo0002ooooo`;o0000:Oooool00ol0003ooooooooo
o`1Vooooo`03o`000?oooooooooo02_ooooo00?o003oooooooooool0=oooool00ol0003ooooooooo
o`0=ooooo`005Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Sooooo0ooo
0004ooooo`?oo`000oooool3ool000Cooooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo
0003ooooo`?oo`001Oooool00ooo003oooooooooo`03ooooo`?oo`000oooool3ool000Gooooo00?o
o`00ooooooooool00oooool3ool000?ooooo0ooo0005ooooo`03ool00?oooooooooo00?ooooo0ooo
0003ooooo`?oo`001Oooool00ooo003oooooooooo`02ooooo`?oo`001?ooool3ool000Gooooo00?o
o`00ooooooooool00_ooool3ool000Cooooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo
0003ooooo`?oo`001?ooool3ool000Cooooo0ooo0003ooooo`?oo`000oooool00ol0003ooooooooo
o`0Wooooo`;o0000Ioooool00ol0003oooooooooo`0[ooooo`03o`00oooooooooooo03Kooooo0_l0
000?ooooo`005Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`;o003o1Oooool2o`00o`_ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo0_l0
0?l5ooooo`03ool00?oooooooooo00Cooooo00?o003oooooooooool00oooool2o`00o`Gooooo00?o
o`00ooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
o`00ooooooooool00oooool2o`00o`Gooooo00?o003oooooooooool01?ooool00ooo003ooooooooo
o`03ooooo`;o003o1Oooool00ol00?ooooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`;o003o1Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00_ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0IOooool00ol0003ooooooooo
o`0=ooooo`005Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o
003oooooooooool00oooool2o`00o`Cooooo0_l00?l5ooooo`;o003o1Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`03ooooo`;o003o1Oooool00ooo003oooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool00oooool00ooo003oooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool01?ooool00ooo003oooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01?ooool00ooo003oooooooooo`03ooooo`;o003o1Oooool00ol00?oooooooooo
o`04ooooo`03ool00?oooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`03ooooo`;o003o1_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo0_l0
0?l5ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`02ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0I_ooool00ol0003ooooooooo
o`0[ooooo`03o`00oooooooooooo03Oooooo00?o0000ooooooooool03Oooool001Kooooo0_l00004
ooooo`;o00001?ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool00oooool2o`00o`Kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00Cooooo00?oo`00ooooooooool00oooool2o`00o`Gooooo0_l00?l5
ooooo`03ool00?oooooooooo00?ooooo0_l00?l6ooooo`03o`00oooooooooooo00?ooooo00?oo`00
ooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?oo`00
ooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?oo`00
ooooooooool02_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo0_l00?l4
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool2o`00o`Cooooo0_l00?l5
ooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1V
ooooo`03o`000?oooooooooo02_ooooo00?o003oooooooooool0=oooool00ol0003oooooooooo`0=
ooooo`007?ooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Cooooo0_l00?l5oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03oooo
o`03ool00?oooooooooo00?ooooo0_l00?l5ooooo`03o`00oooooooooooo00Cooooo00?oo`00oooo
ooooool00oooool2o`00o`Gooooo00?o003oooooooooool01?ooool00ooo003oooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool00ooo003oooooooooo`03oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ooo003oooooooooo`03oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool2o`00o`Gooooo0_l00?l6oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02oooo
o`;o003o2_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo06Kooooo00?o0000oooo
ooooool0:oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo037ooooo00?o0000oooo
ooooool03Oooool001cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooo003o00Cooooo0_l00?l4ooooo`03o`00oooooooo003o00Kooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`04ooooo`;o003o1?ooool2o`00o`Gooooo0_l00?l5ooooo`03
ool00?oooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`05ooooo`03
ool00?oooooooooo00?ooooo00?o003oooooooooool01?ooool2o`00o`Gooooo00?oo`00oooooooo
ool00oooool2o`00o`Cooooo00?o003oooooool00?l01Oooool00ooo003oooooooooo`03ooooo`;o
003o1Oooool00ol00?ooooooooooo`04ooooo`03ool00?oooooooooo00?ooooo0_l00?l5ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooo003o00Cooooo0_l00?l4ooooo`03o`00oooooooo003o00Kooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo02Oooooo0_l0001Wooooo`03
o`000?oooooooooo02[ooooo00?o003oooooooooool01?ooool2o`00oc7ooooo0_l0000?ooooo`00
7?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l0
1?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`03ooooo`;o003o1?ooool00ol00?ooooooooooo`04ooooo`;o003o
1Oooool00ooo003oooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
0oooool00ooo003oooooooooo`05ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`05oooo
o`03ool00?oooooooooo00?ooooo0_l00?l4ooooo`03o`00oooooooo003o00Gooooo00?oo`00oooo
ooooool00oooool2o`00o`Gooooo0_l00?l5ooooo`03ool00?oooooooooo00?ooooo0_l00?l5oooo
o`03o`00oooooooooooo00?ooooo0_l00?l6ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ool00?l01?ooool2o`00o`Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00;ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`14oooo
o`03o`00oooooooooooo01oooooo00?o0000ooooooooool0:oooool00ol00?ooooooooooo`03oooo
o`;o003o<_ooool00ol0003oooooooooo`0=ooooo`007?ooool2o`0000Gooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooo`00o`04ooooo`;o003o1_ooool00ol00?ooooooooooo`02ooooo`;o
003o1Oooool00ol00?ooooooooooo`04ooooo`03ool00?oooooooooo00?ooooo0_l00?l6ooooo`03
o`00oooooooooooo00?ooooo00?oo`00ooooooooool00oooool00ol00?ooooooo`00o`05ooooo`03
o`00oooooooooooo00?ooooo00?oo`00ooooooooool00oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00Gooooo00?oo`00ooooooooool01Oooool01Ol00?oooooooooooooooooo003o
00Oooooo00?oo`00ooooooooool00oooool2o`00o`Cooooo0_l00?l6ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo
00?ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`14ooooo`03o`00oooooooooooo
01oooooo00?o0000ooooooooool0:_ooool2o`00o`Gooooo0_l00?lbooooo`03o`000?oooooooooo
00gooooo000Looooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01_ooool01Ol00?oo
oooooooooooooooo003o00Kooooo00?o003oooooool00?l01?ooool00ol00?ooooooo`00o`03oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool02_ooool00ooo003oooooooooo`03oooo
o`03o`00oooooooo003o00?ooooo00?o003oooooooooool01Oooool00ooo003oooooooooo`03oooo
o`03o`00oooooooo003o00?ooooo00?o003oooooooooool01Oooool00ooo003oooooooooo`05oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ooo003oooooooooo`03oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool00oooool00ooo003oooooooooo`09oooo
o`03o`00oooooooo003o00Cooooo0_l00?l4ooooo`03o`00oooooooo003o00Kooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`03ooooo`05o`00ooooooooooooooooool00?l00_ooool0
0ol00?ooooooooooo`07ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0A?ooool0
0ol00?ooooooooooo`0Oooooo`03o`000?oooooooooo02[ooooo0_l00?l<ooooo`03o`00oooooooo
oooo02[ooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool01?ooool01?l0
0?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00Go003ooooooooooooooooo
o`00o`02ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`03ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`02ooooo`;o003o1Oooool00ooo
003oooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01Oooool00ooo
003oooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01Oooool00ooo
003oooooooooo`03ooooo`03o`00oooooooo003o00?ooooo00?o003oooooool00?l01Oooool00ooo
003oooooooooo`03ooooo`03o`00oooooooo003o00?ooooo00?o003oooooool00?l01Oooool00ooo
003oooooooooo`03ooooo`;o003o1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`03ooooo`04o`00oooooooooooo
o`00o`?ooooo00Co003ooooooooooooo003o1Oooool01Ol00?oooooooooooooooooo003o00Gooooo
00?o0000ooooooooool09oooool2o`0004Gooooo00?o003oooooooooool07oooool00ol0003ooooo
ooooo`0Zooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0Yooooo`;o00003oooool001cooooo00?o0000ooooooooool01?ooool01?l00?oooooooooo
ool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00Go003oooooooooooooooooo`00o`02oooo
o`03o`00oooooooooooo00[ooooo00Oo003oooooooooooooooooo`00oooooooo003o00Cooooo00?o
003oooooooooool01?ooool2o`00o`Gooooo00?oo`00ooooooooool02Oooool00ol00?ooooooo`00
o`05ooooo`03ool00?oooooooooo00Gooooo00Oo003oooooooooooooooooo`00oooooooo003o00Go
oooo00?oo`00ooooooooool00oooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooo003o00Go
oooo00?oo`00ooooooooool00_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooo003o
00Gooooo00?oo`00ooooooooool00oooool2o`00o`Kooooo00?o003oooooooooool00_ooool00ol0
0?ooooooo`00o`06ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`03ooooo`04o`00oooo
ooooooooo`00o`?ooooo00Co003ooooooooooooo003o0_ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00?ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`14ooooo`03
o`00oooooooooooo01oooooo00?o0000ooooooooool0<Oooool2o`00oc;ooooo00?o0000oooooooo
ool03Oooool001cooooo0_l00005ooooo`03o`00oooooooooooo00Cooooo00Co003ooooooooooooo
003o2Oooool01?l00?ooooooooooool00?l2ooooo`;o003o0_ooool01?l00?ooooooooooool00?l5
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01?ooool2o`00o`Gooooo00?oo`00
ooooooooool00oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00;ooooo00?oo`00
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00ooo
ool00ooo003oooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01_oo
ool00ooo003oooooooooo`06ooooo`04o`00ooooooooooooo`00o`Oooooo00?oo`00ooooooooool0
0oooool2o`00o`Cooooo00?o003oooooool00?l01_ooool01Ol00?oooooooooooooooooo003o00;o
oooo00Co003ooooooooooooo003o1_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00Cooooo00Oo003oooooooooooooooooo`00oooooooo003o00Kooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`14ooooo`03o`00oooooooooooo01oooooo00?o0000ooooooooool0:_oo
ool2o`00o`Gooooo0_l00?l5ooooo`03o`00oooooooooooo02[ooooo00?o0000ooooooooool03Ooo
ool001cooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Cooooo00Go003oooooooooooooooooo`00o`02ooooo`04o`00ooooooooooooo`00o`?ooooo
00?o003oooooooooool01?ooool00ol00?ooooooo`00o`0;ooooo`03ool00?oooooooooo00?ooooo
00?o003oooooool00?l00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?oo`00oooooooo
ool00_ooool01ol00?oooooooooooooooooo003oooooool00?l02?ooool00ooo003oooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`03ooooo`03ool00?oo
oooooooo00;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`03ooooo`03ool00?oo
oooooooo00Wooooo00?o003oooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`04o`00
ooooooooooooo`00o`Kooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`03ooooo`03
o`00oooooooo003o00Cooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo04?ooooo0_l00?lCooooo`03o`00oooooooooooo00_ooooo00?o0000oooooooo
ool00oooool00ol00?ooooooooooo`0Tooooo`;o003o1_ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool08oooool00ol0003oooooooooo`0=ooooo`00
7?ooool00ol0003oooooooooo`05ooooo`;o003o1Oooool2o`00o`Cooooo00?o003oooooool00?l0
1?ooool00ol00?ooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`Kooooo00Co003ooooooooo
oooo003o1Oooool00ol00?ooooooooooo`02ooooo`;o003o1Oooool00ooo003oooooooooo`03oooo
o`03o`00oooooooo003o00?o003o2?ooool00ooo003oooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo0_l00?l3ooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool01_ooool2o`00
o`?ooooo00?o003oooooooooool00oooool00ooo003oooooooooo`02ooooo`07o`00oooooooooooo
ooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00?ooooo00?oo`00ooooooooool00ooo
ool2o`00o`Cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`05o`00oooo
ooooooooooooool00?l00_ooool01ol00?oooooooooooooooooo003oooooool00?l01?ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo0_l00?l7ooooo`03o`000?oooooooooo
02Oooooo0_l00014ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool02oooool00ol0
003oooooooooo`03ooooo`03o`00oooooooooooo02?ooooo00?o003oooooool00?l01Oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool08_ooool2o`00
00oooooo000Looooo`03o`000?oooooooooo00cooooo0_l00?l4ooooo`?o003o1?ooool00ol00?oo
ooooooooo`06ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l2ooooo`05o`00oooooooooooo
ooooool00?l01_ooool2o`00o`Gooooo00?oo`00ooooooooool01_ooool2o`00o`Cooooo00?o003o
ooooooooool00_ooool00ooo003oooooooooo`0<ooooo`03o`00oooooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`;o003o0_ooool00ol00?ooooooooooo`03
ooooo`03ool00?oooooooooo00?ooooo0_l00?l:ooooo`04o`00ooooooooooooo`00o`Wooooo00Oo
003oooooooooooooooooo`00oooooooo003o00Cooooo0_l00?l5ooooo`03o`00oooooooooooo00co
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`13ooooo`;o003o4oooool00ol00?oo
ooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0:oooool2o`00o`co
oooo00?o003oooooooooool08oooool00ol0003oooooooooo`0=ooooo`007?ooool2o`0001[ooooo
0_l00?l4ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool01ol00?oooooo
oooooooooooo003oooooool00?l01?ooool2o`00o`Gooooo00?oo`00ooooooooool00oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ol0
0?ooooooooooo`0<ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool00oooool2o`00
o`Cooooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`05ooooo`?o003o1?ooool2o`00
oa[ooooo00?o0000ooooooooool07_ooool5o`0000Cooooo00?o0000ooooooooool0A?ooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo00oooooo00?o003oooooool00?l01?ooool00ol0
0?ooooooo`00o`04ooooo`;o003o1_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
01gooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool08?ooool2o`00o`Co
oooo00?o003oooooooooool01_ooool01?l00?ooooooooooool00?l;ooooo`03ool00?oooooooooo
00?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`03ooooo`03ool00?oooooooooo
00Wooooo00?o003oooooool00?l00oooool01ol00?oooooooooooooooooo003oooooool00?l01?oo
ool00ol00?ooooooooooo`0Pooooo`03o`000?oooooooooo01oooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`13ooooo`;o003o4oooool00ol00?ooooooooooo`0;ooooo`03o`00
0?oooooooooo00;ooooo0_l00?lCooooo`03o`00oooooooooooo00oooooo00?o003oooooool00?l0
1_ooool00ol00?ooooooooooo`02ooooo`;o003o1Oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo01gooooo00?o0000ooooooooool03Oooool000oooooo0ol00004ooooo`;o00001?oo
ool00ol0003oooooooooo`0Pooooo`;o003o1_ooool01Ol00?oooooooooooooooooo003o00Gooooo
00?o003oooooooooool00_ooool2o`00o`Gooooo00?oo`00ooooooooool00oooool00ol00?oooooo
ooooo`0;ooooo`03ool00?oooooooooo00;ooooo00?o003oooooooooool03?ooool00ooo003ooooo
ooooo`0<ooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00?ooooo00?oo`00ooooooooool00oooool2o`00o`Cooooo
00?o003oooooool00?l00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;ooooo
0_l00?lQooooo`03o`000?oooooooooo01Sooooo1Ol00003ooooo`03o`000?oooooooooo00Cooooo
0_l00014ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool02oooool00ol0003ooooo
ooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool03oooool00ol00?oooooo
o`00o`04ooooo`03o`00oooooooooooo00Cooooo0_l00?l5ooooo`;o003o1Oooool00ol00?oooooo
ooooo`0Looooo`;o00003oooool0013ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo02Kooooo00?o003oooooool00?l00oooool01?l00?oooooo
ooooool00?l7ooooo`;o003o1Oooool00ooo003oooooooooo`0<ooooo`03o`00oooooooooooo00;o
oooo00?oo`00ooooooooool03?ooool00ol00?ooooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`03ooooo`03ool00?oooooooooo00?o
oooo0_l00?l:ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`0Wooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`13ooooo`;o003o4_ooool0
0ol00?ooooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo0_l00?lCooooo`03o`00oooooooo
oooo01Kooooo00?o003oooooool00?l02oooool2o`00o`Gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0Fooooo`03o`000?oooooooooo00gooooo000@ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00000oooool3o`0002Kooooo0_l00?l4ooooo`04o`00oooooooo
ooooo`00o`;ooooo00Oo003oooooooooooooooooo`00oooooooo003o00Gooooo00?oo`00oooooooo
ool00_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ol00?ooooooooooo`0<ooooo`03ool00?oooooooooo017ooooo00?oo`00oooooooo
ool00oooool2o`00o`Oooooo00?o003oooooooooool01?ooool2o`00obOooooo0_l0000Pooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`13ooooo`;o003o4oooool00ol0
0?ooooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool04?ooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooooooo003o00Cooooo00?o003oooooool00?l01?ooool2o`00
o`Kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
01Kooooo00?o0000ooooooooool03Oooool0013ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo02Oooooo00?o003oooooooooool01Oooool01?l0
0?ooooooooooool00?l;ooooo`03ool00?oooooooooo00;ooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`02ooooo`05ool00?ooooooooooooooool00?l03oooool00ooo003ooooooooo
o`08ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`0Vooooo`03o`00
0?oooooooooo01kooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo04Co
oooo00?o003oooooooooool04?ooool2o`00o`gooooo00?o0000ooooooooool00_ooool2o`00oa;o
oooo0_l00?lAooooo`03o`00oooooooo003o00Kooooo00?o003oooooooooool00_ooool2o`00o`co
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Fooooo`03o`000?oooooooooo00go
oooo000@ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`0]ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?o003oooooooooool03?ooool00ooo003o
ooooooooo`02ooooo`03o`00oooooooooooo00cooooo00?oo`00ooooooooool03?ooool00ol00?oo
ooooooooo`02ooooo`05ool00?ooooooooooooooool00?l02Oooool00ol00?ooooooooooo`03oooo
o`03ool00?oooooooooo00;ooooo00?o003oooooool00?l00oooool01ol00?oooooooooooooooooo
003oooooool00?l0;_ooool00ol0003oooooooooo`0Oooooo`?o00001Oooool00ol0003ooooooooo
o`12ooooo`03o`00oooooooooooo01;ooooo0_l00?l=ooooo`03o`000?oooooooooo00;ooooo00?o
003oooooooooool04Oooool2o`00oa7ooooo00?o003oooooool00?l01?ooool00ol00?oooooooooo
o`04ooooo`;o003o1Oooool2o`00o`cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0?ooooo`03o`000?oooooooooo00gooooo000?ooooo`;o00001?ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo02gooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00
o`05ooooo`03ool00?oooooooooo00gooooo00Go003oooooooooooooooooool0000>ooooo`03o`00
oooooooooooo00;ooooo00Goo`00ooooooooooooooooo`00o`0:ooooo`03o`00oooooooooooo00;o
oooo00Goo`00ooooooooooooooooo`00o`09ooooo`03o`00oooooooooooo00?ooooo00?oo`00oooo
ooooool00_ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool0;?ooool00ol0003oooooooooo`0Wooooo`;o0000@oooool00ol00?ooooooooooo`0Boooo
o`03o`00oooooooooooo00cooooo00?o0000ooooooooool00_ooool2o`00oa?ooooo00?o003ooooo
ooooool05_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00?ooooo0_l00?l5oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>oooo
o`;o00003oooool0013ooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l0000^ooooo`;o
003o1?ooool01_l00?ooooooooooool00?ooooooo`00o`Gooooo00?oo`00ooooooooool03Oooool0
1Ol00?ooooooooooooooooooo`0000?ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`02ooooo`05ool00?ooooooooooooooool00?l03oooool00ooo003oooooooooo`0;ooooo`03o`00
oooooooooooo00?ooooo00?oo`00ooooooooool00_ooool01?l00?ooooooooooool00?l6ooooo`?o
003o;_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04;ooooo00?o003oooooool0
0?l04oooool00ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo0_l00?lBooooo`03
o`00oooooooooooo00oooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooo`00o`04oooo
o`03o`00oooooooooooo00Cooooo0_l00?l5ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooooooo00gooooo000Looooo`03
o`000?oooooooooo02kooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l7oooo
o`03ool00?oooooooooo00;ooooo00?o003oooooooooool02?ooool01Ol00?oooooooooooooooooo
o`0000?ooooo00?o003oooooooooool02Oooool01Ol00?ooooooooooooooooooo`0000?ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`02ooooo`03ool00?oooooooooo017ooooo00?o
o`00ooooooooool02?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02gooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`14ooooo`03o`00oooooooooooo00oooooo00?o
003oooooool00?l03Oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o
003oooooooooool03oooool01?l00?ooooooooooool00?l6ooooo`03o`00oooooooooooo00;ooooo
0_l00?l;ooooo`;o003o1Oooool2o`00o`Kooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`09ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo03?ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?o
003oooooooooool03?ooool01Ooo003ooooooooooooooooo003o00oooooo00?oo`00ooooooooool0
3?ooool00ol00?ooooooooooo`02ooooo`05ool00?ooooooooooooooool00?l02_ooool00ol00?oo
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo0_l00?l01Ooooooo003ooooooooooooo003o
03Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`12ooooo`03o`00oooooooo003o
017ooooo00?o003oooooool00?l03Oooool01Ol0003ooooooooooooooooo003o01?ooooo00?o003o
ooooool00?l04?ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooool00?l01?ooool00ol00?ooooooo`00o`0;ooooo`03o`00oooooooooooo00Cooooo0_l0
0?l5ooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool03Oooool001cooooo00?o0000
ooooooooool0<oooool01_l00?ooooooooooool00?ooooooo`00o`Gooooo00?oo`00ooooooooool0
0_ooool00ol00?ooooooooooo`08ooooo`05o`00oooooooooooooooooooo00000oooool00ol00?oo
ooooooooo`09ooooo`05o`00oooooooooooooooooooo00000oooool00ol00?ooooooooooo`09oooo
o`05o`00oooooooooooooooooooo00000oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool01?l00?ooooooooooool00?l2ooooo`03o`00oooo
oooooooo03;ooooo00?o0000ooooooooool09oooool2o`0004?ooooo00?o003oooooooooool04Ooo
ool00ol00?ooooooooooo`0=ooooo`07o`000?ooooooooooooooool00?ooooooo`00o`0Cooooo`03
o`00oooooooooooo01Gooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooo003o00Cooooo0_l00?l5ooooo`;o003o1Oooool00ol00?ooooooooooo`0?oooo
o`;o00003oooool001cooooo0_l0000gooooo`04o`00ooooooooooooo`00o`Cooooo00?oo`00oooo
ooooool03Oooool01Ol00?ooooooooooooooooooo`0000oooooo00Go003oooooooooooooooooool0
0003ooooo`03o`00oooooooooooo00Wooooo00Go003oooooooooooooooooool00003ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool00_ooool00ooo003oooooooooo`02ooooo`04o`00
ooooooooooooo`00ocOooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`12ooooo`03
o`00oooooooo003o01?ooooo00?o003oooooooooool02oooool01ol0003ooooooooooooooooo003o
ooooool00?l04Oooool00ol00?ooooooo`00o`0@ooooo`04o`00ooooooooooooo`00o`?ooooo00Co
003ooooooooooooo003o0oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Cooooo
0_l00?l6ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`03o`00oooooooooooo00Wooooo
00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool0<oooool01?l00?oooooooooo
ool00?l7ooooo`03ool00?oooooooooo00;ooooo00?o003oooooooooool02?ooool01Ol00?oooooo
ooooooooooooo`0000?ooooo00?o003oooooooooool02Oooool01Ol00?ooooooooooooooooooo`00
00?ooooo00?o003oooooooooool03Oooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo
00Gooooo00Co003ooooooooooooo003o=?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo04Cooooo00?o003oooooooooool03oooool00ol00?ooooooo`00o`0=ooooo`03o`000?oooooo
oooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0@ooooo`04o`00oooooooo
ooooo`00o`Kooooo00Oo003oooooooooooooooooo`00oooooooo003o00_ooooo0_l00?l5ooooo`;o
003o1_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool00_ooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`0cooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool00_ooool00ooo003oooooooooo`02ooooo`03o`00
oooooooooooo00cooooo00Goo`00ooooooooooooooooo`00o`0?ooooo`03ool00?oooooooooo00go
oooo00Go003oooooooooooooooooool00003ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool00_ooool00ooo003oooooooooo`08ooooo`03o`00oooooooooooo03;ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`11ooooo`04o`00ooooooooooooo`00oa7ooooo00?o003o
ooooool00?l03Oooool01Ol0003ooooooooooooooooo003o01?ooooo00?o003oooooool00?l04?oo
ool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l0
1?ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00Cooooo0_l00?l5ooooo`;o003o
1Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool0
3Oooool001cooooo00?o0000ooooooooool0<oooool01?l00?ooooooooooool00?l2ooooo`03o`00
oooooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ol00?ooooooooooo`08ooooo`05o`00
oooooooooooooooooooo00000oooool00ol00?ooooooooooo`09ooooo`05o`00oooooooooooooooo
oooo00000oooool00ol00?ooooooooooo`09ooooo`05o`00oooooooooooooooooooo00000oooool0
0ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
1?l00?ooooooooooool00?l2ooooo`03o`00oooooooooooo03;ooooo00?o0000ooooooooool09ooo
ool2o`0000[ooooo00?o003oooooooooool0=Oooool00ol00?ooooooooooo`0Booooo`03o`00oooo
oooooooo00gooooo00Oo0000ooooooooooooooooo`00oooooooo003o01?ooooo00?o003ooooooooo
ool05Oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo0_l00?l<oooo
o`04o`00ooooooooooooooooo`;o00003oooool001cooooo00?o0000ooooooooool0=_ooool01?l0
0?ooooooooooool00?l4ooooo`03ool00?oooooooooo00gooooo00Go003oooooooooooooooooool0
000?ooooo`05o`00oooooooooooooooooooo00000oooool00ol00?ooooooooooo`09ooooo`05o`00
oooooooooooooooooooo00000oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00;o
oooo00?oo`00ooooooooool00_ooool01?l00?ooooooooooool00?lgooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool02?ooool2o`00ocOooooo00Co003ooooooooooooo003o4oooool0
0ol00?ooooooooooo`0;ooooo`04o`000?ooooooooooo`00o`;ooooo00?o003oooooooooool03_oo
ool01?l00?ooooooooooool00?lCooooo`05o`00ooooooooooooooooool00?l00_ooool01Ol00?oo
oooooooooooooooo003o00Kooooo00?o003oooooool00?l01?ooool2o`00o`Kooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Wooooo00?o0000oooo
ooooool03Oooool001cooooo0_l0000dooooo`03o`00oooooooo003o00Sooooo00?oo`00oooooooo
ool00_ooool00ol00?ooooooooooo`08ooooo`05o`00oooooooooooooooooooo00000oooool00ol0
0?ooooooooooo`09ooooo`05o`00oooooooooooooooooooo00000oooool00ol00?ooooooooooo`0=
ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool00_ooool01_l00?ooooooooooool0
0?ooooooo`00ocGooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`08ooooo`;o003o
>_ooool00ol00?ooooooooooo`0>ooooo`04o`00ooooooooooooo`00o`gooooo00?o0000oooooooo
ool00oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo013ooooo00Go003ooooooooo
ooooooooo`00o`06ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`0;ooooo`;o003o1Ooo
ool2o`00o`Kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00?ooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool0=?ooool0
0ol00?ooooooooooo`07ooooo`03ool00?oooooooooo00;ooooo00?o003oooooooooool03?ooool0
1Ooo003ooooooooooooooooo003o00oooooo00?oo`00ooooooooool03Oooool01Ol00?oooooooooo
ooooooooo`0000;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03ool0
0?oooooooooo00Oooooo00?o003oooooooooool0<oooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo00Sooooo0_l00?l5ooooo`03o`00oooooooooooo02oooooo00Co003ooooooooooooo
003o4?ooool01?l00?ooooooooooool00?l=ooooo`04o`000?ooooooooooo`00o`;ooooo00?o003o
ooooooooool03_ooool01?l00?ooooooooooool00?l?ooooo`05o`00ooooooooooooooooool00?l0
1_ooool01ol00?oooooooooooooooooo003oooooool00?l01?ooool00ol00?ooooooo`00o`04oooo
o`03o`00oooooooooooo00Cooooo0_l00?l4ooooo`03o`00oooooooo003o00Cooooo0_l00?l5oooo
o`03o`00oooooooooooo00?ooooo00?o0000ooooooooool03Oooool001cooooo00?o0000oooooooo
ool0=?ooool2o`00o`?ooooo00?o003oooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
o`00oooooooooooo00Wooooo00Co003oooooooooooooo`000oooool00ol00?ooooooooooo`09oooo
o`05o`00oooooooooooooooooooo00000_ooool00ol00?ooooooooooo`0:ooooo`05o`00oooooooo
oooooooooooo00000_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00?o
o`00ooooooooool00_ooool01?l00?ooooooooooooooool2o`00ocGooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo02oooooo00?o003oooooooooool0
4Oooool00ol00?ooooooooooo`0>ooooo`04o`000?ooooooooooo`00oaKooooo00?o003ooooooooo
ool03Oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`03ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo03Go
oooo00Go003oooooooooooooooooo`00o`04ooooo`03ool00?oooooooooo00kooooo00Co003ooooo
ooooooooo`003oooool01Ol00?ooooooooooooooooooo`0000;ooooo00?o003oooooooooool02_oo
ool01Ol00?ooooooooooooooooooo`0000;ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0fooooo`03
o`000?oooooooooo02Oooooo0_l0000:ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool0;oooool01?l00?ooooooooooool00?lCooooo`03o`00oooooooooooo00_ooooo00Co0000oooo
oooooooo003o0_ooool00ol00?ooooooooooo`0>ooooo`04o`00ooooooooooooo`00oaKooooo00Go
003oooooooooooooooooo`00o`09ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooool0
0?l01_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool02Oooool2o`0000oooooo000Looooo`;o0000=Oooool2o`00o`?ooooo00?o003oooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03o`00oooooooooooo00Wooooo00Co003ooooooooooooo
o`000_ooool00ol00?ooooooooooo`0;ooooo`04o`00ooooooooooooool000;ooooo00?o003ooooo
ooooool03_ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`0fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02?ooool2
o`00o`Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0[ooooo`03o`00oooooooo
oooo00kooooo00Co003ooooooooooooo003o3Oooool00ol0003oooooooooo`03ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool04?ooool01Ol00?oooooooooooooooooo003o00;ooooo
00Go003oooooooooooooooooo`00o`02ooooo`04o`00ooooooooooooo`00o`Kooooo00Oo003ooooo
ooooooooooooo`00oooooooo003o00Kooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`02ooooo`;o003o2oooool00ol0003oooooooooo`0=ooooo`003_ooool5o`0000?ooooo0_l00004
ooooo`03o`000?oooooooooo03kooooo00?oo`00ooooooooool00_ooool00ol00?ooooooooooo`09
ooooo`04o`00ooooooooooooool000;ooooo00?o003oooooooooool03_ooool01?oo003ooooooooo
ool00?l<ooooo`05o`00oooooooooooooooooooo00000_ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00;ooooo00?oo`00ooooooooool0?Oooool00ol0003oooooooooo`0Oooooo`?o
00001Oooool00ol0003oooooooooo`08ooooo`;o003o1Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo02Oooooo00Go003oooooooooooooooooo`00o`0@ooooo`04o`00oooooooooooo
o`00o`gooooo00Co0000oooooooooooo003o0_ooool00ol00?ooooooooooo`0=ooooo`05o`00oooo
ooooooooooooool00?l03oooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003ooooooooo
ooooooooo`00o`02ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Cooooo00?o003oooooool00?l01?ooool2
o`00o`Gooooo00?o003oooooooooool00oooool00ol0003oooooooooo`0=ooooo`003oooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0>Ooo
ool00ol00?ooooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o003oooooooooool03?oo
ool01?oo003oooooooooool00?l=ooooo`04o`00ooooooooooooool000oooooo00Go003ooooooooo
ooooooooool00002ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03o`00oooooooooooo03Sooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool04Oooool00ol0
0?ooooooooooo`0?ooooo`04o`000?ooooooooooo`00oaKooooo00?o003oooooooooool03Oooool0
1Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool01?ooool01?l00?oooooooooo
ool00?l3ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`03ooooo`03o`000?oooooooooo00gooooo000@ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0iooooo`03o`00oooooooooooo00;o
oooo00?oo`00ooooooooool03_ooool01?l00?oooooooooooooo000@ooooo`04o`00oooooooooooo
ool000;ooooo00?o003oooooooooool02oooool01?l00?oooooooooooooo0002ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool00_ooool00ooo003oooooooooo`02ooooo`03o`00oooo
oooooooo03Sooooo00?o0000ooooooooool06?ooool5o`0000?ooooo00?o0000ooooooooool01?oo
ool2o`0000[ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo02Oooooo00Go003oooooooooooooooooo`00o`06ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool03oooool00ol0003oooooo`00o`03ooooo`03o`00oooooooooooo00gooooo
00Go003oooooooooooooooooo`00o`0Fooooo`05o`00ooooooooooooooooool00?l02Oooool01?l0
0?ooooooooooool00?l3ooooo`03o`00oooooooo003o00Cooooo00?o003oooooool00?l01?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool2
o`0000oooooo000Aooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooooooo
ool3o`0003Wooooo00?o003oooooooooool00_ooool01Ooo003ooooooooooooooooo003o00cooooo
00Co003oooooooooooooo`000_ooool00ol00?ooooooooooo`0;ooooo`04o`00ooooooooooooool0
00;ooooo00?o003oooooooooool03_ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo
00;ooooo00?o003oooooooooool0=oooool2o`0002;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`08ooooo`;o003o1Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00?ooooo0_l00?lVooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`0Aooooo`05o`00ooooooooooooooooool00?l00_ooool01Ol00?oooooooooooooo
oooo003o00;ooooo00Co003ooooooooooooo003o1_ooool01ol00?oooooooooooooooooo003ooooo
ool00?l01_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo0_l00?l;oooo
o`03o`000?oooooooooo00gooooo000>ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo03kooooo00Goo`00ooooooooooooooooo`00
o`0<ooooo`04o`00ooooooooooooool000;ooooo00?o003oooooooooool03_ooool01?oo003ooooo
ooooool00?l=ooooo`04o`00ooooooooooooool000;ooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`02ooooo`03ool00?oooooooooo03gooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo0_l00?l4ooooo`;o003o1Oooool2o`00
o`Gooooo0_l00?lRooooo`05o`00ooooooooooooooooool00?l01_ooool00ol00?ooooooooooo`06
ooooo`05o`00ooooooooooooooooool00?l03Oooool00ol0003oooooo`00o`03ooooo`03o`00oooo
oooooooo00gooooo00Go003oooooooooooooooooo`00o`0?ooooo`05o`00ooooooooooooooooool0
0?l01_ooool01?l00?ooooooooooool00?l2ooooo`05o`00ooooooooooooooooool00?l01_ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Cooooo00?o003oooooool00?l01?ooool2
o`00o`Gooooo00?o003oooooooooool00oooool00ol0003oooooooooo`0=ooooo`003_ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`0iooooo`03o`00oooooooooooo00;ooooo00Goo`00ooooooooooooooooo`00o`0?ooooo`04ool0
0?ooooooooooo`00oa3ooooo00?oo`00ooooooooool03_ooool01?l00?oooooooooooooo0002oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03o`00oooooooooooo03Sooooo00?o0000ooooooooool07oooool2o`0000Kooooo00?o0000oooo
ooooool01oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool00oooool2o`00ob;ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`07oooo
o`05o`00ooooooooooooooooool00?l01_ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooo
003o00[ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00;ooooo00Co003ooooooooooooo003o1_ooool01?l00?ooooooooooool00?l3ooooo`04o`00
ooooooooooooo`00o`[ooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`05ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol0003oooooooooo`0=ooooo`00
3oooool3o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo03Wooooo00?o003oooooooooool0
0_ooool00ooo003oooooooooo`0>ooooo`04o`00ooooooooooooool0013ooooo00Co003ooooooooo
ooooo`000_ooool00ol00?ooooooooooo`0;ooooo`06o`00ooooooooooooool00?oooooo003o3?oo
ool00ol00?ooooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o003oooooooooool0>?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Cooooo0_l0000:ooooo`03o`00oooo
oooooooo00;ooooo0_l00?l5ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Sooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooo003o00?ooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`06ooooo`05o`00ooooooooooooooooool0
0?l05_ooool01Ol00?oooooooooooooooooo003o00Wooooo00Co003ooooooooooooo003o0oooool0
0ol00?ooooooo`00o`04ooooo`03o`00oooooooo003o00?ooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo0_l0000?ooooo`007?ooool2o`00
03[ooooo00?o003oooooooooool00_ooool01Ooo003ooooooooooooooooo003o00cooooo00Co003o
ooooooooooooo`000_ooool00ol00?ooooooooooo`0;ooooo`04o`00ooooooooooooool000;ooooo
00?o003oooooooooool03_ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo00;ooooo
00?o003oooooooooool0>?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Oooooo
00?o003oooooool00?l01?ooool2o`00o`Gooooo0_l00?l5ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool07_ooool00ol00?ooooooooooo`03ooooo`;o003o3?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?oooooo
ooooo`03ooooo`;o003o2?ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooool00?l01?ooool00ol00?ooooooo`00o`0:ooooo`07o`00ooooooooooooooooool0
0?ooooooo`00o`06ooooo`03o`00oooooooooooo00Cooooo00Oo003oooooooooooooooooo`00oooo
oooo003o00_ooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool0?_ooool0
1Ooo003ooooooooooooooooo003o00cooooo00Co003oooooooooooooo`000_ooool00ol00?oooooo
ooooo`0;ooooo`04o`00ooooooooooooool000;ooooo00?o003oooooooooool02oooool01_l00?oo
oooooooooooo003oooooo`00oa7ooooo00?oo`00ooooooooool0?Oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo00Oooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`03
ooooo`;o003o1Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`06ooooo`05o`00ooooooooooooooooool00?l01Ooo
ool2o`00o`Kooooo00?o0000o`00ooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`03ooooo`04o`00oooo
ooooooooo`00o`Kooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool00?l3oooo
o`04o`00ooooooooooooo`00o`?ooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`04
ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo03Wooooo00?o003ooooo
ooooool00_ooool01Ooo003ooooooooooooooooo003o00oooooo00?oo`00ooooool00?l04Oooool0
0ooo003oooooooooo`0>ooooo`06o`00ooooooooooooool00?oooooo003o3Oooool01Ol00?oooooo
ooooooooooooo`0000Cooooo00?o003oooooooooool0>?ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00Oooooo00?o003oooooooooool01?ooool2o`00o`Kooooo00?o003ooooooooo
ool00oooool2o`00o`Gooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00gooooo00Go003oooooooooooooooooo`00o`0=ooooo`03o`000?l00?oooooo
00Wooooo0_l00?l7ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooo003o00Kooooo00Go003oooooooooooooooooo`00o`02
ooooo`05o`00ooooooooooooooooool00?l02Oooool00ol00?ooooooooooo`04ooooo`04o`00oooo
ooooooooo`00o`Gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00
0?oooooooooo00gooooo000Looooo`03o`000?oooooooooo03Wooooo00?o003oooooooooool00_oo
ool00ooo003oooooooooo`0?ooooo`03o`00ooooooooo`00013ooooo00Ko003oooooooooooooo`00
ooooool00?l>ooooo`06o`00ooooooooooooool00?oooooo003o3Oooool01Ol00?oooooooooooooo
ooooo`0000Cooooo00?o003oooooooooool0>?ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00Wooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo01;ooooo00?o003oooooooooool01oooool00ol00?ooooooo`00o`07ooooo`03o`00oooo
oooooooo00Sooooo0_l00?l6ooooo`03o`000?l00?oooooo00?ooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo
003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`06
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`0=
ooooo`007?ooool2o`0003[ooooo00?o003oooooooooool00_ooool00ooo003oooooooooo`0?oooo
o`05o`00ooooooooo`00ooooool00?l03_ooool01_l00?oooooooooooooo003oooooo`00oa7ooooo
00?oo`00ooooooooool03Oooool01Ol00?ooooooooooooooooooo`0000Cooooo00?o003ooooooooo
ool0>?ooool00ol0003oooooooooo`0Wooooo`;o00002?ooool00ol00?ooooooo`00o`04ooooo`;o
003o1Oooool2o`00o`Gooooo0_l00?l5ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool0
0?l03?ooool00ol00?ooooooooooo`03ooooo`;o003o1_ooool00ol0003oooooooooo`03ooooo`03
o`00oooooooooooo00?ooooo0_l00?l7ooooo`03o`00oooooooooooo017ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooo003o00Kooooo00Go003ooooooooo
ooooooooo`00o`02ooooo`04o`00ooooooooooooo`00o`Kooooo00?o003oooooooooool01?ooool0
1ol00?oooooooooooooooooo003oooooool00?l02_ooool2o`0000oooooo000Looooo`03o`000?oo
oooooooo03kooooo00Goo`00ooooooooooooooooo`00o`0=ooooo`05o`00ooooooooo`00ooooool0
0?l03oooool01Ol00?ooooooool00?oooooo003o00oooooo00Go003ooooooooo003oooooo`00o`0A
ooooo`03ool00?oooooooooo03gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`07
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool00oooool2o`00o`Gooooo00?o003o
ooooooooool02_ooool2o`00oaWooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`07
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00oooool2o`00o`Kooooo00?o0000
o`00ooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool01?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00Oooooo00Co003o
oooooooooooo003o0oooool01?l00?ooooooooooool00?l6ooooo`07o`00ooooooooooooooooool0
0?ooooooo`00o`04ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool03Oooool001co
oooo00?o0000ooooooooool0>Oooool00ol00?ooooooooooo`02ooooo`05ool00?oooooooooooooo
ool00?l03oooool00ooo003oooooo`00o`0Aooooo`03ool00?oooooooooo00oooooo00Go003ooooo
oooo003oooooo`00o`0=ooooo`05o`00oooooooooooooooooooo00000oooool00ol00?oooooooooo
o`0iooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01oooool00ol00?oooooooooo
o`04ooooo`;o003o1_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Cooooo0_l0
0?l<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02oooool00ol0003o003ooooo
o`08ooooo`03o`00oooooooo003o00Oooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`03ooooo`;o003o1_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Kooooo00Go
003oooooooooooooooooo`00o`02ooooo`05o`00ooooooooooooooooool00?l02Oooool00ol00?oo
ooooooooo`04ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`04ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo03Wo
oooo00?o003oooooooooool00_ooool01Ooo003ooooooooooooooooo003o00gooooo00?o003ooooo
oooo00004Oooool01Ol00?ooooooool00?oooooo003o00oooooo00Go003ooooooooo003oooooo`00
o`0=ooooo`05o`00oooooooooooooooooooo00000oooool00ol00?ooooooooooo`0iooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`;o003o
1Oooool2o`00o`Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`04o`00
ooooooooooooo`00o`Oooooo00?o003oooooooooool01oooool00ol00?ooooooo`00o`06ooooo`03
o`000?l00?oooooo00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00?ooooo0_l00?l>ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00oooool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00Go003o
ooooooooooooooooo`00o`02ooooo`05o`00ooooooooooooooooool00?l01_ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool03Oooool001cooooo0_l0
000jooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool03oooool00ol00?ooooooool0
000Aooooo`05o`00ooooooooo`00ooooool00?l03oooool01Ol00?ooooooool00?oooooo003o00go
oooo00Go003oooooooooooooooooool00003ooooo`03o`00oooooooooooo03Wooooo00?o0000oooo
ooooool09oooool2o`0000Oooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooo`00o`04
ooooo`03o`00oooooooo003o00Cooooo00?o003oooooool00?l01?ooool2o`00o`Gooooo0_l00?l5
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00;ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooo003o00Kooooo00?o0000o`00ooooool00oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooo003o00Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`04ooooo`03o`00oooo
oooo003o00Kooooo00Go003oooooooooooooooooo`00o`02ooooo`04o`00ooooooooooooo`00o`Ko
oooo00Go003oooooooooooooooooo`00o`02ooooo`07o`00ooooooooooooooooool00?ooooooo`00
o`0:ooooo`;o00003oooool001cooooo00?o0000ooooooooool0?_ooool01Ooo003ooooooooooooo
oooo003o00gooooo00Go003ooooooooo003oooooo`00o`0?ooooo`05o`00ooooooooo`00ooooool0
0?l04Oooool00ooo003oooooooooo`0Aooooo`05ool00?ooooooooooooooool00?l0>oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo00Kooooo00Co003ooooooooooooo003o1Oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool02oooool2
o`00o`Gooooo00?o003oooooooooool04Oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooool00?l01_ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00?ooooo00?o
003oooooooooool01_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003ooooooooooooo
ooooo`00o`06ooooo`04o`00ooooooooooooo`00o`;ooooo00Go003oooooooooooooooooo`00o`07
ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo03[ooooo00Go003ooooo
ooooooooooooool00003ooooo`03o`00oooooooooooo00gooooo00?oo`00ooooool00?l04Oooool0
0ooo003oooooooooo`0?ooooo`04o`00ooooooooo`00o`00o`kooooo00Go003ooooooooooooooooo
ool0000oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01_ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooo003o00Cooooo00?o003oooooool00?l01?ooool00ol00?oooooo
o`00o`04ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooool00?l01_ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00?ooooo0_l00?l6ooooo`03o`00oooooooooooo00?ooooo
0_l00?l6ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01?ooool00ol00?oooooo
ooooo`06ooooo`05o`00ooooooooooooooooool00?l00_ooool01Ol00?oooooooooooooooooo003o
00;ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`05ooooo`03o`000?oooooo
oooo00gooooo000Looooo`03o`000?oooooooooo03[ooooo00Go003oooooooooooooooooool00003
ooooo`03o`00oooooooooooo00cooooo00Co003oool00?oooooo003o3oooool01?l00?ooooooool0
0?l00?l@ooooo`04o`00ooooooooo`00o`00o`kooooo00Go003oooooooooooooooooool00003oooo
o`03o`00oooooooooooo03Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0=oooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool00_ooool2o`00o`Gooooo0_l00?l5oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`06oooo
o`05o`00ooooooooooooooooool00?l01_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00?ooooo0_l00?l=ooooo`03o`00oooooooooooo00Wooooo00?o003oooooool00?l01?ooool0
0ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`Kooooo00Go003ooooooooooooooooo
o`00o`05ooooo`05o`00ooooooooooooooooool00?l01oooool00ol0003oooooooooo`0=ooooo`00
7?ooool2o`0003_ooooo00Go003oooooooooooooooooool0000Booooo`03o`00oooo003ooooo013o
oooo00Co003ooooooooo003o003o4?ooool01?l00?ooooooool00?l00?l>ooooo`05o`00oooooooo
oooooooooooo00000oooool00ol00?ooooooooooo`0iooooo`03o`000?oooooooooo02Oooooo0_l0
0007ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooool00?l01?ooool00ol00?oooooo
o`00o`04ooooo`03o`00oooooooo003o00Cooooo0_l00?l5ooooo`;o003o1Oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool01?l00?oooooo
ooooool00?l3ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooo`00o`06ooooo`03o`00oooooooooooo00?ooooo00Go003oooooooooooooooooo`00o`02oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`02oooo
o`;o003o1oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo0_l00?l6oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooool00?l00oooool00ol00?ooooooooooo`04oooo
o`04o`00ooooooooooooo`00o`Kooooo00?o003oooooooooool02oooool2o`0000oooooo000?oooo
o`?o00001?ooool2o`0000Cooooo00?o0000ooooooooool0>_ooool01Ol00?oooooooooooooooooo
o`0000?ooooo00?o003oooooooooool03?ooool00ol00?ooo`00o`00o`0Aooooo`03o`00oooo003o
003o01;ooooo00?oo`00ooooooooool04Oooool01Ooo003ooooooooooooooooo003o03_ooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`06ooooo`04o`00ooooooooooooo`00o`Gooooo
00?o003oooooooooool00_ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool00oooool2o`00o`Gooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0:ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01_ooool00ol0003o
ooooooooo`03ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo00Cooooo0_l00?l4ooooo`03o`00oooooooooooo00Kooooo00Go003ooooo
ooooooooooooo`00o`02ooooo`05o`00ooooooooooooooooool00?l01_ooool01?l00?oooooooooo
ool00?l2ooooo`05o`00ooooooooooooooooool00?l01oooool00ol0003oooooooooo`0=ooooo`00
3_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`0nooooo`05ool00?ooooooooooooooool00?l03_ooool00ol00?ooo`00o`00o`0B
ooooo`03ool00?oooooooooo013ooooo00?o003oool00?l00?l03_ooool01Ol00?oooooooooooooo
ooooo`0003oooooo00?o0000ooooooooool08?ooool2o`0000Gooooo00?o0000ooooooooool01_oo
ool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooo003o00Cooooo00?o003oooooool00?l0
1?ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00?ooooo00Go003ooooooooooooo
ooooo`00o`09ooooo`03o`00oooooooooooo00?ooooo00Go003oooooooooooooooooo`00o`09oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`;o003o1?ooool00ol00?ooooooo`00o`06oooo
o`03o`00oooooooooooo00Cooooo00Go003oooooooooooooooooo`00o`02ooooo`05o`00oooooooo
ooooooooool00?l00_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00Gooooo
00?o0000ooooooooool03Oooool001;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooo
oooooooooooo000003cooooo00Go003oooooooooooooooooool00003ooooo`03o`00oooooooooooo
00cooooo0ooo000Aooooo`?oo`004Oooool3ool000kooooo00Go003oooooooooooooooooool00003
ooooo`03o`00oooooooooooo03Wooooo00?o0000ooooooooool07oooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`02ooooo`;o003o3?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01_ooool01Ol00?oooooooooooooooooo003o00Kooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Kooooo00?o003oooooooooool0
0oooool2o`00o`_ooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`03ooooo`04o`00
ooooooooooooo`00o`Kooooo00Go003oooooooooooooooooo`00o`05ooooo`05o`00oooooooooooo
ooooool00?l01oooool00ol0003oooooooooo`0=ooooo`004?ooool2o`0000?ooooo00Co0000oooo
oooooooo00000oooool3o`0003[ooooo00Go003oooooooooooooooooool0000Booooo`?oo`004Ooo
ool3ool0017ooooo0ooo000>ooooo`05o`00oooooooooooooooooooo00000oooool00ol00?oooooo
ooooo`0hooooo`;o00008Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Go
oooo00?o003oooooooooool00ooo00000ooooooo003oooooo`03ool000;ooooo00?o003ooooooooo
00000_oo0002ooooo`04o`00oooo003oo`00ool000?ooooo00Co003oool00?oo003oo`000oooool0
1?l00?ooo`00ool00?oo0003ooooo`?oo`001?ooool3ool000Cooooo0ooo0003ooooo`?oo`0000Co
ooooo`00oooooooooooo0ooo0004ooooo`?oo`000oooool3ool000;ooooo00?o003ooooooooo0000
0_oo0003ooooo`?oo`001?ooool3ool000;ooooo00?o003ooooooooo00000_oo0003ooooo`?oo`00
1?ooool3ool000?ooooo00Co003oool00?oo003oo`000oooool3ool000Cooooo0ooo0004ooooo`?o
o`000oooool3ool00004o`00ooooooooooooooooo`?oo`0000?o003oooooooooool00ooo0004oooo
o`?oo`0000Coooooo`00oooooooooooo0ooo00000ooooooo003oooooo`03ool000Cooooo0ooo0003
ooooo`03o`000?oooooooooo00gooooo000Booooo`04o`000?ooooooooooo`0000;ooooo00Go0000
ooooooooooooooooo`00000looooo`05o`00oooooooooooooooooooo00000oooool00ol00?oooooo
ooooo`0<ooooo`?oo`004Oooool3ool0017ooooo0ooo000Booooo`05ool00?ooooooooooooooool0
0?l0>oooool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`0000Cooooo2?l000000ol0
0?oo0000o`000003ool000?o00000ooo0002o`000003o`00ool0003oo`0000;oo`000_l000001?l0
0?ooo`00ool00?oo0004o`0000?oo`000ol000001?l00?ooo`00ool00?oo0003o`0000?oo`001?l0
0003ool000Co00000ooo0003o`0000?oo`0000Co003oo`000?l0003o00000ooo0004o`0000?oo`00
0ol00003ool000;o000000?o003oo`000?oo00000_oo0003o`0000?oo`001?l00003ool000;o0000
00?o003oo`000?oo00000_oo0003o`0000?oo`001?l00003ool000?o000000Co003oool00?oo003o
o`000ol00003ool000Co00000ooo0004o`0000?oo`000ol00003ool000Co00000ooo00000ol00?oo
0000o`000003ool00004o`000?l00?oo0000o`0000?oo`001?l00003ool00003o`000?l00?oo0000
00?oo`001?l00003ool000Co00003oooool000kooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0?_ooool01Ooo003ooooooooooooo
oooo003o02?ooooo00?o0000ooooooooool08Oooool01Ol00?ooooooooooooooooooo`0003oooooo
00?o0000ooooooooool07oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Go
oooo00?o003oooooooooool00ooo00000ooooooo003oooooo`03ool000;ooooo00?o003ooooooooo
00000_oo0002ooooo`04o`00oooo003oo`00ool000?ooooo00Co003oool00?oo003oo`000oooool0
1?l00?ooo`00ool00?oo0003ooooo`?oo`001?ooool3ool000Cooooo0ooo0003ooooo`?oo`001?oo
ool3ool000Cooooo0ooo0003ooooo`?oo`0000Coooooo`00oooooooooooo0ooo0003ooooo`?oo`00
1?ooool3ool00004ooooool00?ooooooooooo`?oo`000oooool3ool000Cooooo0ooo0004ooooo`?o
o`000oooool3ool000Cooooo0ooo0004ooooo`?oo`000oooool3ool00004o`00oooooooooooooooo
o`?oo`0000?o003oooooooooool00ooo00001?oooooo003oooooooooool3ool00004o`00oooooooo
ooooooooo`?oo`0000?o003oooooooooool00ooo00001?oooooo003oooooooooool3ool000?ooooo
00?o0000ooooooooool03Oooool000oooooo0ol00004ooooo`;o00001?ooool00ol0003ooooooooo
o`0jooooo`05o`00oooooooooooooooooooo00000_ooool00ol00?ooooooooooo`0Rooooo`03o`00
0?oooooooooo027ooooo00Go003oooooooooooooooooool00003ooooo`03o`00oooooooooooo03Wo
oooo00?o0000ooooooooool07oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Cooooo00Oo003oooooooooooooooooo`00oooooooo003o00_ooooo0_l00?l6ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00ool0
003ooooo00_ooooo00?o003oooooooooool02_ooool01Ol00?oooooooooooooooooo003o00;ooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool00oooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooool00?l01_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?ooooo
00Co003ooooooooooooo003o2?ooool00ol0003oooooooooo`0=ooooo`007?ooool2o`0003_ooooo
00Go003oooooooooooooooooool0000Wooooo`03o`000?oooooooooo027ooooo00Go003ooooooooo
ooooooooool00003ooooo`03o`00oooooooooooo03Wooooo00?o0000ooooooooool08?ooool2o`00
00Gooooo00?o0000ooooooooool02Oooool01?l00?ooooooooooool00?l2ooooo`05o`00oooooooo
ooooooooool00?l01_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooo003o00Cooooo
00?o003oooooool00?l01?ooool00ol00?ooooooooooo`04ooooo`;o003o1Oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool03Oooool01Ol00?oooooo
oooooooooooo003o00Gooooo00?o003oo`000?ooool01?ooool01?l00?ooooooooooool00?l3oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool01Ol00?oooooooooooooooooo
003o00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00?ooooo0_l00?l4ooooo`03o`00oooooooo003o00Cooooo00?o003oooooool00?l01_ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool03Oooool0
01cooooo00?o0000ooooooooool0>_ooool01Ol00?ooooooooooooooooooo`0000;ooooo00?o003o
ooooooooool08_ooool00ol0003oooooooooo`0Uooooo`05ool00?ooooooooooooooool00?l0>ooo
ool00ol0003oooooooooo`0Wooooo`;o00001_ooool01Ol00?oooooooooooooooooo003o00Gooooo
00Go003oooooooooooooooooo`00o`02ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooo003o00Cooooo0_l00?l5ooooo`;o003o3?ooool00ol0
0?ooooooo`00o`04ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool01?l0
0?ooooooooooool00?l3ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool0
1?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02?oo
ool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo0_l00?l4ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`03ooooo`03o`00
oooooooooooo00Sooooo0_l0000?ooooo`007?ooool00ol0003oooooooooo`0nooooo`04ool00?oo
ooooooooo`00obCooooo00?o0000ooooooooool08Oooool01Ol00?ooooooooooooooooooo`0003oo
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`05ooooo`05o`00oooooooooooooooo
ool00?l00_ooool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`?ooooo00Co
003ooooooooooooo003o0oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Gooooo
00?o003oooooooooool00oooool2o`00o`Gooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool01?l00?oooooo
ooooool00?l9ooooo`03o`00ool0003ooooo00Cooooo00?o003oooooool00?l02_ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool2o`00o`Ko
oooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooo003o00Co
oooo00?o003oooooool00?l00oooool01?l00?ooooooooooool00?l8ooooo`03o`000?oooooooooo
00gooooo000Looooo`03o`000?oooooooooo03[ooooo00Go003oooooooooooooooooool00002oooo
o`03o`00oooooooooooo02;ooooo00?o0000ooooooooool08Oooool01Ol00?oooooooooooooooooo
o`0000?ooooo00?o003oooooooooool0>Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`07ooooo`05o`00oooooooo
ooooooooool00?l00_ooool01ol00?oooooooooooooooooo003oooooool00?l02oooool2o`00o`co
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool02_ooool00ol00?oo0000ooooo`0;ooooo`03o`00oooooooooooo00[o
oooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo0_l00?l5oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o2?ooool00ol0003oooooooooo`0=
ooooo`007?ooool2o`0003_ooooo00Go003oooooooooooooooooool0000Wooooo`03o`000?oooooo
oooo02;ooooo00Co003oooooooooooooo`000oooool00ol00?ooooooooooo`0iooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool02Oooool01?l00?ooooooooooool00?l6ooooo`03o`00
oooooooooooo00Oooooo00Oo003oooooooooooooooooo`00oooooooo003o00Cooooo00?o003ooooo
ool00?l01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00?o003oo`00
0?ooool01?ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool01Oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool04Oooool0
0ol00?ooooooooooo`03ooooo`;o003o1Oooool2o`00o`Cooooo00?o003oooooool00?l01?ooool0
0ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01_ooool0
0ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`0jooooo`05o`00oooooooooooo
oooooooo00000_ooool00ol00?ooooooooooo`0Rooooo`03o`000?oooooooooo02;ooooo00Co003o
ooooooooooooo`000oooool00ol00?ooooooooooo`0iooooo`03o`000?oooooooooo02Oooooo0_l0
0006ooooo`05o`00ooooooooooooooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00;o
oooo00Co003ooooooooooooo003o2Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o
00?ooooo00?o003oooooool00?l01Oooool2o`00o`cooooo0_l00?l5ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool00oooool2o`00o`Cooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooo003o00?ooooo00?o003oooooooooool02?ooool2o`00
00oooooo000Looooo`03o`000?oooooooooo03kooooo00Coo`00oooooooooooo003o9?ooool00ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo03gooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`05ooooo`05o`00ooooooooooooooooool00?l01Oooool01?l00?ooooooooooool0
0?l3ooooo`04o`00ooooooooooooo`00o`Kooooo00?o003oooooooooool01?ooool01?l00?oooooo
ooooool00?l5ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo000000Go
oooo00?o003oooooool00?l02Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Co
oooo00?o003oooooool00?l01?ooool00ol00?ooooooo`00o`03ooooo`04o`00ooooooooooooo`00
o`Sooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool0>_ooool01Ol00?oo
ooooooooooooooooo`0000;ooooo00?o003oooooooooool08_ooool00ol0003oooooooooo`0Roooo
o`04o`00ooooooooooooool000?ooooo00?o003oooooooooool0>Oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool01?ooool01Ol00?oooooooooooooo
oooo003o00Kooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool00?l2ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Cooooo0_l00?l:ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooo`00000<ooooo`03o`00oooooooooooo00[ooooo00Co003ooooooooo
oooo003o0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool00oooool2o`00o`Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l8
ooooo`03o`000?oooooooooo00gooooo000Looooo`;o0000>oooool01Ol00?oooooooooooooooooo
o`0000;ooooo00?o003oooooooooool08_ooool00ol0003oooooooooo`0Rooooo`04o`00oooooooo
ooooool000?ooooo00?o003oooooooooool0>Oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00Wooooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`08ooooo`04o`00oooo
ooooooooo`00o`;ooooo00Go003oooooooooooooooooo`00o`02ooooo`05o`00oooooooooooooooo
ool00?l02?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo000000Gooooo0_l00?l5oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool01?l00?ooooooooooool00?l3
ooooo`03o`00oooooooooooo01Oooooo0_l00?l5ooooo`;o003o1?ooool00ol00?ooooooo`00o`04
ooooo`;o003o1_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Oooooo00?o0000
ooooooooool03Oooool001cooooo00?o0000ooooooooool0>_ooool01Ol00?oooooooooooooooooo
o`0002Oooooo00?o0000ooooooooool08_ooool01?l00?oooooooooooooo0003ooooo`03o`00oooo
oooooooo03Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`04o`00
ooooooooooooo`00o`?ooooo00?o003oooooooooool00oooool01Ol00?oooooooooooooooooo003o
00;ooooo00Oo003oooooooooooooooooo`00oooooooo003o00Cooooo00?o003oooooool00?l01?oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02_oo
ool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00ooo
ool2o`00o`Gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooo003o00Wooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`04ooooo`;o003o1?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo0_l00?l4ooooo`03o`00oooo
oooooooo00Wooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool0?_ooool0
1?oo003oooooooooool00?lTooooo`03o`000?oooooooooo02Gooooo00?oo`00ooooooooool0?Ooo
ool00ol0003oooooooooo`0Wooooo`;o00001Oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00?ooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool00?l=ooooo`04
o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`0Coooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool2o`00o`Gooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooo`000005ooooo`;o003o2_ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`03o`00oooooooooooo00Cooooo0_l00?l4oooo
o`03o`00oooooooo003o00Sooooo0_l0000?ooooo`007?ooool00ol0003oooooooooo`0jooooo`05
o`00oooooooooooooooooooo00000_ooool00ol00?ooooooooooo`0Rooooo`03o`000?oooooooooo
02;ooooo00Co003oooooooooooooo`000_ooool00ol00?ooooooooooo`0jooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`05o`00oooooooo
ooooooooool00?l01_ooool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`;o
oooo00?o003oooooooooool02?ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooool000003?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;o
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Wo
oooo00?o0000ooooooooool03Oooool001cooooo0_l0000kooooo`05o`00oooooooooooooooooooo
00000_ooool00ol00?ooooooooooo`0Rooooo`03o`000?oooooooooo02;ooooo00Co003ooooooooo
ooooo`000_ooool00ol00?ooooooooooo`0jooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool02Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00Sooooo00Co003ooooo
oooooooo003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003ooooooooooooooooo
o`00o`08ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00oooool01Ol00?oooooo
oooooooooooo003o00;ooooo00?o0000ooooooooool00oooool2o`00o`Gooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo01kooooo00?o003ooooooooo
ool00oooool2o`00o`Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Oooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool0
>_ooool01Ol00?ooooooooooooooooooo`0002Oooooo00?o0000ooooooooool08_ooool01?l00?oo
oooooooooooo0002ooooo`03o`00oooooooooooo03[ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l00oooool01?l0
0?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o
0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Oo003oooooooooooooooooo`00oooooooo
003o00Cooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00[ooooo0_l00?l5ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool2
o`00o`Gooooo00Go003oooooooooooooooooo`00o`08ooooo`;o003o2Oooool00ol00?oooooooooo
o`0Jooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool2o`00o`Kooooo00?o
003oooooooooool03_ooool00ol0003oooooooooo`0=ooooo`004?ooool3o`0000?ooooo0_l00004
ooooo`03o`000?oooooooooo03kooooo00Coo`00oooooooooooo003o9?ooool00ol0003ooooooooo
o`0Uooooo`04ool00?ooooooooooo`00occooooo00?o0000ooooooooool09oooool2o`0000Gooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`?o
oooo00Co003ooooooooooooo003o2Oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`0Cooooo`05o`00oooooooo
ooooooooool00?l02?ooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00
0?oooooooooo00?ooooo0_l00?l9ooooo`03o`00oooooooooooo00gooooo00Go003ooooooooooooo
ooooo`00o`0Looooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`03o`00oooooooooooo00Co
oooo0_l00?l4ooooo`03o`00oooooooo003o00Sooooo0_l0000?ooooo`004Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000010ooooo`04ool00?oooooooooo
o`00obCooooo00?o0000ooooooooool08_ooool01?l00?oooooooooooooo000oooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooo003o00?ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooo`00o`04ooooo`03o`00
oooooooo003o00gooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo013ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`08ooooo`04
o`00ooooooooooooo`0000Gooooo00?o003oooooooooool01?ooool01Ol00?oooooooooooooooooo
003o00Sooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l08oooool00ol00?oooooooooo
o`03ooooo`;o003o1Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Wooooo00?o
0000ooooooooool03Oooool000kooooo1Ol00002ooooo`04o`000?ooooooooooo`0000?ooooo0ol0
000jooooo`05o`00oooooooooooooooooooo00000_ooool00ol00?ooooooooooo`0Rooooo`03o`00
0?oooooooooo02;ooooo00Co003oooooooooooooo`000_ooool00ol00?ooooooooooo`0iooooo`;o
00008Oooool3o`0000Gooooo00?o0000ooooooooool02oooool00ol00?ooooooooooo`0?ooooo`03
o`00oooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool00?l9
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03?ooool01Ol00?oooooooooooooo
oooo003o00oooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`000?oooooooooo00[ooooo
00?o003oooooooooool02_ooool2o`00o`Gooooo00?o003oooooooooool09Oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oooooo
o`00o`09ooooo`03o`000?oooooooooo00gooooo000>ooooo`04o`000?ooooooooooo`0000?ooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0jooooo`05o`00oooooooooooooooo
oooo00009oooool00ol0003oooooooooo`0Rooooo`04o`00ooooooooooooool000;ooooo00?o003o
ooooooooool0>_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol00?ooooooooooo`03ooooo`;o003o1?ooool00ol00?ooooooo`00o`04
ooooo`03o`00oooooooo003o00Cooooo00?o003oooooool00?l00oooool01?l00?ooooooooooool0
0?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00Go003oooooooooooooooooo`00o`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Aooooo`05
o`00ooooooooooooooooool00?l00_ooool00ol0003oooooooooo`0:ooooo`05o`00oooooooooooo
ooooool00?l02?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo027ooooo00?o003o
ooooooooool00oooool2o`00o`Kooooo00?o003oooooooooool03_ooool00ol0003oooooooooo`0=
ooooo`003oooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool0>oooool01?l00?oooooooooooooo0002ooooo`03o`00oooooooooooo02;ooooo00?o
0000ooooooooool09Oooool01?oo003oooooooooool00?llooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool01?ooool2o`0000Cooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooo003o00Cooooo00?o003oooooool00?l02_ooool01?l00?oooooo
ooooool00?l3ooooo`03o`00oooooooooooo00?ooooo00Go003oooooooooooooooooo`00o`02oooo
o`03o`00oooooooooooo017ooooo00Go003oooooooooooooooooo`00o`0?ooooo`03o`00oooooooo
oooo00Cooooo00?o0000ooooooooool02_ooool01Ol00?oooooooooooooooooo003o00oooooo00Go
003oooooooooooooooooo`00o`0Sooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
1?ooool2o`00o`Cooooo0_l00?l9ooooo`;o00003oooool0013ooooo0_l00003ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool0?_ooool01?oo003oooooooooool00?lTooooo`03
o`000?oooooooooo02;ooooo00Co003oooooooooooooo`00?oooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`03oooo
o`;o003o1?ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooo003o00Cooooo00?o003ooooo
ool00?l02_ooool01?l00?ooooooooooool00?l2ooooo`05o`00ooooooooooooooooool00?l01_oo
ool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo017ooooo00Co003ooooooooooooo0000
4?ooool00ol00?ooooooooooo`0=ooooo`05o`00ooooooooooooooooool00?l0:Oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00?ooooo0_l00?l:ooooo`03o`000?oooooooooo00go
oooo000Aooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o0000??ooool01?l00?oooooo
oooooooo0002ooooo`03o`00oooooooooooo02;ooooo00?o0000ooooooooool08_ooool01?l00?oo
oooooooooooo0002ooooo`03o`00oooooooooooo03[ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o003oooooooooool04?ooool00ol0
0?ooooooo`00o`03ooooo`03o`00oooooooooooo00Oooooo00Co003ooooooooooooo003o1_ooool0
1Ol00?oooooooooooooooooo003o00oooooo00Go003oooooooooooooooooo`00o`0?ooooo`05o`00
ooooooooooooooooool00?l00_ooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo017o
oooo00?o003oooooooooool0:oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?o
oooo0_l00?l:ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo03_ooooo
00Co003oooooooooooooo`009oooool00ol0003oooooooooo`0Rooooo`04o`00ooooooooooooool0
00;ooooo00?o003oooooooooool0>_ooool00ol0003oooooooooo`0Oooooo`;o00001_ooool00ol0
003oooooooooo`03ooooo`03o`00oooooooooooo00?ooooo0_l00?l4ooooo`03o`00oooooooo003o
00Kooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`03ooooo`04o`00oooooooooooo
o`00o`?ooooo00Co003ooooooooooooo003o1_ooool01?l00?ooooooooooool00?l3ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool04Oooool01?l00?ooooooooooool00?l3ooooo`03
o`000?oooooooooo00[ooooo00Co003ooooooooooooo003o?_ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00oooooo00?o0000ooooooooool03Oooool001cooooo00?o0000oooooooo
ool0>oooool01_l00?oooooooooooooo003oooooo`00obGooooo00?o0000ooooooooool09Oooool0
1?oo003oooooooooool00?llooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooo`00o`04ooooo`03o`00oooooooo003o00[ooooo00Co003ooooooooooooo003o
0oooool00ol00?ooooooooooo`03ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oo
ooooooooo`0Aooooo`04o`00ooooooooooooo`00oa3ooooo00?o003oooooooooool01?ooool00ol0
003oooooooooo`0:ooooo`04o`00ooooooooooooo`00oa3ooooo00Co003ooooooooooooo003o<Ooo
ool00ol00?ooooooooooo`03ooooo`;o003o2_ooool00ol0003oooooooooo`0=ooooo`007?ooool0
0ol0003oooooooooo`0kooooo`06o`00ooooooooooooool00?oooooo003o9Oooool00ol0003ooooo
ooooo`0Rooooo`04o`00ooooooooooooool003oooooo00?o0000ooooooooool09oooool2o`0000Co
oooo00?o003oooooooooool00oooool2o`00o`Cooooo00?o003oooooool00?l01?ooool00ol00?oo
ooooo`00o`04ooooo`03o`00oooooooo003o00Kooooo00Go003oooooooooooooooooo`00o`05oooo
o`05o`00ooooooooooooooooool00?l01_ooool00ol00?ooooooooooo`0=ooooo`04o`00oooooooo
ooooo`00oa?ooooo00Go003oooooooooooooooooo`00000?ooooo`03o`00oooooooooooo00kooooo
00Co003ooooooooooooo003o<Oooool00ol00?ooooooooooo`03ooooo`;o003o2Oooool2o`0000oo
oooo000Looooo`;o0000??ooool01_l00?oooooooooooooo003oooooo`00obGooooo00?o0000oooo
ooooool08_ooool01?l00?oooooooooooooo0002ooooo`03o`00oooooooooooo03[ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool01?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00Oooooo00Co003o
oooooooooooo003o2_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00kooooo00Co
003ooooooooooooo003o0oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo017ooooo
00Co003ooooooooooooo003o<Oooool00ol00?ooooooooooo`03ooooo`;o003o2_ooool00ol0003o
ooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`0nooooo`03ool00?oooooooooo02Gooooo
00?o0000ooooooooool08oooool00ol00?ooooooool00002ooooo`03o`00oooooooooooo03[ooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo00?ooooo
0_l00?l6ooooo`03o`00oooooooooooo00?ooooo0_l00?l4ooooo`03o`00oooooooo003o00Cooooo
00Co003ooooooooooooo003o1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`0Aooooo`04o`00ooooooooooooo`00o`?ooooo00?o0000
ooooooooool02_ooool01?l00?ooooooooooool00?m<ooooo`03o`00oooooooooooo00Sooooo00?o
0000ooooooooool03Oooool001cooooo00?o0000ooooooooool0>oooool01_l00?oooooooooooooo
003oooooo`00obGooooo00?o0000ooooooooool09Oooool01?oo003oooooooooool00?llooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00?ooooo0_l00?l5ooooo`;o003o2oooool00ol00?ooooooo`00o`04ooooo`03
o`00oooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0Aoooo
o`04o`00ooooooooooooo`00oa3ooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`0:
ooooo`04o`00ooooooooooooo`00oa?ooooo00?o003oooooooooool0=Oooool00ol00?oooooooooo
o`09ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo03_ooooo00Ko003o
ooooooooooooo`00ooooool00?lUooooo`03o`000?oooooooooo02Gooooo00?oo`00ooooooooool0
?Oooool00ol0003oooooooooo`0Wooooo`;o00001?ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00?ooooo0_l00?l5ooooo`;o003o1Oooool2o`00o`Kooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooo
oooo003o4?ooool01?l00?ooooooooooool00?l@ooooo`04o`00ooooooooooooo`00o`?ooooo00?o
0000ooooooooool03?ooool00ol00?ooooooooooo`0?ooooo`04o`00ooooooooooooo`00ocOooooo
00?o003oooooooooool02?ooool2o`0000oooooo000Looooo`;o0000??ooool01_l00?oooooooooo
oooo003oooooo`00obGooooo00?o0000ooooooooool08oooool00ol00?ooooooool00002ooooo`03
o`00oooooooooooo03[ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Cooooo0_l00?l4ooooo`03o`00oooooooooooo00Kooooo00Go003ooooooooo
ooooooooo`00o`09ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool04_ooool01Ol0
0?oooooooooooooooooo000000cooooo00?o003oooooooooool04Oooool01?l00?ooooooooooool0
0?m3ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo03kooooo00?oo`00
ooooooooool09Oooool00ol0003oooooooooo`0Sooooo`03o`00ooooooooo`0000;ooooo00?o003o
ooooooooool0>_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Wooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0:ooooo`;o003o1?ooool00ol00?ooooooo`00o`04
ooooo`03o`00oooooooo003o00Kooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool04Oooool00ol00?ooooooo`00o`04ooooo`03o`000?oo
oooooooo00[ooooo00?o003oooooool00?l04Oooool00ol00?ooooooooooo`14ooooo`03o`000?oo
oooooooo00gooooo000Looooo`03o`000?oooooooooo03_ooooo00Ko003oooooooooooooo`00oooo
ool00?lUooooo`03o`000?oooooooooo02?ooooo00?o003ooooooooo00000_ooool00ol00?oooooo
ooooo`0jooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool00_ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`;o003o1Oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooo003o00Cooooo00?o003oooooool00?l00oooool01?l00?oooooo
ooooool00?l3ooooo`03o`00oooooooooooo017ooooo00?o003oooooool00?l04Oooool00ol00?oo
ooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o003oooooool00?l05?ooool00ol00?oo
ooooooooo`11ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo03_ooooo
00Ko003oooooooooooooo`00ooooool00?lUooooo`03o`000?oooooooooo02Gooooo00?oo`00oooo
ooooool0?Oooool00ol0003oooooooooo`0Wooooo`;o00000oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`;o003o1_ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l3
ooooo`04o`00ooooooooooooo`00oa3ooooo00?o003oooooool00?l04Oooool00ol00?ooooooo`00
o`04ooooo`03o`000?oooooooooo00cooooo00?o003oooooooooool03oooool01?l00?oooooooooo
ool00?m2ooooo`;o00003oooool001cooooo0_l0000looooo`06o`00ooooooooooooool00?oooooo
003o9Oooool00ol0003oooooooooo`0Sooooo`03o`00ooooooooo`0000;ooooo00?o003ooooooooo
ool0>_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Wooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`04ooooo`;o003o1Oooool2o`00o`Cooooo00?o003ooooooooo
ool01_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol0
003oooooooooo`0:ooooo`03o`00oooooooooooo017ooooo00?o003oooooool00?l0A?ooool00ol0
003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`0nooooo`03ool00?oooooo003o02Go
oooo00?o0000ooooooooool08oooool00ol00?ooooooool00002ooooo`03o`00oooooooooooo03[o
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool02_ooool2o`00o`Cooooo00?o003oooooool00?l01?ooool00ol00?oo
ooooo`00o`0:ooooo`04o`00ooooooooooooo`00oa3ooooo00?o003oooooool00?l04Oooool00ol0
0?ooooooo`00o`04ooooo`03o`000?oooooooooo00[ooooo00?o003oooooool00?l04Oooool00ol0
0?ooooooooooo`14ooooo`03o`000?oooooooooo00gooooo000?ooooo`?o00001?ooool2o`0000Co
oooo00?o0000ooooooooool0>oooool01?l00?oooooooooooooo000Wooooo`03o`000?oooooooooo
02?ooooo00?o003ooooooooo00000_ooool00ol00?ooooooooooo`0jooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool03oooool2o`00o`Gooooo0_l00?l5ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooool00?l01?ooool2o`00o`Cooooo00Co003ooooooooooooo003o0oooool0
0ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool01?ooool0
0ol0003oooooooooo`0:ooooo`03o`00oooooooo003o01?ooooo00?o003oooooooooool0@_ooool0
0ol0003oooooooooo`0=ooooo`003_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`0kooooo`06o`00ooooooooooooool00?oooooo
003o9Oooool00ol0003oooooooooo`0Uooooo`03ool00?oooooooooo03gooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo0_l00?l5ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`04
o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool04Oooool2o`00oa;ooooo0_l00?l5oooo
o`03o`000?oooooooooo00_ooooo00?o003oooooooooool04?ooool00ol00?ooooooo`00o`14oooo
o`03o`000?oooooooooo00gooooo000Booooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooooooo0ol0000kooooo`06o`00ooooooooooooool00?oooooo003o9Oooool00ol0003ooooo
ooooo`0Sooooo`03o`00ooooooooo`0003kooooo0_l0000Yooooo`;o00004?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooo003o00Kooooo00?o003oooooooooool04?ooool00ol00?oooooo
ooooo`0Aooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol00?oooooo
ooooo`0Aooooo`03o`00oooooooo003o04?ooooo0_l0000?ooooo`004_ooool01?l0003ooooooooo
ool00002ooooo`05o`000?ooooooooooooooool00000@?ooool00ooo003oooooo`00o`0Uooooo`03
o`000?oooooooooo02?ooooo00Go003ooooooooo003oooooo`00o`0mooooo`03o`000?oooooooooo
01kooooo1Ol00004ooooo`03o`000?oooooooooo01gooooo00?o003oooooooooool00oooool2o`00
o`Gooooo0_l00?l;ooooo`03o`00oooooooo003o017ooooo0_l00?lBooooo`;o003o1Oooool00ol0
003oooooooooo`0:ooooo`;o003o4_ooool00ol00?ooooooooooo`14ooooo`03o`000?oooooooooo
00gooooo000>ooooo`Co00000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
03cooooo00?o003ooooooooo00009oooool00ol0003oooooooooo`0Sooooo`05o`00ooooooooo`00
ooooool00?l0?Oooool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool05_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo0_l0
0?l5ooooo`;o003o1?ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooo003o017ooooo00?o
003oooooooooool04Oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00[ooooo0_l0
0?lDooooo`03o`00oooooooooooo04;ooooo00?o0000ooooooooool03Oooool000kooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo03cooooo00Go
003ooooooooo003oooooo`00o`0Uooooo`03o`000?oooooooooo02Gooooo00?oo`00ooooool00?l0
?Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
5_ooool00ol00?ooooooooooo`0:ooooo`;o003o1Oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooo003o00Cooooo00?o003oooooooooool04Oooool2o`00oa;ooooo0_l00?l5ooooo`03o`00
0?oooooooooo00_ooooo00?o003oooooooooool04?ooool00ol00?ooooooo`00o`14ooooo`03o`00
0?oooooooooo00gooooo000>ooooo`Go00000oooool2o`0000Cooooo0_l0000mooooo`05o`00oooo
ooooo`00ooooool00?l09Oooool00ol0003oooooooooo`0Sooooo`03o`00ooooooooo`0003oooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`03ooooo`;o00005oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool00_ooool00ol00?oooooo
o`00o`06ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool04Oooool00ol00?oooooo
ooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool04?ooool2o`00odCooooo
0_l0000?ooooo`007?ooool00ol0003oooooooooo`0nooooo`03ool00?l00?oooooo02Gooooo00?o
0000ooooooooool08oooool01Ol00?ooooooool00?oooooo003o03gooooo00?o0000ooooooooool0
7_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool07Oooool00ol00?oo
ooooooooo`03ooooo`;o003o1_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo003o017o
oooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00[o
oooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`14ooooo`03o`000?oooooooooo00go
oooo000Looooo`03o`000?oooooooooo03kooooo00?oo`00ooooooooool09Oooool00ol0003ooooo
ooooo`0Sooooo`05o`00ooooooooo`00ooooool00?l0?Oooool00ol0003oooooooooo`0Nooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Mooooo`03o`00oooooooooooo
00?ooooo0_l00?l5ooooo`;o003o1_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o
017ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo
00[ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`13ooooo`03o`000?oooooooooo
00gooooo000Looooo`03o`000?oooooooooo03cooooo00Co003ooooooooo003o003o9_ooool00ol0
003oooooooooo`0Uooooo`03ool00?oooooo003o03gooooo00?o0000ooooooooool07oooool3o`00
00Gooooo00?o0000ooooooooool08oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo
017ooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo
017ooooo0_l00?m5ooooo`03o`000?oooooooooo00gooooo000Looooo`;o0000?Oooool01?l00?oo
ooooool00?l00?lVooooo`03o`000?oooooooooo02Cooooo00?o003oool00?ooool0?_ooool00ol0
003oooooooooo`0Wooooo`;o0000:oooool00ol00?ooooooooooo`03ooooo`;o003o1oooool00ol0
0?ooooooooooo`0Sooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0
0?ooooooooooo`0Aooooo`;o003oA?ooool2o`0000oooooo000Looooo`03o`000?oooooooooo03co
oooo00Co003ooooooooo003o003o9_ooool00ol0003oooooooooo`0Tooooo`04o`00oooo003ooooo
o`00ocgooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Sooooo`;o003o1Oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l09Oooool0
0ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o003oooooooooool04Oooool0
0ol00?ooooooooooo`14ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo
03kooooo00?oo`00ooooooooool09Oooool00ol0003oooooooooo`0Tooooo`04o`00oooo003ooooo
o`00ocgooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Sooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`;o003o;Oooool0
0ol0003oooooooooo`0Nooooo`03o`00oooooooooooo04Cooooo00?o0000ooooooooool03Oooool0
01cooooo00?o0000ooooooooool0??ooool01?l00?ooooooool00?l00?lVooooo`03o`000?oooooo
oooo02Gooooo00?oo`00ooooool00?l0?Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo02[ooooo00?o003oooooooooool00oooool2o`00o`Gooooo00?o003oooooooooool0;?ooool0
0ol0003oooooooooo`0Nooooo`03o`00oooooooooooo04Cooooo00?o0000ooooooooool03Oooool0
01cooooo0_l0000mooooo`04o`00ooooooooo`00o`00obKooooo00?o0000ooooooooool09?ooool0
0ol00?ooo`00ooooo`0nooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0:_ooool0
0ol00?ooooooooooo`03ooooo`;o003o1Oooool2o`00obgooooo00?o0000ooooooooool07_ooool0
0ol00?ooooooooooo`14ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo
03cooooo00Co003ooooooooo003o003o9_ooool00ol0003oooooooooo`0Tooooo`04o`00oooo003o
ooooo`00ocgooooo00?o0000ooooooooool09oooool2o`0002_ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02_ooooo00?o0000ooooooooool07_oo
ool00ol00?ooooooooooo`13ooooo`;o00003oooool001cooooo00?o0000ooooooooool0?_ooool0
0ooo003oooooooooo`0Uooooo`03o`000?oooooooooo02Cooooo00Co003oool00?oooooo003o?Ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02[ooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`03ooooo`;o003o;Oooool00ol0003oooooooooo`0Nooooo`03o`00oooo
oooooooo04Cooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool0??ooool0
1?l00?ooooooool00?l00?lVooooo`03o`000?oooooooooo02Gooooo00?oo`00o`00ooooool0?Ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo033ooooo0_l00?l5ooooo`03o`00oooo
oooooooo02cooooo00?o0000ooooooooool07_ooool00ol00?ooooooooooo`14ooooo`03o`000?oo
oooooooo00gooooo000Looooo`;o0000?Oooool01?l00?ooooooool00?l00?lVooooo`03o`000?oo
oooooooo02Gooooo00?oo`00ooooooooool0?Oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo033ooooo0_l00?l5ooooo`;o003o;Oooool00ol0003oooooooooo`0Nooooo`03o`00oooo
oooooooo04Cooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool0??ooool0
1?l00?ooooooool00?l00?lVooooo`03o`000?oooooooooo02Cooooo00?o003oool00?l00?l0?_oo
ool00ol0003oooooooooo`0Wooooo`;o0000<Oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo02_ooooo00?o0000ooooooooool0I?ooool2o`0000oooooo000?ooooo`?o00001?ooool2
o`0000Cooooo00?o0000ooooooooool0?_ooool00ooo003oooooooooo`0Uooooo`03o`000?oooooo
oooo02Cooooo00?o003oool00?l00?l0?_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo03Oooooo00?o003oooooooooool0;?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooo
oooo00gooooo000>ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo03gooooo00?o003oool00?ooool09_ooool00ol0003ooooooooo
o`0Tooooo`03o`00oooo003o003o03kooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0gooooo`03o`00oooooooooooo02cooooo00?o0000ooooooooool0IOooool00ol0003ooooooooo
o`0=ooooo`003_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`0mooooo`?oo`009_ooool00ol0003oooooooooo`0Tooooo`?oo`00
?_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Oooooo00?o003oooooooooool0
;?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00gooooo000>ooooo`Co00000ooo
ool01?l0003oooooooooool00003ooooo`?o0000?Oooool3ool002Kooooo00?o0000ooooooooool0
9?ooool3ool003gooooo0_l0000Yooooo`;o0000>?ooool00ol00?ooooooooooo`0/ooooo`03o`00
0?oooooooooo06Cooooo0_l0000?ooooo`003_ooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool0?Oooool3ool002Kooooo00?o0000ooooooooool0
9?ooool3ool003kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0gooooo`03o`00
oooooooooooo02cooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0=ooooo`003ooo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
I_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
I_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00gooooo000@ooooo`;o00001?oo
ool2o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool03Oooool001coooood_l0000Yooooom;o00003oooool0
0?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool0
0?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool0
0?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool002;ooooo0_l0000N
ooooo`?o00007?ooool3o`0000Cooooo0_l0000Iooooo`?o00000oooool3o`0001Sooooo1Ol00003
ooooo`;o00006?ooool5o`0000;ooooo0ol0001<ooooo`;o00007oooool3o`0001cooooo0ol00004
ooooo`;o00006Oooool3o`0000?ooooo0ol0000Hooooo`Go00000oooool2o`0001Sooooo1Ol00002
ooooo`?o0000;Oooool0027ooooo00Co0000oooooooooooo00007?ooool01Ol0003ooooooooooooo
oooo000001cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Iooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`0Fooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00006?ooool01_l0003oooooooooool0003oooooo`0000?ooooo
00?o0000ooooooooool0B?ooool01?l0003oooooooooool0000Mooooo`05o`000?oooooooooooooo
ool000007?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Wooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool0000Hooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooooooo`0Zooooo`008Oooool01?l0003oooooooooool0000Pooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Iooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0001Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`18ooooo`04o`00
0?ooooooooooo`00027ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0001Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00006Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02[ooooo000Qooooo`04o`000?ooooooooooo`00023ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Wooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
B?ooool01?l0003oooooooooool0000Qooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool0000Iooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool06?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo02[ooooo000Qooooo`04o`000?oooooooooo
o`0001cooooo1?l0000Mooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00006Ooo
ool01?l0003oooooooooooooool4o`0001Sooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0001Oooooo00Ko0000ooooooooooooooooo`000?ooool4o`0004_ooooo00Co
0000oooooooooooo00007Oooool4o`0001gooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000Iooooo`04o`000?ooooooooooooooo`Co00006?ooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00005oooool01_l0003ooooooooooooooooo0000ooooo`Co
0000;Oooool0027ooooo00Co0000oooooooooooo00007?ooool00ol0003oooooooooo`0Mooooo`;o
00001?ooool01?l0003oooooooooool0000Hooooo`;o00000oooool00ol0003oooooooooo`0Ioooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Gooooo`07o`000?oo
ooooooooooooool0003oooooo`00001>ooooo`04o`000?ooooooooooo`0001gooooo00?o0000oooo
ooooool07Oooool2o`0000Cooooo00Co0000oooooooooooo00006?ooool2o`0000?ooooo00?o0000
ooooooooool06Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5oooool01ol0003ooooooooooooooooo0000ooooool00000<?ooool002;ooooo0_l0000Mooooo`Go
00007?ooool00ol0003oooooooooo`03ooooo`;o00006_ooool01?l0003oooooooooooooool5o`00
01Sooooo0ol00004ooooo`;o00006Oooool3o`0000;ooooo1Ol0001;ooooo`;o00007_ooool5o`00
01cooooo00?o0000ooooooooool00oooool2o`0001[ooooo00Co0000oooooooooooooooo1Ol0000H
ooooo`?o00001?ooool2o`0001Wooooo0ol00002ooooo`Go0000;?ooool00?oooooonOooool00?oo
oooonOooool00?oooooonOooool00?oooooonOooool001Oooooo0_l00005oooooloo00009?ooool3
o`0000Coooood?l0000@ooooo`005_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool08Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`005_ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo00Oooooo0ooo0004ooooo`?oo`002oooool3ool000?ooooo0ooo
000;ooooo`?oo`001?ooool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000Cooooo0ooo
0004ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`001?ooool3ool000Cooooo0ooo
0003ooooo`?oo`001?ooool3ool000Cooooo0ooo0004ooooo`?oo`001?ooool3ool000[ooooo0ooo
0004ooooo`?oo`002oooool3ool000?ooooo0ooo0003ooooo`03o`000?oooooooooo01_ooooo1Ol0
0005ooooo`05o`000?ooooooooooooooool00000c_ooool00ol0003oooooooooo`0>ooooo`005_oo
ool01?l0003oooooooooool00004ooooo`;o00000oooool00ooo003oooooooooo`02ooooo`?oo`00
1?ooool3ool000Gooooo00?oo`00ooooooooool00oooool3ool000?ooooo0ooo0005ooooo`03ool0
0?oooooooooo00?ooooo0ooo0004ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`00
1?ooool3ool000Cooooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo0004ooooo`?oo`00
1?ooool3ool000?ooooo0ooo0004ooooo`?oo`001?ooool3ool000Cooooo0ooo0004ooooo`?oo`00
1?ooool00ooo003oooooooooo`03ooooo`?oo`001?ooool3ool000Gooooo00?oo`00ooooooooool0
0oooool3ool000?ooooo0ooo0002ooooo`;o00009Oooool2o`0000Cooooo0ol0003:ooooo`?o0000
4?ooool001Kooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo0ooo0004ooooo`?oo`001Oooool00ooo003oooooooooo`03ooooo`?oo`00
0oooool3ool000Gooooo00?oo`00ooooooooool00oooool3ool000Cooooo0ooo0004ooooo`?oo`00
0oooool3ool000Cooooo0ooo0004ooooo`?oo`001?ooool3ool000Cooooo0ooo0003ooooo`?oo`00
1?ooool3ool000Cooooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo0004ooooo`?oo`00
1?ooool3ool000Cooooo0ooo0004ooooo`03ool00?oooooooooo00?ooooo0ooo0004ooooo`?oo`00
1Oooool00ooo003oooooooooo`03ooooo`?oo`000oooool3ool000?ooooo00?o0000ooooooooool0
9Oooool01Ol0003ooooooooooooooooo00000<kooooo00?o0000ooooooooool03_ooool001Kooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo017o
oooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo01;o
oooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0Qooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000Gooooo`;o
00001Oooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo017ooooo00?oo`00oooooooo
ool04Oooool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo01;ooooo00?oo`00oooooooo
ool03oooool00ol0003oooooooooo`0Rooooo`?o00001?ooool00ol0003oooooooooo`3<ooooo`03
o`000?oooooooooo00kooooo000Nooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool0
4Oooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo07Oooooo00?oo`00ooooooooool0
4_ooool00ooo003oooooooooo`0>ooooo`;o0000:oooool2o`000<cooooo0_l0000@ooooo`007_oo
ool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool04Ooo
ool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool03ooo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_oo
ool001kooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooo
oooo017ooooo00?oo`00ooooooooool0Moooool00ooo003oooooooooo`0Booooo`03ool00?oooooo
oooo00oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooo
oooo00kooooo000Nooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool04Oooool00ooo
003oooooooooo`0Aooooo`03ool00?oooooooooo07Oooooo00?oo`00ooooooooool04_ooool00ooo
003oooooooooo`0?ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0
003oooooooooo`0>ooooo`007_ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo017o
oooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo01;o
oooo00?oo`00ooooooooool03_ooool2o`0002_ooooo0_l0003<ooooo`;o00004?ooool001kooooo
00?o0000ooooooooool00_ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo017ooooo
00?oo`00ooooooooool0Moooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00oooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo
000Nooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool04Oooool00ooo003ooooooooo
o`0Aooooo`03ool00?oooooooooo07Oooooo00?oo`00ooooooooool04_ooool00ooo003ooooooooo
o`0?ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003ooooooooo
o`0>ooooo`007_ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo017ooooo00?oo`00
ooooooooool04Oooool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo01;ooooo00?oo`00
ooooooooool03oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0<cooooo00?o0000
ooooooooool03_ooool001kooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0Aoooo
o`03ool00?oooooooooo017ooooo00?oo`00ooooooooool0Moooool00ooo003oooooooooo`0Boooo
o`03ool00?oooooooooo00kooooo0_l0000[ooooo`;o0000c?ooool2o`00013ooooo000Nooooo`03
o`000?oooooooooo00;ooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0Aooooo`03
ool00?oooooooooo07Oooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0?ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`00
7_ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool0
4Oooool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool0
3oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool0
3_ooool001kooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0Aooooo`03ool00?oo
oooooooo017ooooo00?oo`00ooooooooool0Moooool00ooo003oooooooooo`0Booooo`03ool00?oo
oooooooo00oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oo
oooooooo00kooooo000Nooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool04Oooool0
0ooo003oooooooooo`0Aooooo`03ool00?oooooooooo07Oooooo00?oo`00ooooooooool04_ooool0
0ooo003oooooooooo`0>ooooo`;o0000:oooool2o`000<cooooo0_l0000@ooooo`007_ooool00ol0
003oooooooooo`02ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool04Oooool00ooo
003oooooooooo`1gooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool03oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool0013o
oooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo017o
oooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo01;o
oooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0Qooooo`Go00000oooool00ol0003o
ooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000Aooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo017o
oooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo01;o
oooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`004Oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo0_l00003ooooo`03ool00?oooooooooo
017ooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo
01;ooooo00?oo`00ooooooooool03_ooool2o`0001gooooo1Ol00003ooooo`03o`000?oooooooooo
00?ooooo0ol0003:ooooo`?o00004?ooool0017ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool04Oooool00ooo
003oooooooooo`0Aooooo`03ool00?oooooooooo07Oooooo00?oo`00ooooooooool04_ooool00ooo
003oooooooooo`0?ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000Aooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo
017ooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo
01;ooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0Qooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000@oooo
o`;o00001?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo00?oo`00
ooooooooool04Oooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo07Oooooo00?oo`00
ooooooooool04_ooool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo027ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_oo
ool0017ooooo00?o0000ooooooooool00oooool2o`0000Gooooo00?o0000ooooooooool00_ooool0
0ooo003oooooooooo`0Aooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool0Moooool0
0ooo003oooooooooo`0Booooo`03ool00?oooooooooo00kooooo0_l0000Tooooo`?o00001?ooool2
o`000<cooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo
017ooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo
01;ooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
0<cooooo00?o0000ooooooooool03_ooool001kooooo00?o0000ooooooooool00_ooool00ooo003o
ooooooooo`0Aooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool0Moooool00ooo003o
ooooooooo`0Booooo`03ool00?oooooooooo00oooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`000?oooooooooo00;ooooo
00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo07Oooooo
00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`007_ooool00ol0003ooooooooo
o`02ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool04Oooool00ooo003ooooooooo
o`1gooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool03_ooool2o`0002_ooooo0_l0
003<ooooo`;o00004?ooool001kooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0A
ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool0Moooool00ooo003oooooooooo`0B
ooooo`03ool00?oooooooooo00oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<
ooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`000?oooooooooo00;ooooo00?oo`00oooo
ooooool04Oooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo07Oooooo00?oo`00oooo
ooooool04_ooool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0c?ooool00ol0003oooooooooo`0>ooooo`007_ooool00ol0003oooooooooo`02ooooo`03
ool00?oooooooooo017ooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`1gooooo`03
ool00?oooooooooo01;ooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool001kooooo00?o0000ooooooooool0
0_ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool0
Moooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00kooooo0_l0000[ooooo`;o0000
c?ooool2o`00013ooooo000Nooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool04Ooo
ool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo07Oooooo00?oo`00ooooooooool04_oo
ool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?oo
ool00ol0003oooooooooo`0>ooooo`007_ooool00ol0003oooooooooo`02ooooo`03ool00?oooooo
oooo017ooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`1gooooo`03ool00?oooooo
oooo01;ooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo0<cooooo00?o0000ooooooooool03_ooool001kooooo00?o0000ooooooooool00_ooool00ooo
003oooooooooo`0Aooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool0Moooool00ooo
003oooooooooo`0Booooo`03ool00?oooooooooo00oooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`000?oooooooooo00;o
oooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo07Oo
oooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0>ooooo`;o0000:oooool2o`000<co
oooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo017ooooo
00?oo`00ooooooooool04Oooool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo01;ooooo
00?oo`00ooooooooool03oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0<cooooo
00?o0000ooooooooool03_ooool000oooooo1Ol00003ooooo`;o00001Oooool00ol0003ooooooooo
o`02ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool04Oooool00ooo003ooooooooo
o`1gooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool03oooool00ol0003ooooooooo
o`0Rooooo`?o00001?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000@
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`02ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool04Oooool00ooo003ooooo
ooooo`1gooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool03oooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0c?ooool00ol0003ooooo
ooooo`0>ooooo`004Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool00_ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo017ooooo
00?oo`00ooooooooool0Moooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00oooooo
00?o0000ooooooooool06oooool5o`0000?ooooo00?o0000ooooooooool00oooool3o`000<[ooooo
0ol0000@ooooo`004_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0
0_ooool2o`0000?ooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0Aooooo`03ool0
0?oooooooooo07Oooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0>ooooo`;o0000
9Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool0
3_ooool000oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo017o
oooo00?oo`00ooooooooool0Moooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00oo
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0<co
oooo00?o0000ooooooooool03_ooool000oooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0Aoooo
o`03ool00?oooooooooo017ooooo00?oo`00ooooooooool0Moooool00ooo003oooooooooo`0Boooo
o`03ool00?oooooooooo00oooooo00?o0000ooooooooool08_ooool2o`0000Gooooo00?o0000oooo
ooooool0c?ooool00ol0003oooooooooo`0>ooooo`004?ooool3o`0000Cooooo0_l00005ooooo`03
o`000?oooooooooo00;ooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0Aooooo`03
ool00?oooooooooo07Oooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0?ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool00oooool2o`000<cooooo0_l0000@ooooo`00
7_ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool0
4Oooool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool0
3_ooool2o`0002_ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`007_oo
ool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool04Ooo
ool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool03ooo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_oo
ool001kooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooo
oooo017ooooo00?oo`00ooooooooool0Moooool00ooo003oooooooooo`0Booooo`03ool00?oooooo
oooo00oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooo
oooo00kooooo000Nooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool04Oooool00ooo
003oooooooooo`0Aooooo`03ool00?oooooooooo07Oooooo00?oo`00ooooooooool04_ooool00ooo
003oooooooooo`0?ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0
003oooooooooo`0>ooooo`007_ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo017o
oooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo01;o
oooo00?oo`00ooooooooool03_ooool2o`0002_ooooo0_l0003<ooooo`;o00004?ooool001kooooo
00?o0000ooooooooool00_ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo017ooooo
00?oo`00ooooooooool0Moooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00oooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo
000Nooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool04Oooool00ooo003ooooooooo
o`0Aooooo`03ool00?oooooooooo07Oooooo00?oo`00ooooooooool04_ooool00ooo003ooooooooo
o`0?ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003ooooooooo
o`0>ooooo`007_ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo017ooooo00?oo`00
ooooooooool04Oooool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo01;ooooo00?oo`00
ooooooooool03oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0<cooooo00?o0000
ooooooooool03_ooool001kooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0Aoooo
o`03ool00?oooooooooo017ooooo00?oo`00ooooooooool0Moooool00ooo003oooooooooo`0Boooo
o`03ool00?oooooooooo00kooooo0_l0000[ooooo`;o0000c?ooool2o`00013ooooo000Nooooo`03
o`000?oooooooooo00;ooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0Aooooo`03
ool00?oooooooooo07Oooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0?ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`00
7_ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool0
4Oooool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool0
3oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool0
3_ooool001kooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0Aooooo`03ool00?oo
oooooooo017ooooo00?oo`00ooooooooool0Moooool00ooo003oooooooooo`0Booooo`03ool00?oo
oooooooo00oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oo
oooooooo00kooooo000Nooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool04Oooool0
0ooo003oooooooooo`0Aooooo`03ool00?oooooooooo07Oooooo00?oo`00ooooooooool04_ooool0
0ooo003oooooooooo`0>ooooo`;o0000:oooool2o`000<cooooo0_l0000@ooooo`004?ooool3o`00
00Cooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool04Oooool00ooo
003oooooooooo`0Aooooo`03ool00?oooooooooo07Oooooo00?oo`00ooooooooool04_ooool00ooo
003oooooooooo`0?ooooo`03o`000?oooooooooo02?ooooo0_l00004ooooo`03o`000?oooooooooo
0<cooooo00?o0000ooooooooool03_ooool000oooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0A
ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool0Moooool00ooo003oooooooooo`0B
ooooo`03ool00?oooooooooo00oooooo00?o0000ooooooooool08_ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool001?ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?oo`00
4Oooool3ool001;ooooo00?oo`00ooooooooool0Moooool00ooo003oooooooooo`0Aooooo`?oo`00
4?ooool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooo
oooooooo0ooo0004ooooo`?oo`001?ooool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool0
00Cooooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo0004ooooo`?oo`001?ooool3ool0
00Cooooo0ooo0003ooooo`?oo`001?ooool3ool000Cooooo0ooo0004ooooo`?oo`000oooool3ool0
00Cooooo0ooo0004ooooo`?oo`001?ooool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool0
00Cooooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo0004ooooo`?oo`001?ooool3ool0
00?ooooo00?o0000ooooooooool03_ooool0017ooooo0_l00003ooooo`04o`000?ooooooooooo`00
00Cooooo0_l00002ooooo`?oo`004Oooool3ool001;ooooo00?oo`00ooooooooool0Moooool00ooo
003oooooooooo`0Aooooo`?oo`003oooool2o`0002Cooooo00Co0000oooooooooooo00000oooool3
o`000004oooooooo003oo`00ool000Cooooo0ooo0004ooooo`?oo`001?ooool3ool000?ooooo0ooo
0004ooooo`?oo`001?ooool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000Cooooo0ooo
0004ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`001?ooool3ool000Cooooo0ooo
0003ooooo`?oo`001?ooool3ool000Cooooo0ooo0004ooooo`?oo`001?ooool3ool000?ooooo0ooo
0004ooooo`?oo`001?ooool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000Cooooo0ooo
0004ooooo`?oo`0000Coooooo`000?l0003o00004?ooool001?ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?oo`004Oooool3ool001;o
oooo00?oo`00ooooooooool0Moooool00ooo003oooooooooo`0Aooooo`?oo`004?ooool00ol0003o
ooooooooo`0Rooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooooooo0ooo0004
ooooo`?oo`001?ooool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000Cooooo0ooo0004
ooooo`?oo`000oooool3ool000Cooooo0ooo0004ooooo`?oo`001?ooool3ool000Cooooo0ooo0003
ooooo`?oo`001?ooool3ool000Cooooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo0004
ooooo`?oo`001?ooool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000Cooooo0ooo0004
ooooo`?oo`000oooool3ool000Cooooo0ooo0004ooooo`?oo`001?ooool3ool000?ooooo00?o0000
ooooooooool03_ooool000oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0:_ooool00ooo003oooooooooo`1gooooo`03ool00?oo
oooooooo02Cooooo00?o0000ooooooooool08_ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo0<cooooo00?o0000ooooooooool03_ooool0013ooooo0ol00004ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Zooooo`03ool00?oooooooooo07Oooooo00?oo`00ooooooooool09?oo
ool00ol0003oooooooooo`0Sooooo`;o00001?ooool00ol0003oooooooooo`3<ooooo`03o`000?oo
oooooooo00kooooo000Nooooo`03o`000?oooooooooo02[ooooo00?oo`00ooooooooool0Moooool0
0ooo003oooooooooo`0Sooooo`;o0000:oooool2o`000<cooooo0_l0000@ooooo`007_ooool00ol0
003oooooooooo`0Zooooo`03ool00?oooooooooo07Oooooo00?oo`00ooooooooool09?ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool001ko
oooo00?o0000ooooooooool0:_ooool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo02Co
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00ko
oooo000Nooooo`03o`000?oooooooooo02[ooooo00?oo`00ooooooooool0Moooool00ooo003ooooo
ooooo`0Tooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003ooooo
ooooo`0>ooooo`007_ooool00ol0003oooooooooo`0Zooooo`03ool00?oooooooooo07Oooooo00?o
o`00ooooooooool08oooool2o`0002_ooooo0_l0003<ooooo`;o00004?ooool001kooooo00?o0000
ooooooooool0:_ooool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo02Cooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000Noooo
o`03o`000?oooooooooo02[ooooo00?oo`00ooooooooool0Moooool00ooo003oooooooooo`0Toooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>oooo
o`007_ooool00ol0003oooooooooo`0Zooooo`03ool00?oooooooooo07Oooooo00?oo`00oooooooo
ool09?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0<cooooo00?o0000oooooooo
ool03_ooool001kooooo00?o0000ooooooooool0:_ooool00ooo003oooooooooo`1gooooo`03ool0
0?oooooooooo02?ooooo0_l0000[ooooo`;o0000c?ooool2o`00013ooooo000Nooooo`03o`000?oo
oooooooo02[ooooo00?oo`00ooooooooool0Moooool00ooo003oooooooooo`0Tooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`007_ooool0
0ol0003oooooooooo`0Zooooo`03ool00?oooooooooo07Oooooo00?oo`00ooooooooool09?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool0
01kooooo00?o0000ooooooooool0:_ooool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo
02Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo
00kooooo000Nooooo`03o`000?oooooooooo02[ooooo00?oo`00ooooooooool0Moooool00ooo003o
ooooooooo`0Sooooo`;o0000:oooool2o`000<cooooo0_l0000@ooooo`007_ooool00ol0003ooooo
ooooo`0Zooooo`03ool00?oooooooooo07Oooooo00?oo`00ooooooooool09?ooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool0017ooooo0ol0
0003ooooo`;o00001Oooool00ol0003oooooooooo`0Zooooo`03ool00?oooooooooo07Oooooo00?o
o`00ooooooooool09?ooool00ol0003oooooooooo`0Rooooo`?o00001?ooool00ol0003ooooooooo
o`3<ooooo`03o`000?oooooooooo00kooooo000Booooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02[ooooo00?oo`00ooooooooool0Mooo
ool00ooo003oooooooooo`0Tooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000?ooooo`Go00000_ooool0
1?l0003oooooooooool00004ooooo`;o0000:oooool00ooo003oooooooooo`1gooooo`03ool00?oo
oooooooo02?ooooo0_l0000Uooooo`03o`000?oooooooooo00?ooooo0ol0003:ooooo`?o00004?oo
ool000oooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo02[ooooo00?oo`00ooooooooool0Moooool00ooo003oooooooooo`0Tooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3<ooooo`03o`00
0?oooooooooo00kooooo000@ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0Zooooo`03ool00?oooooooooo07Oooooo00?oo`00ooooooooool0
9?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
c?ooool00ol0003oooooooooo`0>ooooo`004Oooool2o`0000?ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0Zooooo`03ool00?oooooooooo07Oooooo00?oo`00ooooooooool0
9?ooool00ol0003oooooooooo`0Rooooo`;o00001Oooool00ol0003oooooooooo`3<ooooo`03o`00
0?oooooooooo00kooooo000Booooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`03o`000?oo
oooooooo02[ooooo00?oo`00ooooooooool0Moooool00ooo003oooooooooo`0Sooooo`;o00009Ooo
ool00ol0003oooooooooo`03ooooo`;o0000c?ooool2o`00013ooooo000Nooooo`03o`000?oooooo
oooo02[ooooo00?oo`00ooooooooool0Moooool00ooo003oooooooooo`0Tooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`007_ooool00ol0
003oooooooooo`0Zooooo`03ool00?oooooooooo07Oooooo00?oo`00ooooooooool09?ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool001ko
oooo00?o0000ooooooooool0:_ooool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo02Co
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00ko
oooo000Nooooo`03o`000?oooooooooo02[ooooo00?oo`00ooooooooool0Moooool00ooo003ooooo
ooooo`0Sooooo`;o0000:oooool2o`000<cooooo0_l0000@ooooo`007_ooool00ol0003ooooooooo
o`0Zooooo`03ool00?oooooooooo07Oooooo00?oo`00ooooooooool09?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool001kooooo00?o0000
ooooooooool0:_ooool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo02Cooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000Noooo
o`03o`000?oooooooooo02[ooooo00?oo`00ooooooooool0Moooool00ooo003oooooooooo`0Toooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>oooo
o`007_ooool00ol0003oooooooooo`0Zooooo`03ool00?oooooooooo07Oooooo00?oo`00oooooooo
ool08oooool2o`0002_ooooo0_l0003<ooooo`;o00004?ooool001kooooo00?o0000ooooooooool0
:_ooool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo02Cooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`000?oo
oooooooo02[ooooo00?oo`00ooooooooool0Moooool00ooo003oooooooooo`0Tooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`007_ooool0
0ol0003oooooooooo`0Zooooo`03ool00?oooooooooo07Oooooo00?oo`00ooooooooool09?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool0
01kooooo00?o0000ooooooooool0:_ooool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo
02?ooooo0_l0000[ooooo`;o0000c?ooool2o`00013ooooo000Nooooo`03o`000?oooooooooo02[o
oooo00?oo`00ooooooooool0Moooool00ooo003oooooooooo`0Tooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`004?ooool3o`0000Cooooo
0_l00005ooooo`03o`000?oooooooooo02[ooooo00?oo`00ooooooooool0Moooool00ooo003ooooo
ooooo`0Tooooo`03o`000?oooooooooo027ooooo1Ol00003ooooo`03o`000?oooooooooo0<cooooo
00?o0000ooooooooool03_ooool000oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0:_ooool00ooo003oooooooooo`1gooooo`03
ool00?oooooooooo02Cooooo00?o0000ooooooooool08_ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool001?ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`02ooooo`;o0000:oooool00ooo003oooooooooo`1goooo
o`03ool00?oooooooooo02?ooooo0_l0000Uooooo`03o`000?oooooooooo00?ooooo0ol0003:oooo
o`?o00004?ooool001?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02[ooooo00?oo`00ooooooooool0Moooool00ooo003oooooooooo`0Toooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3<oooo
o`03o`000?oooooooooo00kooooo000?ooooo`Co00000oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo02[ooooo00?oo`00ooooooooool0Moooool00ooo003oooooooooo`0Toooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo0<cooooo00?o0000ooooooooool03_ooool000oooooo00?o0000ooooooooool01?ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo02[ooooo00?oo`00ooooooooool0Moooool0
0ooo003oooooooooo`0Tooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool000oooooo1Ol00003
ooooo`;o00001Oooool00ol0003oooooooooo`0Zooooo`03ool00?oooooooooo07Oooooo00?oo`00
ooooooooool08oooool2o`0002Cooooo0ol00004ooooo`;o0000c?ooool2o`00013ooooo000Noooo
o`03o`000?oooooooooo02[ooooo00?oo`00ooooooooool0Moooool00ooo003oooooooooo`0Toooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>oooo
o`007_ooool00ol0003oooooooooo`0Zooooo`03ool00?oooooooooo07Oooooo00?oo`00oooooooo
ool09?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0<cooooo00?o0000oooooooo
ool03_ooool001kooooo00?o0000ooooooooool0:_ooool00ooo003oooooooooo`1gooooo`03ool0
0?oooooooooo02Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`00
0?oooooooooo00kooooo000Nooooo`03o`000?oooooooooo02[ooooo00?oo`00ooooooooool0Mooo
ool00ooo003oooooooooo`0Sooooo`;o0000:oooool2o`000<cooooo0_l0000@ooooo`007_ooool0
0ol0003oooooooooo`0Zooooo`03ool00?oooooooooo07Oooooo00?oo`00ooooooooool09?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool0
01kooooo00?o0000ooooooooool0:_ooool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo
02Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo
00kooooo000Nooooo`03o`000?oooooooooo02[ooooo00?oo`00ooooooooool0Moooool00ooo003o
ooooooooo`0Tooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003o
ooooooooo`0>ooooo`007_ooool00ol0003oooooooooo`0Zooooo`03ool00?oooooooooo07Oooooo
00?oo`00ooooooooool09?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0<cooooo
00?o0000ooooooooool03_ooool001kooooo00?o0000ooooooooool0:_ooool00ooo003ooooooooo
o`1gooooo`03ool00?oooooooooo02?ooooo0_l0000[ooooo`;o0000c?ooool2o`00013ooooo000N
ooooo`03o`000?oooooooooo02[ooooo00?oo`00ooooooooool0Moooool00ooo003oooooooooo`0T
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>
ooooo`007_ooool00ol0003oooooooooo`0Zooooo`03ool00?oooooooooo07Oooooo00?oo`00oooo
ooooool09?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0<cooooo00?o0000oooo
ooooool03_ooool001kooooo00?o0000ooooooooool0:_ooool00ooo003oooooooooo`1gooooo`03
ool00?oooooooooo02Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03
o`000?oooooooooo00kooooo000Nooooo`03o`000?oooooooooo02[ooooo00?oo`00ooooooooool0
Moooool00ooo003oooooooooo`0Sooooo`;o0000:oooool2o`000<cooooo0_l0000@ooooo`004?oo
ool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo02[ooooo00?oo`00ooooooooool0Mooo
ool00ooo003oooooooooo`0Tooooo`03o`000?oooooooooo02;ooooo0ol00004ooooo`03o`000?oo
oooooooo0<cooooo00?o0000ooooooooool03_ooool000oooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`1gooooo`03ool00?oooooooooo02Cooooo00?o0000ooooooooool08Oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`00
3oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`0Yooooo`?oo`00Moooool3ool002Gooooo00?o0000ooooooooool09Oooool01Ol0
003ooooooooooooooooo00000<kooooo00?o0000ooooooooool03_ooool000oooooo1?l00003oooo
o`04o`000?ooooooooooo`0000Cooooo0_l0000Zooooo`?oo`00Moooool3ool002Cooooo0_l0000U
ooooo`;o00001?ooool3o`000<[ooooo0ol0000@ooooo`003oooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00?ooooo0ooo000Iooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0Gooooo`?oo`001Oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo02Gooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00kooooo000@ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo027ooooo00Go0000oooooooooooooooo
o`000003ooooom3o00004?ooool0017ooooo0_l00004ooooo`;o00001Oooooo?o`0002Cooooo0ol0
003Tooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooo
oooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00\
\>"],
  ImageRangeCache->{{{0, 503}, {310.438, 0}} -> {-0.0514703, -0.0309082, \
0.0041808, 0.0041808}, {{12.3125, 240.062}, {303, 162.25}} -> {-6.7051, \
-10.9404, 0.0502515, 0.494487}, {{262.875, 490.688}, {303, 162.25}} -> \
{-19.2978, -3.87259, 0.0502515, 0.0463064}, {{12.3125, 240.062}, {148.125, \
7.375}} -> {-5.16061, -87.2864, 0.147363, 0.49332}, {{262.875, 490.688}, \
{148.125, 7.375}} -> {-42.1612, -11.7081, 0.147552, 0.0492634}}]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DTFT vs. DFT: Example #6: sum of cosine waves (DC, (1+1/6) Hz, \
(2+1/6)Hz)\
\>", "Section"],

Cell[CellGroupData[{

Cell["Sampled sequence", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(x[t_] := 
        1\  + \ 2\ Cos[2 \((1 + 1/6)\) \[Pi]\ t]\  + \ 
          4\ Cos[\((4  \[Pi]\  + \ 2  \[Pi]\ \((1/6)\))\) t];\)\), "\n", 
    \(\(xd = \ sampler[x, fs = 10, {0, 3}];\)\), "\[IndentingNewLine]", 
    \(\(If[OddQ[Length[xd]], \ xd\  = \ Drop[xd, \(-1\)]];\)\), "\n", 
    \(\(gx\  = \ 
        DiscreteListPlot2[xd, \ Blue, \ Frame \[Rule] True, 
          Axes \[Rule] {True, False}, \ ImageSize \[Rule] 504, \ 
          AspectRatio \[Rule] 1/3];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
%%ImageSize: 504 168 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0328407 0.135566 0.0271187 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18801 -0.0125 -3 -9 ]
[.18801 -0.0125 3 0 ]
[.35222 -0.0125 -6 -9 ]
[.35222 -0.0125 6 0 ]
[.51642 -0.0125 -6 -9 ]
[.51642 -0.0125 6 0 ]
[.68062 -0.0125 -6 -9 ]
[.68062 -0.0125 6 0 ]
[.84483 -0.0125 -6 -9 ]
[.84483 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02709 -12 -4.5 ]
[-0.0125 .02709 0 4.5 ]
[-0.0125 .08133 -12 -4.5 ]
[-0.0125 .08133 0 4.5 ]
[-0.0125 .13557 -6 -4.5 ]
[-0.0125 .13557 0 4.5 ]
[-0.0125 .1898 -6 -4.5 ]
[-0.0125 .1898 0 4.5 ]
[-0.0125 .24404 -6 -4.5 ]
[-0.0125 .24404 0 4.5 ]
[-0.0125 .29828 -6 -4.5 ]
[-0.0125 .29828 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18801 0 m
.18801 .00625 L
s
[(5)] .18801 -0.0125 0 1 Mshowa
.35222 0 m
.35222 .00625 L
s
[(10)] .35222 -0.0125 0 1 Mshowa
.51642 0 m
.51642 .00625 L
s
[(15)] .51642 -0.0125 0 1 Mshowa
.68062 0 m
.68062 .00625 L
s
[(20)] .68062 -0.0125 0 1 Mshowa
.84483 0 m
.84483 .00625 L
s
[(25)] .84483 -0.0125 0 1 Mshowa
.125 Mabswid
.05665 0 m
.05665 .00375 L
s
.08949 0 m
.08949 .00375 L
s
.12233 0 m
.12233 .00375 L
s
.15517 0 m
.15517 .00375 L
s
.22085 0 m
.22085 .00375 L
s
.25369 0 m
.25369 .00375 L
s
.28654 0 m
.28654 .00375 L
s
.31938 0 m
.31938 .00375 L
s
.38506 0 m
.38506 .00375 L
s
.4179 0 m
.4179 .00375 L
s
.45074 0 m
.45074 .00375 L
s
.48358 0 m
.48358 .00375 L
s
.54926 0 m
.54926 .00375 L
s
.5821 0 m
.5821 .00375 L
s
.61494 0 m
.61494 .00375 L
s
.64778 0 m
.64778 .00375 L
s
.71346 0 m
.71346 .00375 L
s
.74631 0 m
.74631 .00375 L
s
.77915 0 m
.77915 .00375 L
s
.81199 0 m
.81199 .00375 L
s
.87767 0 m
.87767 .00375 L
s
.91051 0 m
.91051 .00375 L
s
.94335 0 m
.94335 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02709 m
.00625 .02709 L
s
[(-4)] -0.0125 .02709 1 0 Mshowa
0 .08133 m
.00625 .08133 L
s
[(-2)] -0.0125 .08133 1 0 Mshowa
0 .13557 m
.00625 .13557 L
s
[(0)] -0.0125 .13557 1 0 Mshowa
0 .1898 m
.00625 .1898 L
s
[(2)] -0.0125 .1898 1 0 Mshowa
0 .24404 m
.00625 .24404 L
s
[(4)] -0.0125 .24404 1 0 Mshowa
0 .29828 m
.00625 .29828 L
s
[(6)] -0.0125 .29828 1 0 Mshowa
.125 Mabswid
0 .04065 m
.00375 .04065 L
s
0 .05421 m
.00375 .05421 L
s
0 .06777 m
.00375 .06777 L
s
0 .09489 m
.00375 .09489 L
s
0 .10845 m
.00375 .10845 L
s
0 .12201 m
.00375 .12201 L
s
0 .14913 m
.00375 .14913 L
s
0 .16268 m
.00375 .16268 L
s
0 .17624 m
.00375 .17624 L
s
0 .20336 m
.00375 .20336 L
s
0 .21692 m
.00375 .21692 L
s
0 .23048 m
.00375 .23048 L
s
0 .2576 m
.00375 .2576 L
s
0 .27116 m
.00375 .27116 L
s
0 .28472 m
.00375 .28472 L
s
0 .01353 m
.00375 .01353 L
s
0 .31184 m
.00375 .31184 L
s
0 .3254 m
.00375 .3254 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.02381 .32708 m
.02381 .33333 L
s
.18801 .32708 m
.18801 .33333 L
s
.35222 .32708 m
.35222 .33333 L
s
.51642 .32708 m
.51642 .33333 L
s
.68062 .32708 m
.68062 .33333 L
s
.84483 .32708 m
.84483 .33333 L
s
.125 Mabswid
.05665 .32958 m
.05665 .33333 L
s
.08949 .32958 m
.08949 .33333 L
s
.12233 .32958 m
.12233 .33333 L
s
.15517 .32958 m
.15517 .33333 L
s
.22085 .32958 m
.22085 .33333 L
s
.25369 .32958 m
.25369 .33333 L
s
.28654 .32958 m
.28654 .33333 L
s
.31938 .32958 m
.31938 .33333 L
s
.38506 .32958 m
.38506 .33333 L
s
.4179 .32958 m
.4179 .33333 L
s
.45074 .32958 m
.45074 .33333 L
s
.48358 .32958 m
.48358 .33333 L
s
.54926 .32958 m
.54926 .33333 L
s
.5821 .32958 m
.5821 .33333 L
s
.61494 .32958 m
.61494 .33333 L
s
.64778 .32958 m
.64778 .33333 L
s
.71346 .32958 m
.71346 .33333 L
s
.74631 .32958 m
.74631 .33333 L
s
.77915 .32958 m
.77915 .33333 L
s
.81199 .32958 m
.81199 .33333 L
s
.87767 .32958 m
.87767 .33333 L
s
.91051 .32958 m
.91051 .33333 L
s
.94335 .32958 m
.94335 .33333 L
s
.97619 .32958 m
.97619 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .02709 m
1 .02709 L
s
.99375 .08133 m
1 .08133 L
s
.99375 .13557 m
1 .13557 L
s
.99375 .1898 m
1 .1898 L
s
.99375 .24404 m
1 .24404 L
s
.99375 .29828 m
1 .29828 L
s
.125 Mabswid
.99625 .04065 m
1 .04065 L
s
.99625 .05421 m
1 .05421 L
s
.99625 .06777 m
1 .06777 L
s
.99625 .09489 m
1 .09489 L
s
.99625 .10845 m
1 .10845 L
s
.99625 .12201 m
1 .12201 L
s
.99625 .14913 m
1 .14913 L
s
.99625 .16268 m
1 .16268 L
s
.99625 .17624 m
1 .17624 L
s
.99625 .20336 m
1 .20336 L
s
.99625 .21692 m
1 .21692 L
s
.99625 .23048 m
1 .23048 L
s
.99625 .2576 m
1 .2576 L
s
.99625 .27116 m
1 .27116 L
s
.99625 .28472 m
1 .28472 L
s
.99625 .01353 m
1 .01353 L
s
.99625 .31184 m
1 .31184 L
s
.99625 .3254 m
1 .3254 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
0 .13557 m
1 .13557 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .13557 m
.02381 .3254 L
s
.05665 .13557 m
.05665 .22554 L
s
.08949 .13557 m
.08949 .06926 L
s
.12233 .13557 m
.12233 .06705 L
s
.15517 .13557 m
.15517 .18222 L
s
.18801 .13557 m
.18801 .20966 L
s
.22085 .13557 m
.22085 .1124 L
s
.25369 .13557 m
.25369 .07686 L
s
.28654 .13557 m
.28654 .20089 L
s
.31938 .13557 m
.31938 .31743 L
s
.35222 .13557 m
.35222 .24404 L
s
.38506 .13557 m
.38506 .0708 L
s
.4179 .13557 m
.4179 .03105 L
s
.45074 .13557 m
.45074 .15287 L
s
.48358 .13557 m
.48358 .2325 L
s
.51642 .13557 m
.51642 .16268 L
s
.54926 .13557 m
.54926 .09287 L
s
.5821 .13557 m
.5821 .1725 L
s
.61494 .13557 m
.61494 .29432 L
s
.64778 .13557 m
.64778 .25457 L
s
.68062 .13557 m
.68062 .08133 L
s
.71346 .13557 m
.71346 .00794 L
s
.74631 .13557 m
.74631 .12448 L
s
.77915 .13557 m
.77915 .2485 L
s
.81199 .13557 m
.81199 .21297 L
s
.84483 .13557 m
.84483 .11571 L
s
.87767 .13557 m
.87767 .14315 L
s
.91051 .13557 m
.91051 .25832 L
s
.94335 .13557 m
.94335 .25611 L
s
.97619 .13557 m
.97619 .09983 L
s
.005 w
.02381 .3254 Mdot
.05665 .22554 Mdot
.08949 .06926 Mdot
.12233 .06705 Mdot
.15517 .18222 Mdot
.18801 .20966 Mdot
.22085 .1124 Mdot
.25369 .07686 Mdot
.28654 .20089 Mdot
.31938 .31743 Mdot
.35222 .24404 Mdot
.38506 .0708 Mdot
.4179 .03105 Mdot
.45074 .15287 Mdot
.48358 .2325 Mdot
.51642 .16268 Mdot
.54926 .09287 Mdot
.5821 .1725 Mdot
.61494 .29432 Mdot
.64778 .25457 Mdot
.68062 .08133 Mdot
.71346 .00794 Mdot
.74631 .12448 Mdot
.77915 .2485 Mdot
.81199 .21297 Mdot
.84483 .11571 Mdot
.87767 .14315 Mdot
.91051 .25832 Mdot
.94335 .25611 Mdot
.97619 .09983 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 168},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000Z2000`400?l00000o`00003ooooooooi
ooooo`00:Oooool2o`0004Sooooo0ol00015ooooo`?o00001?ooool2o`0004;ooooo0ol00003oooo
o`?o0000@Oooool5o`0000?ooooo0_l00011ooooo`Go00000_ooool3o`0005?ooooo000Xooooo`04
o`000?ooooooooooo`0004Kooooo00Go0000ooooooooooooooooo`000015ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo0000@_ooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool0?oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
047ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo053ooooo000X
ooooo`04o`000?ooooooooooo`0004[ooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0004;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`10ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000@_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo053ooooo000Xooooo`04o`000?ooooooooooo`0004[o
oooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
04;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`11ooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0D?ooool002Sooooo00Co0000oooooooooooo0000A_ooool4o`0004Kooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00012ooooo`04o`000?ooooooooooooooo`Co0000
@Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000@?ooool01_l0
003ooooooooooooooooo0000ooooo`Co0000Doooool002Sooooo00Co0000oooooooooooo0000A_oo
ool00ol0003oooooooooo`16ooooo`;o00001?ooool01?l0003oooooooooool00011ooooo`;o0000
0oooool00ol0003oooooooooo`12ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00010ooooo`07o`000?ooooooooooooooool0003oooooo`00001Fooooo`00:Oooool2
o`0004Oooooo1Ol00015ooooo`03o`000?oooooooooo00?ooooo0_l00013ooooo`04o`000?oooooo
ooooooooo`Go0000@Oooool3o`0000Cooooo0_l00012ooooo`?o00000_ooool5o`0005;ooooo003o
ooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003o
ooooooWooooo003oooooooWooooo000Ooooooooo0000bol0000?ooooo`007oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool03Oooool001oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo00cooooo0_l00?ljooooo`03o`000?oooooooooo04Cooooo00?o0000
ooooooooool03Oooool001oooooo00?o0000ooooooooool0oooooom4ooooo`;o003oPOooool00ol0
003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`3oooooodCooooo00?o003ooooooooo
ool0P?ooool00ol0003oooooooooo`0=ooooo`007oooool3o`000?ooooooA?ooool00ol00?oooooo
ooooo`1oooooo`;o00003oooool001oooooo00?o0000ooooooooool0oooooom4ooooo`03o`00oooo
oooooooo083ooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0oooooom4
ooooo`03o`00oooooooooooo083ooooo00?o0000ooooooooool03Oooool001oooooo00?o0000oooo
ooooool0oooooom4ooooo`03o`00oooooooooooo083ooooo00?o0000ooooooooool03Oooool001Ko
oooo0ol00006ooooo`03o`000?oooooooooo0?ooooooA?ooool00ol00?ooooooooooo`20ooooo`03
o`000?oooooooooo00gooooo000Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooom4ooooo`03o`00oooooooooooo083ooooo00?o0000ooooooooool03Oooool000kooooo1Ol0
00000ooooooo0000o`000003o`0000Kooooo00?o0000ooooooooool0oooooom4ooooo`03o`00oooo
oooooooo083ooooo00?o0000ooooooooool03Oooool001Cooooo00Co0000oooooooooooo00001ooo
ool4o`000?oooooo@oooool00ol00?ooooooooooo`1mooooo`Co00003oooool001Gooooo00?o0000
ooooool000001oooool00ol0003oooooooooo`2looooo`;o003oQOooool00ol00?ooooooooooo`20
ooooo`03o`000?oooooooooo00gooooo000Fooooo`;o00001oooool00ol0003oooooooooo`2loooo
o`;o003oQOooool00ol00?ooooooooooo`20ooooo`03o`000?oooooooooo00gooooo000Gooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0_?ooool00ol00?ooooooooooo`24ooooo`03
o`00oooooooooooo083ooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0
_?ooool00ol00?ooooooooooo`24ooooo`03o`00oooooooooooo083ooooo00?o0000ooooooooool0
3Oooool001oooooo00?o0000ooooooooool0_?ooool00ol00?ooooooooooo`24ooooo`03o`00oooo
oooooooo083ooooo00?o0000ooooooooool03Oooool001oooooo0ol0002looooo`03o`00oooooooo
oooo08Cooooo00?o003oooooooooool0Ooooool2o`0000oooooo000Oooooo`03o`000?oooooooooo
0;cooooo00?o003oooooooooool0Q?ooool00ol00?ooooooooooo`20ooooo`03o`000?oooooooooo
00gooooo000Oooooo`03o`000?oooooooooo0;cooooo00?o003oooooooooool0Q?ooool00ol00?oo
ooooooooo`20ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo0;cooooo
00?o003oooooooooool0Q?ooool00ol00?ooooooooooo`20ooooo`03o`000?oooooooooo00gooooo
000Oooooo`03o`000?oooooooooo0;cooooo00?o003oooooooooool0Q?ooool00ol00?oooooooooo
o`20ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo0;cooooo00?o003o
ooooooooool0Q?ooool00ol00?ooooooooooo`20ooooo`03o`000?oooooooooo00gooooo000Ooooo
o`?o0000_?ooool00ol00?ooooooooooo`24ooooo`03o`00oooooooooooo07oooooo0_l0000?oooo
o`007oooool00ol0003oooooooooo`2looooo`03o`00oooooooooooo08Cooooo00?o003ooooooooo
ool0P?ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`2looooo`03o`00
oooooooooooo08Cooooo00?o003oooooooooool0P?ooool00ol0003oooooooooo`0=ooooo`007ooo
ool00ol0003oooooooooo`2looooo`03o`00oooooooooooo08Cooooo00?o003oooooooooool0P?oo
ool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`2looooo`03o`00oooooooo
oooo08Cooooo00?o003oooooooooool0P?ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0
003oooooooooo`0eooooo`;o003oQOooool00ol00?ooooooooooo`24ooooo`03o`00oooooooooooo
083ooooo00?o0000ooooooooool03Oooool001oooooo0ol0000Vooooo`;o003o3Oooool2o`00ohGo
oooo00?o003oooooooooool0Q?ooool00ol00?ooooooooooo`1oooooo`;o00003oooool001oooooo
00?o0000ooooooooool09_ooool2o`00o`gooooo00?o003oooooooooool0MOooool2o`00o`gooooo
00?o003oooooooooool0Q?ooool00ol00?ooooooooooo`20ooooo`03o`000?oooooooooo00gooooo
000Oooooo`03o`000?oooooooooo02Kooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`1eooooo`;o003o3Oooool00ol00?ooooooooooo`24ooooo`03o`00oooooooooooo083ooooo00?o
0000ooooooooool03Oooool001oooooo00?o0000ooooooooool09_ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo07Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`24
ooooo`03o`00oooooooooooo083ooooo00?o0000ooooooooool03Oooool001Cooooo1Ol00006oooo
o`03o`000?oooooooooo02Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0ioooo
o`;o003o>_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo08Cooooo00?o003ooooo
ooooool0P?ooool00ol0003oooooooooo`0=ooooo`005Oooool01?l0003oooooooooool00006oooo
o`03o`000?oooooooooo02Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0ioooo
o`;o003o>_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo08Cooooo00?o003ooooo
ooooool0P?ooool00ol0003oooooooooo`0=ooooo`003_ooool5o`0000?ooooo00?o0000oooooooo
ool01_ooool4o`0002Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03
o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1eooooo`;o
003o3Oooool00ol00?ooooooooooo`1mooooo`Co00003oooool001Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Vooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
MOooool2o`00o`gooooo00?o003oooooooooool0P?ooool00ol0003oooooooooo`0=ooooo`005?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool09_ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0>Oooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo07Gooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`20ooooo`03o`000?oooooooooo00gooooo000Dooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`0Vooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
MOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo083ooooo00?o0000ooooooooool0
3Oooool001Gooooo0ol00007ooooo`03o`000?oooooooooo02Kooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`1eooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0P?oo
ool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0Vooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool0>Oooool2o`00oc[ooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`20ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo
02Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo
03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`;o003o>_ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo083ooooo00?o0000ooooooooool03Oooool001oo
oooo0ol0000Vooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?oo
ooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?oo
ooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0Ooooool2o`0000oo
oooo000Oooooo`03o`000?oooooooooo02Kooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`1eooooo`;o003o2Oooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003ooooooooo
o`0Vooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?oooooooooo
o`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?oooooooooo
o`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0MOooool2o`00o`Wooooo00?o
0000ooooooooool03Oooool001oooooo00?o0000ooooooooool09_ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo07Gooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0=
ooooo`007oooool00ol0003oooooooooo`0Vooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool0>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool0>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool0MOooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00gooooo000Oooooo`03
o`000?oooooooooo02Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03
o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03
o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1eooooo`03
o`00oooooooooooo00Sooooo00?o0000ooooooooool03Oooool001oooooo0ol0000Vooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0iooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0iooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool0MOooool00ol00?ooooooooooo`07ooooo`;o0000
3oooool001oooooo00?o0000ooooooooool09_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo02[ooooo0_l00?l=ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`1eooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool03Ooo
ool001oooooo00?o0000ooooooooool09_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo02[ooooo0_l00?l=ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`1eooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool03Oooool0
01oooooo00?o0000ooooooooool09_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
02[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool0>Oooool2o`00oc[ooooo00?o003oooooooooool02?ooool00ol0
003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0Vooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wo
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo03Wo
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`;o003o>_ooool00ol00?oo
ooooooooo`08ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo02Kooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo
00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo
00?o003oooooooooool0>Oooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00gooooo
000Oooooo`?o00009_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo02[ooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00Oooooo0_l0
000?ooooo`007oooool00ol0003oooooooooo`0Vooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`;o003o:oooool00ol00?ooooooooooo`0i
ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool03Oooool001oooooo00?o0000oooo
ooooool09_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo02[ooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool0>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool03?ooool2o`00ob_ooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`08oooo
o`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo02Kooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003ooooooooo
ool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool0:_ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00Sooooo00?o0000oooooooo
ool03Oooool001Kooooo0_l00007ooooo`03o`000?oooooooooo02Kooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0
>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
:_ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool0
3Oooool001Gooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0Vooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00
oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo02[ooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`08ooooo`03o`00
0?oooooooooo00gooooo000Eooooo`04o`000?ooooooooooo`0000Kooooo2ol000000ol00?oo0000
o`00000<o`000003o`00ool0003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000
o`00000<o`000003o`00ool0003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000
o`00000<o`000003o`00ool0003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000
o`00000<o`000003o`00ool0003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000
o`00000<o`000003o`00ool0003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000
o`00000<o`000003o`00ool0003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000
o`00000<o`000003o`00ool0003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000
o`00000<o`000003o`00ool0003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000
o`00000<o`000003o`00ool0003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000
o`00000<o`000003o`00ool0003o000000co000000?o003oo`000?l000002Ol0000?ooooo`005Ooo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
:_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
:_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
6oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01Oooooo00?o0000ooooooooool0
3Oooool001Gooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo02[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo02[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo01_ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Kooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Gooooo`03o`00
0?oooooooooo00gooooo000Eooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0
2?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
6oooool2o`00o`gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Gooooo`03o`00
0?oooooooooo00gooooo000Fooooo`;o00001oooool00ol0003oooooooooo`08ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo02[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo02[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo01_ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Kooooo`;o003o3Ooo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01Oooooo00?o0000ooooooooool03Ooo
ool001oooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo02[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo01Oooooo00?o0000ooooooooool03Oooool001oooooo0ol00008ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
02[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
02[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
01_ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool05_ooool2o`0000oooooo000Oooooo`03o`000?oooooooooo00So
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo02[o
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo00go
oooo000Oooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0Zooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0:_ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0:_ooool2o`00o`gooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01Oooooo
00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool02?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0Zooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0Zooooo`;o003o3Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01_ooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool05oooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`08
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0K
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0i
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo01Oooooo00?o0000ooooooooool03Oooool001oooooo00?o0000oooo
ooooool02?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo02[ooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool06oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo02[ooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo00gooooo000Oooooo`03
o`000?oooooooooo00Sooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Zooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`;o
003o7?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo02[ooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo00gooooo000Oooooo`?o0000
2?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo0_l00?lLooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo01Kooooo0_l0000?ooooo`007oooool00ol0003oooooooooo`08ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo02[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo03Wooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo02[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Gooooo`03o`000?oo
oooooooo00gooooo000Oooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0:_ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool0
0ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0:_ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01Oooooo00?o0000ooooooooool03Oooool0
01oooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
02[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo
02[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool05oooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003o
ooooooooo`08ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0:_ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0:_ooool2o`00o`go
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01Oo
oooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool02?ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0Zooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0iooooo`03o`00oooooooooooo02[ooooo0_l00?l=ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo02[ooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo00gooooo
000Oooooo`?o00002?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo02[ooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01Kooooo0_l0
000?ooooo`007oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo02[ooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003o
ooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool05oooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`08oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool0:_ooool2o`00o`gooooo00?o003ooooo
ooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool0>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo02[ooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo00gooooo000Dooooo`Go
00001_ooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool0:_ooool2o`00o`gooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0iooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo02[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Gooooo`03
o`000?oooooooooo00gooooo000Eooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooooooo
ool02?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003ooooooooo
ool0:_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool0>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo02[ooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo00gooooo000Fooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo03Wooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0iooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo02[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Gooooo`03o`00
0?oooooooooo00gooooo000Gooooo`03o`000?oooooooooo00Gooooo1?l00007ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0Zooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooo
oooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo01Cooooo1?l0000?ooooo`005?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool02?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o
003oooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0>Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo02[ooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo00gooooo000D
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`08ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0Zooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooo
oooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo01Oooooo00?o0000ooooooooool03Oooool001Gooooo0ol00007ooooo`03o`000?oooooo
oooo00Sooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooo
oooo02[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo03Wooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool05oooool00ol0003oooooooooo`0=ooooo`007oooool00ol0
003oooooooooo`08ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol0
0?ooooooooooo`0Zooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0:_ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo01Oooooo00?o0000ooooooooool03Oooool001oo
oooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wo
oooo00?o003oooooooooool0:_ooool2o`00o`gooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0:_ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo01Oooooo00?o0000ooooooooool03Oooool001oooooo
0ol00008ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?oooooo
ooooo`0Zooooo`;o003o3Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo
00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool05_ooool2o`0000oooooo000Oooooo`03o`000?oooooooooo00Sooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0:_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01Oooooo00?o
0000ooooooooool03Oooool001oooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Z
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool05oooool00ol0003oooooooooo`0=
ooooo`007oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool0>Oooool2o`00oc[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0ioooo
o`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0ioooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo01Oooooo00?o0000ooooooooool03Oooool001oooooo00?o0000oooooooo
ool02?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo0_l00?ljooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0iooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`;o
003o:oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01Oooooo00?o0000oooooooo
ool03Oooool001oooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo07Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00
oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00
oooooooooooo00cooooo0_l00?l[ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
5oooool00ol0003oooooooooo`0=ooooo`007oooool3o`0000Sooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`1eooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Ooo
ool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Ooo
ool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool05_oo
ool2o`0000oooooo000Oooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`1eooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool0
0ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool0
0ol00?ooooooooooo`0iooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool05oooool0
0ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool0MOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
03Wooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
03Wooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
01Oooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool02?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo07Gooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0Gooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo00Sooooo
00?o003oooooooooool03?ooool2o`00ogKooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0iooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0Gooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo00Sooooo00?o
003oooooooooool03?ooool2o`00ogKooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0iooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0iooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0Gooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo00Sooooo00?o003o
ooooooooool0Q?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003o
ooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003o
ooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01Oooooo00?o0000
ooooooooool03Oooool001oooooo0ol00008ooooo`03o`00oooooooooooo08Cooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0iooooo`;o003o>_ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo03Wooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo01Kooooo0_l0000?ooooo`007oooool00ol0003oooooooooo`08ooooo`03
o`00oooooooooooo08Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`;o
003o>_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003ooooooooo
ool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01Oooooo00?o0000oooooooo
ool03Oooool001oooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`24ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool0MOooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo03Wooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo01Oooooo00?o0000ooooooooool03Oooool001Kooooo0ol00006ooooo`03o`000?oo
oooooooo00Sooooo00?o003oooooooooool0Q?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo07Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0iooooo`03o`00oooo
oooooooo03Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Gooooo`03o`000?oo
oooooooo00gooooo000Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool0
0ol00?ooooooooooo`24ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0MOooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0>Oooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01Oooooo00?o0000ooooooooool03Oooool0
01Cooooo1Ol00006ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool0Q?ooool00ol0
0?ooooooooooo`0<ooooo`;o003oM_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
03Wooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
01Oooooo00?o0000ooooooooool03Oooool001Cooooo00Co0000oooooooooooo00001oooool4o`00
00Oooooo00?o003oooooooooool0Q?ooool00ol00?ooooooooooo`0<ooooo`;o003oM_ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool0>Oooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo01Cooooo1?l0000?ooooo`005Oooool00ol0003o
ooooo`000007ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool0Q?ooool00ol00?oo
ooooooooo`24ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0>Oooool2o`00oc[o
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo00go
oooo000Fooooo`;o00001oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo08Cooooo
00?o003oooooooooool0Q?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03Wooooo
0_l00?ljooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool05oooool00ol0003ooooo
ooooo`0=ooooo`005oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o
003oooooooooool0Q?ooool00ol00?ooooooooooo`24ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0MOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01Oooooo00?o
0000ooooooooool03Oooool001oooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`24
ooooo`03o`00oooooooooooo08Cooooo00?o003oooooooooool03?ooool2o`00ogKooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo00gooooo000Ooooo
o`03o`000?oooooooooo00Sooooo00?o003oooooooooool0Q?ooool00ol00?ooooooooooo`24oooo
o`03o`00oooooooooooo00cooooo0_l00?mfooooo`03o`00oooooooooooo00cooooo0_l00?lHoooo
o`03o`000?oooooooooo00gooooo000Oooooo`?o00002?ooool00ol00?ooooooooooo`24ooooo`03
o`00oooooooooooo08Cooooo00?o003oooooooooool0Q?ooool2o`00o`gooooo0_l00?lGooooo`;o
00003oooool001oooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`24ooooo`03o`00
oooooooooooo08Cooooo00?o003oooooooooool0Q?ooool2o`00obOooooo00?o0000ooooooooool0
3Oooool001oooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`24ooooo`03o`00oooo
oooooooo08Cooooo00?o003oooooooooool0[Oooool00ol0003oooooooooo`0=ooooo`007oooool0
0ol0003oooooooooo`08ooooo`03o`00oooooooooooo08Cooooo00?o003oooooooooool0Q?ooool0
0ol00?ooooooooooo`2]ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo
00Sooooo00?o003oooooooooool0Q?ooool00ol00?ooooooooooo`24ooooo`03o`00oooooooooooo
0:gooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool02?ooool00ol00?oo
ooooooooo`24ooooo`03o`00oooooooooooo08Cooooo00?o003oooooooooool0[Oooool00ol0003o
ooooooooo`0=ooooo`007oooool3o`0000Sooooo00?o003oooooooooool0Q?ooool00ol00?oooooo
ooooo`24ooooo`03o`00oooooooooooo0:cooooo0_l0000?ooooo`007oooool00ol0003ooooooooo
o`08ooooo`03o`00oooooooooooo08Cooooo00?o003oooooooooool0Q?ooool00ol00?oooooooooo
o`2]ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo00Sooooo00?o003o
ooooooooool0Q?ooool00ol00?ooooooooooo`24ooooo`03o`00oooooooooooo0:gooooo00?o0000
ooooooooool03Oooool001oooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`24oooo
o`03o`00oooooooooooo08Cooooo00?o003oooooooooool0[Oooool00ol0003oooooooooo`0=oooo
o`007oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo08Cooooo00?o003ooooooooo
ool0Q?ooool00ol00?ooooooooooo`2]ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`00
0?oooooooooo00Sooooo00?o003oooooooooool0Q?ooool00ol00?ooooooooooo`24ooooo`03o`00
oooooooooooo0:gooooo00?o0000ooooooooool03Oooool001oooooo0ol00008ooooo`03o`00oooo
oooooooo08Cooooo00?o003oooooooooool0Q?ooool00ol00?ooooooooooo`2/ooooo`;o00003ooo
ool001oooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`24ooooo`03o`00oooooooo
oooo08Cooooo00?o003oooooooooool0[Oooool00ol0003oooooooooo`0=ooooo`007oooool00ol0
003oooooooooo`08ooooo`03o`00oooooooooooo08Cooooo00?o003oooooooooool0Q?ooool00ol0
0?ooooooooooo`2]ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo00So
oooo00?o003oooooooooool0Q?ooool00ol00?ooooooooooo`24ooooo`03o`00oooooooooooo0:go
oooo00?o0000ooooooooool03Oooool001Gooooo0ol00007ooooo`03o`000?oooooooooo00Sooooo
00?o003oooooooooool0Q?ooool00ol00?ooooooooooo`24ooooo`;o003o[_ooool00ol0003ooooo
ooooo`0=ooooo`005?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
2?ooool00ol00?ooooooooooo`24ooooo`03o`00oooooooooooo08Cooooo0_l00?n^ooooo`03o`00
0?oooooooooo00gooooo000Dooooo`05o`000?ooooooooooooooool000001_ooool4o`0000Oooooo
00?o003oooooooooool0Q?ooool00ol00?ooooooooooo`3ooooooc;ooooo1?l0000?ooooo`005?oo
ool4o`0000Oooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`24ooooo`03o`00oooo
oooooooo0?oooooo=Oooool00ol0003oooooooooo`0=ooooo`005?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool0Q?ooool00ol00?ooooooooooo`3o
ooooocGooooo00?o0000ooooooooool03Oooool001Gooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`08ooooo`03o`00oooooooooooo08Cooooo00?o003oooooooooool0ooooooleoooo
o`03o`000?oooooooooo00gooooo000Fooooo`;o00001oooool00ol0003oooooooooo`08ooooo`03
o`00oooooooooooo08Cooooo00?o003oooooooooool0ooooooleooooo`03o`000?oooooooooo00go
oooo000Oooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool0Q?ooool00ol00?oooooo
ooooo`3oooooocGooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool02?oo
ool00ol00?ooooooooooo`24ooooo`03o`00oooooooooooo0?oooooo=Oooool00ol0003ooooooooo
o`0=ooooo`007oooool3o`0000Sooooo00?o003oooooooooool0Q?ooool00ol00?ooooooooooo`3o
ooooocCooooo0_l0000?ooooo`007oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo
08Cooooo00?o003oooooooooool0ooooooleooooo`03o`000?oooooooooo00gooooo000Oooooo`03
o`000?oooooooooo00Sooooo00?o003oooooooooool0Q?ooool2o`00oooooooo=_ooool00ol0003o
ooooooooo`0=ooooo`007oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo08Cooooo
0_l00?ooooooocKooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool02?oo
ool00ol00?ooooooooooo`3ooooookcooooo00?o0000ooooooooool03Oooool001oooooo00?o0000
ooooooooool02?ooool2o`00oooooooo_Oooool00ol0003oooooooooo`0=ooooo`007oooool3o`00
00Sooooo0_l00?oooooookcooooo0_l0000?ooooo`007oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`14ooooo`03
o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
3Oooool001ooooooool0003;o`0000oooooo0000\
\>"],
  ImageRangeCache->{{{0, 503}, {167, 0}} -> {-2.84841, -6.1864, 0.0666496, \
0.0807125}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Magnitude plot of DTFT as a function of frequency", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(X\[Theta]\  = DTFT[xd, \[Theta]]\  // \ Simplify; 
    g1 = Plot[
        Abs[X\[Theta]\  /. \ \[Theta] \[Rule] \ 2  \[Pi]\ f/fs], {f, \(-fs\)/
            2, fs/2}, \ PlotStyle \[Rule] {Blue, \ Dashing[{ .01}]}, \ 
        PlotRange \[Rule] All, PlotPoints \[Rule] 200];\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.0050357 0.00974792 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00504 -6 -4.5 ]
[-0.0125 .00504 0 4.5 ]
[-0.0125 .10251 -12 -4.5 ]
[-0.0125 .10251 0 4.5 ]
[-0.0125 .19999 -12 -4.5 ]
[-0.0125 .19999 0 4.5 ]
[-0.0125 .29747 -12 -4.5 ]
[-0.0125 .29747 0 4.5 ]
[-0.0125 .39495 -12 -4.5 ]
[-0.0125 .39495 0 4.5 ]
[-0.0125 .49243 -12 -4.5 ]
[-0.0125 .49243 0 4.5 ]
[-0.0125 .58991 -12 -4.5 ]
[-0.0125 .58991 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00504 m
.00625 .00504 L
s
[(0)] -0.0125 .00504 1 0 Mshowa
0 .10251 m
.00625 .10251 L
s
[(10)] -0.0125 .10251 1 0 Mshowa
0 .19999 m
.00625 .19999 L
s
[(20)] -0.0125 .19999 1 0 Mshowa
0 .29747 m
.00625 .29747 L
s
[(30)] -0.0125 .29747 1 0 Mshowa
0 .39495 m
.00625 .39495 L
s
[(40)] -0.0125 .39495 1 0 Mshowa
0 .49243 m
.00625 .49243 L
s
[(50)] -0.0125 .49243 1 0 Mshowa
0 .58991 m
.00625 .58991 L
s
[(60)] -0.0125 .58991 1 0 Mshowa
.125 Mabswid
0 .02453 m
.00375 .02453 L
s
0 .04403 m
.00375 .04403 L
s
0 .06352 m
.00375 .06352 L
s
0 .08302 m
.00375 .08302 L
s
0 .12201 m
.00375 .12201 L
s
0 .14151 m
.00375 .14151 L
s
0 .161 m
.00375 .161 L
s
0 .1805 m
.00375 .1805 L
s
0 .21949 m
.00375 .21949 L
s
0 .23899 m
.00375 .23899 L
s
0 .25848 m
.00375 .25848 L
s
0 .27798 m
.00375 .27798 L
s
0 .31697 m
.00375 .31697 L
s
0 .33646 m
.00375 .33646 L
s
0 .35596 m
.00375 .35596 L
s
0 .37546 m
.00375 .37546 L
s
0 .41445 m
.00375 .41445 L
s
0 .43394 m
.00375 .43394 L
s
0 .45344 m
.00375 .45344 L
s
0 .47294 m
.00375 .47294 L
s
0 .51193 m
.00375 .51193 L
s
0 .53142 m
.00375 .53142 L
s
0 .55092 m
.00375 .55092 L
s
0 .57042 m
.00375 .57042 L
s
0 .60941 m
.00375 .60941 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00504 m
1 .00504 L
s
.99375 .10251 m
1 .10251 L
s
.99375 .19999 m
1 .19999 L
s
.99375 .29747 m
1 .29747 L
s
.99375 .39495 m
1 .39495 L
s
.99375 .49243 m
1 .49243 L
s
.99375 .58991 m
1 .58991 L
s
.125 Mabswid
.99625 .02453 m
1 .02453 L
s
.99625 .04403 m
1 .04403 L
s
.99625 .06352 m
1 .06352 L
s
.99625 .08302 m
1 .08302 L
s
.99625 .12201 m
1 .12201 L
s
.99625 .14151 m
1 .14151 L
s
.99625 .161 m
1 .161 L
s
.99625 .1805 m
1 .1805 L
s
.99625 .21949 m
1 .21949 L
s
.99625 .23899 m
1 .23899 L
s
.99625 .25848 m
1 .25848 L
s
.99625 .27798 m
1 .27798 L
s
.99625 .31697 m
1 .31697 L
s
.99625 .33646 m
1 .33646 L
s
.99625 .35596 m
1 .35596 L
s
.99625 .37546 m
1 .37546 L
s
.99625 .41445 m
1 .41445 L
s
.99625 .43394 m
1 .43394 L
s
.99625 .45344 m
1 .45344 L
s
.99625 .47294 m
1 .47294 L
s
.99625 .51193 m
1 .51193 L
s
.99625 .53142 m
1 .53142 L
s
.99625 .55092 m
1 .55092 L
s
.99625 .57042 m
1 .57042 L
s
.99625 .60941 m
1 .60941 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .06352 m
.02395 .06352 L
.02408 .0635 L
.02423 .06347 L
.02437 .06344 L
.02462 .06334 L
.02489 .0632 L
.02519 .063 L
.02551 .06273 L
.02608 .06211 L
.02722 .06035 L
.02847 .05764 L
.02973 .05413 L
.03109 .04955 L
.03355 .0395 L
.03593 .02833 L
.03718 .02239 L
.03787 .01938 L
.03821 .01805 L
.03852 .01696 L
.03882 .01607 L
.03898 .01568 L
.03915 .01534 L
.03924 .01519 L
.03932 .01507 L
.03948 .0149 L
.03956 .01484 L
.03966 .0148 L
.03974 .01479 L
.03982 .01481 L
.03997 .01489 L
.0401 .01502 L
.04024 .01523 L
.0404 .01552 L
.04071 .0163 L
.04101 .01722 L
.04331 .02736 L
.04579 .03913 L
.04809 .04882 L
.05031 .05628 L
.05156 .05947 L
.05269 .06169 L
.05327 .06257 L
.05389 .06331 L
.05442 .06377 L
.05472 .06397 L
.055 .0641 L
.05516 .06416 L
.05524 .06418 L
.05532 .0642 L
Mistroke
.05541 .06422 L
.05548 .06423 L
.05563 .06425 L
.05577 .06425 L
.05593 .06424 L
.05608 .06421 L
.05621 .06418 L
.05637 .06413 L
.05651 .06408 L
.05684 .0639 L
.05716 .06367 L
.05751 .06336 L
.05815 .06261 L
.05874 .06173 L
.06007 .05903 L
.06125 .05591 L
.0625 .05187 L
.06706 .03222 L
.0683 .02617 L
.0696 .02009 L
.07013 .01792 L
.07043 .01689 L
.07071 .01607 L
.07086 .01568 L
.07103 .01534 L
.07119 .01511 L
.07133 .01496 L
.07147 .01489 L
.07162 .01488 L
.07177 .01495 L
.07192 .0151 L
.07207 .01532 L
.07221 .01558 L
.07252 .01637 L
.0731 .01836 L
.07417 .02312 L
.07659 .03513 L
.07903 .0465 L
.08132 .05537 L
.08239 .05873 L
.08351 .06166 L
.0841 .06293 L
.08474 .06411 L
.08528 .06493 L
.08587 .06563 L
.0862 .06594 L
.08651 .06617 L
.0868 .06633 L
.08694 .0664 L
.08711 .06646 L
Mistroke
.08725 .0665 L
.08739 .06652 L
.08754 .06654 L
.08769 .06654 L
.08782 .06654 L
.08795 .06652 L
.08809 .06649 L
.08823 .06645 L
.0884 .06638 L
.08856 .0663 L
.08891 .06608 L
.08923 .06582 L
.08956 .06548 L
.09013 .06476 L
.09076 .06374 L
.09199 .06112 L
.09311 .05803 L
.09564 .04885 L
.09813 .0373 L
.10044 .02547 L
.1016 .01986 L
.10217 .01754 L
.10241 .0167 L
.10269 .01594 L
.10281 .01565 L
.10295 .0154 L
.1031 .0152 L
.10323 .01509 L
.10339 .01504 L
.10354 .01508 L
.10367 .01519 L
.10382 .01539 L
.10397 .01566 L
.10413 .01605 L
.10447 .01706 L
.10507 .01944 L
.10994 .04455 L
.11218 .05473 L
.11462 .06337 L
.11595 .06677 L
.11659 .06807 L
.11718 .06903 L
.11778 .06982 L
.11835 .07035 L
.11866 .07056 L
.11895 .0707 L
.1191 .07075 L
.11919 .07077 L
.11927 .07079 L
.11935 .0708 L
Mistroke
.11944 .07081 L
.11952 .07082 L
.1196 .07082 L
.11974 .07081 L
.11989 .07079 L
.12003 .07076 L
.12016 .07072 L
.12031 .07066 L
.12047 .07057 L
.12077 .07038 L
.12108 .07012 L
.12141 .06977 L
.12201 .06898 L
.12317 .06681 L
.12423 .06414 L
.12655 .0561 L
.12906 .0445 L
.13142 .0317 L
.13267 .02471 L
.13336 .02108 L
.13401 .01808 L
.13431 .01695 L
.13462 .01603 L
.13479 .01568 L
.13488 .01553 L
.13497 .01542 L
.13513 .01531 L
.13521 .01529 L
.13529 .01531 L
.13544 .0154 L
.13557 .01557 L
.13571 .01583 L
.13587 .0162 L
.13618 .01719 L
.13647 .01833 L
.13877 .03086 L
.14127 .04554 L
.14359 .05765 L
.14584 .0672 L
.14698 .07099 L
.14762 .07279 L
.14823 .07426 L
.14881 .07545 L
.14945 .0765 L
.14973 .07687 L
.15003 .07722 L
.15031 .07748 L
.15057 .07767 L
.15073 .07777 L
.1509 .07786 L
Mistroke
.15107 .07792 L
.15116 .07795 L
.15125 .07797 L
.15133 .07798 L
.15141 .07799 L
.15156 .078 L
.15172 .07798 L
.15181 .07797 L
.15189 .07795 L
.15203 .07791 L
.15217 .07786 L
.15247 .07769 L
.15277 .07747 L
.15309 .07716 L
.15369 .07638 L
.15425 .07544 L
.15551 .07252 L
.15674 .06867 L
.15806 .06351 L
.16046 .05157 L
.16306 .03586 L
.16429 .02803 L
.16495 .02386 L
.16558 .02027 L
.16611 .01771 L
.16626 .01711 L
.16641 .01662 L
.16654 .01626 L
.16668 .01595 L
.16683 .01574 L
.16698 .01564 L
.16712 .01566 L
.16726 .01579 L
.16742 .01606 L
.16756 .01641 L
.16789 .01755 L
.16846 .02033 L
.16907 .02398 L
.17017 .03131 L
.17267 .04846 L
.17506 .06352 L
.17633 .07044 L
.17766 .07682 L
.17886 .08155 L
.17949 .08367 L
.18017 .08564 L
.18079 .08714 L
.18136 .08825 L
.18194 .08912 L
.1822 .08943 L
Mistroke
.18248 .0897 L
.18264 .08983 L
.18279 .08993 L
.18293 .09 L
.18309 .09007 L
.18323 .09011 L
.18336 .09014 L
.18349 .09015 L
.18364 .09015 L
.1838 .09012 L
.18389 .0901 L
.18397 .09008 L
.18412 .09001 L
.18428 .08992 L
.18456 .08972 L
.18487 .08942 L
.18542 .0887 L
.18601 .08764 L
.18709 .085 L
.18824 .08113 L
.18951 .07573 L
.19205 .06144 L
.19461 .04328 L
.19694 .02527 L
.19751 .02127 L
.19782 .01935 L
.19811 .01783 L
.19827 .01714 L
.19842 .01664 L
.1985 .01642 L
.19858 .01626 L
.19867 .01614 L
.19876 .01607 L
.19891 .0161 L
.199 .01619 L
.19908 .01632 L
.19923 .0167 L
.19937 .0172 L
.19965 .0185 L
.19994 .02025 L
.20047 .02399 L
.20165 .03374 L
.20624 .07238 L
.2088 .09026 L
.21112 .1026 L
.21228 .10706 L
.21289 .10892 L
.21354 .11051 L
.2141 .11156 L
.21442 .11202 L
Mistroke
.21473 .11235 L
.21487 .11248 L
.215 .11258 L
.21512 .11265 L
.21525 .11272 L
.21539 .11276 L
.21553 .11279 L
.21568 .1128 L
.21582 .11279 L
.21597 .11275 L
.2161 .1127 L
.21625 .11262 L
.21641 .11251 L
.21673 .1122 L
.21703 .11182 L
.2176 .11082 L
.21814 .10957 L
.21934 .10566 L
.22065 .09971 L
.22303 .08449 L
.22557 .06275 L
.22794 .03849 L
.22898 .02752 L
.22957 .02183 L
.22985 .01952 L
.23012 .01779 L
.23025 .01716 L
.2304 .01671 L
.23054 .01655 L
.23067 .01662 L
.2308 .01694 L
.23095 .01755 L
.23111 .01845 L
.23125 .01949 L
.23183 .02482 L
.23245 .03171 L
.23496 .06268 L
.23734 .09177 L
.23994 .12046 L
.24245 .14314 L
.24355 .15097 L
.24473 .15782 L
.24537 .16076 L
.24595 .16297 L
.24651 .16463 L
.24682 .16536 L
.2471 .16589 L
.24741 .16633 L
.24757 .16652 L
.24773 .16666 L
Mistroke
.24787 .16675 L
.24801 .1668 L
.24816 .16683 L
.24831 .16683 L
.24847 .16678 L
.24856 .16674 L
.24864 .16669 L
.24878 .16657 L
.24894 .16641 L
.24927 .16594 L
.24964 .16522 L
.25027 .16343 L
.25088 .16112 L
.252 .15516 L
.25322 .14634 L
.25453 .13396 L
.25693 .10392 L
.25947 .06238 L
.26061 .04113 L
.26124 .02934 L
.26155 .02392 L
.2617 .02155 L
.26183 .01968 L
.26197 .01818 L
.2621 .01728 L
.26224 .01702 L
.26238 .01759 L
.26254 .01902 L
.26261 .01999 L
.2627 .02121 L
.26299 .02623 L
.26404 .04917 L
.26893 .17586 L
.27363 .30633 L
.27863 .43499 L
.28113 .48979 L
.28344 .53227 L
.28569 .56483 L
.28682 .57766 L
.28807 .58887 L
.2887 .59331 L
.2893 .59678 L
.28983 .59927 L
.29041 .60131 L
.29075 .60216 L
.29105 .60272 L
.29121 .60296 L
.2913 .60306 L
.29139 .60315 L
.29147 .60321 L
Mistroke
.29156 .60326 L
.29172 .60331 L
.29188 .60331 L
.29202 .60327 L
.2921 .60323 L
.29219 .60317 L
.29235 .60301 L
.29249 .60282 L
.29265 .60257 L
.29293 .602 L
.29322 .60124 L
.29352 .60026 L
.29406 .59804 L
.29464 .595 L
.29528 .59089 L
.29642 .58153 L
.29748 .5706 L
.29995 .53749 L
.30219 .49899 L
.30701 .39544 L
.31165 .28095 L
.31659 .15967 L
.31904 .10453 L
.32134 .05825 L
.32247 .03799 L
.32302 .0289 L
.32354 .02138 L
.32383 .01793 L
.32399 .01641 L
.32413 .01539 L
.32422 .015 L
.32429 .01479 L
.32438 .01472 L
.32446 .01482 L
.32461 .0154 L
.3247 .01591 L
.32478 .0165 L
.32532 .02207 L
.32591 .02907 L
.3283 .05576 L
.32956 .06703 L
.3309 .07665 L
.33209 .08319 L
.33272 .08591 L
.3334 .08828 L
.33402 .08995 L
.3343 .09053 L
.33459 .09106 L
.33486 .09145 L
.33514 .09177 L
Mistroke
.33529 .09191 L
.33544 .09202 L
.33558 .0921 L
.33571 .09215 L
.33585 .09219 L
.336 .09221 L
.33614 .09221 L
.33627 .09218 L
.33642 .09213 L
.33651 .09209 L
.33659 .09205 L
.33689 .09183 L
.33717 .09154 L
.33749 .09112 L
.33813 .08999 L
.33868 .08872 L
.33928 .08705 L
.34036 .08333 L
.34277 .07228 L
.34531 .05782 L
.34991 .02982 L
.35112 .02325 L
.35172 .02042 L
.35227 .01821 L
.35257 .01723 L
.3529 .01638 L
.35307 .01604 L
.35324 .01581 L
.35333 .01571 L
.35341 .01565 L
.3535 .0156 L
.35359 .01557 L
.35373 .01558 L
.35389 .01566 L
.35403 .0158 L
.35417 .01597 L
.35449 .01658 L
.35479 .01735 L
.35597 .0215 L
.35722 .02683 L
.35944 .03736 L
.36403 .06402 L
.36638 .08204 L
.3689 .1052 L
.37389 .16068 L
.3787 .21887 L
.38332 .26901 L
.38571 .28942 L
.38693 .29788 L
.38824 .30532 L
Mistroke
.38884 .30809 L
.38947 .31056 L
.39005 .31245 L
.39059 .31385 L
.3911 .31484 L
.39139 .31526 L
.39165 .31556 L
.39179 .31568 L
.39193 .31579 L
.39201 .31583 L
.39209 .31587 L
.39224 .31592 L
.39238 .31594 L
.39253 .31594 L
.39267 .31591 L
.3928 .31586 L
.39296 .31578 L
.3931 .31567 L
.39338 .31539 L
.39367 .31499 L
.39399 .31443 L
.39457 .31309 L
.3951 .3115 L
.39631 .30649 L
.3976 .29921 L
.39997 .28057 L
.40218 .25761 L
.40688 .19448 L
.41188 .11534 L
.41438 .07601 L
.41548 .06003 L
.41607 .0522 L
.41669 .04457 L
.4173 .03839 L
.41759 .03602 L
.41785 .03424 L
.41812 .03293 L
.41826 .03243 L
.41841 .03207 L
.41856 .03188 L
.41869 .03184 L
.41881 .03192 L
.41894 .03213 L
.41909 .0325 L
.41923 .03299 L
.41955 .0345 L
.41985 .03643 L
.42018 .03889 L
.42133 .04907 L
.42371 .0714 L
Mistroke
.42497 .08174 L
.42631 .09107 L
.4275 .09771 L
.42813 .1006 L
.42881 .10319 L
.42943 .10509 L
.43 .10643 L
.43054 .10735 L
.43082 .10769 L
.43096 .10783 L
.43112 .10795 L
.43127 .10804 L
.43142 .1081 L
.43158 .10814 L
.43167 .10815 L
.43175 .10815 L
.4319 .10813 L
.43204 .10809 L
.43212 .10806 L
.4322 .10801 L
.43235 .10792 L
.43264 .10766 L
.43294 .10729 L
.43348 .10637 L
.43416 .10474 L
.4348 .10276 L
.436 .09793 L
.43843 .08418 L
.44066 .06782 L
.44312 .04781 L
.44433 .03875 L
.4449 .03513 L
.44543 .03246 L
.44569 .03144 L
.44597 .03063 L
.44612 .03034 L
.44625 .03014 L
.4464 .03002 L
.44649 .02999 L
.44656 .02999 L
.44669 .03005 L
.44681 .03018 L
.44695 .03038 L
.44709 .03068 L
.44738 .03154 L
.44764 .03257 L
.44822 .03561 L
.44886 .03974 L
.45001 .04844 L
.45236 .0672 L
Mistroke
.45495 .08529 L
.45613 .09193 L
.45741 .09762 L
.45802 .09979 L
.45861 .10147 L
.45913 .10265 L
.45943 .10319 L
.4597 .10359 L
.45998 .10391 L
.46013 .10404 L
.46029 .10415 L
.46042 .10422 L
.46055 .10427 L
.46069 .1043 L
.46084 .10431 L
.46092 .1043 L
.461 .10428 L
.46108 .10426 L
.46117 .10422 L
.46132 .10414 L
.46149 .10402 L
.4618 .1037 L
.46208 .10329 L
.46272 .10203 L
.4633 .10043 L
.46398 .09804 L
.46462 .09525 L
.46577 .08889 L
.46701 .0803 L
.46922 .06045 L
.47163 .03413 L
.47229 .02713 L
.47265 .02388 L
.47283 .02258 L
.47299 .02162 L
.47314 .02098 L
.47328 .02063 L
.47342 .02053 L
.47351 .02061 L
.47359 .02078 L
.47374 .02133 L
.47382 .02178 L
.4739 .02227 L
.47424 .02508 L
.47483 .03192 L
.47545 .04057 L
.47656 .05784 L
.47907 .10067 L
.48367 .18318 L
.48856 .26393 L
Mistroke
.49082 .29502 L
.49327 .32243 L
.49461 .33424 L
.49584 .34296 L
.49702 .34926 L
.49762 .35167 L
.49793 .35272 L
.49827 .3537 L
.4986 .35447 L
.4989 .35505 L
.49919 .35546 L
.49935 .35564 L
.4995 .35577 L
.49964 .35586 L
.49978 .35592 L
.49992 .35596 L
.50008 .35596 L
.50021 .35593 L
.50034 .35588 L
.50047 .35579 L
.50062 .35567 L
.50079 .35549 L
.50094 .35528 L
.5013 .35468 L
.50161 .354 L
.50194 .35311 L
.50251 .35119 L
.50314 .34851 L
.50436 .34167 L
.50548 .33355 L
.50799 .30918 L
.51278 .24334 L
.51738 .16443 L
.51995 .11812 L
.52228 .07711 L
.52345 .05766 L
.52471 .03824 L
.52529 .03042 L
.5256 .0267 L
.5259 .0238 L
.52603 .02276 L
.52615 .02193 L
.52629 .0212 L
.52642 .02076 L
.52657 .02054 L
.5267 .02059 L
.52684 .02092 L
.527 .02155 L
.52713 .02233 L
.52728 .02338 L
Mistroke
.52759 .02596 L
.52813 .03147 L
.52934 .04509 L
.53155 .06794 L
.53391 .08685 L
.53523 .09451 L
.53582 .09719 L
.53643 .09957 L
.53701 .10134 L
.53731 .1021 L
.53764 .1028 L
.53794 .10332 L
.53821 .1037 L
.53834 .10385 L
.53848 .10399 L
.53861 .10409 L
.53875 .10418 L
.53883 .10422 L
.53892 .10426 L
.53899 .10428 L
.53908 .1043 L
.53922 .10431 L
.53938 .10429 L
.53946 .10426 L
.53954 .10424 L
.53963 .10419 L
.53972 .10414 L
.53988 .10403 L
.54005 .10388 L
.54035 .10352 L
.54067 .10301 L
.54125 .10181 L
.54184 .1002 L
.54238 .0984 L
.5436 .09324 L
.54581 .08045 L
.54829 .06212 L
.55059 .04378 L
.55114 .03976 L
.55173 .03586 L
.55201 .03431 L
.5523 .03287 L
.55255 .03182 L
.55281 .03094 L
.55297 .03054 L
.55312 .03027 L
.55327 .03009 L
.55341 .03 L
.55349 .02999 L
.55357 .03 L
Mistroke
.55372 .03011 L
.55381 .03022 L
.5539 .03036 L
.55406 .0307 L
.55434 .03155 L
.5546 .03258 L
.55519 .03564 L
.55637 .04383 L
.55747 .05259 L
.55996 .07263 L
.56221 .0883 L
.5634 .09504 L
.56466 .10079 L
.5653 .1031 L
.566 .10517 L
.5663 .1059 L
.56663 .10658 L
.56694 .10711 L
.56723 .10751 L
.56754 .10783 L
.56771 .10796 L
.56779 .10801 L
.56788 .10806 L
.56797 .10809 L
.56805 .10812 L
.5682 .10815 L
.56835 .10815 L
.5685 .10813 L
.56864 .10808 L
.56878 .10801 L
.56892 .10792 L
.56905 .10781 L
.56936 .10748 L
.56966 .10706 L
.57021 .10599 L
.57082 .10438 L
.57206 .09979 L
.5732 .09397 L
.57428 .08717 L
.57651 .06944 L
.57777 .05773 L
.57895 .04652 L
.57955 .04113 L
.58011 .03667 L
.58043 .03466 L
.58059 .03378 L
.58077 .033 L
.58091 .03249 L
.58099 .03227 L
.58108 .03209 L
Mistroke
.58122 .03188 L
.58136 .03184 L
.58144 .03187 L
.58153 .03197 L
.58169 .03229 L
.58178 .03258 L
.58187 .03291 L
.58204 .03368 L
.58235 .0356 L
.58269 .03831 L
.58391 .05184 L
.58886 .12724 L
.59362 .20205 L
.59821 .26204 L
.60056 .28534 L
.60188 .29564 L
.60309 .30334 L
.60432 .30931 L
.60497 .3117 L
.60565 .31365 L
.60594 .31429 L
.60625 .31486 L
.60654 .31529 L
.60681 .31559 L
.60696 .31572 L
.60711 .31581 L
.60726 .31589 L
.60735 .31592 L
.60743 .31593 L
.60751 .31594 L
.60759 .31594 L
.60768 .31594 L
.60777 .31592 L
.60792 .31587 L
.608 .31582 L
.60808 .31578 L
.60823 .31567 L
.60839 .31552 L
.60868 .31517 L
.609 .31468 L
.60934 .314 L
.60995 .31243 L
.61053 .31055 L
.61161 .30604 L
.61277 .29974 L
.61518 .28234 L
.61773 .25865 L
.62232 .20671 L
.6272 .14768 L
.63191 .09734 L
Mistroke
.63431 .07643 L
.63691 .0578 L
.64172 .03171 L
.64412 .02115 L
.6447 .01897 L
.64532 .01704 L
.64551 .01659 L
.64568 .01623 L
.64585 .01595 L
.64601 .01575 L
.64616 .01563 L
.64632 .01557 L
.64641 .01557 L
.64649 .01559 L
.64665 .0157 L
.64679 .01585 L
.64694 .01608 L
.64722 .01665 L
.64754 .01756 L
.64783 .01858 L
.64908 .02425 L
.6513 .03699 L
.65611 .06619 L
.65831 .07763 L
.65956 .08301 L
.66074 .08709 L
.66129 .08866 L
.66188 .09002 L
.66219 .09061 L
.66253 .09115 L
.66283 .09155 L
.66312 .09184 L
.66328 .09197 L
.66345 .09208 L
.66361 .09215 L
.66376 .09219 L
.66391 .09221 L
.664 .09221 L
.66409 .0922 L
.66417 .09219 L
.66425 .09217 L
.66435 .09213 L
.66443 .09209 L
.66458 .092 L
.66474 .09188 L
.66502 .0916 L
.66535 .09115 L
.66566 .09062 L
.66625 .08928 L
.66687 .08741 L
Mistroke
.66798 .08284 L
.66918 .07613 L
.67049 .06656 L
.67285 .04366 L
.67417 .02819 L
.67474 .02132 L
.67507 .01784 L
.67523 .01644 L
.67538 .01545 L
.67553 .01485 L
.67567 .01473 L
.67581 .01512 L
.6759 .01556 L
.67597 .0161 L
.67614 .01754 L
.67628 .01915 L
.67661 .02342 L
.67795 .04516 L
.68037 .09218 L
.6852 .20256 L
.68985 .3187 L
.69479 .43691 L
.69725 .48838 L
.69955 .52959 L
.70176 .56157 L
.70299 .57574 L
.70413 .58635 L
.70535 .59498 L
.706 .59833 L
.70633 .59971 L
.70669 .60096 L
.707 .60183 L
.70728 .60245 L
.70755 .60289 L
.70769 .60305 L
.70784 .60319 L
.70793 .60324 L
.70801 .60328 L
.70816 .60332 L
.70824 .60332 L
.70832 .6033 L
.70841 .60327 L
.7085 .60323 L
.70865 .60311 L
.70879 .60295 L
.70895 .60274 L
.70911 .60245 L
.70942 .60176 L
.70975 .60082 L
.71033 .59856 L
Mistroke
.71103 .59495 L
.71167 .59082 L
.71291 .58027 L
.71409 .56752 L
.71651 .533 L
.71874 .49235 L
.72351 .38249 L
.72809 .25875 L
.73297 .12449 L
.73522 .06683 L
.73641 .03892 L
.73672 .03213 L
.73706 .0254 L
.73721 .02264 L
.73738 .02013 L
.73751 .01845 L
.73767 .01729 L
.73783 .01704 L
.73791 .01735 L
.738 .01788 L
.73815 .01948 L
.7383 .0215 L
.739 .03371 L
.74023 .0569 L
.74266 .09784 L
.74508 .12968 L
.74615 .14073 L
.7473 .15041 L
.74791 .15463 L
.74847 .15793 L
.74904 .16075 L
.74957 .16288 L
.75018 .16477 L
.7505 .16552 L
.75067 .16583 L
.75085 .16613 L
.75102 .16636 L
.75117 .16653 L
.75132 .16666 L
.75148 .16676 L
.75162 .16681 L
.75176 .16683 L
.7519 .16682 L
.75206 .16678 L
.75221 .1667 L
.75229 .16664 L
.75237 .16657 L
.7527 .1662 L
.75298 .16574 L
.75329 .16511 L
Mistroke
.75399 .16317 L
.75463 .16078 L
.75587 .15456 L
.75706 .14683 L
.75944 .12658 L
.76166 .10328 L
.76638 .04589 L
.76762 .03091 L
.76827 .02378 L
.76863 .02044 L
.7688 .01907 L
.76896 .01802 L
.76911 .01726 L
.76925 .01678 L
.7694 .01656 L
.76949 .01656 L
.76957 .01665 L
.76972 .01706 L
.76981 .01742 L
.76989 .01782 L
.77023 .02013 L
.77079 .02521 L
.7714 .03142 L
.77377 .05621 L
.77636 .07975 L
.77755 .08875 L
.77883 .09688 L
.78003 .10303 L
.78114 .1074 L
.78174 .10924 L
.78237 .11076 L
.78268 .11135 L
.78301 .11187 L
.7832 .11212 L
.78337 .11231 L
.78353 .11246 L
.78371 .11259 L
.78387 .11269 L
.78402 .11275 L
.78417 .11278 L
.78431 .1128 L
.78439 .1128 L
.78447 .11279 L
.78462 .11276 L
.7847 .11273 L
.78478 .1127 L
.78496 .11261 L
.78511 .1125 L
.78526 .11237 L
.78553 .11208 L
Mistroke
.78614 .11115 L
.7867 .10998 L
.78731 .10836 L
.78855 .104 L
.79077 .09289 L
.79311 .07731 L
.79562 .05727 L
.798 .03675 L
.79925 .02619 L
.79994 .02104 L
.80028 .01892 L
.80043 .01812 L
.80059 .01737 L
.80075 .01679 L
.80089 .01639 L
.80105 .01613 L
.80114 .01607 L
.80122 .01606 L
.8013 .01611 L
.80138 .0162 L
.80147 .01636 L
.80156 .01659 L
.80172 .0171 L
.80189 .01782 L
.8025 .02133 L
.80307 .02538 L
.80538 .04321 L
.8076 .05917 L
.81004 .07349 L
.8112 .07891 L
.81245 .08358 L
.81314 .08564 L
.81377 .08718 L
.8144 .08841 L
.81471 .08889 L
.815 .08927 L
.81529 .08959 L
.81555 .08981 L
.81569 .08991 L
.81585 .09 L
.81593 .09004 L
.81601 .09007 L
.81617 .09012 L
.81624 .09013 L
.81633 .09014 L
.81648 .09015 L
.81663 .09014 L
.81677 .09011 L
.81691 .09007 L
.81708 .09 L
Mistroke
.81725 .0899 L
.81741 .08979 L
.81769 .08954 L
.81797 .08924 L
.81848 .08851 L
.81903 .08751 L
.81963 .08615 L
.82076 .08286 L
.82202 .07817 L
.82455 .06572 L
.82708 .05014 L
.8294 .03427 L
.83058 .02624 L
.83168 .01959 L
.83196 .01819 L
.83223 .01708 L
.83238 .01658 L
.83254 .01615 L
.83268 .01586 L
.83282 .0157 L
.83297 .01563 L
.83311 .01568 L
.83326 .01585 L
.83335 .01601 L
.83343 .01617 L
.83376 .01718 L
.83407 .01849 L
.83523 .02498 L
.83646 .03284 L
.83868 .04667 L
.8411 .05966 L
.84237 .06529 L
.84371 .07019 L
.84491 .07362 L
.84559 .07513 L
.84623 .07626 L
.84682 .07705 L
.84709 .07734 L
.84735 .07756 L
.84765 .07776 L
.8478 .07784 L
.84797 .07791 L
.84811 .07795 L
.84824 .07798 L
.84839 .07799 L
.84855 .07799 L
.84863 .07799 L
.84871 .07798 L
.84885 .07794 L
.84901 .07789 L
Mistroke
.84918 .07782 L
.84949 .07764 L
.84977 .07741 L
.85041 .07669 L
.8511 .07562 L
.85225 .07313 L
.85352 .06943 L
.85587 .06017 L
.85839 .0474 L
.86078 .03356 L
.86204 .02612 L
.86273 .02226 L
.86338 .01901 L
.86366 .01781 L
.86395 .01675 L
.8641 .01628 L
.86427 .01587 L
.86442 .01558 L
.86456 .0154 L
.86465 .01534 L
.86473 .0153 L
.86482 .01529 L
.8649 .01532 L
.86504 .01543 L
.8652 .01565 L
.86528 .01581 L
.86536 .01599 L
.86552 .0164 L
.86587 .0176 L
.86708 .02335 L
.86818 .02945 L
.87067 .04312 L
.87298 .05413 L
.87521 .06247 L
.87646 .06595 L
.87759 .06832 L
.87818 .06925 L
.8785 .06967 L
.8788 .07 L
.87908 .07026 L
.87933 .07045 L
.87961 .07062 L
.87976 .07069 L
.87991 .07074 L
.88006 .07078 L
.88021 .07081 L
.88029 .07082 L
.88038 .07082 L
.88054 .07082 L
.88068 .0708 L
Mistroke
.88084 .07077 L
.88097 .07073 L
.88112 .07067 L
.88144 .07049 L
.88179 .07023 L
.88242 .06958 L
.88307 .06866 L
.88366 .06759 L
.885 .06444 L
.88618 .06085 L
.88743 .0563 L
.89201 .03453 L
.89331 .02753 L
.89455 .02119 L
.89509 .01875 L
.89567 .01662 L
.89596 .01581 L
.89613 .01547 L
.89621 .01534 L
.89629 .01523 L
.89644 .0151 L
.89657 .01504 L
.89672 .01506 L
.89688 .01517 L
.89703 .01537 L
.89711 .01551 L
.89719 .01566 L
.89749 .01641 L
.89805 .01837 L
.8993 .02419 L
.90156 .03578 L
.90401 .04736 L
.90631 .05619 L
.90744 .05962 L
.90851 .06228 L
.9091 .06348 L
.90974 .06457 L
.91033 .06536 L
.91087 .06591 L
.91119 .06615 L
.91149 .06633 L
.91164 .0664 L
.91181 .06646 L
.91189 .06648 L
.91198 .06651 L
.91207 .06652 L
.91215 .06653 L
.9123 .06654 L
.91244 .06654 L
.9126 .06653 L
Mistroke
.91268 .06651 L
.91277 .0665 L
.91291 .06645 L
.91307 .0664 L
.91335 .06626 L
.91362 .06608 L
.91392 .06583 L
.91452 .06519 L
.91508 .06441 L
.91559 .06353 L
.91686 .06076 L
.91806 .05738 L
.9203 .0493 L
.92494 .02748 L
.92618 .02146 L
.92679 .01882 L
.92734 .0168 L
.92764 .01594 L
.92778 .01562 L
.92792 .01533 L
.92808 .0151 L
.92822 .01496 L
.92831 .0149 L
.92839 .01488 L
.92855 .0149 L
.92863 .01494 L
.92871 .015 L
.9288 .0151 L
.92888 .01521 L
.92903 .01546 L
.92919 .0158 L
.92955 .01681 L
.92988 .01796 L
.93469 .04051 L
.93689 .04968 L
.93815 .05405 L
.93932 .05751 L
.94047 .06025 L
.94171 .06242 L
.94236 .06322 L
.94271 .06356 L
.94303 .06382 L
.94331 .06399 L
.94361 .06413 L
.94378 .06418 L
.94387 .0642 L
.94395 .06422 L
.94409 .06424 L
.94425 .06425 L
.9444 .06424 L
Mistroke
.94454 .06423 L
.94467 .0642 L
.94481 .06417 L
.94496 .06412 L
.94513 .06405 L
.94542 .06388 L
.94594 .06348 L
.94651 .06285 L
.94713 .06198 L
.9478 .06082 L
.94901 .05812 L
.95142 .05065 L
.95396 .04026 L
.95637 .0289 L
.95742 .02387 L
.95856 .01884 L
.95886 .01767 L
.95919 .01659 L
.95949 .01577 L
.95964 .01545 L
.95977 .01521 L
.95991 .01502 L
.96003 .01489 L
.96017 .01481 L
.96032 .0148 L
.96047 .01486 L
.96055 .01492 L
.96063 .015 L
.96078 .01521 L
.96092 .01547 L
.96123 .0162 L
.96155 .01721 L
.96213 .01941 L
.96345 .02533 L
.96803 .04619 L
.97038 .05448 L
.9717 .05806 L
.97291 .06057 L
.97372 .06185 L
.97448 .06272 L
.97487 .06305 L
.9751 .0632 L
.97531 .06331 L
.97553 .0634 L
.97564 .06344 L
.97576 .06347 L
.97587 .0635 L
.97597 .06351 L
.97608 .06352 L
.97619 .06352 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<oooool3o`0002kooooo1Ol0000]ooooo`;o0000;_ooool5o`00033ooooo0ol0000Roooo
o`00=?ooool00ol0003oooooooooo`0^ooooo`04o`000?ooooooooooo`0002cooooo00Co0000oooo
oooooooo0000;_ooool01?l0003oooooooooool0000aooooo`03o`000?oooooooooo027ooooo000[
ooooo`Go000000?oooooo`000?l000000ol0000Xooooo`Go00000oooool00ol0003oooooooooo`0/
ooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool0;_ooool5o`0002;ooooo000a
ooooo`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool0:oooool01?l0003ooooooooo
ool0000`ooooo`03o`000?oooooooooo02gooooo00Co0000oooooooooooo00008oooool003;ooooo
00?o0000ooooool00000;oooool01Ol0003ooooooooooooooooo000002cooooo00Co0000oooooooo
oooo0000;Oooool01Ol0003ooooooooooooooooo000002oooooo00?o0000ooooool000008oooool0
03?ooooo0_l0000_ooooo`05o`000?ooooooooooooooool00000;?ooool01?l0003oooooooooool0
000]ooooo`05o`000?ooooooooooooooool00000<?ooool2o`0002?ooooo000dooooo`03o`000?oo
oooooooo02kooooo0ol0000^ooooo`;o0000;oooool3o`0003;ooooo00?o0000ooooooooool08Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool000[ooooo0_l0003ooooooaGooooo
0009ooooo`04o`000?ooooooooooo`0000Coooooool0000=o`0000?ooooo0009ooooo`04o`000?oo
ooooooooo`0000Cooooo0ol00004ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`02ooooo`?o00000oooool000Wooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`01ooooo`002Oooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo08?ooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`01ooooo`002Ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool0
1Oooool2o`00o`Oooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`04ooooo`;o003o
9_ooool00ol0003oooooooooo`0Sooooo`;o003o1_ooool00ol00?ooooooooooo`0>ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0>ooooo`03o`00
oooooooooooo00kooooo00?o003oooooooooool01Oooool2o`00o`Wooooo00?o0000ooooooooool0
0Oooool000[ooooo0_l00005ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool09Ooo
ool00ol0003oooooooooo`0Sooooo`;o003o1_ooool2o`00o`oooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`05ooooo`;o003o1oooool00ol00?ooooooooooo`05ooooo`;o003o1ooo
ool2o`00o`Oooooo00?o003oooooooooool01Oooool2o`00o`Wooooo00?o0000ooooooooool00Ooo
ool0017ooooo0_l00008ooooo`03o`00oooooooo003o00Kooooo00?o003oooooooooool03_ooool2
o`00o`Oooooo00?o003oooooooooool01Oooool2o`00o`Oooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`00oooooooooooo03Gooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`05ooooo`;o003o1oooool2o`00o`Kooooo00?o003oooooooooool01_ooool2
o`00o`Kooooo0_l00?lAooooo`;o00000oooool0017ooooo00?o0000ooooooooool01oooool00ol0
0?ooooooo`00o`07ooooo`03o`00oooooooooooo00gooooo0_l00?l6ooooo`03o`00oooooooooooo
00Kooooo0_l00?l?ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool06oooool2o`00
o`Kooooo00?o0000ooooooooool00oooool2o`00ocOooooo00?o003oooooooooool03Oooool2o`00
o`Oooooo0_l00?l8ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo003o00Ko
oooo00?o003oooooool00?l01oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool01?ooool2o`00o`Oooooo00?o003oooooooooool03Oooool2o`00o`So
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`04ooooo`;o003o1Oooool2o`00o`Ko
oooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool03Oooool01?l00?ooooooooooool00?l5ooooo`;o003o3oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooo003o00Wooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool03oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o
00kooooo00?o003oooooool00?l01oooool00ol00?ooooooooooo`04ooooo`;o003o1oooool00ol0
0?ooooooooooo`0=ooooo`;o003o1Oooool01?l00?ooooooooooool00?l?ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool00oooool2o`00o`Kooooo00?o0000ooooooooool00oooool0
0ol00?ooooooooooo`04ooooo`;o003o1_ooool00ol00?ooooooooooo`0=ooooo`04o`00oooooooo
ooooo`00o`Gooooo0_l00?l?ooooo`03o`00oooooooooooo00Gooooo0_l00?l8ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooool00?l03Oooool01?l00?ooooooooooool00?l5ooooo`03o`00
oooooooo003o00Wooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool02Ooo
ool2o`00o`Cooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooo003o01Kooooo0_l00?l5ooooo`04o`00ooooooooooooo`00o`oooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo0_l00?l>ooooo`03
o`00oooooooooooo00cooooo00Co003ooooooooooooo003o1Oooool2o`00o`oooooo00?o003ooooo
ooooool01Oooool2o`00o`Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1oooool00ol00?ooooooooooo`03
ooooo`04o`00ooooooooooooo`00o`Sooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool01_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool03_oo
ool01?l00?ooooooooooool00?l7ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool0
5oooool00ol00?ooooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo
003o1?ooool00ol00?ooooooooooo`06ooooo`04o`00ooooooooooooo`00o`Oooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o
00001oooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003oooooooooool02oooool01?l0
0?ooooooooooool00?l=ooooo`03o`00oooooooo003o00oooooo0_l00?lIooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`04ooooo`;o003o1_ooool0
0ol0003oooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01Oooool2
o`00obOooooo0_l00?l7ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l01Oooool0
1?l00?ooooooooooool00?l<ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool02Oooool2o`0000?ooooo000Aooooo`03o`00
0?oooooooooo00Kooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`06ooooo`;o003o3_ooool00ol0
0?ooooooo`00o`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooool00?l01?ooool00ol0
0?ooooooo`00o`05ooooo`;o003o1_ooool00ol0003oooooooooo`03ooooo`;o003o1Oooool00ol0
0?ooooooo`00o`05ooooo`;o003o3Oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003o
ooooool00?l03oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool00oooool01?l00?ooooooooooool00?l8ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`0:ooooo`05o`00ooooooooooooooooool0
0?l01oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Kooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l03Oooool00ol0
0?ooooooo`00o`04ooooo`03o`00oooooooo003o00Cooooo00?o003oooooool00?l01_ooool00ol0
003oooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01?ooool00ol0
0?ooooooooooo`0=ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooo`00o`0@
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l02?ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0;ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00Gooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool02oooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`08oooo
o`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
003o01Kooooo00?o003oooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooool00?l01oooool01Ol00?oooooooooooooooooo003o00Sooooo00?o
0000ooooooooool00oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo01;ooooo00?o
003oooooooooool00_ooool01ol00?oooooooooooooooooo003oooooool00?l03_ooool00ol00?oo
ooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`06ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`04ooooo`;o003o1Oooool00ol00?ooooooo`00o`0>oooo
o`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooool00?l01oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooo003o00?ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0=
ooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo00;ooooo00Oo003oooooooooooooooooo`00oooooooo003o00kooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l7ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Go
oooo00?o0000ooooooooool00Oooool0017ooooo0_l00005ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01Oooool2o`00o`Wooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0:ooooo`04o`00ooooooooooooo`00o`gooooo00?o003oooooool00?l05?ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooo003o00Kooooo00?o0000ooooooooool01Oooool01Ol00?oo
oooooooooooooooo003o00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`0Woooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00Cooooo0_l00?l6ooooo`03o`00oooooooooooo00cooooo0_l00003ooooo`004Oooool00ol0
003oooooooooo`0Dooooo`;o003o1oooool2o`00o`Gooooo00Co003ooooooooooooo003o2?ooool0
1Ol00?oooooooooooooooooo003o00gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00
o`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooool00?l01?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooo003o00Kooooo00?o0000ooooooooool00oooool00ol00?ooooooo`00
o`03ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l03Oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l04?ooool00ol00?ooooooo`00o`08ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool01_ooool00ol00?ooooooo`00o`06ooooo`;o003o5_ooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Mooooo`03o`00oooooooooooo00Go
oooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;o
oooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o
00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo003o
00Cooooo00?o003oooooooooool01?ooool01?l00?ooooooooooool00?l5ooooo`03o`000?oooooo
oooo00?ooooo00?o003oooooooooool00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool03Oooool00ol00?ooooooooooo`02ooooo`07o`00ooooooooooooooooool00?oo
ooooo`00o`0@ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`06ooooo`04o`00oooooooo003oo`00o`Gooooo0_l00?lOooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo02Kooooo0_l00?l5ooooo`04o`00ooooooooooooo`00
o`?ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?lFooooo`04o`00oooooooo
ooooo`00o`;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooo003o00Oooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00?ooooo
00?o0000ooooooooool00_ooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool01?ooool01_l00?ooooooooooool00?oooooo
o`00o`kooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`05o`00oooo
ooooooooooooool00?l02_ooool00ol00?ooooooooooo`0Uooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo02gooooo00Co003ooooooooooooo003o2?ooool01?l00?oooooo
ooooool00?l7ooooo`03o`00oooooooooooo00cooooo00Ko003ooooooooooooo003oooooool00?lE
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0:ooooo`03o`000?oo
oooooooo00Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00Cooooo00Ko003ooooooooooooo003oooooool00?l>ooooo`03o`00oooooooooooo00Go
oooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool09Oooool00ol0003oooooooooo`01ooooo`004Oooool2o`0002ko
oooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooool00?l04oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo
00Gooooo00Go003oooooooooooooooooo`00o`06ooooo`04o`00ooooooooooooo`00obOooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooool00?l0;_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo02oooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo003o01[ooooo00?o003o
ooooooooool02_ooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooooooo00;ooooo00Co
003ooooooooooooo003o0_ooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`02ooooo`05o`00ooooooooooooooooool00?l00_ooool01Ol0
0?oooooooooooooooooo003o01;ooooo00?o003oooooool00?l04Oooool00ol00?ooooooo`00o`08
ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooo`00o`0_ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo03Gooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l03_ooool00ol00?oooooooooo
o`02o`00o`Oooooo00?o003oooooooooool02_ooool01?l00?ooooooooooool00?l2ooooo`03o`00
oooooooooooo00Cooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`000?oooooooooo00;o
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00
o`?ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`05ooooo`;o003o0oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool2o`00
oc3ooooo00?o0000ooooooooool00Oooool000?ooooo0ol00004ooooo`;o00001Oooool00ol0003o
ooooooooo`0eooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00kooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09oooo
o`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00;ooooo00Co003ooooooooooooo003o3oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo03Sooooo00?o0000ooooooooool00Oooool000Cooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo03Sooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`0=ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?oooooo
ooooool00?lgooooo`03o`000?oooooooooo007ooooo0004ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00001?ooool3o`0003Sooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooo003o02cooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`08ooooo`03o`000?oooooooooo00Kooooo0_l00?l<ooooo`03o`00oooooooooooo01Ko
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool0<oooool3o`0000?ooooo0004ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0fooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooool00?l06oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Co
oooo0_l00?l4ooooo`03o`00oooooooooooo02Cooooo00?o003oooooool00?l02oooool00ol00?oo
ooooooooo`0fooooo`03o`000?oooooooooo007ooooo0004ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0fooooo`?o003o2Oooool00ol00?oo
ooooo`00o`0=ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`02ooooo`;o003o2oooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Oo
oooo0_l00?liooooo`03o`000?oooooooooo007ooooo0003ooooo`;o00001?ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo03Kooooo0_l00?l5ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00ko
oooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o>?ooool00ol0003oooooooooo`01oooo
o`001?ooool00ol0003oooooooooo`03ooooo`;o00001Oooool00ol0003oooooooooo`0mooooo`03
o`00oooooooooooo01;ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo01Gooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0?ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0;ooooo`04
o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool0?Oooool00ol0003oooooooooo`01oooo
o`004Oooool2o`0003kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo02kooooo00?o0000ooooooooool05?ooool00ol00?ooooooooooo`0Fooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0looooo`;o
00000oooool0017ooooo00?o0000ooooooooool0@Oooool01?l00?ooooooooooool00?lKooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03
o`000?oooooooooo01Cooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo03gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
@Oooool01Ol00?oooooooooooooooooo003o00cooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0Iooooo`04o`00ooooooooooooo`00od?ooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool0?_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
013ooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo
01[ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0>ooooo`04o`00oooooooooooo
o`00od3ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0?_ooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
0?ooooooooooo`0Jooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02oooool01?l0
0?ooooooooooool00?l2ooooo`03o`00oooooooooooo03kooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool0?_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool0;_ooool00ol0003oooooooooo`0Dooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool0?_ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0003oo
oooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0fooooo`03o`00oooooooooooo
00;ooooo00?o0000ooooooooool05?ooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool0?Oooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo047o
oooo00Go003oooooooooooooooooo`00o`0Kooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool04?ooool00ol00?ooooooooooo`02ooooo`05o`000?ooooooooooooooool00?l04oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Wooooo00Go003oooooooooooooooooo`00
o`13ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo03kooooo00Co003o
oooooooooooo003o0oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00Go
0000ooooooooooooooooo`00o`0Looooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
3_ooool00ol00?ooooooooooo`11ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo03kooooo00Co003ooooooooooooo003o4?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`05o`00
0?ooooooooooooooool00?l07?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooool00?l0@?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`0oooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0;_ooool01Ol0003ooooo
oooooooooooo003o01?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`10ooooo`03
o`000?oooooooooo007ooooo000Aooooo`;o0000@?ooool2o`00o`Cooooo00?o003oooooooooool0
>oooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo03kooooo0_l00003ooooo`004Ooo
ool00ol0003oooooooooo`0oooooo`;o003o1?ooool00ol00?ooooooooooo`0Iooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`05o`000?oo
ooooooooooooool00?l04oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Wooooo
00?o003oooooooooool00_ooool2o`00od7ooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool0AOooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00Go
0000ooooooooooooooooo`00o`0Cooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`1Aooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo05;ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo017ooooo00?o003oooooooooool00_ooool01Ol0003ooooooooooooooooo003o01cooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`1Aooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo05;ooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo01Kooooo00Go0000ooooooooooooooooo`00o`0Cooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo04Gooooo00?o0000ooooooooool00Oooool0017ooooo0_l00016ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool0;_ooool00ol0003oooooooooo`0Eooooo`03o`00oooo
oooooooo01Kooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`14ooooo`;o00000ooo
ool0017ooooo00?o0000ooooooooool0AOooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooo
oooo01Gooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`15ooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo04Gooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool04Oooool00ol0
0?ooooooooooo`02ooooo`05o`000?ooooooooooooooool00?l04oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool0AOooool00ol0003oooooooooo`01
ooooo`000_ooool5o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo04Gooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool04Oooool00ol00?ooooooooooo`02ooooo`05o`000?ooooooooooooooool00?l07?ooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo057ooooo00?o0000ooooooooool00Oooool0
00?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo057ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo017ooooo00?o003oooooooooool00_ooool01Ol0003ooooooooooooooooo003o01_ooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo04Gooooo
00?o0000ooooooooool00Oooool000Cooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00004ooooo`?o0000AOooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02oooooo
00?o0000ooooooooool05Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool0@oooool3o`0000?ooooo0005ooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Gooooo00?o003oooooooooool0
=oooool01Ol00?oooooooooooooooooo000001Sooooo00?o003oooooooooool08Oooool00ol00?oo
ooooooooo`15ooooo`03o`000?oooooooooo007ooooo0002ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04Gooooo00?o003ooooo
ooooool06_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01;ooooo00Go003ooooo
ooooooooooooo`000003ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo04Gooooo00?o0000ooooooooool00Oooool0
00;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool0AOooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0Booooo`05o`00ooooooooooooooooool00000
0oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
DOooool00ol0003oooooooooo`01ooooo`000oooool3o`0000Cooooo0_l00005ooooo`03o`000?oo
oooooooo057ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo01?ooooo00Go003oooooooooooooooooo`000002ooooo`03o`00oooooooooooo01[ooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`1Aooooo`03o`000?oooooooooo007ooooo
000Aooooo`;o0000D_ooool00ol00?ooooooooooo`0_ooooo`04o`000?ooooooooooo`00oaGooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool0A?ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo04Gooooo00?o
003oooooooooool0>oooool00ol0003oooooooooo`0Fooooo`03o`00oooooooooooo01Gooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`15ooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo04Gooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo01?ooooo00Go003oooooooooooooooooo`000002ooooo`03o`00oooo
oooooooo01?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Jooooo`03o`00oooo
oooooooo04Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0A_ooool0
0ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0Cooooo`05o`00ooooooooooooooooool000000_ooool00ol00?oooooooooo
o`0Cooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?oooooooooo
o`1Aooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo057ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01?ooooo00Go003o
ooooooooooooooooo`000002ooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool03ooo
ool00ol00?ooooooooooo`1Aooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo057ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo01Oooooo00Co0000oooooooooooo003o5Oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`15ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`;o0000Aoooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo02oooooo00?o0000ooooooooool05_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool0A?ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo
04Kooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
01?ooooo00Go003oooooooooooooooooo`00000Hooooo`03o`00oooooooooooo023ooooo00?o003o
ooooooooool0A_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`16oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo01?ooooo00Go003oooooooooooooooooo`000002ooooo`03o`00oooooooo
oooo01?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooo
oooo04Kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0A_ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0Cooooo`05o`00ooooooooooooooooool000000_ooool00ol00?ooooooooooo`0I
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0DOooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`1Aooooo`03o`00oooooooooooo00oooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`0Cooooo`05o`00ooooooooooooooooool000000_ooool0
0ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool02?ooool0
0ol00?ooooooooooo`16ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000Aoooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo02oooooo00?o0000ooooooooool05oooool00ol0
0?ooooooooooo`0Dooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0AOooool2o`00
00?ooooo000Aooooo`03o`000?oooooooooo04Kooooo00?o003oooooooooool0=oooool01?l00?oo
ooooooooool0000Iooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool0A_ooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`16ooooo`03o`00oooooooooooo01[o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Eooooo`04o`00ooooooooooooo`00
00;ooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
01[ooooo00?o003oooooooooool0A_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`16ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04?ooool01Ol00?oo
oooooooooooooooo003o01[ooooo00Co0000oooooooooooo003o6oooool00ol00?ooooooooooo`0@
ooooo`03o`00oooooooooooo053ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool0DOooool00ol00?ooooooooooo`0@ooooo`05o`00ooooooooooooooooool00?l06_ooool0
0ol0003oooooo`00o`0Kooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0D?ooool0
0ol0003oooooooooo`01ooooo`004Oooool2o`0004Oooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`0]ooooo`06o`00ooooooooooooo`000?oooooo003o5oooool01Ol00?oooooooooo
oooooooo003o01?ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`15ooooo`;o0000
0oooool0017ooooo00?o0000ooooooooool0A_ooool00ol00?ooooooooooo`0gooooo`04o`00oooo
ooooooooo`0001Wooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo04Kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0A_oo
ool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l05oooool01_l00?oooooo
ooooool0003oooooo`00oaOooooo00Go003oooooooooooooooooo`00o`0Mooooo`03o`00oooooooo
oooo04Kooooo00?o0000ooooooooool00Oooool000?ooooo0ol00004ooooo`;o00001Oooool00ol0
003oooooooooo`16ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool04Oooool01Ol0
0?oooooooooooooooooo003o01Oooooo00Ko003ooooooooooooo0000ooooool00?lGooooo`05o`00
ooooooooooooooooool00?l04oooool00ol00?ooooooooooo`1@ooooo`03o`000?oooooooooo007o
oooo0002ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo053ooooo00?o003oooooooooool04Oooool01?l00?ooooooooooool00?lK
ooooo`03o`000?oooooo003o01_ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`1@
ooooo`03o`000?oooooooooo007ooooo0006ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00_ooool3o`00053ooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0F
ooooo`06o`00ooooooooooooo`000?oooooo003o6?ooool01?l00?ooooooooooool00?lCooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool0A?ooool3o`0000?ooooo0004ooooo`;o0000
0oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04Kooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`0]ooooo`04o`00ooooooooooooo`0001[ooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo04Kooooo00?o0000oooo
ooooool00Oooool000Kooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo04Kooooo00?o003oooooooooool07?ooool00ol00?ooooooo`00o`0Hoooo
o`04o`00ooooooooooooo`0001[ooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`16
ooooo`03o`000?oooooooooo007ooooo0002ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo04Kooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`0Booooo`03o`00oooooooo003o01Sooooo00Ko003ooooooooooooo0000
ooooool00?lHooooo`03o`00oooooooo003o01kooooo00?o003oooooooooool0A_ooool00ol0003o
ooooooooo`01ooooo`000oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo053ooooo
00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Iooooo`03o`000?oooooo003o01[ooooo
00?o003oooooooooool04_ooool00ol00?ooooooooooo`1@ooooo`03o`000?oooooooooo007ooooo
000Aooooo`;o0000DOooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01[ooooo00?o
0000o`00ooooool06Oooool2o`00oaCooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`15ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0A_ooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo02kooooo00?o003oooooool00000<Oooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo04Kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool0A_ooool00ol00?ooooooooooo`0hooooo`03o`00oooooooo000003_ooooo00?o003ooooo
ooooool0A_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`17ooooo`03
o`00oooooooooooo03Oooooo00Co003oooooool0003o003o>_ooool00ol00?ooooooooooo`16oooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04Oooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0`ooooo`03o`000?l00?oooooo02oooooo00?o003ooooooooo
ool0D?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1@ooooo`03o`00
oooooooooooo033ooooo00?o0000o`00ooooool0;oooool00ol00?ooooooooooo`1@ooooo`03o`00
0?oooooooooo007ooooo000Aooooo`;o0000B?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo02kooooo00Co003oooooool0003o003o<?ooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo04Gooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`17ooooo`03o`00oooo
oooooooo03Oooooo00?o003oooooool00000<Oooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo04Kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Aoooool0
0ol00?ooooooooooo`0gooooo`04o`00oooooooo0000o`00ocWooooo00?o003oooooooooool0Aooo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`17ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool0;oooool2o`00oc7ooooo00?o003oooooooooool0D?ooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1@ooooo`03o`00oooooooooooo
033ooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`1@ooooo`03o`000?oooooooooo
007ooooo000Aooooo`;o0000DOooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo033o
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`16ooooo`;o00000oooool0017ooooo
00?o0000ooooooooool0Aoooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo033ooooo
00?o0000ooooooooool0<?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo04Oooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Aoooool00ol00?oooooooooo
o`0iooooo`03o`000?oooooooooo03Sooooo00?o003oooooooooool0Aoooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`17ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool0<Oooool00ol0003oooooooooo`0hooooo`03o`00oooooooooooo04Oooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Coooool00ol00?ooooooooooo`0aoooo
o`03o`000?oooooooooo033ooooo00?o003oooooooooool0Coooool00ol0003oooooooooo`01oooo
o`004Oooool2o`00053ooooo00?o003oooooooooool0<Oooool00ol0003oooooooooo`0`ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool0A_ooool2o`0000?ooooo000Aooooo`03o`00
0?oooooooooo04Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0aooooo`03o`00
0?oooooooooo033ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`17ooooo`03o`00
0?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04Oooooo00?o003oooooooooool0>Ooo
ool00ol0003oooooooooo`0hooooo`03o`00oooooooooooo04Oooooo00?o0000ooooooooool00Ooo
ool000Cooooo0ol00003ooooo`;o00001Oooool00ol0003oooooooooo`17ooooo`03o`00oooooooo
oooo03Wooooo00?o0000ooooooooool0>?ooool00ol00?ooooooooooo`17ooooo`03o`000?oooooo
oooo007ooooo0005ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo04Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0a
ooooo`03o`000?oooooooooo033ooooo00?o003oooooooooool0Coooool00ol0003oooooooooo`01
ooooo`000_ooool5o`0000;ooooo00Co0000oooooooooooo00001?ooool3o`0004oooooo00?o003o
ooooooooool0<Oooool00ol0003oooooooooo`0`ooooo`03o`00oooooooooooo04gooooo0ol00003
ooooo`000_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool0Aoooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo037ooooo00?o
0000ooooooooool0<?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo04Oooooo00?o
0000ooooooooool00Oooool000?ooooo00?o0000ooooool000000oooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo04Oooooo00?o003oooooooooool0>Oooool00ol0003ooooooooo
o`0`ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0Aoooool00ol0003ooooooooo
o`01ooooo`001?ooool2o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`17ooooo`03o`00oooooooooooo03Wooooo00?o0000ooooooooool0>?ooool00ol00?oooooooooo
o`17ooooo`03o`000?oooooooooo007ooooo0005ooooo`03o`000?oooooooooo00;ooooo0_l00005
ooooo`03o`000?oooooooooo04Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0a
ooooo`03o`000?oooooooooo033ooooo00?o003oooooooooool0Coooool00ol0003oooooooooo`01
ooooo`004Oooool2o`00053ooooo00?o003oooooooooool0<Oooool00ol0003oooooooooo`0`oooo
o`03o`00oooooooooooo04kooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1?ooooo`03
o`00oooooooooooo037ooooo00?o0000ooooooooool0<?ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo04Oooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
Aoooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo037ooooo00?o0000ooooooooool0
<?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo04Oooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool0Aoooool00ol00?ooooooooooo`0iooooo`03o`000?oo
oooooooo03Sooooo00?o003oooooooooool0Aoooool00ol0003oooooooooo`01ooooo`004Oooool0
0ol0003oooooooooo`18ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0<Oooool0
0ol0003oooooooooo`0`ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0Aoooool0
0ol0003oooooooooo`01ooooo`004Oooool2o`00053ooooo00?o003oooooooooool0<Oooool00ol0
003oooooooooo`0`ooooo`03o`00oooooooooooo04kooooo0_l00003ooooo`004Oooool00ol0003o
ooooooooo`1?ooooo`03o`00oooooooooooo037ooooo00?o0000ooooooooool0<?ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo04Sooooo00?o0000ooooooooool00Oooool0017ooooo
00?o0000ooooooooool0B?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo037ooooo
00?o0000ooooooooool0<?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo04Sooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0B?ooool00ol00?oooooooooo
o`0hooooo`03o`000?oooooooooo03Oooooo00?o003oooooooooool0B?ooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`18ooooo`03o`00oooooooooooo03Sooooo00?o0000
ooooooooool0=oooool00ol00?ooooooooooo`18ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo04Sooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0aoooo
o`03o`000?oooooooooo037ooooo00?o003oooooooooool0C_ooool00ol0003oooooooooo`01oooo
o`004Oooool2o`00053ooooo00?o003oooooooooool0<Oooool00ol0003oooooooooo`0aooooo`03
o`00oooooooooooo04gooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`18ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool0<_ooool00ol0003oooooooooo`0aooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool0B?ooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`18ooooo`03o`00oooooooooooo03Sooooo00?o0000ooooooooool0=ooo
ool00ol00?ooooooooooo`18ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo04Sooooo00?o003oooooooooool0>?ooool00ol0003oooooooooo`0gooooo`03o`00oooooooo
oooo04Sooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0B?ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo03;ooooo00?o0000ooooooooool0<Oooool00ol0
0?ooooooooooo`1>ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000Coooool00ol00?oo
ooooooooo`0booooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0COooool2o`0000?o
oooo000Aooooo`03o`000?oooooooooo04kooooo00?o003oooooooooool0<_ooool00ol0003ooooo
ooooo`0aooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0B?ooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`18ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool0<_ooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool0B?ooool00ol0003oooooooooo`01ooooo`000oooool3o`0000Cooooo0_l00005
ooooo`03o`000?oooooooooo04Sooooo00?o003oooooooooool0>?ooool00ol0003oooooooooo`0g
ooooo`03o`00oooooooooooo04Sooooo00?o0000ooooooooool00Oooool000;ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0B?oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo03;ooooo00?o0000ooooooooool0<Ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo04Sooooo00?o0000ooooooooool00Ooo
ool000Kooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`?o0000C_oo
ool00ol00?ooooooooooo`0booooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0C?oo
ool3o`0000?ooooo0006ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1>ooooo`03o`00oooooooooooo03;ooooo00?o0000ooooooooool0<Ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo04Sooooo00?o0000ooooooooool00Ooo
ool000;ooooo1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0B?oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo03;ooooo00?o0000ooooooooool0<Ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo04Sooooo00?o0000ooooooooool00Ooo
ool000;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo04Sooooo00?o003oooooooooool0>?ooool00ol0003oooooooooo`0gooooo`03o`00oooo
oooooooo04Sooooo00?o0000ooooooooool00Oooool000;ooooo1Ol00003ooooo`;o00001Oooool0
0ol0003oooooooooo`19ooooo`03o`00oooooooooooo03Oooooo00?o0000ooooooooool0=oooool0
0ol00?ooooooooooo`18ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000B_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo03;ooooo00?o0000ooooooooool0<Oooool00ol0
0?ooooooooooo`1=ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0C_ooool00ol00?oo
ooooooooo`0booooo`03o`000?oooooooooo037ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`19ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04Wooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0booooo`03o`000?oooooooooo03;ooooo
00Go003oooooooooooooooooo`00o`1;ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo04Wooooo00?o003oooooooooool0=oooool00ol0003oooooooooo`0fooooo`03o`00
oooooooooooo04Wooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0BOoo
ool00ol00?ooooooooooo`0gooooo`03o`000?oooooooooo03Kooooo00?o003oooooooooool0BOoo
ool00ol0003oooooooooo`01ooooo`004Oooool2o`0004[ooooo00Go003oooooooooooooooooo`00
o`0eooooo`03o`000?oooooooooo03;ooooo00?o003oooooooooool0C?ooool2o`0000?ooooo000A
ooooo`03o`000?oooooooooo04gooooo00?o003oooooooooool0<oooool00ol0003oooooooooo`0b
ooooo`03o`00oooooooooooo04gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool0COooool00ol00?ooooooooooo`0cooooo`03o`000?oooooooooo03;ooooo00Go003ooooo
ooooooooooooo`00o`1;ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
04Wooooo00?o003oooooooooool0=oooool00ol0003oooooooooo`0booooo`05o`00oooooooooooo
ooooool00?l0Boooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`19oooo
o`03o`00oooooooooooo03Oooooo00?o0000ooooooooool0=_ooool00ol00?ooooooooooo`19oooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04Wooooo00Go003ooooooooo
ooooooooo`00o`0eooooo`03o`000?oooooooooo03;ooooo00?o003oooooooooool0COooool00ol0
003oooooooooo`01ooooo`004Oooool2o`0004kooooo00?o003oooooooooool0<oooool00ol0003o
ooooooooo`0booooo`03o`00oooooooooooo04cooooo0_l00003ooooo`004Oooool00ol0003ooooo
ooooo`1=ooooo`03o`00oooooooooooo03?ooooo00?o0000ooooooooool0<_ooool01Ol00?oooooo
oooooooooooo003o04_ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
BOooool01Ol00?oooooooooooooooooo003o03Gooooo00?o0000ooooooooool0<_ooool01Ol00?oo
oooooooooooooooo003o04_ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0B_ooool00ol00?ooooooooooo`0fooooo`03o`000?oooooooooo03Kooooo00?o003ooooooooo
ool0BOooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1:ooooo`04o`00
ooooooooooooo`00ocGooooo00?o0000ooooooooool0=_ooool00ol00?ooooooooooo`19ooooo`03
o`000?oooooooooo007ooooo000Aooooo`;o0000Boooool01?l00?ooooooooooool00?leooooo`03
o`000?oooooooooo03;ooooo00?o003oooooooooool0C?ooool2o`0000?ooooo000Aooooo`03o`00
0?oooooooooo04gooooo00?o003oooooooooool0<oooool00ol0003oooooooooo`0cooooo`03o`00
oooooooo003o04cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0B_oo
ool00ol00?ooooooo`00o`0fooooo`03o`000?oooooooooo03?ooooo00?o003oooooool00?l0C?oo
ool00ol0003oooooooooo`01ooooo`000oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooo
oooo04[ooooo00?o003oooooooooool0=_ooool00ol0003oooooooooo`0eooooo`03o`00oooooooo
oooo04[ooooo00?o0000ooooooooool00Oooool000;ooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0B_ooool00ol00?oooooooooo
o`0fooooo`03o`000?oooooooooo03Gooooo00?o003oooooooooool0B_ooool00ol0003ooooooooo
o`01ooooo`000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
1?ooool3o`0004[ooooo00?o003oooooool00?l0=_ooool00ol0003oooooooooo`0cooooo`03o`00
oooooooooooo04[ooooo0ol00003ooooo`000_ooool4o`0000?ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`1<ooooo`03o`00oooooooooooo03Cooooo00?o0000ooooooooool0
<oooool00ol00?ooooooooooo`1<ooooo`03o`000?oooooooooo007ooooo0002ooooo`03o`000?oo
oooooooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1<ooooo`03o`00
oooooooooooo03Cooooo00?o0000ooooooooool0<oooool00ol00?ooooooo`00o`1<ooooo`03o`00
0?oooooooooo007ooooo0003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`1;ooooo`03o`00oooooooooooo03Gooooo00?o0000ooooooooool0
=?ooool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo007ooooo0004ooooo`;o00001?oo
ool2o`0000Gooooo00?o0000ooooooooool0Boooool00ol00?ooooooooooo`0eooooo`03o`000?oo
oooooooo08;ooooo00?o0000ooooooooool00Oooool0017ooooo0_l00024ooooo`03o`000?oooooo
oooo087ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
007ooooo000Aoooooooo00003Ol00003ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.95693, -5.26575, \
0.0394232, 0.385168}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Phase plot of DTFT as a function of index k", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(g2 = 
        Plot[Arg[
            X\[Theta]\  /. \ \[Theta] \[Rule] \ 2  \[Pi]\ f/fs], {f, \(-fs\)/
              2, fs/2}, \ PlotStyle \[Rule] {Blue, \ Dashing[{ .01}]}, \ 
          PlotRange \[Rule] All, PlotPoints \[Rule] 200];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309473 0.0938566 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0279 -12 -4.5 ]
[-0.0125 .0279 0 4.5 ]
[-0.0125 .12176 -12 -4.5 ]
[-0.0125 .12176 0 4.5 ]
[-0.0125 .21562 -12 -4.5 ]
[-0.0125 .21562 0 4.5 ]
[-0.0125 .30947 -6 -4.5 ]
[-0.0125 .30947 0 4.5 ]
[-0.0125 .40333 -6 -4.5 ]
[-0.0125 .40333 0 4.5 ]
[-0.0125 .49719 -6 -4.5 ]
[-0.0125 .49719 0 4.5 ]
[-0.0125 .59104 -6 -4.5 ]
[-0.0125 .59104 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0279 m
.00625 .0279 L
s
[(-3)] -0.0125 .0279 1 0 Mshowa
0 .12176 m
.00625 .12176 L
s
[(-2)] -0.0125 .12176 1 0 Mshowa
0 .21562 m
.00625 .21562 L
s
[(-1)] -0.0125 .21562 1 0 Mshowa
0 .30947 m
.00625 .30947 L
s
[(0)] -0.0125 .30947 1 0 Mshowa
0 .40333 m
.00625 .40333 L
s
[(1)] -0.0125 .40333 1 0 Mshowa
0 .49719 m
.00625 .49719 L
s
[(2)] -0.0125 .49719 1 0 Mshowa
0 .59104 m
.00625 .59104 L
s
[(3)] -0.0125 .59104 1 0 Mshowa
.125 Mabswid
0 .04667 m
.00375 .04667 L
s
0 .06545 m
.00375 .06545 L
s
0 .08422 m
.00375 .08422 L
s
0 .10299 m
.00375 .10299 L
s
0 .14053 m
.00375 .14053 L
s
0 .1593 m
.00375 .1593 L
s
0 .17807 m
.00375 .17807 L
s
0 .19685 m
.00375 .19685 L
s
0 .23439 m
.00375 .23439 L
s
0 .25316 m
.00375 .25316 L
s
0 .27193 m
.00375 .27193 L
s
0 .2907 m
.00375 .2907 L
s
0 .32824 m
.00375 .32824 L
s
0 .34702 m
.00375 .34702 L
s
0 .36579 m
.00375 .36579 L
s
0 .38456 m
.00375 .38456 L
s
0 .4221 m
.00375 .4221 L
s
0 .44087 m
.00375 .44087 L
s
0 .45964 m
.00375 .45964 L
s
0 .47841 m
.00375 .47841 L
s
0 .51596 m
.00375 .51596 L
s
0 .53473 m
.00375 .53473 L
s
0 .5535 m
.00375 .5535 L
s
0 .57227 m
.00375 .57227 L
s
0 .00913 m
.00375 .00913 L
s
0 .60981 m
.00375 .60981 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0279 m
1 .0279 L
s
.99375 .12176 m
1 .12176 L
s
.99375 .21562 m
1 .21562 L
s
.99375 .30947 m
1 .30947 L
s
.99375 .40333 m
1 .40333 L
s
.99375 .49719 m
1 .49719 L
s
.99375 .59104 m
1 .59104 L
s
.125 Mabswid
.99625 .04667 m
1 .04667 L
s
.99625 .06545 m
1 .06545 L
s
.99625 .08422 m
1 .08422 L
s
.99625 .10299 m
1 .10299 L
s
.99625 .14053 m
1 .14053 L
s
.99625 .1593 m
1 .1593 L
s
.99625 .17807 m
1 .17807 L
s
.99625 .19685 m
1 .19685 L
s
.99625 .23439 m
1 .23439 L
s
.99625 .25316 m
1 .25316 L
s
.99625 .27193 m
1 .27193 L
s
.99625 .2907 m
1 .2907 L
s
.99625 .32824 m
1 .32824 L
s
.99625 .34702 m
1 .34702 L
s
.99625 .36579 m
1 .36579 L
s
.99625 .38456 m
1 .38456 L
s
.99625 .4221 m
1 .4221 L
s
.99625 .44087 m
1 .44087 L
s
.99625 .45964 m
1 .45964 L
s
.99625 .47841 m
1 .47841 L
s
.99625 .51596 m
1 .51596 L
s
.99625 .53473 m
1 .53473 L
s
.99625 .5535 m
1 .5535 L
s
.99625 .57227 m
1 .57227 L
s
.99625 .00913 m
1 .00913 L
s
.99625 .60981 m
1 .60981 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30947 m
1 .30947 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .30947 m
.02847 .27609 L
.03089 .26002 L
.03218 .25241 L
.03288 .24865 L
.03355 .2455 L
.03417 .24303 L
.0345 .24196 L
.03484 .24104 L
.03514 .24046 L
.03522 .24034 L
.0353 .24023 L
.03546 .24008 L
.03561 .24001 L
.03575 .24001 L
.03588 .24007 L
.03602 .24021 L
.03618 .24047 L
.03632 .24082 L
.03646 .24123 L
.0366 .24178 L
.03676 .24253 L
.03692 .2435 L
.03722 .24579 L
.03749 .24864 L
.03774 .25206 L
.03802 .25685 L
.03832 .26339 L
.03948 .30507 L
.04012 .33436 L
.04071 .35757 L
.04102 .36677 L
.04135 .37459 L
.04172 .3811 L
.04206 .38544 L
.04235 .38816 L
.04267 .3903 L
.04283 .3911 L
.043 .39177 L
.04316 .39225 L
.04331 .39258 L
.04345 .39279 L
.04361 .39294 L
.04369 .39297 L
.04378 .39298 L
.04393 .39294 L
.04408 .39283 L
.04423 .39266 L
.04436 .39246 L
.0445 .39219 L
Mistroke
.04482 .39141 L
.04516 .39036 L
.04578 .388 L
.04812 .37567 L
.05314 .34164 L
.05798 .30651 L
.06263 .27448 L
.06504 .26082 L
.06563 .25819 L
.06625 .25587 L
.06661 .25484 L
.06694 .25413 L
.0671 .25388 L
.06718 .25377 L
.06727 .25368 L
.06735 .25362 L
.06743 .25358 L
.06758 .25356 L
.06773 .25362 L
.06787 .25375 L
.06802 .25399 L
.0681 .25417 L
.06818 .25436 L
.06833 .25485 L
.0685 .25553 L
.0688 .25725 L
.06909 .25951 L
.06939 .26275 L
.06964 .26637 L
.06992 .27142 L
.07025 .27906 L
.07055 .2879 L
.07122 .31462 L
.07181 .34242 L
.07244 .3686 L
.07301 .38542 L
.07333 .39219 L
.07363 .39703 L
.07391 .40041 L
.07416 .40278 L
.07444 .40472 L
.07458 .40547 L
.07474 .40614 L
.07491 .40671 L
.07507 .40712 L
.07521 .40737 L
.07536 .40755 L
.07544 .4076 L
.07553 .40763 L
.07563 .40763 L
Mistroke
.07571 .4076 L
.07587 .40749 L
.07595 .4074 L
.07603 .4073 L
.07633 .40677 L
.07665 .40597 L
.07724 .40401 L
.07849 .39835 L
.07961 .39205 L
.08214 .37577 L
.08698 .34121 L
.09163 .30748 L
.09399 .29134 L
.09524 .28345 L
.09658 .27588 L
.09724 .27265 L
.09787 .27006 L
.09843 .26823 L
.09859 .26783 L
.09875 .26747 L
.0989 .26719 L
.09904 .26698 L
.09918 .26684 L
.09931 .26675 L
.09945 .26672 L
.09961 .26677 L
.09974 .26689 L
.09988 .26711 L
.10002 .2674 L
.10014 .26774 L
.10029 .2683 L
.10043 .26895 L
.10059 .2698 L
.10076 .27096 L
.10104 .27348 L
.10134 .27711 L
.10164 .28196 L
.10197 .28895 L
.10228 .29754 L
.10257 .30744 L
.10369 .35947 L
.10399 .37327 L
.10432 .38608 L
.10461 .39533 L
.10491 .40311 L
.10527 .41 L
.10559 .41463 L
.10589 .41769 L
.10606 .41905 L
.10621 .42008 L
Mistroke
.10636 .42088 L
.10651 .42159 L
.10668 .42215 L
.10676 .4224 L
.10685 .42259 L
.10699 .42285 L
.10708 .42295 L
.10716 .42302 L
.10729 .42309 L
.10745 .42307 L
.10759 .42299 L
.10773 .42285 L
.10788 .42263 L
.10803 .42236 L
.10857 .42095 L
.1092 .41864 L
.10978 .41604 L
.11109 .40901 L
.11586 .37719 L
.12043 .34363 L
.12531 .30868 L
.12755 .29426 L
.12874 .2877 L
.12939 .28463 L
.13 .28222 L
.13033 .28117 L
.13063 .2804 L
.13079 .28007 L
.13097 .2798 L
.13106 .2797 L
.13114 .27962 L
.13123 .27956 L
.13133 .27953 L
.13149 .27955 L
.13158 .27961 L
.13166 .2797 L
.13181 .27993 L
.13189 .2801 L
.13197 .28031 L
.13212 .28078 L
.13228 .28143 L
.13256 .28305 L
.13272 .28427 L
.13287 .28563 L
.13321 .28967 L
.13351 .29458 L
.13383 .30157 L
.13414 .31061 L
.13443 .32138 L
.13498 .34719 L
Mistroke
.1356 .37924 L
.13616 .40397 L
.13645 .41329 L
.13676 .42111 L
.1371 .42758 L
.13741 .43187 L
.1377 .43475 L
.13796 .43668 L
.1381 .43746 L
.13825 .43816 L
.13841 .43873 L
.13856 .43913 L
.13869 .43939 L
.13883 .43957 L
.13895 .43965 L
.13908 .43968 L
.13922 .43964 L
.13937 .43952 L
.13951 .43935 L
.13964 .43914 L
.13992 .43854 L
.14023 .43768 L
.14085 .43542 L
.14196 .43013 L
.14447 .41487 L
.14934 .38014 L
.15402 .34525 L
.15641 .32794 L
.15901 .31037 L
.16021 .30313 L
.16088 .29959 L
.1615 .29665 L
.16207 .29442 L
.16232 .29362 L
.16259 .29289 L
.16273 .2926 L
.16288 .29234 L
.16303 .29213 L
.16318 .29201 L
.16326 .29197 L
.16335 .29196 L
.16343 .29197 L
.16351 .29201 L
.16365 .29217 L
.16381 .29244 L
.16395 .29282 L
.16411 .29338 L
.16426 .29407 L
.1644 .29486 L
.16466 .29685 L
Mistroke
.16494 .29979 L
.16527 .30467 L
.16558 .31107 L
.16586 .31872 L
.16616 .32947 L
.1673 .39088 L
.16759 .40629 L
.16786 .41873 L
.16813 .42862 L
.16837 .43594 L
.16863 .44219 L
.16892 .44734 L
.16921 .45111 L
.16952 .45397 L
.16967 .45501 L
.16983 .45591 L
.16998 .45658 L
.17011 .45706 L
.17027 .45745 L
.17036 .45762 L
.17044 .45774 L
.17052 .45783 L
.1706 .45788 L
.17069 .45791 L
.17078 .4579 L
.17092 .45783 L
.17101 .45776 L
.17108 .45767 L
.17124 .45743 L
.17141 .4571 L
.17172 .45632 L
.17199 .45543 L
.17332 .44957 L
.17561 .43579 L
.17811 .4184 L
.18302 .38172 L
.18775 .3462 L
.19016 .329 L
.19143 .32062 L
.19277 .3127 L
.19335 .30973 L
.19397 .30702 L
.19433 .30575 L
.19466 .30484 L
.19481 .30449 L
.19489 .30434 L
.19498 .3042 L
.19506 .3041 L
.19514 .30401 L
.19529 .30391 L
Mistroke
.19545 .30391 L
.19559 .30401 L
.19572 .3042 L
.19587 .30451 L
.19602 .305 L
.19619 .30572 L
.19635 .30661 L
.19649 .30762 L
.19677 .31026 L
.19692 .31223 L
.19707 .31439 L
.19733 .31947 L
.19761 .32676 L
.19884 .39232 L
.19913 .4125 L
.19944 .4312 L
.19971 .44397 L
.2 .45476 L
.20026 .46186 L
.20054 .46753 L
.20081 .47142 L
.20105 .47403 L
.20131 .47605 L
.20146 .47689 L
.2016 .4775 L
.20175 .47798 L
.20188 .4783 L
.20204 .47854 L
.20219 .47865 L
.20232 .47866 L
.20247 .47858 L
.20263 .47841 L
.20277 .47818 L
.20303 .4776 L
.20331 .47679 L
.20395 .47435 L
.20454 .47158 L
.20706 .45626 L
.21185 .42126 L
.21646 .38565 L
.22136 .34837 L
.22363 .33247 L
.22483 .32502 L
.22609 .31855 L
.2264 .31732 L
.22673 .31623 L
.22692 .31574 L
.22709 .31539 L
.22718 .31526 L
.22727 .31514 L
Mistroke
.22735 .31507 L
.22743 .31503 L
.22758 .31504 L
.22772 .31515 L
.22787 .31541 L
.22796 .31562 L
.22803 .31587 L
.22818 .31648 L
.22835 .31739 L
.22851 .31866 L
.22867 .3202 L
.22882 .32208 L
.22899 .32464 L
.22914 .32745 L
.22929 .33111 L
.22943 .33513 L
.22958 .34051 L
.22985 .35301 L
.23016 .37364 L
.2305 .40275 L
.23082 .43203 L
.23111 .45447 L
.23141 .47202 L
.23158 .47914 L
.23174 .48453 L
.23202 .49169 L
.23218 .49465 L
.23233 .49684 L
.23248 .49865 L
.23264 .50018 L
.23281 .50145 L
.23298 .50233 L
.23307 .5027 L
.23316 .50302 L
.23325 .50326 L
.23334 .50343 L
.23349 .50362 L
.23357 .50366 L
.23366 .50367 L
.23374 .50364 L
.23382 .50358 L
.23398 .5034 L
.23413 .50314 L
.23427 .50282 L
.23458 .50191 L
.23491 .50067 L
.23609 .49486 L
.2411 .46001 L
.24593 .42214 L
.25058 .38508 L
Mistroke
.25294 .36655 L
.25553 .347 L
.25671 .33865 L
.25799 .33068 L
.25861 .32749 L
.25891 .32618 L
.25919 .32519 L
.25932 .32482 L
.25945 .32453 L
.25957 .3243 L
.25972 .32414 L
.25986 .3241 L
.25999 .32419 L
.26014 .32445 L
.26029 .32494 L
.26044 .3257 L
.26052 .32627 L
.2606 .32689 L
.26074 .32836 L
.26089 .33045 L
.26103 .33293 L
.26115 .33592 L
.26129 .34018 L
.26144 .34627 L
.2616 .3551 L
.26177 .36864 L
.26193 .38641 L
.26208 .40766 L
.26238 .45648 L
.26253 .4769 L
.26267 .4917 L
.2628 .50268 L
.26294 .51146 L
.26308 .51807 L
.26323 .52347 L
.26336 .52688 L
.2635 .5297 L
.26362 .53176 L
.26374 .53322 L
.26389 .53461 L
.26402 .53555 L
.26417 .53627 L
.26433 .53676 L
.26446 .53698 L
.26459 .53706 L
.26473 .53701 L
.26488 .53683 L
.26504 .53654 L
.26517 .53619 L
.26548 .53516 L
Mistroke
.26604 .53266 L
.2673 .52524 L
.26985 .50703 L
.27468 .46882 L
.27932 .4307 L
.28426 .38969 L
.28902 .35002 L
.2936 .31182 L
.29847 .27116 L
.30316 .23204 L
.30814 .1904 L
.31294 .14996 L
.31756 .1095 L
.31989 .08655 L
.32053 .07935 L
.32122 .07065 L
.32182 .06176 L
.32214 .0562 L
.32247 .04921 L
.3228 .04088 L
.32309 .03116 L
.32324 .02536 L
.32339 .01793 L
.32354 .59919 L
.32367 .58975 L
.32397 .5619 L
.32413 .54052 L
.32429 .51732 L
.32462 .46725 L
.32479 .44731 L
.32494 .43239 L
.32521 .41265 L
.32536 .40481 L
.32551 .39783 L
.32603 .38078 L
.32635 .37338 L
.32665 .36757 L
.3272 .35862 L
.32838 .34395 L
.32963 .33135 L
.33186 .3119 L
.33644 .2774 L
.33899 .26042 L
.34131 .24651 L
.34375 .2341 L
.34482 .22964 L
.34544 .22746 L
.34601 .22569 L
.34659 .22424 L
.34685 .22372 L
Mistroke
.34712 .22325 L
.3474 .2229 L
.34755 .22275 L
.3477 .22265 L
.34785 .22258 L
.34799 .22256 L
.34807 .22256 L
.34816 .22258 L
.34831 .22265 L
.34847 .22278 L
.34861 .22295 L
.34877 .2232 L
.34894 .22354 L
.34929 .22453 L
.34961 .22581 L
.34991 .22736 L
.35023 .22954 L
.35082 .23516 L
.35112 .23922 L
.35146 .24469 L
.35175 .25063 L
.35206 .25824 L
.35265 .27713 L
.35319 .29968 L
.35442 .35513 L
.3551 .37816 L
.35573 .39292 L
.35631 .40284 L
.35695 .41069 L
.35755 .41623 L
.3581 .42024 L
.35917 .42605 L
.36031 .43039 L
.36145 .4335 L
.36208 .43482 L
.36267 .43579 L
.36321 .43648 L
.36349 .43677 L
.3638 .43702 L
.36409 .43721 L
.36436 .43732 L
.36448 .43736 L
.36462 .4374 L
.36475 .43741 L
.36487 .43742 L
.36503 .43742 L
.36517 .4374 L
.3653 .43737 L
.36544 .43733 L
.36559 .43727 L
Mistroke
.36576 .43719 L
.36605 .437 L
.36657 .43653 L
.36714 .43582 L
.36776 .43482 L
.36843 .43349 L
.36963 .43043 L
.37205 .42207 L
.37459 .41058 L
.37919 .38471 L
.38408 .35234 L
.38878 .31813 L
.39379 .27946 L
.39861 .24032 L
.40324 .20078 L
.40818 .15543 L
.41063 .13026 L
.41293 .1029 L
.41406 .08666 L
.41513 .06783 L
.41572 .05509 L
.41636 .03817 L
.41665 .02936 L
.4168 .02409 L
.41695 .01882 L
.41709 .60332 L
.41724 .59734 L
.41749 .58602 L
.41863 .52439 L
.41985 .46086 L
.42056 .43484 L
.42119 .41656 L
.42244 .38989 L
.42362 .37081 L
.42489 .35338 L
.42721 .32599 L
.43213 .27412 L
.43687 .22399 L
.43925 .19602 L
.44143 .16561 L
.44255 .14628 L
.44377 .11939 L
.44499 .08166 L
.44566 .0549 L
.44598 .04019 L
.44613 .03348 L
.44628 .02599 L
.44643 .01879 L
.44657 .60175 L
.44672 .59463 L
Mistroke
.44688 .58706 L
.44752 .55796 L
.44865 .51711 L
.44933 .49834 L
.44997 .48346 L
.45118 .46071 L
.45358 .4261 L
.4558 .39973 L
.46053 .34991 L
.46507 .30354 L
.4676 .2758 L
.4687 .26213 L
.46991 .24466 L
.47048 .23477 L
.47109 .22196 L
.47166 .20618 L
.47218 .18619 L
.47249 .17028 L
.47277 .15171 L
.47341 .09499 L
.47398 .04337 L
.47411 .03305 L
.47426 .02309 L
.47435 .01789 L
.47442 .60316 L
.47457 .59518 L
.47515 .57199 L
.47547 .56236 L
.47576 .55494 L
.47686 .53351 L
.47815 .51504 L
.47936 .50043 L
.48401 .45307 L
.48896 .40746 L
.49372 .3649 L
.4983 .32444 L
.50318 .28147 L
.50787 .23991 L
.51286 .19498 L
.51766 .14965 L
.51986 .12708 L
.52111 .11298 L
.52229 .09807 L
.52344 .08034 L
.52408 .06761 L
.52467 .05251 L
.52526 .03136 L
.52542 .02385 L
.52551 .01931 L
.5256 .01472 L
Mistroke
.52567 .59986 L
.52576 .59457 L
.52591 .58442 L
.52658 .52486 L
.52691 .49353 L
.52721 .46879 L
.52776 .43558 L
.52806 .42253 L
.52835 .41244 L
.52895 .3961 L
.5296 .38258 L
.53092 .36187 L
.53214 .34625 L
.53687 .29544 L
.54189 .24422 L
.54441 .2169 L
.54673 .18893 L
.54899 .1553 L
.55013 .13319 L
.55078 .11793 L
.55138 .10077 L
.55198 .08079 L
.55262 .0549 L
.5529 .04218 L
.5532 .02805 L
.55333 .02212 L
.55346 .01571 L
.5536 .59837 L
.55374 .59179 L
.55495 .53949 L
.55627 .49874 L
.55752 .47139 L
.55869 .4515 L
.56123 .41692 L
.56595 .36468 L
.57096 .31272 L
.57347 .28522 L
.57579 .25656 L
.57696 .23929 L
.57805 .21962 L
.57919 .19203 L
.57979 .17224 L
.58044 .14501 L
.58166 .0774 L
.582 .05855 L
.58235 .04016 L
.58266 .02614 L
.58274 .02257 L
.58283 .01886 L
.58292 .01548 L
Mistroke
.58299 .60219 L
.58314 .597 L
.58329 .59176 L
.58356 .58308 L
.58418 .56636 L
.58542 .54094 L
.58665 .52177 L
.58799 .50444 L
.59042 .47756 L
.59535 .43062 L
.6001 .38943 L
.60467 .35185 L
.60953 .31362 L
.61421 .27879 L
.61918 .24458 L
.62397 .21582 L
.62639 .20363 L
.62858 .19442 L
.62972 .19046 L
.63096 .18692 L
.63164 .18532 L
.63226 .18409 L
.63285 .18314 L
.63318 .1827 L
.63349 .18236 L
.63378 .18208 L
.6341 .18184 L
.63424 .18176 L
.63439 .18168 L
.63452 .18163 L
.63466 .18158 L
.6348 .18155 L
.63493 .18153 L
.63505 .18152 L
.63518 .18153 L
.63533 .18154 L
.63546 .18157 L
.6356 .18161 L
.63576 .18167 L
.63608 .18184 L
.63643 .18211 L
.63676 .18243 L
.63707 .18279 L
.63764 .18364 L
.63825 .18479 L
.63942 .18773 L
.64052 .19157 L
.64119 .19461 L
.64182 .19818 L
.64239 .20218 L
Mistroke
.64301 .20777 L
.64365 .21556 L
.64426 .22566 L
.6448 .2381 L
.64539 .25639 L
.64659 .30946 L
.64723 .33749 L
.64759 .35021 L
.64792 .36022 L
.64823 .36798 L
.64857 .37481 L
.64917 .38357 L
.64946 .38673 L
.64977 .38942 L
.65006 .39142 L
.65033 .39287 L
.65063 .39415 L
.65079 .39468 L
.65095 .39516 L
.65111 .39552 L
.65125 .3958 L
.65139 .396 L
.65154 .39617 L
.65163 .39625 L
.65171 .39631 L
.6518 .39635 L
.6519 .39638 L
.65198 .39639 L
.65206 .39638 L
.65215 .39636 L
.65224 .39633 L
.65232 .39628 L
.65241 .39622 L
.65257 .39608 L
.65287 .3957 L
.65315 .39523 L
.65346 .39461 L
.65401 .39322 L
.65526 .389 L
.65779 .3773 L
.66275 .34713 L
.66753 .31203 L
.66993 .29165 L
.67212 .26918 L
.67271 .26161 L
.67334 .25164 L
.67363 .24606 L
.67394 .23902 L
.67422 .23083 L
.67449 .22126 L
Mistroke
.67479 .20636 L
.67495 .19534 L
.67511 .1822 L
.67539 .15048 L
.67569 .10499 L
.67602 .05835 L
.67621 .03904 L
.67638 .02546 L
.67653 .01533 L
.67662 .60021 L
.6767 .5962 L
.67701 .58393 L
.67731 .57505 L
.67758 .56852 L
.67819 .55703 L
.67929 .54174 L
.68178 .51562 L
.68659 .47298 L
.69122 .43391 L
.69614 .39276 L
.70088 .3532 L
.70544 .31515 L
.7103 .27463 L
.71497 .23567 L
.71993 .1944 L
.72472 .15504 L
.72932 .11828 L
.73189 .09919 L
.7331 .09115 L
.73363 .08803 L
.73422 .08505 L
.73449 .0839 L
.73478 .08289 L
.73494 .08245 L
.73509 .08215 L
.73524 .08196 L
.73538 .08189 L
.73553 .08196 L
.73561 .08206 L
.73569 .08224 L
.73584 .08273 L
.73598 .08343 L
.73606 .08396 L
.73615 .08464 L
.7363 .0862 L
.73646 .08852 L
.73664 .09207 L
.7368 .09631 L
.73694 .1017 L
.73707 .1081 L
Mistroke
.73721 .1173 L
.73737 .13088 L
.73753 .15037 L
.73783 .19645 L
.73808 .23377 L
.73822 .24932 L
.73835 .26022 L
.7385 .26982 L
.73865 .27653 L
.73878 .28118 L
.73893 .28503 L
.73909 .28818 L
.73924 .29032 L
.7394 .29203 L
.73948 .29269 L
.73957 .29329 L
.73972 .29404 L
.73981 .29434 L
.73988 .29454 L
.74003 .29479 L
.74017 .29485 L
.74031 .29479 L
.74046 .2946 L
.74058 .29436 L
.74071 .29403 L
.74102 .29304 L
.7413 .29187 L
.74252 .28526 L
.74383 .27653 L
.7488 .2388 L
.75358 .20072 L
.75817 .16451 L
.76074 .14521 L
.76307 .12919 L
.76423 .12235 L
.76484 .11933 L
.76518 .11792 L
.76549 .11682 L
.76576 .11606 L
.76592 .11573 L
.76606 .1155 L
.76621 .11534 L
.7663 .11529 L
.76638 .11528 L
.76652 .11534 L
.76668 .11555 L
.76682 .11588 L
.76698 .11641 L
.76712 .11711 L
.76725 .11795 L
Mistroke
.76751 .12016 L
.76764 .12165 L
.76778 .12363 L
.76808 .12957 L
.76825 .13419 L
.76841 .13953 L
.7687 .15274 L
.76885 .16146 L
.76901 .17285 L
.7696 .22503 L
.76985 .24657 L
.77013 .26503 L
.7703 .27347 L
.77046 .27984 L
.77076 .28914 L
.77093 .29289 L
.77109 .2956 L
.77127 .29806 L
.77144 .29986 L
.77159 .30109 L
.77174 .30209 L
.77188 .30274 L
.77202 .30327 L
.77218 .30365 L
.77227 .30379 L
.77235 .30387 L
.77251 .30393 L
.77266 .30387 L
.7728 .30373 L
.77294 .30349 L
.77308 .3032 L
.77321 .30288 L
.77382 .30077 L
.77442 .29801 L
.77506 .29458 L
.77728 .28027 L
.78187 .24618 L
.78676 .20834 L
.79147 .17298 L
.79387 .15662 L
.79513 .14913 L
.79582 .14561 L
.79647 .1429 L
.79676 .14191 L
.79705 .14115 L
.7972 .14082 L
.79728 .14068 L
.79737 .14054 L
.79752 .14037 L
.79766 .14029 L
Mistroke
.79775 .14028 L
.79783 .14031 L
.79792 .14037 L
.79802 .14048 L
.79818 .14078 L
.79827 .14101 L
.79835 .14128 L
.79851 .14192 L
.79865 .14269 L
.79882 .14381 L
.79898 .14515 L
.79926 .14832 L
.7994 .15039 L
.79955 .15312 L
.79983 .15929 L
.80008 .16705 L
.80039 .17923 L
.80066 .19374 L
.80129 .23555 L
.80186 .27098 L
.80218 .28513 L
.80247 .29458 L
.80275 .30107 L
.80304 .30617 L
.80332 .30958 L
.80357 .3118 L
.80372 .31273 L
.80387 .31352 L
.80402 .3141 L
.80415 .31449 L
.80431 .3148 L
.8044 .31492 L
.80448 .31499 L
.80463 .31505 L
.80479 .31499 L
.80487 .31492 L
.80495 .31483 L
.80514 .31456 L
.80529 .31423 L
.80546 .31381 L
.80607 .31175 L
.80722 .3063 L
.80845 .29909 L
.81066 .28423 L
.81566 .24723 L
.82047 .21091 L
.82511 .17852 L
.82634 .1712 L
.8275 .16548 L
.82808 .16326 L
Mistroke
.82841 .16229 L
.82871 .16161 L
.82879 .16146 L
.82888 .16133 L
.82903 .16115 L
.82913 .16108 L
.82922 .16104 L
.8293 .16104 L
.82939 .16106 L
.82947 .16111 L
.82955 .1612 L
.82964 .16132 L
.82973 .16148 L
.82988 .16186 L
.83004 .16241 L
.83018 .16308 L
.83034 .164 L
.8305 .16513 L
.83067 .16663 L
.83098 .17017 L
.83126 .17475 L
.8316 .18226 L
.83196 .19326 L
.83226 .20568 L
.8326 .22254 L
.83325 .26065 L
.83357 .27769 L
.83387 .29072 L
.83413 .30002 L
.83442 .30799 L
.83471 .31403 L
.83502 .31872 L
.83518 .32057 L
.83533 .32204 L
.83561 .32415 L
.83577 .32503 L
.83592 .32567 L
.83608 .32621 L
.83616 .32644 L
.83625 .32661 L
.83639 .32684 L
.83647 .32692 L
.83655 .32697 L
.83669 .32699 L
.83685 .32693 L
.83698 .3268 L
.83713 .3266 L
.83726 .32636 L
.83739 .32609 L
.83801 .32424 L
Mistroke
.83869 .32147 L
.83992 .31509 L
.84484 .28203 L
.84958 .24686 L
.85414 .21361 L
.85667 .19675 L
.85778 .19023 L
.85837 .18713 L
.859 .1842 L
.85961 .18179 L
.85991 .18087 L
.86018 .18018 L
.86045 .17966 L
.86059 .17947 L
.86074 .17933 L
.86087 .17927 L
.86099 .17927 L
.86113 .17934 L
.86127 .1795 L
.86135 .17963 L
.86143 .17979 L
.86158 .18018 L
.86174 .18074 L
.86192 .18155 L
.86207 .18242 L
.86223 .18358 L
.86252 .18634 L
.86281 .19005 L
.86312 .19531 L
.86338 .20115 L
.86367 .20926 L
.86498 .2701 L
.8653 .28581 L
.86563 .30011 L
.86594 .3108 L
.86623 .31869 L
.86648 .32419 L
.86676 .3288 L
.86706 .33263 L
.86734 .33518 L
.86764 .3371 L
.86781 .33789 L
.86796 .33845 L
.86811 .33886 L
.86825 .33912 L
.86841 .33932 L
.86855 .33941 L
.8687 .33941 L
.86883 .33935 L
.86897 .33922 L
Mistroke
.86913 .33901 L
.86929 .33871 L
.86944 .33838 L
.86973 .3376 L
.87025 .33581 L
.87082 .33341 L
.87326 .3197 L
.87818 .28549 L
.88292 .25064 L
.88747 .21879 L
.88981 .20496 L
.89045 .20183 L
.89112 .19905 L
.8917 .19723 L
.89185 .19684 L
.89202 .19649 L
.89218 .19623 L
.89232 .19604 L
.89247 .19591 L
.89255 .19587 L
.89264 .19586 L
.89273 .19586 L
.89281 .1959 L
.89297 .19605 L
.89311 .19628 L
.89325 .19659 L
.8934 .19704 L
.89356 .19767 L
.89373 .19855 L
.89392 .19974 L
.89426 .20271 L
.8946 .20681 L
.8949 .21191 L
.89519 .21828 L
.89546 .22576 L
.89608 .24899 L
.89733 .30764 L
.89763 .31844 L
.89794 .32771 L
.89828 .33554 L
.8986 .34096 L
.89889 .34473 L
.89917 .34738 L
.89947 .34947 L
.89964 .35034 L
.89979 .35097 L
.89993 .3514 L
.90008 .35176 L
.90022 .35199 L
.90034 .35213 L
Mistroke
.90049 .35222 L
.90057 .35222 L
.90065 .35221 L
.90079 .35213 L
.90094 .35199 L
.90107 .3518 L
.90121 .35156 L
.90146 .351 L
.90203 .34925 L
.90267 .3467 L
.90326 .3439 L
.90459 .33651 L
.90702 .32086 L
.91175 .28702 L
.9163 .25399 L
.91883 .23664 L
.92115 .22253 L
.92233 .21671 L
.9229 .21442 L
.92342 .21277 L
.92371 .2121 L
.92384 .21185 L
.92397 .21164 L
.92412 .21146 L
.92426 .21136 L
.9244 .21132 L
.92449 .21132 L
.92456 .21135 L
.92464 .2114 L
.92473 .21149 L
.92488 .21172 L
.92503 .21205 L
.92517 .21246 L
.92533 .21309 L
.92548 .2138 L
.92581 .21599 L
.9261 .21859 L
.9264 .22242 L
.92673 .22777 L
.92703 .23429 L
.92756 .25042 L
.92814 .27426 L
.92877 .30411 L
.92912 .31901 L
.92944 .33084 L
.92974 .33973 L
.93002 .34628 L
.93032 .352 L
.93065 .35665 L
.93094 .35966 L
Mistroke
.93125 .36206 L
.93141 .36297 L
.93158 .36375 L
.93174 .36433 L
.93188 .36474 L
.93196 .36492 L
.93205 .36508 L
.93221 .36528 L
.9323 .36534 L
.93238 .36538 L
.93247 .36539 L
.93257 .36537 L
.93265 .36532 L
.93274 .36525 L
.93283 .36516 L
.93291 .36506 L
.93322 .36451 L
.9335 .3638 L
.93378 .36298 L
.93439 .36067 L
.93564 .35463 L
.9403 .3247 L
.94526 .2889 L
.95003 .25513 L
.95244 .24 L
.95349 .23433 L
.95462 .22933 L
.95493 .22828 L
.95526 .22733 L
.95553 .2267 L
.95569 .22641 L
.95584 .22621 L
.95599 .22606 L
.95613 .22598 L
.95625 .22596 L
.95639 .22601 L
.95654 .22614 L
.9567 .22639 L
.95685 .22673 L
.95699 .22714 L
.95714 .22774 L
.95731 .22855 L
.95761 .23049 L
.95793 .23345 L
.95829 .23798 L
.95859 .24325 L
.95892 .25061 L
.95951 .26925 L
.96074 .32363 L
.96107 .33711 L
Mistroke
.96143 .34894 L
.96174 .35697 L
.96207 .36386 L
.96239 .36873 L
.96267 .3721 L
.96299 .37483 L
.96315 .37588 L
.96332 .37682 L
.96348 .37747 L
.96362 .37796 L
.96378 .37839 L
.96393 .37867 L
.96407 .37884 L
.9642 .37892 L
.96435 .37895 L
.9645 .37889 L
.96465 .37877 L
.9648 .37857 L
.96495 .37833 L
.96509 .37804 L
.96564 .37656 L
.96623 .37438 L
.96686 .37156 L
.96907 .35915 L
.97409 .32471 L
.97619 .30947 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<oooool3o`0002kooooo1Ol0000]ooooo`;o0000;_ooool5o`00033ooooo0ol0000Roooo
o`00=?ooool00ol0003oooooooooo`0^ooooo`04o`000?ooooooooooo`0002cooooo00Co0000oooo
oooooooo0000;_ooool01?l0003oooooooooool0000aooooo`03o`000?oooooooooo027ooooo000[
ooooo`Go000000?oooooo`000?l000000ol0000Xooooo`Go00000oooool00ol0003oooooooooo`0/
ooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool0;_ooool5o`0002;ooooo000a
ooooo`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool0:oooool01?l0003ooooooooo
ool0000`ooooo`03o`000?oooooooooo02gooooo00Co0000oooooooooooo00008oooool003;ooooo
00?o0000ooooool00000;oooool01Ol0003ooooooooooooooooo000002cooooo00Co0000oooooooo
oooo0000;Oooool01Ol0003ooooooooooooooooo000002oooooo00?o0000ooooool000008oooool0
03?ooooo0_l0000_ooooo`05o`000?ooooooooooooooool00000;?ooool01?l0003oooooooooool0
000]ooooo`05o`000?ooooooooooooooool00000<?ooool2o`0002?ooooo000dooooo`03o`000?oo
oooooooo02kooooo0ol0000^ooooo`;o0000;oooool3o`0003;ooooo00?o0000ooooooooool08Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0017oooooool0
000=o`0000?ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00Oooool0
017ooooo0_l0000Nooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool07?ooool2o`00
00?ooooo000Aooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0P_ooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo00?ooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo05?ooooo
00?o0000ooooooooool00Oooool000Wooooo0ol00005ooooo`03o`000?oooooooooo06cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool05_ooool00ol00?ooooooooooo`1Cooooo`03o`000?oooooooooo007ooooo0008
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1Dooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Cooooo00?o0000ooooooooool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo01Kooooo00?o003oooooooooool0Doooool00ol0003oooooooooo`01ooooo`000_ooool5
o`0000Gooooo00?o0000ooooooooool00_ooool3o`0005Cooooo00?o003oooooooooool05Oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool07_ooool0
0ol00?ooooooooooo`1Aooooo`?o00000oooool000[ooooo0_l00005ooooo`03o`000?oooooooooo
05?ooooo0_l00?lGooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0Doooool00ol0
003oooooooooo`01ooooo`003?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05?o
oooo0_l00?lGooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0Doooool00ol0003o
ooooooooo`01ooooo`002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool0K?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo05?ooooo00?o0000oooooooo
ool00Oooool000Wooooo0ol00005ooooo`03o`000?oooooooooo05?ooooo0_l00?lGooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo01Kooooo00?o003oooooooooool0Doooool00ol0003oooooooooo`01ooooo`004Ooo
ool2o`0005Cooooo0_l00?lGooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`1cooooo`;o00000oooool0017ooooo00?o0000ooooooooool0Doooool2
o`00oaOooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`1Dooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo05?ooooo0_l00?lGooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`;o003o5oooool2o`00
oeGooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0K?ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool2o`00oaOo
oooo0_l00?mEooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06cooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo
0_l00?lHooooo`03o`00oooooooooooo05?ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0
001Dooooo`;o003o5oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`00oooooooooooo01kooooo00?o
003oooooooooool0D_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo05?ooooo0_l00?lG
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0M
ooooo`03o`00oooooooooooo05Cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool0Doooool2o`00oaOooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Gooooo0_l00?lGooooo`;o003oEOooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`1/ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`05ooooo`;o003o5oooool2o`00oeGooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool0K?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01?ooool2o`00oaOooooo0_l00?mEooooo`03o`00
0?oooooooooo007ooooo000Aooooo`;o0000E?ooool2o`00oaOooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool02_oo
ool2o`00o`Oooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo04?ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1Cooooo`;o003o5oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`00oooooooooooo00Cooooo0_l00?lOooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool0A?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`1Booooo`03o`00oooooooo003o01Oooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo0_l00?lGooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool0A?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`1Dooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Gooooo0_l00?lGooooo`;o003o3oooool00ol00?oo
ooooooooo`13ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06_ooooo
0_l00?l7ooooo`03o`00oooooooooooo00Cooooo0_l00?l6ooooo`03o`000?oooooooooo00?ooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`;o003o5oooool2o`00o`oooooo
00?o003oooooooooool0@oooool00ol0003oooooooooo`01ooooo`004Oooool2o`0005?ooooo00?o
003oooooool00?l05oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01?ooool2o`00oaSooooo00?o003oooooooooool02oooool00ol00?ooooooo`00
o`14ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0D_ooool00ol00?ooooooo`00o`0G
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool01?ooool2o`00oaoooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`15ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo05;ooooo00?o003oooooool00?l05_ooool2o`00o`Oooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l00?l6oooo
o`;o003o1_ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ool00?l0AOooool00ol0003oooooooooo`01ooooo`002?ooool5o`0000Cooooo00?o0000oooooooo
ool0D_ooool00ol00?ooooooo`00o`0Fooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l00?l6ooooo`03
o`00oooooooooooo00Gooooo0_l00?lGooooo`;o003oEOooool00ol0003oooooooooo`01ooooo`00
2Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo06_ooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`04ooooo`;o003o1_ooool00ol0003oooooooooo`02ooooo`;o
003o1oooool00ol00?ooooooooooo`04ooooo`;o003o5oooool2o`00oaOooooo00?o003ooooooooo
ool0>oooool00ol0003oooooooooo`01ooooo`000_ooool5o`0000?ooooo00?o0000ooooooooool0
1?ooool3o`0005;ooooo00?o003oooooooooool05_ooool2o`00o`Oooooo00?o003oooooooooool0
1?ooool2o`00o`Kooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00Cooooo0_l00?lHooooo`03o`00oooooooooooo00_ooooo00?o003oooooool00?l0
1_ooool2o`00oc_ooooo0ol00003ooooo`002oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo05;ooooo00?o003oooooool00?l05oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`0:ooooo`;o003o8?oo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo003o00Kooooo0_l00?lmooooo`03o`000?oo
oooooooo007ooooo0008ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`1Aooooo`04o`00ooooooooooooo`00oaKooooo0_l00?l6ooooo`;o003o1_ooool2o`00o`Kooooo
00?o0000ooooooooool00_ooool2o`00o`Kooooo0_l00?lOooooo`03o`00oooooooooooo00_ooooo
00Co003ooooooooooooo003o1_ooool2o`00ocgooooo00?o0000ooooooooool00Oooool000Sooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo057ooooo00Co003ooooooooo
oooo003o5_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`;o003o1_ooool00ol00?ooooooooooo`05oooo
o`;o003o5oooool2o`00o`cooooo00Co003ooooooooooooo003o1_ooool00ol00?ooooooooooo`0l
ooooo`03o`000?oooooooooo007ooooo0009ooooo`?o00001Oooool00ol0003oooooooooo`1[oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01?ooool2o`00o`Kooooo00?o0000oooo
ooooool00_ooool2o`00o`Kooooo00?o003oooooooooool01Oooool2o`00oaOooooo0_l00?lGoooo
o`03o`00oooooooooooo03_ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001/ooooo`;o
003o1_ooool2o`00o`Kooooo0_l00?l6ooooo`03o`000?oooooooooo00;ooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`04ooooo`;o003o6?ooool00ol00?ooooooooooo`0:ooooo`04
o`00ooooooooooooo`00o`Oooooo00?o003oooooooooool0>_ooool2o`0000?ooooo000Aooooo`03
o`000?oooooooooo057ooooo00Co003ooooooooooooo003o5oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`0:oooo
o`;o003o1oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00[ooooo00Co003ooooo
oooooooo003o1Oooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo03?ooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0DOooool01?l00?ooooooooooool00?lG
ooooo`03o`00oooooooooooo00Cooooo0_l00?l6ooooo`03o`00oooooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol00?ooooooooooo`04ooooo`;o003o7oooool00ol00?ooooooooooo`0;
ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01_ooool00ol00?oooooooooo
o`0dooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo057ooooo00Co003o
oooooooooooo003o5Oooool00ol00?ooooooo`00o`06ooooo`;o003o1oooool00ol00?oooooooooo
o`04ooooo`07o`000?ooooooooooooooool00?ooooooo`00o`06ooooo`03o`00oooooooooooo00Go
oooo0_l00?lGooooo`03o`00oooooooooooo00_ooooo00Co003ooooooooooooo003o1Oooool00ol0
0?ooooooooooo`06ooooo`;o003o=Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`1Dooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00Oo0000ooooooooooooooooo`00oooooooo
003o00Kooooo00?o003oooooooooool01Oooool2o`00oaOooooo0_l00?lNooooo`;o003o=Oooool0
0ol0003oooooooooo`01ooooo`004Oooool2o`0006_ooooo00?o003oooooool00?l01_ooool2o`00
o`Kooooo0_l00?l6ooooo`07o`000?ooooooooooooooool00?ooooooo`00o`07ooooo`03o`00oooo
oooooooo00Cooooo0_l00?lGooooo`;o003o5oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo03;ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1@ooooo`05o`00oooooooo
ooooooooool00?l05oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`00oooooooooooo00Cooooo0_l0
0?lHooooo`03o`00oooooooooooo00Wooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00
ooooooooooooo`00o`Kooooo00?o003oooooooooool01_ooool2o`00obcooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool0D?ooool01Ol00?oooooooooooooooooo003o01Oo
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o01oo
oooo00?o003oooooooooool02_ooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooo
oooooooo003o1_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02[ooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0D?ooool01Ol00?oooooooooooooooooo
003o01Gooooo00?o003oooooool00?l01_ooool2o`00o`Oooooo00?o003oooooooooool01?ooool0
1ol0003ooooooooooooooooo003oooooool00?l01Oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo01Kooooo00?o003oooooooooool02_ooool01Ol00?oooooooooooooooooo003o00Co
oooo00?o003oooooooooool01_ooool01?l00?ooooooooooool00?ldooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo053ooooo00Go003oooooooooooooooooo`00o`0Eoooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`07o`000?ooooooooooooooool00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Kooooo0_l0
0?lGooooo`;o003o5?ooool00ol00?ooooooooooo`06ooooo`04o`00ooooooooooooo`00o`Gooooo
00?o003oooooool00?l0;?ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0006[ooooo00Co
003ooooooooooooo003o1oooool00ol00?ooooooooooo`04ooooo`;o003o1_ooool01?l0003ooooo
ooooool00?l2ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool2o`00oaOo
oooo0_l00?lGooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00oooool00ol00?oo
ooooo`00o`0[ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0D?ooool00ol00?oooooo
ooooo`0Iooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool2o`00o`Kooooo
00Co0000oooooooooooo003o2_ooool00ol00?ooooooooooo`04ooooo`;o003o6?ooool00ol00?oo
ooooooooo`09ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l8
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01oooool00ol00?ooooooooooo`0R
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo053ooooo00Go003ooooo
ooooooooooooo`00o`0Gooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o003oooooool00?l05?ooool2
o`00o`[ooooo00?o003oooooooooool02Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co
003ooooooooooooo003o1Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo003o00Oooooo
00?o003oooooooooool08_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`1@ooooo`05o`00ooooooooooooooooool00?l05?ooool01?l00?ooooooooooool00?l6ooooo`;o
003o1_ooool2o`00o`Kooooo00Co0000oooooooooooo003o0_ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooo003o01?ooooo00Co003ooooooooooooo003o2?ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00?ooooo00Co003ooooooooooooo003o3_ooool2o`00obCooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool0Coooool2o`00o`?ooooo00?o003oooooooooool04_oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?oo
ool01?l0003oooooooooool00?l2ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
1_ooool2o`00o`_ooooo00Co003ooooooooooooo003o2?ooool2o`00o`oooooo00Go003ooooooooo
ooooooooo`00o`08ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo02?ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001Zoooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool2o`00o`Kooooo00Co0000oooo
oooooooo003o0_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Kooooo0_l00?l;
ooooo`03o`00oooooooooooo00Wooooo0_l00?lGooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool00oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool06Oooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo06Wooooo00Co003ooooo
oooooooo003o1Oooool00ol00?ooooooo`00o`06ooooo`;o003o1_ooool01?l0003oooooooooool0
0?l:ooooo`03o`00oooooooooooo00Cooooo0_l00?lHooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Kooooo0_l00?l7ooooo`;o
003o6oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1?ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`00
oooooooo003o00Oooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool01_ooool01?l00?ooooooooooool00?l7ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool06Oooool00ol0003oooooooooo`01ooooo`002Oooool3o`0000Go
oooo00?o0000ooooooooool0Coooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;o
oooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo
00Gooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o
01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo003o00Kooooo00?o003o
ooooooooool06oooool00ol0003oooooooooo`01ooooo`002_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo04oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Boooo
o`03o`00oooooooooooo00Kooooo00?o003oooooool00?l01oooool00ol00?ooooooooooo`04oooo
o`04o`000?ooooooooooo`00o`;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooo003o00[ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00Sooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooool00?l01_ooool00ol00?ooooooooooo`0Kooooo`03o`000?oooooooooo007ooooo
0002ooooo`Go00000oooool00ol0003oooooooooo`04ooooo`?o0000E?ooool00ol00?oooooooooo
o`0Aooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`04o`000?ooooooooooo`00o`;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooo003o00[ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`05ooooo`;o003o7?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooo
oooo003o1Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo003o00Kooooo00?o003ooooo
ooooool04?ooool3o`0000?ooooo000:ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0J?ooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooool00?l01_ooool2o`00
o`Kooooo00?o0000ooooool00?l00oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooool00?l05oooool2o`00o`Wooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1Oooool0
1?l00?ooooooooooool00?l7ooooo`03o`00oooooooooooo00Cooooo0_l00?lCooooo`03o`000?oo
oooooooo007ooooo000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0C_ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o0000ooooooooool02oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooo003o01Oooooo0_l00?l9ooooo`03o`00oooooooo
oooo00?ooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00Wooooo
00Co003ooooooooooooo003o2?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Co
oooo0_l00?lCooooo`03o`000?oooooooooo007ooooo0009ooooo`;o00001_ooool00ol0003ooooo
ooooo`1>ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00_ooool3o`00oa3ooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo
00?o0000ooooooooool00oooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00oa7o
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l4ooooo`05o`00oooooooooooo
ooooool00?l03?ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01?l00?ooooooooooool00?l7ooooo`03o`00oooooooooooo017ooooo00?o0000ooooooooool0
0Oooool000[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1>ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`0<ooooo`05o`00oooo
ooooooooooooool00?l01Oooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00Cooooo
00?o0000ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`So
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0:ooooo`05o`00oooooooooooooooo
ool00?l01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool02Oooool00ol0003oooooooooo`01ooooo`004Oooool2o`0004oooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00cooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Kooooo00?o003oooooool0
0?l02Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool06Oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooooooo003o1Oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooo003o00Wooooo0_l00003ooooo`004Oooool00ol0
003oooooooooo`1Iooooo`03o`00oooooooo003o00cooooo00Go003oooooooooooooooooo`00o`07
ooooo`03o`00oooooooooooo00Cooooo0_l00?l6ooooo`03o`000?oooooo003o00?ooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00oooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00Kooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01_oo
ool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l0
2_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1>ooooo`03o`00oooo
oooooooo01_ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`07ooooo`;o003o1_oo
ool00ol0003oooooo`00o`0;ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l05ooo
ool2o`00o`Wooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l4ooooo`05o`00
ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ool00?l01_ooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo00Oooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`03ooooo`05
o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo
00Sooooo00Co003ooooooooooooo003o4?ooool2o`00o`Gooooo00?o003oooooooooool01Oooool2
o`00o`Wooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l4ooooo`05o`00oooo
ooooooooooooool00?l03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00;ooooo
00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00[o
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01_ooool2o`00odKooooo
00?o003oooooooooool00oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooo
oooo003o1_ooool2o`00o`Kooooo00?o0000o`00ooooool00oooool00ol00?ooooooooooo`02oooo
o`04o`00ooooooooooooo`00oa3ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`05
ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`0:ooooo`05o`00oooo
ooooooooooooool00?l01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool02?ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000Oooooo0_l0
0?l7ooooo`;o003o?Oooool00ol00?ooooooooooo`03ooooo`05o`00ooooooooooooooooool00?l0
0_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`04ooooo`03o`000?l00?oooooo00?ooooo00Go003ooooooooooooo
ooooo`00o`09ooooo`03o`00oooooooo003o00Sooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`05ooooo`;o003o3oooool00ol00?ooooooo`00o`08ooooo`03o`00oooooooooooo00?o
oooo00Co003ooooooooooooo003o2Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01oooool00ol00?ooooooo`00o`09ooooo`;o00000oooool0017o
oooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`;o003oAoooool01?l00?oo
ooooooooool00?l;ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool00oooool00ol0
0?ooooooo`00o`06ooooo`03o`000?l00?oooooo00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l02?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`06
ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`08ooooo`05o`00
ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`06ooooo`04o`00ooooooooooooo`00
o`[ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool04?ooool00ol00?oo
ooooooooo`0jooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01_ooool00ol0
003o003oooooo`0;ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l05oooool2o`00
o`Sooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo
00Kooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00Co
003ooooooooooooo003o2_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`08ooooo`03o`00oooooooooooo04;ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0Eooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03?ooool2o`00o`Sooooo00?o003oooooooooool0
1?ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Sooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool02oooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`05ooooo`04o`00ooooooooooooo`00o`Go
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Co
oooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo
oooo00Kooooo00?o0000ooooooooool00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Kooooo00?o
003oooooool00?l04Oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
3?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool0
0Oooool0017ooooo0_l00006ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l0
1oooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Cooooo00Co003ooooooooooooo
003o0oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`04ooooo`03o`000?l00?oooooo00?ooooo00Go003ooooooooo
ooooooooo`00o`08ooooo`04o`00ooooooooooooo`00o`Oooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool0
0ol00?ooooooo`00o`08ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o2?oo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l05?ooool00ol00?oooooo
ooooo`07ooooo`;o00000oooool0017ooooo00?o0000ooooooooool01Oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooo003o00Oooooo00?o003oooooooooool0>Oooool01?l00?oooooooooo
ool00?l3ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o0000o`00ooooool00oooool01Ol00?oooooo
oooooooooooo003o00Sooooo00Co003ooooooooooooo003o1oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool07_ooool01?l00?ooooooooooool00?l4
ooooo`05o`00ooooooooooooooooool00?l02?ooool01Ol00?oooooooooooooooooo003o00Cooooo
00?o003oooooooooool01_ooool01?l00?ooooooooooool00?l:ooooo`03o`000?oooooooooo007o
oooo000Aooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`06ooooo`;o003oA?ooool00ol00?ooooooooooo`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Kooooo00?o0000o`00oooo
ool00oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooo
oooo003o6?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l01?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`04ooooo`04o`00ooooooooooooo`00o`[ooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool02?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo003o00Kooooo0_l0
0?l[ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05Oooool01Ol00?oooooooooo
oooooooo003o00Wooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`07ooooo`05o`00
ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?lFooooo`03o`00oooooooo003o
00Oooooo00?o003oooooooooool01Oooool2o`00o`Oooooo0_l00?l8ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00kooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool01Oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`0Zooooo`03o`00oooo
oooooooo00Cooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0>ooooo`05o`00
ooooooooooooooooool00?l02Oooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool01Oooool2o`00o`Oooooo0_l00?l>ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003o
ooooooooool00_l00?l3ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool04?ooool0
0ol0003oooooooooo`01ooooo`004Oooool2o`0000Kooooo00Co003ooooooooooooo003o1Oooool0
0ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Oooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o0ooo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`03ooooo`04o`00ooooooooooooo`00o`Wooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`05ooooo`;o003o2?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l=ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01oooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo00Co
oooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Sooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02Sooooo00?o003o
ooooool00?l01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00Co003o
oooooooooooo003o2Oooool01?l00?ooooooooooool00?l6ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00Cooooo
00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`08ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`08ooooo`05o`00ooooooooooooooooool00?l02_ooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00Ko
oooo00Co003ooooooooooooo003o3_ooool00ol00?ooooooo`00o`06ooooo`;o003o;?ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool0
0?l6ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`02ooooo`04o`00ooooooooooooo`00oa3ooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0Fooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l01_ooool00ol00?oooooo
o`00o`08ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo
007ooooo000:ooooo`;o00001Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o
00Kooooo0_l00?lRooooo`03o`00oooooooooooo01gooooo00Go003oooooooooooooooooo`00o`08
ooooo`04o`00ooooooooooooo`00o`Kooooo00?o0000ooooooooool02oooool00ol00?oooooooooo
o`02ooooo`04o`00ooooooooooooo`00oaKooooo00?o003oooooool00?l01oooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l01_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Gooooo00Go003oooooooooooooooooo`00o`04ooooo`05
o`00ooooooooooooooooool00?l03_ooool00ol0003oooooooooo`01ooooo`002Oooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00Go003oooooooooooooooooo`00o`04
ooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooooooo003o1Oooool00ol00?oooooooooo
o`0?ooooo`;o003o6Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo003o00Gooooo00?o
003oooooooooool03Oooool01Ol00?oooooooooooooooooo003o00Sooooo00?o003oooooooooool0
1oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l0
1oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
1Oooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool04?ooool00ol0003oooooooooo`01ooooo`002Oooool01?l0003oooooooooool00004ooooo`Oo
000000Go003oo`000?l0003o0000o`00o`04o`000004o`00ool0003o0000o`00o`Go000000Co003o
o`000?l0003o003o1Ol000000ol00?oo0000o`00000?o`0000;o003o6Ol000000ol00?oo0000o`00
0005o`000003o`00ool0003o003o00Go000000?o003oo`000?l000001_l000000ol00?oo0000o`00
0004o`000005o`00ool0003o0000o`000?l00?l00ol000000ol00?oo0000o`000002o`000004o`00
ool0003o0000o`00o`Ko000000?o003oo`000?l000000ol000001?l00?oo0000o`000?l00?l4o`00
0003o`00ool0003o000000co000000?o003oo`000?l000001ol000000ol00?oo0000o`000002o`00
0003o`00ool0003o000000So000000?o003oo`000?l000005_l000000ol00?oo0000o`000007o`00
0003o`00ool0003o000000Co000000Co003oo`000?l0003o003o3Ol000000ol00?oo0000o`000005
o`000005o`00ool0003o0000o`000?l00?l01ol00003ooooo`002Oooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool00_ooool01?l00?oooooooooo
ool00?l8ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooo
o`00o`0Qooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l01Oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o2Oooool01?l00?oo
ooooooooool00?l6ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0Nooooo`;o003o2?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l01_ooool00ol0003oooooooooo`01ooooo`002Oooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00gooooo00Co003ooooooooooooo003o3Oooool01?l00?oooooooooo
ool00?l6ooooo`03o`00oooooooo003o00Kooooo0_l00?l7ooooo`;o003o6_ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`02ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oo`000?ooool01?ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1_ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool07oooool00ol0
0?ooooooooooo`05ooooo`;o003o2?ooool00ol00?ooooooooooo`03ooooo`04o`00oooooooooooo
o`00o`Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooo
oooo007ooooo0009ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool04?ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooooooo003o1Ooo
ool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Oooooo00?o003oooooooooool0
3_ooool00ol00?ooooooooooo`0Nooooo`04o`00ooooooooooooo`00o`Cooooo00?o003ooooooooo
ool00_ooool01?l00?ooooooooooool00?l5ooooo`03o`00ool0003ooooo00cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo00Co003ooooooooooooo003o1_oo
ool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_oo
ool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool0
2?ooool00ol0003oooooooooo`01ooooo`002_ooool2o`0000Gooooo00?o0000ooooooooool02?oo
ool00ol00?ooooooooooo`0:ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01_ooool2o`00oa3ooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Eooooo`04o`00ooooooooooooo`00o`Wo
oooo00?o003oooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00go
oooo00Co003ooooooooooooo003o1_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo
00Gooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`05ooooo`04o`00oooooooooooo
o`00o`Sooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooool2o`00
00Wooooo00Go003oooooooooooooooooo`00o`08ooooo`05o`00ooooooooooooooooool00?l01?oo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo003o00Oooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo0_l00?l6ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool01?ooool01?l00?ooooooooooool00?l4ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool01_ooool00ol00?oo0000ooooo`04ooooo`04o`00
ooooooooooooo`00o`Cooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Xooooo`03
o`00oooooooo003o00kooooo00?o003oooooooooool01Oooool01Ol00?oooooooooooooooooo003o
00Gooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`08ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01oooool0
0ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00oaOooooo0_l00?l7ooooo`03o`00oooo
oooooooo00Kooooo0_l00?l6ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00?ooooo00?o003oo`000?ooool01?oo
ool00ol00?ooooooo`00o`09ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0<_ooool2o`00o`Wooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l01_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0<ooooo`05o`00
ooooooooooooooooool00?l04?ooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00
o`kooooo00?o003oooooooooool01_ooool2o`00oa3ooooo0_l00?l6ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00?ooooo00?o003oo`000?ooool01?ooool00ol00?ooooooo`00o`09ooooo`05o`00oooooooooooo
ooooool00?l01Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool0<?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo003o00Sooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`06oooo
o`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00
o`06ooooo`03o`00oooooooo003o00Kooooo0_l00?lPooooo`03o`00oooooooooooo00Gooooo00Co
003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00oooool00ol00?oo0000ooooo`04ooooo`03o`00oooooooooooo00Gooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo01;ooooo00Go003oooooooooooooooooo`00o`06
ooooo`03o`00oooooooooooo02Wooooo00?o003oooooooooool01Oooool2o`00o`Kooooo00?o003o
ooooool00?l01Oooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo00Sooooo00?o003oooooooooool02_ooool01Ol00?oooooooooooooooooo
003o00Cooooo00Co003ooooooooooooo003o1Oooool01?l00?ooooooooooool00?l5ooooo`03o`00
oooooooo003o00Kooooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool05Oooool01?l00?ooooooooooool00?l8ooooo`03
o`00oooooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0<ooooo`05
o`00ooooooooooooooooool00?l01_ooool00ol00?ooooooooooo`0aooooo`;o003o1_ooool00ol0
0?ooooooo`00o`08ooooo`03o`00oooooooooooo00Gooooo00?o0000ooooooooool00Oooool0017o
oooo0_l00009ooooo`04o`00ooooooooooooo`00o`Wooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l03Oooool01?l00?ooooooooooool00?l8ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`;o003o
1_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo
003o2?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o003oooooool0
0?l01Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00Go003ooooooooo
ooooooooo`00o`09ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo0_l00003ooooo`004Oooool00ol0003o
ooooooooo`08ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o1?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06?ooool0
0ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00Oooooo0_l00?l6ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01Oooool01?l00?ooooooooooool00?l4ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool00_ooool00ol00?ooooooo`000005ooooo`03o`00oooo
oooo003o00Wooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`09ooooo`05o`00oooo
ooooooooooooool00?l02Oooool00ol00?ooooooooooo`0cooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool01Oooool2o`00o`03ooooool00?oooooo00Kooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool02?ooool01?l00?ooooooooooool00?l5ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool02_ooool01Ol00?oooooooooooooooooo003o00go
oooo00?o003oooooooooool01_ooool00ol00?ooooooo`00o`0@ooooo`;o003o1_ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooo000000Gooooo00?o003oooooool00?l02Oooool01Ol00?oo
oooooooooooooooo003o00Cooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo03Sooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Oooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool02oooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`Sooooo00?o003ooooo
ooooool01_ooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1Ooo
ool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o01Sooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo003o00Gooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool000001Oooool00ol00?oo
ooooooooo`05ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0>_ooool00ol0
0?ooooooo`00o`06ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`06ooooo`04o`00ooooooooooooo`00
o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo
003o1Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01oooooo00?o003oooooool0
0?l02Oooool01Ol00?oooooooooooooooooo003o00Kooooo00?o0000ooooooooool02oooool01?l0
0?ooooooooooool00?l4ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo03[ooooo0_l00?l8ooooo`03o`00oooooooo
oooo00Kooooo00?o0000ooooooooool00Oooool0017ooooo0_l00009ooooo`04o`00oooooooooooo
o`00o`Sooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool02oooool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`ko
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00go
oooo00?o003oooooool00?l02Oooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Go
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wo
oooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
04Cooooo00?o003oooooooooool01Oooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo00So
oooo00Co003ooooooooooooo003o1Oooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
003o00Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
000000Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l9ooooo`03o`00oooo
oooooooo00Wooooo00Co003ooooooooooooo003o2_ooool00ol00?ooooooooooo`13ooooo`;o003o
2?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`08ooooo`03o`00oooo
oooo003o00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`0=ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooool00?l01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool00_ooool00ol00?ooooooo`000005ooooo`03o`00oooooooo003o00Sooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`19ooooo`;o003o2?ooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`07ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l@ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0>ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooooooooooooooo
o`00o`02ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool01Oooool01?l00?oooooo
ooooool00?l4ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`19ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool00Oooool0017ooooo
00?o0000ooooooooool04Oooool00ol00?ooooooo`00o`08ooooo`03o`00oooooooooooo00?ooooo
00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0Pooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1?oo
ool01Ol00?oooooooooooooooooo003o00;ooooo00?o0000ooooooooool02oooool01?l00?oooooo
ooooool00?l4ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool01oooool00ol0003o
ooooooooo`01ooooo`004Oooool2o`0000[ooooo0_l00?l8ooooo`03o`00oooooooooooo00?ooooo
00Co003ooooooooooooo003o1Oooool00ol00?ooooooooooo`05ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool05Oooool0
0ol00?ooooooo`00o`08ooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool01?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00Go003oooooooooooooooooo`00
o`0?ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`1=ooooo`;o00000oooool0017ooooo00?o0000ooooooooool02Oooool2o`00o`Sooooo00?o003o
ooooooooool00oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00Wooooo00Go
003oooooooooooooooooo`00o`08ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo
003o1Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooo
oooo003o1?ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o0000ooooooooool00oooool2
o`00o`Kooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
003o00[ooooo00?o003oooooooooool0C_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`09ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`06ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool04oooool0
1?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01Ooo
ool01Ol00?oooooooooooooooooo003o00;ooooo00?o0000ooooooooool00oooool2o`00o`Wooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00cooooo0ol00?mKooooo`03
o`000?oooooooooo007ooooo0009ooooo`?o00001Oooool00ol0003oooooooooo`0Aooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oo
oooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o0000
ooooooooool00oooool2o`00o`Wooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Cooooo`03o`000?oo
oooooooo007ooooo000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Oooool2
o`00o`Wooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
1oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0
1oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooooooo
ooooooooo`00o`02ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool01Oooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`1>ooooo`03o`000?oooooooooo007ooooo000:ooooo`03o`000?oooooooooo00Co
oooo0ol0000Booooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01_ooool00ol00?oo
ooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`04
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo01Gooooo00?o003oooooool00?l02?ooool00ol00?ooooooooooo`09
ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05
ooooo`05o`00ooooooooooooooooool00?l05?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo04cooooo0ol00003ooooo`002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01;ooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooo003o00Sooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`03ooooo`;o003o1_oo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0Cooo
ool00ol0003oooooooooo`01ooooo`002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01Wooooo00?o003oooooooooool01_ooool00ol00?ooooooo`00o`0Jooooo`05o`00oooooooo
ooooooooool00?l01?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Kooooo00Go
003oooooooooooooooooo`00o`0:ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool0
1Oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o0000ooooooooool00oooool2o`00o`So
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo04oo
oooo00?o0000ooooooooool00Oooool000Wooooo0_l00006ooooo`03o`000?oooooooooo01Wooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool01_ooool01Ol00?oooooooooooooooooo003o013ooooo00?o003ooooooooo
ool01_ooool01Ol00?oooooooooooooooooo003o01;ooooo00?o003oooooooooool01Oooool01Ol0
0?oooooooooooooooooo003o00;ooooo00?o0000ooooooooool00oooool2o`00o`Sooooo00?o003o
ooooooooool00oooool01?l00?ooooooooooool00?lEooooo`03o`00oooooooooooo05?ooooo00?o
0000ooooooooool00Oooool000[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0K
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00oooool01?l00?ooooooooooool0
0?l4ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo01Oooooo00Go003oooooooooooooooooo`00o`0:ooooo`03o`00oooooooo003o00Go
oooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l3ooooo`03o`000?oooooooooo
00?ooooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo
01Kooooo00Go003oooooooooooooooooo`00o`1Aooooo`03o`000?oooooooooo007ooooo000Aoooo
o`;o00006oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo003o00Gooooo00Co003ooooo
oooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooooooo
o`00o`08ooooo`03o`00oooooooooooo027ooooo00?o003oooooool00?l01oooool00ol00?oooooo
ooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o003oooooool00?l01Oooool00ol00?oooooo
ooooo`0Fooooo`05o`00ooooooooooooooooool00?l0D?ooool2o`0000?ooooo000Aooooo`03o`00
0?oooooooooo01[ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool01_ooool01Ol00?oooooooooooooooooo003o00So
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`06ooooo`04o`00ooooooooooooo`00
o`_ooooo0_l00?l8ooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04oooool01Ol0
0?oooooooooooooooooo003o057ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool08_ooool2o`00o`kooooo00?o003oooooooooool01_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Kooooo00Co003ooooooooooooo003o2oooool2o`00o`Kooooo00?o003oooooooooool01Ooo
ool01?l00?ooooooooooool00?l3ooooo`03o`000?oooooooooo00?ooooo0_l00?l6ooooo`03o`00
oooooooo003o00Sooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`1?ooooo`03o`00
0?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo02;ooooo0_l00?l6ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool01oooool01Ol00?oooooooooooooooooo003o013ooooo
00?o003oooooooooool01_ooool2o`00o`03ooooool00?oooooo01;ooooo00?o003oooooooooool0
1Oooool01?l00?ooooooooooool00?l3ooooo`03o`000?oooooooooo00?ooooo0_l00?l8ooooo`03
o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o5Oooool00ol00?ooooooooooo`1Coooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo02?ooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Gooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Oooooo0_l00?lDooooo`03
o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o0oooool00ol0003oooooooooo`03oooo
o`03o`00oooooooooooo00Gooooo0_l00?l6ooooo`03o`00oooooooooooo01Kooooo00?o003ooooo
ooooool0Doooool00ol0003oooooooooo`01ooooo`004Oooool2o`0002Cooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Gooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`0Qooooo`;o003o1_ooool00ol00?ooooooo`00o`05ooooo`04
o`00ooooooooooooo`00o`?ooooo00?o0000ooooooooool02oooool2o`00o`Kooooo00?o003ooooo
ooooool05_ooool01?l00?ooooooooooool00?mAooooo`;o00000oooool0017ooooo00?o0000oooo
ooooool0:_ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Gooooo00Co003ooooo
oooooooo003o2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01Gooooo0_l00?l8
ooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o5Oooool01?l00?oooooooooo
ool00?mBooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo02cooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`04o`00ooooooooooooo`00o`Cooooo
00Go003oooooooooooooooooo`00o`0<ooooo`03o`00oooooooooooo01Gooooo0_l00?l6ooooo`03
o`00oooooooo003o00Gooooo00?o003oooooool00?l01?ooool00ol0003oooooooooo`03ooooo`;o
003o1_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01Kooooo00?o003ooooooooo
ool0D?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0[ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l03?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Go
oooo00?o003oooooool00?l01?ooool00ol0003oooooooooo`03ooooo`;o003o1oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooo003o06cooooo00?o0000ooooooooool00Oooool0017ooooo
00?o0000ooooooooool0:oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooo003o00Gooooo
00?o003oooooool00?l01?ooool00ol0003oooooooooo`03ooooo`;o003o1oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooo003o01Kooooo00?o003oooooooooool0Doooool00ol0003ooooo
ooooo`01ooooo`004Oooool2o`0002cooooo00?o003oooooooooool01Oooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooooooo00Gooooo00Go003oooooooooooooooooo`00o`0Tooooo`;o003o
1_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Cooooo00?o0000ooooooooool0
0oooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool00ol00?ooooooooooo`0Fooooo`04o`00
ooooooooooooo`00oe7ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`0cooooo`;o003o
1_ooool01?l00?ooooooooooool00?l8ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool05Oooool2o`00o`Sooooo00?o003oooooooooool02_ooool00ol0003oooooooooo`04ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`0Fooooo`04
o`00ooooooooooooo`00oe;ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0<oooool00ol00?ooooooooooo`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooo
ooooooooooooo`00o`0<ooooo`03o`00oooooooooooo01Gooooo0_l00?l7ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`03ooooo`;o003o1_ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0DOooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0mooooo`03o`00oooooooooooo
00?ooooo00Go003oooooooooooooooooo`00o`0<ooooo`03o`00oooooooooooo01Gooooo0_l00?l6
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l01?ooool00ol0003oooooooooo`03
ooooo`;o003o1oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Kooooo00?o003o
ooooooooool0DOooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0doooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Moooo
o`03o`00oooooooooooo00Gooooo00?o003oooooool00?l01?ooool00ol0003oooooooooo`03oooo
o`;o003o1oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o01Kooooo00?o003ooooo
ooooool0Doooool00ol0003oooooooooo`01ooooo`004Oooool2o`0003Cooooo0_l00?l6ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool09_ooool2o`00o`Kooooo0_l00?l6ooooo`03
o`00oooooooo003o00Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`05ooooo`;o
003o1_ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooo003o05;ooooo0_l00003ooooo`00
4Oooool00ol0003oooooooooo`0kooooo`03o`00oooooooo003o00Sooooo00?o003oooooooooool0
8oooool2o`00o`Oooooo00?o003oooooooooool02oooool00ol0003oooooooooo`0;ooooo`;o003o
1_ooool00ol00?ooooooo`00o`0Fooooo`03o`00oooooooo003o05?ooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool0>oooool00ol00?ooooooo`00o`08ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool05Oooool2o`00o`Oooooo00?o003oooooooooool02ooo
ool00ol0003oooooooooo`03ooooo`;o003o1_ooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo01Cooooo00?o003oooooool00?l0Doooool00ol0003oooooooooo`01ooooo`002?ooool5
o`0000Cooooo00?o0000ooooooooool0>oooool2o`00o`Kooooo00Co003ooooooooooooo003o3Ooo
ool00ol00?ooooooooooo`0Eooooo`;o003o1_ooool00ol00?ooooooooooo`05ooooo`;o003o1Ooo
ool00ol0003oooooooooo`03ooooo`;o003o1_ooool2o`00o`Oooooo00?o003oooooooooool05ooo
ool00ol00?ooooooooooo`1Aooooo`03o`000?oooooooooo007ooooo0009ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0??ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`05ooooo`;o003o1Ooo
ool00ol0003oooooooooo`03ooooo`;o003o1oooool00ol00?ooooooooooo`04ooooo`;o003o5ooo
ool00ol00?ooooooooooo`1Cooooo`03o`000?oooooooooo007ooooo000:ooooo`03o`000?oooooo
oooo00Cooooo0ol0000kooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool0
0ol00?ooooooooooo`0Mooooo`;o003o1_ooool2o`00o`Gooooo00?o0000ooooooooool00oooool0
0ol00?ooooooooooo`05ooooo`;o003o1_ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooo
003o057ooooo0ol00003ooooo`002oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
03_ooooo0_l00?l9ooooo`03o`00oooooooooooo02?ooooo0_l00?l6ooooo`;o003o1_ooool00ol0
0?ooooooooooo`04ooooo`03o`000?oooooooooo00_ooooo0_l00?l6ooooo`03o`00oooooooooooo
01Kooooo00?o003oooooool00?l0Doooool00ol0003oooooooooo`01ooooo`002?ooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool0>oooool2o`00o`Wooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`0Eooooo`;o003o1oooool00ol00?ooooooooooo`0;oooo
o`03o`000?oooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05oooo
o`;o003o5oooool2o`00oeCooooo00?o0000ooooooooool00Oooool000Sooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo04?ooooo00?o003oooooool00?l03_ooool00ol0
0?ooooooooooo`0Eooooo`;o003o1_ooool2o`00o`Kooooo0_l00?l5ooooo`03o`000?oooooooooo
00?ooooo0_l00?l6ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05_ooool00ol0
0?ooooooooooo`1Booooo`03o`000?oooooooooo007ooooo0009ooooo`?o00001Oooool00ol0003o
ooooooooo`13ooooo`03o`00oooooooo003o00kooooo00?o003oooooooooool07Oooool00ol00?oo
ooooooooo`05ooooo`;o003o1Oooool00ol0003oooooooooo`03ooooo`;o003o1_ooool00ol00?oo
ooooooooo`05ooooo`;o003oKOooool00ol0003oooooooooo`01ooooo`004Oooool2o`0004Cooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Mooooo`;o003o1_ooool2o`00o`Gooooo
00?o0000ooooooooool00oooool2o`00o`Kooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0Fooooo`03o`00oooooooooooo05;ooooo0_l00003ooooo`004Oooool00ol0003ooooooooo
o`13ooooo`03o`00oooooooo003o02Kooooo0_l00?l6ooooo`;o003o1_ooool2o`00o`Gooooo00?o
0000ooooooooool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Kooooo0_l0
0?mDooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04Gooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0Eooooo`;o003o1oooool00ol00?ooooooooooo`0;
ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05
ooooo`;o003o5oooool2o`00oeCooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool0A?ooool2o`00o`kooooo00?o003oooooooooool05Oooool2o`00o`Oooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l00?l6oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`1Boooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04Cooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`0Eooooo`;o003o1_ooool00ol00?ooooooooooo`05ooooo`;o
003o1Oooool00ol0003oooooooooo`03ooooo`;o003o1_ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo06cooooo00?o0000ooooooooool00Oooool0017ooooo0_l00015ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Cooooo00?o0000ooooooooool00oooool2o`00o`Kooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo05;ooooo0_l00003ooooo`004Ooo
ool00ol0003oooooooooo`14ooooo`03o`00oooooooooooo02Gooooo0_l00?l6ooooo`;o003o1_oo
ool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0Dooo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1/ooooo`;o003o1oooool0
0ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo05?ooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool0E?ooool00ol00?ooooooooooo`0Eooooo`;o003o1oooool00ol0
0?ooooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo0_l00?l6ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`1Cooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo05Cooooo00?o003oooooooooool05Oooool2o`00o`Ko
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo0_l00?l6ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool05_ooool00ol00?oo
ooooooooo`1Cooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000EOooool00ol00?oooooo
ooooo`0Mooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`;o003o1_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Kooooo
00?o003oooooooooool0D_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo05Cooooo00?o
003oooooooooool07Oooool2o`00o`Kooooo00?o003oooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`0Fooooo`03o`00oooooooooooo05?ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool0K?ooool2o`00o`Kooooo0_l00?l6ooooo`03o`00oooooooooooo00Cooooo00?o0000
ooooooooool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Kooooo00?o003o
ooooooooool0Doooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Doooo
o`03o`00oooooooooooo01Gooooo0_l00?l7ooooo`03o`00oooooooooooo00_ooooo00?o0000oooo
ooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool05_ooool00ol00?ooooooooooo`1Cooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo05Cooooo00?o003oooooooooool05Oooool2o`00o`Kooooo0_l00?l6ooooo`03
o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool2o`00o`Kooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo05?ooooo00?o0000oooooooo
ool00Oooool0017ooooo0_l0001Eooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0_l00?l6ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool0Joooool2o`0000?ooooo000Aooooo`03o`000?oo
oooooooo05Cooooo00?o003oooooooooool07Oooool2o`00o`Kooooo00?o003oooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`;o003o1_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo01Kooooo00?o003oooooooooool0Doooool00ol0003oooooooooo`01ooooo`004Oooool0
0ol0003oooooooooo`1/ooooo`;o003o1_ooool2o`00o`Kooooo00?o003oooooooooool01?ooool0
0ol0003oooooooooo`0;ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool05_ooool0
0ol00?ooooooooooo`1Cooooo`03o`000?oooooooooo007ooooo0009ooooo`?o00001Oooool00ol0
003oooooooooo`1Dooooo`03o`00oooooooooooo01Gooooo0_l00?l6ooooo`03o`00oooooooooooo
00cooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`1Cooooo`03o`000?oooooooooo
007ooooo0008ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1Doooo
o`03o`00oooooooooooo01Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool2o`00o`Kooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo05?ooooo00?o0000oooo
ooooool00Oooool000cooooo00?o0000ooooooooool00_ooool3o`0005Cooooo00?o003ooooooooo
ool05_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`;o003o1_ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo06[ooooo0ol00003ooooo`002_ooool2o`0000Gooooo00?o0000ooooooooool0
E?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo05?ooooo00?o0000ooooooooool0
0Oooool000cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1]ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo01Kooooo00?o003oooooooooool0Doooool00ol0003oooooooooo`01ooooo`002?ooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0KOooool00ol00?oooooooooo
o`0Cooooo`03o`000?oooooooooo01?ooooo00?o003oooooooooool05_ooool00ol00?oooooooooo
o`1Cooooo`03o`000?oooooooooo007ooooo0009ooooo`?o00001Oooool00ol0003oooooooooo`1]
ooooo`03o`00oooooooooooo01?ooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`01
ooooo`004Oooool2o`0008Cooooo00?o0000ooooooooool0POooool2o`0000?ooooo000Aooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00Oooool0017oooooool0000=o`0000?ooooo
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.95693, -3.79054, \
0.0394232, 0.0400035}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Magnitude plot of DFT as a function of frequency", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fft\  = \ DFT[xd];\)\), "\n", 
    \(\(g3 = 
        DiscreteListPlot[\({#[\([1]\)], \ Abs[#[\([2]\)]]} &\)\  /@ \ fft, 
          Red, \ PlotRange \[Rule] All, \ Frame \[Rule] True, \ 
          Axes \[Rule] False];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0328407 0.0147151 0.0140063 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18801 -0.0125 -3 -9 ]
[.18801 -0.0125 3 0 ]
[.35222 -0.0125 -6 -9 ]
[.35222 -0.0125 6 0 ]
[.51642 -0.0125 -6 -9 ]
[.51642 -0.0125 6 0 ]
[.68062 -0.0125 -6 -9 ]
[.68062 -0.0125 6 0 ]
[.84483 -0.0125 -6 -9 ]
[.84483 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15478 -12 -4.5 ]
[-0.0125 .15478 0 4.5 ]
[-0.0125 .29484 -12 -4.5 ]
[-0.0125 .29484 0 4.5 ]
[-0.0125 .4349 -12 -4.5 ]
[-0.0125 .4349 0 4.5 ]
[-0.0125 .57497 -12 -4.5 ]
[-0.0125 .57497 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18801 0 m
.18801 .00625 L
s
[(5)] .18801 -0.0125 0 1 Mshowa
.35222 0 m
.35222 .00625 L
s
[(10)] .35222 -0.0125 0 1 Mshowa
.51642 0 m
.51642 .00625 L
s
[(15)] .51642 -0.0125 0 1 Mshowa
.68062 0 m
.68062 .00625 L
s
[(20)] .68062 -0.0125 0 1 Mshowa
.84483 0 m
.84483 .00625 L
s
[(25)] .84483 -0.0125 0 1 Mshowa
.125 Mabswid
.05665 0 m
.05665 .00375 L
s
.08949 0 m
.08949 .00375 L
s
.12233 0 m
.12233 .00375 L
s
.15517 0 m
.15517 .00375 L
s
.22085 0 m
.22085 .00375 L
s
.25369 0 m
.25369 .00375 L
s
.28654 0 m
.28654 .00375 L
s
.31938 0 m
.31938 .00375 L
s
.38506 0 m
.38506 .00375 L
s
.4179 0 m
.4179 .00375 L
s
.45074 0 m
.45074 .00375 L
s
.48358 0 m
.48358 .00375 L
s
.54926 0 m
.54926 .00375 L
s
.5821 0 m
.5821 .00375 L
s
.61494 0 m
.61494 .00375 L
s
.64778 0 m
.64778 .00375 L
s
.71346 0 m
.71346 .00375 L
s
.74631 0 m
.74631 .00375 L
s
.77915 0 m
.77915 .00375 L
s
.81199 0 m
.81199 .00375 L
s
.87767 0 m
.87767 .00375 L
s
.91051 0 m
.91051 .00375 L
s
.94335 0 m
.94335 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15478 m
.00625 .15478 L
s
[(10)] -0.0125 .15478 1 0 Mshowa
0 .29484 m
.00625 .29484 L
s
[(20)] -0.0125 .29484 1 0 Mshowa
0 .4349 m
.00625 .4349 L
s
[(30)] -0.0125 .4349 1 0 Mshowa
0 .57497 m
.00625 .57497 L
s
[(40)] -0.0125 .57497 1 0 Mshowa
.125 Mabswid
0 .04273 m
.00375 .04273 L
s
0 .07074 m
.00375 .07074 L
s
0 .09875 m
.00375 .09875 L
s
0 .12677 m
.00375 .12677 L
s
0 .18279 m
.00375 .18279 L
s
0 .2108 m
.00375 .2108 L
s
0 .23882 m
.00375 .23882 L
s
0 .26683 m
.00375 .26683 L
s
0 .32285 m
.00375 .32285 L
s
0 .35087 m
.00375 .35087 L
s
0 .37888 m
.00375 .37888 L
s
0 .40689 m
.00375 .40689 L
s
0 .46292 m
.00375 .46292 L
s
0 .49093 m
.00375 .49093 L
s
0 .51894 m
.00375 .51894 L
s
0 .54695 m
.00375 .54695 L
s
0 .60298 m
.00375 .60298 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18801 .61178 m
.18801 .61803 L
s
.35222 .61178 m
.35222 .61803 L
s
.51642 .61178 m
.51642 .61803 L
s
.68062 .61178 m
.68062 .61803 L
s
.84483 .61178 m
.84483 .61803 L
s
.125 Mabswid
.05665 .61428 m
.05665 .61803 L
s
.08949 .61428 m
.08949 .61803 L
s
.12233 .61428 m
.12233 .61803 L
s
.15517 .61428 m
.15517 .61803 L
s
.22085 .61428 m
.22085 .61803 L
s
.25369 .61428 m
.25369 .61803 L
s
.28654 .61428 m
.28654 .61803 L
s
.31938 .61428 m
.31938 .61803 L
s
.38506 .61428 m
.38506 .61803 L
s
.4179 .61428 m
.4179 .61803 L
s
.45074 .61428 m
.45074 .61803 L
s
.48358 .61428 m
.48358 .61803 L
s
.54926 .61428 m
.54926 .61803 L
s
.5821 .61428 m
.5821 .61803 L
s
.61494 .61428 m
.61494 .61803 L
s
.64778 .61428 m
.64778 .61803 L
s
.71346 .61428 m
.71346 .61803 L
s
.74631 .61428 m
.74631 .61803 L
s
.77915 .61428 m
.77915 .61803 L
s
.81199 .61428 m
.81199 .61803 L
s
.87767 .61428 m
.87767 .61803 L
s
.91051 .61428 m
.91051 .61803 L
s
.94335 .61428 m
.94335 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15478 m
1 .15478 L
s
.99375 .29484 m
1 .29484 L
s
.99375 .4349 m
1 .4349 L
s
.99375 .57497 m
1 .57497 L
s
.125 Mabswid
.99625 .04273 m
1 .04273 L
s
.99625 .07074 m
1 .07074 L
s
.99625 .09875 m
1 .09875 L
s
.99625 .12677 m
1 .12677 L
s
.99625 .18279 m
1 .18279 L
s
.99625 .2108 m
1 .2108 L
s
.99625 .23882 m
1 .23882 L
s
.99625 .26683 m
1 .26683 L
s
.99625 .32285 m
1 .32285 L
s
.99625 .35087 m
1 .35087 L
s
.99625 .37888 m
1 .37888 L
s
.99625 .40689 m
1 .40689 L
s
.99625 .46292 m
1 .46292 L
s
.99625 .49093 m
1 .49093 L
s
.99625 .51894 m
1 .51894 L
s
.99625 .54695 m
1 .54695 L
s
.99625 .60298 m
1 .60298 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .51894 L
s
.05665 .01472 m
.05665 .10775 L
s
.08949 .01472 m
.08949 .14469 L
s
.12233 .01472 m
.12233 .33083 L
s
.15517 .01472 m
.15517 .22338 L
s
.18801 .01472 m
.18801 .12178 L
s
.22085 .01472 m
.22085 .48788 L
s
.25369 .01472 m
.25369 .60332 L
s
.28654 .01472 m
.28654 .24202 L
s
.31938 .01472 m
.31938 .16817 L
s
.35222 .01472 m
.35222 .13644 L
s
.38506 .01472 m
.38506 .11927 L
s
.4179 .01472 m
.4179 .10911 L
s
.45074 .01472 m
.45074 .10304 L
s
.48358 .01472 m
.48358 .09978 L
s
.51642 .01472 m
.51642 .09875 L
s
.54926 .01472 m
.54926 .09978 L
s
.5821 .01472 m
.5821 .10304 L
s
.61494 .01472 m
.61494 .10911 L
s
.64778 .01472 m
.64778 .11927 L
s
.68062 .01472 m
.68062 .13644 L
s
.71346 .01472 m
.71346 .16817 L
s
.74631 .01472 m
.74631 .24202 L
s
.77915 .01472 m
.77915 .60332 L
s
.81199 .01472 m
.81199 .48788 L
s
.84483 .01472 m
.84483 .12178 L
s
.87767 .01472 m
.87767 .22338 L
s
.91051 .01472 m
.91051 .33083 L
s
.94335 .01472 m
.94335 .14469 L
s
.97619 .01472 m
.97619 .10775 L
s
.015 w
.02381 .51894 Mdot
.05665 .10775 Mdot
.08949 .14469 Mdot
.12233 .33083 Mdot
.15517 .22338 Mdot
.18801 .12178 Mdot
.22085 .48788 Mdot
.25369 .60332 Mdot
.28654 .24202 Mdot
.31938 .16817 Mdot
.35222 .13644 Mdot
.38506 .11927 Mdot
.4179 .10911 Mdot
.45074 .10304 Mdot
.48358 .09978 Mdot
.51642 .09875 Mdot
.54926 .09978 Mdot
.5821 .10304 Mdot
.61494 .10911 Mdot
.64778 .11927 Mdot
.68062 .13644 Mdot
.71346 .16817 Mdot
.74631 .24202 Mdot
.77915 .60332 Mdot
.81199 .48788 Mdot
.84483 .12178 Mdot
.87767 .22338 Mdot
.91051 .33083 Mdot
.94335 .14469 Mdot
.97619 .10775 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005oooool2o`0002Wooooo0ol0000Uooooo`?o00001?ooool2o`0002?ooooo0ol00003oooo
o`?o00008_ooool5o`0000?ooooo0_l0000Qooooo`Go00000_ooool3o`0002[ooooo000Fooooo`04
o`000?ooooooooooo`0002Oooooo00Go0000ooooooooooooooooo`00000Uooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00008oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool08?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
027ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo02Oooooo000F
ooooo`04o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02Oooooo000Fooooo`04o`000?ooooooooooo`0002_o
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
02?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Rooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool09oooool001Kooooo00Co0000oooooooooooo00009oooool4o`0002Kooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co0000
8_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0
003ooooooooooooooooo0000ooooo`Co0000:_ooool001Kooooo00Co0000oooooooooooo00009ooo
ool00ol0003oooooooooo`0Vooooo`;o00001?ooool01?l0003oooooooooool0000Rooooo`;o0000
0oooool00ol0003oooooooooo`0Sooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool0000Pooooo`07o`000?ooooooooooooooool0003oooooo`00000]ooooo`005oooool2
o`0002Sooooo1Ol0000Uooooo`03o`000?oooooooooo00?ooooo0_l0000Tooooo`04o`000?oooooo
ooooooooo`Go00008_ooool3o`0000Cooooo0_l0000Rooooo`?o00000_ooool5o`0002Wooooo003o
ooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Aoooooooo00003Ol0
0003ooooo`002_ooool2o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`01
ooooo`002Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3o
ooooo`Wooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool3
o`0000Cooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00;ooooo0ol00003ooooo`002Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00Cooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00Cooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`04ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooooooo`04ooooo`03o`000?oooooooooo007ooooo000:ooooo`;o00001Oooool00ol0
003oooooooooo`04ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo
003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo
003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo
003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo
003oooooooooo`04ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Co
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Go
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Go
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Go
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Co
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo007ooooo000A
ooooo`;o00001Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00
ooooooooool00oooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Cooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo00Cooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oo
oooooooo00Cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`05ooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool00Oooool0017ooooo
0_l00005ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`03ooooo`;o00000oooool0017ooooo00?o0000ooooooooool01?ooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05oooo
o`03ool00?oooooooooo00Cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool01?ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo
ool01?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03o`00
0?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Ooo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Ooo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool00Ooo
ool0017ooooo0_l00005ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Oooool3
ool000Kooooo0ooo0005ooooo`?oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`03ooooo`;o00000oooool0
017ooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`04ooooo`?oo`001_ooool3ool0
00Kooooo0ooo0005ooooo`?oo`001_ooool3ool000Oooooo00?oo`00ooooooooool01_ooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo
003oooooooooo`05ooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`04ooooo`?oo`001oooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`04ooooo`?oo`001_ooool3ool000Kooooo0ooo0006ooooo`?oo`001Oooool3ool000Ko
oooo0ooo0006ooooo`?oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Go
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`04ooooo`?oo`001Oooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo
0ooo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Cooooo0ooo0006ooooo`?oo`008?ooool3ool000Kooooo
0ooo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Cooooo0ooo0005ooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool3ool000Oooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01?ooool3ool003;ooooo0ooo0007ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Cooooo0ooo
0005ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?oo`00
ooooooooool03_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01Oooool3ool004?ooooo0ooo0007ooooo`03ool00?oooooooooo00Gooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01?ooool3ool000Oooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`05ooooo`?oo`00@oooool3ool000Oooooo00?oo`00oooo
ooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`04ooooo`?oo`001oooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo00kooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Cooooo0ooo0007ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool3ool004?ooooo0ooo0007ooooo`03
ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01?ooool3ool000Oooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00cooooo00?o0000oooooooo
ool00Oooool0017ooooo0_l00005ooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Cooooo0ooo0007ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool0EOooool00ooo003oooooooooo`05ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Cooooo0ooo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`0;ooooo`;o00000oooool0017ooooo00?o0000ooooooooool01?oo
ool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0EOoo
ool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00Gooooo0ooo001Dooooo`?oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool03_ooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool03_ooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo
003oooooooooo`05ooooo`?oo`00E?ooool3ool000Oooooo00?oo`00ooooooooool01_ooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool03_ooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool03?ooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo00go
oooo0ooo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool03_ooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003o
ooooooooo`05ooooo`?oo`00E?ooool3ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool03_ooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Cooooo0ooo000>ooooo`03o`000?oooooooooo007o
oooo0003ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool01?ooool00ooo003ooooo
ooooo`0=ooooo`?oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00kooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool0I_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool01?ooool3ool000kooooo00?o0000ooooooooool00Oooool000Cooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo
00?oo`00ooooooooool03Oooool3ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`0>ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo06Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool03_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Cooooo0ooo000>ooooo`03o`000?oooooooooo007ooooo
0004ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool3o`0000Cooooo
00?oo`00ooooooooool05oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00kooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool0I_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool04oooool3o`0000?ooooo0004ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo01Oooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo06Kooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool03_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01Gooooo
00?o0000ooooooooool00Oooool000Cooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool05oooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0I_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`0>ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool05Oooool00ol0003ooooo
ooooo`01ooooo`000oooool2o`0000Cooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`04ooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`0>ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`04ooooo`?oo`00I_ooool3ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`0Eooooo`03o`000?oooooooooo007ooooo0004ooooo`03o`000?oooooooooo00?ooooo0_l0
0005ooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool05oooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Cooooo0ooo001Vooooo`?oo`001oooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool03_ooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool01?ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool03_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01?ooool3ool006Kooooo0ooo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool05Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04oooo
o`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0>oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`1goooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0>oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo01Oooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool05Oooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000Gooooo00?oo`00ooooooooool0
5oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo07Oooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`0Dooooo`;o00000oooool0017ooooo00?o0000ooooooooool01?oo
ool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool03_oo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0Mooo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool03_oo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool0Moooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ooo
003oooooooooo`0Gooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool03_ooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0Moooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool03_ooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool0Moooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01Go
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ooo003ooooo
ooooo`0Gooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool03_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0Moooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool03_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool01?ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool03_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool0Moooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool03_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01Gooooo00?o
0000ooooooooool00Oooool0017ooooo0_l00005ooooo`03ool00?oooooooooo01Oooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool05?ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?oo`00oooo
ooooool05oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00kooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo07Oooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00kooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo00Cooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo07Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Eooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0
5oooool00ooo003oooooooooo`04ooooo`?oo`004?ooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool0Moooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool03Oooool3ool000Oooooo00?oo`00ooooooooool0
5Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03ool00?oo
oooooooo01Oooooo00?oo`00ooooooooool01?ooool3ool0013ooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo07Oooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00gooooo0ooo0007ooooo`03ool00?oo
oooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool0
0ooo003oooooooooo`0Gooooo`03ool00?oooooooooo00Cooooo0ooo000@ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`1gooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0=ooooo`?oo`001oooool0
0ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
00Cooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo
01Gooooo00?o0000ooooooooool00Oooool0017ooooo0_l00005ooooo`03ool00?oooooooooo01Oo
oooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool0Moooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Dooooo`;o00000oooool0017ooooo
00?o0000ooooooooool01?ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01Oooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`04ooooo`?oo`00N?ooool3ool000Oooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01Gooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ooo003ooooooooo
o`0Gooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`04ooooo`?oo`00N?ooool3ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`0Gooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool01?ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01Oooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`04ooooo`?oo`00N?ooool3ool000Oooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01Gooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`0Goooo
o`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`29oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Eoooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?oo`00oooooooo
ool05oooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool0ROooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01Oooooo00?oo`00oooooooo
ool05Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03ool0
0?oooooooooo01Oooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo08Wooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Gooooo`03ool0
0?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?oo
ool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`29ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool05ooo
ool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00001Oooool0
0ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`29ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool05oooool0
0ooo003oooooooooo`0Dooooo`;o00000oooool0017ooooo00?o0000ooooooooool01?ooool00ooo
003oooooooooo`0Gooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool01_ooool00ooo
003oooooooooo`29ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool05oooool00ooo
003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Co
oooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool0ROooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01Oo
oooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`04ooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool05oooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo08Wooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`0Gooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool01?ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01Oooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`29ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool05oooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo0002
ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`0G
ooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`29
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0E
ooooo`03o`000?oooooooooo007ooooo0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo01Oooooo00?o
o`00ooooooooool05oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo08Wooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01Gooooo00?o
0000ooooooooool00Oooool000Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0004ooooo`?o00001?ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01Oooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`29ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool05oooool00ooo003oooooooooo`0Cooooo`?o00000oooool000Gooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`29ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool05ooo
ool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo0002ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo
00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool0ROooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01Oooooo
00?oo`00ooooooooool05Oooool00ol0003oooooooooo`01ooooo`000_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03
ool00?oooooooooo01Oooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo08Wooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Gooooo`03
ool00?oooooooooo01Gooooo00?o0000ooooooooool00Oooool000?ooooo0ol00004ooooo`;o0000
1Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool0
5oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo08Wooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`0Gooooo`03ool00?oo
oooooooo01Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`29ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Eooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool05oooool0
0ooo003oooooooooo`0Gooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0ROooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool05Oooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo
01Oooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
08Wooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo
01Gooooo00?o0000ooooooooool00Oooool0017ooooo0_l00005ooooo`03ool00?oooooooooo01Oo
oooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo08Wo
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01Co
oooo0_l00003ooooo`004Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo01Kooooo
0ooo000Hooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0ROooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo01Kooooo0ooo000Fooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool05_ooool3ool001Sooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`29ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool05_ooool3ool001Kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool01?ooool00ooo003oooooooooo`0Fooooo`?oo`006?ooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo08Wooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0F
ooooo`?oo`005_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04oooo
o`03ool00?oooooooooo037ooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`29oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0;oooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo037ooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`29ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool0;oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03ool0
0?oooooooooo037ooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`29ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool0;oooool00ol0003oooooooooo`01ooooo`004Ooo
ool2o`0000Gooooo00?oo`00ooooooooool0<Oooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo08Wooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0^ooooo`;o00000ooo
ool0017ooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`0aooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool0ROooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo02oooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ooo
003oooooooooo`0aooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0ROooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo02oooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`0aooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool0ROooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo02oo
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ooo003ooooo
ooooo`0aooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0ROooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo02oooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool01?ooool00ooo003oooooooooo`0aooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool0ROooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo02oooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`0a
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0ROooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo02oooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool01?ooool00ooo003oooooooooo`0aooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool0ROooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo02oooooo00?o0000oooo
ooooool00Oooool0017ooooo0_l00005ooooo`03ool00?oooooooooo037ooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`29ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool0;_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0
<Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo08Wooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`0_ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo00Cooooo00?oo`00ooooooooool0<Oooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo08Wooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0_ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0<Oooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo08Wooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`0_ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
00Cooooo00?oo`00ooooooooool0<Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
08Wooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0_ooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0<Oooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo08Wooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`0_ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo
00?oo`00ooooooooool0<Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo08Wooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0_ooooo`03o`000?oooooooooo007ooooo
000Aooooo`;o00001Oooool00ooo003oooooooooo`0aooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool0ROooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo02kooooo0_l0
0003ooooo`004Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo037ooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`29ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool0;oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04oooo
o`03ool00?oooooooooo037ooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`29oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0;oooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo037ooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`29ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool0;oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03ool0
0?oooooooooo037ooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`29ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool0;oooool00ol0003oooooooooo`01ooooo`000ooo
ool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0<Ooo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo08Wooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`0_ooooo`03o`000?oooooooooo007ooooo0002ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo
00?oo`00ooooooooool0<Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo08Wooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0_ooooo`03o`000?oooooooooo007ooooo
0006ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`03ool00?oooooooooo037ooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`29ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0;oooool00ol0003ooooo
ooooo`01ooooo`001?ooool2o`0000?ooooo00Co0000oooooooooooo00001?ooool3o`0000Cooooo
00?oo`00ooooooooool0<Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo08Wooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0]ooooo`?o00000oooool000Kooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00?oo`00ooooooooool0<Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo08Wooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0_ooooo`03o`000?oooooooooo007ooooo
0002ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Cooooo00?oo`00ooooooooool0<Oooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo08Wooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0_ooooo`03
o`000?oooooooooo007ooooo0003ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0
1?ooool00ooo003oooooooooo`0aooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
ROooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo02oooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`0aooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool0ROooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo02oooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool0
0ooo003oooooooooo`0aooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0ROooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo02oooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`0aooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool0ROooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
02oooooo00?o0000ooooooooool00Oooool0017ooooo0_l00005ooooo`03ool00?oooooooooo037o
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`29ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool0;_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo00Cooooo
00?oo`00ooooooooool0<Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo08Wooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0_ooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0<Oooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo08Wooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`0_ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?oo`00
ooooooooool0<Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo08Wooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`0_ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0<Oooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo08Wooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0_oooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?oo`00oooooooo
ool0<Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo08Wooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`0_ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo00Cooooo00?oo`00ooooooooool0<?ooool3ool000Oooooo00?oo`00ooooooooool0
ROooool00ooo003oooooooooo`04ooooo`?oo`00<Oooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo033ooooo0ooo0007ooooo`03ool00?oo
oooooooo08Wooooo00?oo`00ooooooooool01?ooool3ool0037ooooo00?o0000ooooooooool00Ooo
ool0017ooooo0_l00005ooooo`03ool00?oooooooooo033ooooo0ooo0007ooooo`03ool00?oooooo
oooo08Wooooo00?oo`00ooooooooool01?ooool3ool0033ooooo0_l00003ooooo`004Oooool00ol0
003oooooooooo`04ooooo`03ool00?oooooooooo03[ooooo00?oo`00ooooooooool0ROooool00ooo
003oooooooooo`0hooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Co
oooo00?oo`00ooooooooool0>_ooool00ooo003oooooooooo`29ooooo`03ool00?oooooooooo03So
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ooo003ooooo
ooooo`0jooooo`03ool00?oooooooooo08Wooooo00?oo`00ooooooooool0>?ooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo03[ooooo00?o
o`00ooooooooool0ROooool00ooo003oooooooooo`0hooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0>_ooool00ooo003oooooooooo`29
ooooo`03ool00?oooooooooo03Sooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool01?ooool00ooo003oooooooooo`0jooooo`03ool00?oooooooooo08Wooooo00?oo`00oooo
ooooool0>?ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000?ooooo0ooo000looooo`03
ool00?oooooooooo08Wooooo00?oo`00ooooooooool0=oooool2o`0000?ooooo000Aooooo`03o`00
0?oooooooooo00;ooooo0ooo000looooo`03ool00?oooooooooo08Wooooo00?oo`00ooooooooool0
>?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`02ooooo`?oo`00??oo
ool00ooo003oooooooooo`29ooooo`03ool00?oooooooooo03Sooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0@Oooool00ooo003oooooooooo`29ooooo`03ool00?oooooo
oooo03Sooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0@Oooool00ooo
003oooooooooo`29ooooo`03ool00?oooooooooo03Sooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool0@Oooool00ooo003oooooooooo`29ooooo`03ool00?oooooooooo03So
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0@Oooool00ooo003ooooo
ooooo`29ooooo`03ool00?oooooooooo03Sooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool0@Oooool00ooo003oooooooooo`29ooooo`03ool00?oooooooooo03Sooooo00?o
0000ooooooooool00Oooool0017ooooo0_l00012ooooo`03ool00?oooooooooo08Wooooo00?oo`00
ooooooooool0=oooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo047ooooo00?oo`00oooo
ooooool0ROooool00ooo003oooooooooo`0hooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo047ooooo00?oo`00ooooooooool0ROooool00ooo003oooooooooo`0hooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo047ooooo00?oo`00ooooooooool0
ROooool00ooo003oooooooooo`0hooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo047ooooo00?oo`00ooooooooool0ROooool00ooo003oooooooooo`0hooooo`03o`000?oo
oooooooo007ooooo0004ooooo`?o00000oooool2o`0000Gooooo00?o0000ooooooooool0@Oooool0
0ooo003oooooooooo`29ooooo`03ool00?oooooooooo03Sooooo00?o0000ooooooooool00Oooool0
00Gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0@Oooool00ooo003oooooooooo`29ooooo`03ool00?oooooooooo03Sooooo00?o0000
ooooooooool00Oooool000;ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Cooooo0ol00011
ooooo`03ool00?oooooooooo08Wooooo00?oo`00ooooooooool0=_ooool3o`0000?ooooo0002oooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`11ooooo`03ool00?oooooooooo08Wooooo00?oo`00ooooooooool0>?ooool00ol0003ooooooooo
o`01ooooo`000oooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool0@Oooool00ooo003oooooooooo`29ooooo`03ool00?oooooooooo03Sooooo00?o
0000ooooooooool00Oooool000Cooooo0_l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool0@Oooool00ooo003oooooooooo`29ooooo`03ool00?oooooooooo03Sooooo00?o
0000ooooooooool00Oooool000Gooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000
ooooooooool0@Oooool00ooo003oooooooooo`29ooooo`03ool00?oooooooooo03Sooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0@Oooool00ooo003oooooooooo`29oooo
o`03ool00?oooooooooo03Sooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0@Oooool00ooo003oooooooooo`29ooooo`03ool00?oooooooooo03Sooooo00?o0000oooooooo
ool00Oooool0017ooooo0_l00011ooooo`?oo`00ROooool3ool003Sooooo0_l00003ooooo`004Ooo
ool00ol0003oooooooooo`10ooooo`?oo`00ROooool3ool003Wooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0@?ooool3ool008Wooooo0ooo000iooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00Oooool0017o
ooooool0000=o`0000?ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.77509, -4.35587, \
0.114327, 0.268064}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Phase plot of DFT as a function of index k", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fft\  = \ DFT[xd];\)\), "\n", 
    \(\(g4 = 
        DiscreteListPlot[\({#[\([1]\)], \ 
                Arg[#[\([2]\)] + 0.0000001]} &\)\  /@ \ fft, Red, \ 
          PlotRange \[Rule] {\(-\[Pi]\), \ \[Pi]}, \ Frame \[Rule] True, \ 
          Axes \[Rule] False];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0328407 0.309017 0.0983632 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18801 -0.0125 -3 -9 ]
[.18801 -0.0125 3 0 ]
[.35222 -0.0125 -6 -9 ]
[.35222 -0.0125 6 0 ]
[.51642 -0.0125 -6 -9 ]
[.51642 -0.0125 6 0 ]
[.68062 -0.0125 -6 -9 ]
[.68062 -0.0125 6 0 ]
[.84483 -0.0125 -6 -9 ]
[.84483 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01393 -12 -4.5 ]
[-0.0125 .01393 0 4.5 ]
[-0.0125 .11229 -12 -4.5 ]
[-0.0125 .11229 0 4.5 ]
[-0.0125 .21065 -12 -4.5 ]
[-0.0125 .21065 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40738 -6 -4.5 ]
[-0.0125 .40738 0 4.5 ]
[-0.0125 .50574 -6 -4.5 ]
[-0.0125 .50574 0 4.5 ]
[-0.0125 .60411 -6 -4.5 ]
[-0.0125 .60411 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18801 0 m
.18801 .00625 L
s
[(5)] .18801 -0.0125 0 1 Mshowa
.35222 0 m
.35222 .00625 L
s
[(10)] .35222 -0.0125 0 1 Mshowa
.51642 0 m
.51642 .00625 L
s
[(15)] .51642 -0.0125 0 1 Mshowa
.68062 0 m
.68062 .00625 L
s
[(20)] .68062 -0.0125 0 1 Mshowa
.84483 0 m
.84483 .00625 L
s
[(25)] .84483 -0.0125 0 1 Mshowa
.125 Mabswid
.05665 0 m
.05665 .00375 L
s
.08949 0 m
.08949 .00375 L
s
.12233 0 m
.12233 .00375 L
s
.15517 0 m
.15517 .00375 L
s
.22085 0 m
.22085 .00375 L
s
.25369 0 m
.25369 .00375 L
s
.28654 0 m
.28654 .00375 L
s
.31938 0 m
.31938 .00375 L
s
.38506 0 m
.38506 .00375 L
s
.4179 0 m
.4179 .00375 L
s
.45074 0 m
.45074 .00375 L
s
.48358 0 m
.48358 .00375 L
s
.54926 0 m
.54926 .00375 L
s
.5821 0 m
.5821 .00375 L
s
.61494 0 m
.61494 .00375 L
s
.64778 0 m
.64778 .00375 L
s
.71346 0 m
.71346 .00375 L
s
.74631 0 m
.74631 .00375 L
s
.77915 0 m
.77915 .00375 L
s
.81199 0 m
.81199 .00375 L
s
.87767 0 m
.87767 .00375 L
s
.91051 0 m
.91051 .00375 L
s
.94335 0 m
.94335 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01393 m
.00625 .01393 L
s
[(-3)] -0.0125 .01393 1 0 Mshowa
0 .11229 m
.00625 .11229 L
s
[(-2)] -0.0125 .11229 1 0 Mshowa
0 .21065 m
.00625 .21065 L
s
[(-1)] -0.0125 .21065 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .40738 m
.00625 .40738 L
s
[(1)] -0.0125 .40738 1 0 Mshowa
0 .50574 m
.00625 .50574 L
s
[(2)] -0.0125 .50574 1 0 Mshowa
0 .60411 m
.00625 .60411 L
s
[(3)] -0.0125 .60411 1 0 Mshowa
.125 Mabswid
0 .0336 m
.00375 .0336 L
s
0 .05327 m
.00375 .05327 L
s
0 .07295 m
.00375 .07295 L
s
0 .09262 m
.00375 .09262 L
s
0 .13196 m
.00375 .13196 L
s
0 .15164 m
.00375 .15164 L
s
0 .17131 m
.00375 .17131 L
s
0 .19098 m
.00375 .19098 L
s
0 .23033 m
.00375 .23033 L
s
0 .25 m
.00375 .25 L
s
0 .26967 m
.00375 .26967 L
s
0 .28934 m
.00375 .28934 L
s
0 .32869 m
.00375 .32869 L
s
0 .34836 m
.00375 .34836 L
s
0 .36803 m
.00375 .36803 L
s
0 .38771 m
.00375 .38771 L
s
0 .42705 m
.00375 .42705 L
s
0 .44673 m
.00375 .44673 L
s
0 .4664 m
.00375 .4664 L
s
0 .48607 m
.00375 .48607 L
s
0 .52542 m
.00375 .52542 L
s
0 .54509 m
.00375 .54509 L
s
0 .56476 m
.00375 .56476 L
s
0 .58443 m
.00375 .58443 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18801 .61178 m
.18801 .61803 L
s
.35222 .61178 m
.35222 .61803 L
s
.51642 .61178 m
.51642 .61803 L
s
.68062 .61178 m
.68062 .61803 L
s
.84483 .61178 m
.84483 .61803 L
s
.125 Mabswid
.05665 .61428 m
.05665 .61803 L
s
.08949 .61428 m
.08949 .61803 L
s
.12233 .61428 m
.12233 .61803 L
s
.15517 .61428 m
.15517 .61803 L
s
.22085 .61428 m
.22085 .61803 L
s
.25369 .61428 m
.25369 .61803 L
s
.28654 .61428 m
.28654 .61803 L
s
.31938 .61428 m
.31938 .61803 L
s
.38506 .61428 m
.38506 .61803 L
s
.4179 .61428 m
.4179 .61803 L
s
.45074 .61428 m
.45074 .61803 L
s
.48358 .61428 m
.48358 .61803 L
s
.54926 .61428 m
.54926 .61803 L
s
.5821 .61428 m
.5821 .61803 L
s
.61494 .61428 m
.61494 .61803 L
s
.64778 .61428 m
.64778 .61803 L
s
.71346 .61428 m
.71346 .61803 L
s
.74631 .61428 m
.74631 .61803 L
s
.77915 .61428 m
.77915 .61803 L
s
.81199 .61428 m
.81199 .61803 L
s
.87767 .61428 m
.87767 .61803 L
s
.91051 .61428 m
.91051 .61803 L
s
.94335 .61428 m
.94335 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01393 m
1 .01393 L
s
.99375 .11229 m
1 .11229 L
s
.99375 .21065 m
1 .21065 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .40738 m
1 .40738 L
s
.99375 .50574 m
1 .50574 L
s
.99375 .60411 m
1 .60411 L
s
.125 Mabswid
.99625 .0336 m
1 .0336 L
s
.99625 .05327 m
1 .05327 L
s
.99625 .07295 m
1 .07295 L
s
.99625 .09262 m
1 .09262 L
s
.99625 .13196 m
1 .13196 L
s
.99625 .15164 m
1 .15164 L
s
.99625 .17131 m
1 .17131 L
s
.99625 .19098 m
1 .19098 L
s
.99625 .23033 m
1 .23033 L
s
.99625 .25 m
1 .25 L
s
.99625 .26967 m
1 .26967 L
s
.99625 .28934 m
1 .28934 L
s
.99625 .32869 m
1 .32869 L
s
.99625 .34836 m
1 .34836 L
s
.99625 .36803 m
1 .36803 L
s
.99625 .38771 m
1 .38771 L
s
.99625 .42705 m
1 .42705 L
s
.99625 .44673 m
1 .44673 L
s
.99625 .4664 m
1 .4664 L
s
.99625 .48607 m
1 .48607 L
s
.99625 .52542 m
1 .52542 L
s
.99625 .54509 m
1 .54509 L
s
.99625 .56476 m
1 .56476 L
s
.99625 .58443 m
1 .58443 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .30902 m
.02381 .30902 L
s
.05665 .30902 m
.05665 .35262 L
s
.08949 .30902 m
.08949 .39437 L
s
.12233 .30902 m
.12233 .43706 L
s
.15517 .30902 m
.15517 .19528 L
s
.18801 .30902 m
.18801 .37475 L
s
.22085 .30902 m
.22085 .44596 L
s
.25369 .30902 m
.25369 .1686 L
s
.28654 .30902 m
.28654 .19176 L
s
.31938 .30902 m
.31938 .21151 L
s
.35222 .30902 m
.35222 .22947 L
s
.38506 .30902 m
.38506 .24633 L
s
.4179 .30902 m
.4179 .26251 L
s
.45074 .30902 m
.45074 .27823 L
s
.48358 .30902 m
.48358 .29369 L
s
.51642 .30902 m
.51642 .30902 L
s
.54926 .30902 m
.54926 .32435 L
s
.5821 .30902 m
.5821 .3398 L
s
.61494 .30902 m
.61494 .35553 L
s
.64778 .30902 m
.64778 .3717 L
s
.68062 .30902 m
.68062 .38857 L
s
.71346 .30902 m
.71346 .40652 L
s
.74631 .30902 m
.74631 .42628 L
s
.77915 .30902 m
.77915 .44943 L
s
.81199 .30902 m
.81199 .17207 L
s
.84483 .30902 m
.84483 .24329 L
s
.87767 .30902 m
.87767 .42275 L
s
.91051 .30902 m
.91051 .18098 L
s
.94335 .30902 m
.94335 .22366 L
s
.97619 .30902 m
.97619 .26541 L
s
.015 w
.02381 .30902 Mdot
.05665 .35262 Mdot
.08949 .39437 Mdot
.12233 .43706 Mdot
.15517 .19528 Mdot
.18801 .37475 Mdot
.22085 .44596 Mdot
.25369 .1686 Mdot
.28654 .19176 Mdot
.31938 .21151 Mdot
.35222 .22947 Mdot
.38506 .24633 Mdot
.4179 .26251 Mdot
.45074 .27823 Mdot
.48358 .29369 Mdot
.51642 .30902 Mdot
.54926 .32435 Mdot
.5821 .3398 Mdot
.61494 .35553 Mdot
.64778 .3717 Mdot
.68062 .38857 Mdot
.71346 .40652 Mdot
.74631 .42628 Mdot
.77915 .44943 Mdot
.81199 .17207 Mdot
.84483 .24329 Mdot
.87767 .42275 Mdot
.91051 .18098 Mdot
.94335 .22366 Mdot
.97619 .26541 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005oooool2o`0002Wooooo0ol0000Uooooo`?o00001?ooool2o`0002?ooooo0ol00003oooo
o`?o00008Oooool5o`0000?ooooo0_l0000Rooooo`Go00000_ooool3o`0002[ooooo000Fooooo`04
o`000?ooooooooooo`0002Oooooo00Go0000ooooooooooooooooo`00000Uooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00008oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool07oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
02;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo02Oooooo000F
ooooo`04o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02Oooooo000Fooooo`04o`000?ooooooooooo`0002_o
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
02?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Qooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool09oooool001Kooooo00Co0000oooooooooooo00009oooool4o`0002Kooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co0000
8Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00008Oooool01_l0
003ooooooooooooooooo0000ooooo`Co0000:_ooool001Kooooo00Co0000oooooooooooo00009ooo
ool00ol0003oooooooooo`0Vooooo`;o00001?ooool01?l0003oooooooooool0000Rooooo`;o0000
0oooool00ol0003oooooooooo`0Rooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool0000Qooooo`07o`000?ooooooooooooooool0003oooooo`00000]ooooo`005oooool2
o`0002Sooooo1Ol0000Uooooo`03o`000?oooooooooo00?ooooo0_l0000Tooooo`04o`000?oooooo
ooooooooo`Go00008Oooool3o`0000Cooooo0_l0000Sooooo`?o00000_ooool5o`0002Wooooo003o
ooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Boooooooo00002ol0
0004ooooo`002_ooool3o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`002Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`02ooooo`000oooool5o`0000Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool000_ooooo0_l00005ooooo`?o
0000ooooool5ooooo`?o00001?ooool000gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool000Wooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`002_oo
ool3o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000B
ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool2o`00
0?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003o
ooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool0
0_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000B
ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool2o`00
0?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003o
ooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool0
0_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000B
ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool2o`00
0?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003o
ooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool0
0_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000B
ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool2o`00
0?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003o
ooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool0
0_ooool000Wooooo1Ol00004ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooooooo
o`02ooooo`002_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo0?oooooo1ooo
ool00ol0003oooooooooo`02ooooo`000oooool5o`0000?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool000cooooo00?o0000oooo
ooooool00oooool3o`000?oooooo1Oooool3o`0000Cooooo0009ooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool000Wo
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0
003oooooooooo`02ooooo`002_ooool3o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`03
o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooo
ooooo`02ooooo`004_ooool2o`000?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooo
oooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3ooooo
o`Oooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03
o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooo
ooooo`02ooooo`004_ooool2o`000?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooo
oooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3ooooo
o`Oooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03
o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo03oooooo0ooo0034ooooo`03o`00
0?oooooooooo00;ooooo000Booooo`;o0000@?ooool3ool0097ooooo0ooo000_ooooo`;o00001?oo
ool001;ooooo00?o0000ooooooooool0?oooool3ool0097ooooo0ooo000`ooooo`03o`000?oooooo
oooo00;ooooo000Booooo`03o`000?oooooooooo043ooooo00?oo`00ooooooooool0T?ooool3ool0
01Oooooo0ooo000Fooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo043o
oooo00?oo`00ooooooooool0TOooool00ooo003oooooooooo`0Fooooo`?oo`005_ooool00ol0003o
ooooooooo`02ooooo`004_ooool00ol0003oooooooooo`10ooooo`03ool00?oooooooooo097ooooo
00?oo`00ooooooooool05_ooool3ool001Kooooo00?o0000ooooooooool00_ooool001;ooooo0_l0
0011ooooo`03ool00?oooooooooo00Gooooo0ooo0029ooooo`03ool00?oooooooooo01Oooooo00?o
o`00ooooooooool05?ooool2o`0000Cooooo000Booooo`03o`000?oooooooooo02Gooooo0ooo000H
ooooo`03ool00?oooooooooo00Gooooo0ooo0029ooooo`03ool00?oooooooooo01Oooooo00?oo`00
ooooooooool05Oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`0Uoooo
o`?oo`006?ooool00ooo003oooooooooo`05ooooo`?oo`00ROooool00ooo003oooooooooo`0Goooo
o`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00_ooool000[ooooo0ol00005ooooo`03
o`000?oooooooooo02Gooooo0ooo000Hooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool0R?ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01Gooooo00?o0000oooooooo
ool00_ooool000_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Vooooo`03ool0
0?oooooooooo01Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`28ooooo`03ool0
0?oooooooooo01Oooooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`02ooooo`000ooo
ool5o`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Vooooo`03ool00?oo
oooooooo01Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`04ooooo`?oo`00POoo
ool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool00_oo
ool000_ooooo00?o0000ooooooooool01?ooool3o`0002Kooooo00?oo`00ooooooooool05oooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Cooooo0ooo0021ooooo`03ool00?oooooo
oooo01Oooooo00?oo`00ooooooooool04oooool3o`0000Cooooo000;ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool09_ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01?ooool3ool0087ooooo00?oo`00ooooooooool05oooool00ooo
003oooooooooo`0Eooooo`03o`000?oooooooooo00;ooooo000:ooooo`;o00001_ooool00ol0003o
ooooooooo`0Vooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo07oooooo00?oo`00ooooooooool05oooool00ooo003o
ooooooooo`0Eooooo`03o`000?oooooooooo00;ooooo000;ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool09_ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`1oooooo`03ool00?oooooooooo01Oooooo
00?oo`00ooooooooool01Oooool3ool000gooooo00?o0000ooooooooool00_ooool001;ooooo00?o
0000ooooooooool09_ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`04ooooo`?oo`00N?ooool00ooo003ooooooooo
o`0Gooooo`03ool00?oooooooooo00Gooooo0ooo000=ooooo`03o`000?oooooooooo00;ooooo000B
ooooo`;o00009oooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`04ooooo`?oo`00N?ooool00ooo003oooooooooo`0G
ooooo`03ool00?oooooooooo00Gooooo0ooo000<ooooo`;o00001?ooool001;ooooo00?o0000oooo
ooooool09_ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`04ooooo`?oo`00N?ooool00ooo003oooooooooo`0Goooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`02oooo
o`004_ooool00ol0003oooooooooo`0Vooooo`03ool00?oooooooooo01Oooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo
ool0Moooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool03?ooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`0Vooooo`03ool0
0?oooooooooo01Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Gooooo00?oo`00ooooooooool0Moooool00ooo003oooooooooo`05ooooo`?oo`00
3oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool0
0_ooool001;ooooo00?o0000ooooooooool09_ooool00ooo003oooooooooo`0Gooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oo
oooooooo00Gooooo0ooo001_ooooo`03ool00?oooooooooo00Gooooo0ooo000?ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`02ooooo`004_ooool2
o`0002Oooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`05ooooo`?oo`00Koooool0
0ooo003oooooooooo`05ooooo`?oo`003oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00_ooooo0_l00004ooooo`004_ooool00ol0003oooooooooo`0Vooooo`03ool00?oooooooooo
01Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Gooooo00?oo`00ooooooooool01Oooool3ool006oooooo00?oo`00ooooooooool01_ooool00ooo
003oooooooooo`0>ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool03?ooool00ol0
003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`0Vooooo`03ool00?oooooooooo01Oo
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Go
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`1^ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00co
oooo00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool09_ooool00ooo003ooooo
ooooo`0Gooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01?ooool3ool006Oooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool03?ooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`04ooooo`?oo`00Ioooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00kooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`04ooooo`?oo`001Oooool00ol0003ooooooooo
o`02ooooo`004_ooool2o`0002Oooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Cooooo0ooo001Wooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool03_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Cooooo0ooo0004
ooooo`;o00001?ooool001;ooooo00?o0000ooooooooool09_ooool00ooo003oooooooooo`0Goooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`1Uoooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Cooooo0ooo0005ooooo`03o`000?oooooooooo00;ooooo000Booooo`03
o`000?oooooooooo02Kooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01?ooool3ool005kooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`00
0?oooooooooo02Kooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01?ooool3ool005kooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`000?oo
oooooooo02Kooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool01?ooool3ool005kooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooo
oooo02Kooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`1Looooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`02ooooo`004_ooool2o`00
02Oooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`04ooooo`?oo`00EOooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool01_ooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00;ooooo0_l00004ooooo`004_ooool00ol0003o
ooooooooo`0Vooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01?ooool3ool005Go
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo000;ooooo`;o00001Oooool00ol0003oooooooooo`0Vooooo`03ool00?oooooooooo01Oooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool01?ooool3ool005Gooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`0>ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo000:ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool09_ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool0E?ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00kooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool000[ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`02ooooo`?oo`008Oooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool01Oooool3ool004cooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`0>ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo000:ooooo`04o`000?ooooooooooo`0000Cooooo
0ol00002ooooo`?oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Gooooo
0ooo0007ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Kooooo00Coo`00oooooooooooooooo0ol00004ooooo`00
2_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo0ooo0007ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0?ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool0B_ooool3ool000Oooooo00?oo`00oooooooo
ool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01gooooo00?o0000oooooooo
ool00_ooool000[ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0<ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0?ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool0E?ooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo01Oooooo00?oo`00ooooooooool07Oooool00ol0003oooooooooo`02ooooo`00
2oooool2o`0000Gooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Gooooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo05;ooooo0ooo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool0
7Oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`0<ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0?ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool0D_ooool3ool000Oooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool05ooo
ool00ooo003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo000Booooo`;o00003Oooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool03oooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo05;ooooo0ooo0007ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo01Oooooo00?oo`00ooooooooool07?ooool2o`0000Cooooo000Booooo`03o`000?oooooooooo
00cooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo
00oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`1Looooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
01Oooooo00?oo`00ooooooooool07Oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003o
ooooooooo`0<ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003o
ooooooooo`0?ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0Foooool3ool000Oo
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01Oo
oooo00?oo`00ooooooooool07Oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003ooooo
ooooo`0<ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`0?ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0Foooool3ool000Oooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01Oooooo
00?oo`00ooooooooool07Oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003ooooooooo
o`0<ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003ooooooooo
o`0?ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0Foooool3ool000Oooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01Oooooo00?o
o`00ooooooooool07Oooool00ol0003oooooooooo`02ooooo`004_ooool2o`0000gooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00oooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`1Uooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01cooooo0_l00004
ooooo`004_ooool00ol0003oooooooooo`0;ooooo`?oo`001oooool00ooo003oooooooooo`05oooo
o`03ool00?oooooooooo00oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`1Uoooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Goooo
o`03ool00?oooooooooo01gooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000oooooooo
ool02oooool3ool000Oooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0?ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool0I?ooool3ool000Oooooo00?oo`00oooooooo
ool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01gooooo00?o0000oooooooo
ool00_ooool001;ooooo00?o0000ooooooooool02oooool3ool000Oooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`0?ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
I?ooool3ool000Oooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Gooooo`03ool0
0?oooooooooo01gooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool05Ooo
ool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`1Tooooo`?oo`001oooool00ooo003oooooooooo`05ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo01Oooooo00?oo`00ooooooooool07Oooool00ol0003oooooooooo`02ooooo`004_ooool2
o`0001Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0?ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool0K_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo01Oooooo00?oo`00ooooooooool07?ooool2o`0000Cooooo000Booooo`03o`000?oooooooooo
01Gooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0?ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool0K?ooool3ool000Oooooo00?oo`00ooooooooool01_ooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool05oooool00ooo
003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo01Go
oooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0=ooooo`?oo`002?ooool00ooo003o
ooooooooo`1/ooooo`?oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01go
oooo00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool05Oooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo00gooooo0ooo0008ooooo`03ool00?oooooooooo06cooooo
0ooo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool07Oooool00ol0003ooooo
ooooo`02ooooo`004_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo00Gooooo00?o
o`00ooooooooool03Oooool3ool000Sooooo00?oo`00ooooooooool0M_ooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`0Gooooo`03ool00?oooooooooo01gooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000
ooooooooool05Oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo01Sooooo00?oo`00
ooooooooool0MOooool3ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool07Oooool00ol0003oooooooooo`02
ooooo`004_ooool2o`0001Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Hoooo
o`03ool00?oooooooooo07Gooooo0ooo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01cooooo0_l00004oooo
o`004_ooool00ol0003oooooooooo`0Cooooo`?oo`001oooool00ooo003oooooooooo`0Hooooo`03
ool00?oooooooooo07Gooooo0ooo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01gooooo00?o0000oooooooo
ool00_ooool000[ooooo0ol00005ooooo`03o`000?oooooooooo01?ooooo0ooo0007ooooo`03ool0
0?oooooooooo01Sooooo00?oo`00ooooooooool0Ooooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Mooooo`03o`00
0?oooooooooo00;ooooo000;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04ooo
ool3ool000Oooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`1oooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Gooooo`03ool00?oo
oooooooo01gooooo00?o0000ooooooooool00_ooool000_ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Mooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool0O_ooool3
ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooo
oooo01gooooo00?o0000ooooooooool00_ooool000_ooooo00?o0000ooooooooool01?ooool3o`00
01gooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`1nooooo`?oo`001oooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool06oooool3o`00
00Cooooo000;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07Oooool00ooo003o
ooooooooo`0Hooooo`03ool00?oooooooooo07kooooo0ooo0007ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Mooooo`03o`000?oooooooooo00;o
oooo000:ooooo`;o00001_ooool00ol0003oooooooooo`0Mooooo`03ool00?oooooooooo01Sooooo
00?oo`00ooooooooool0R?ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01Oooooo
00?oo`00ooooooooool07Oooool00ol0003oooooooooo`02ooooo`002oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01gooooo00?oo`00ooooooooool06?ooool00ooo003ooooooooo
o`28ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool05Oooool3ool001oooooo00?o
0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool07Oooool00ooo003oooooooooo`0H
ooooo`03ool00?oooooooooo08Kooooo0ooo0008ooooo`03ool00?oooooooooo01Gooooo0ooo000O
ooooo`03o`000?oooooooooo00;ooooo000Booooo`;o00007_ooool00ooo003oooooooooo`0Hoooo
o`03ool00?oooooooooo08Kooooo0ooo0008ooooo`03ool00?oooooooooo01Gooooo0ooo000Noooo
o`;o00001?ooool001;ooooo00?o0000ooooooooool07Oooool00ooo003oooooooooo`0Hooooo`03
ool00?oooooooooo08Kooooo0ooo0008ooooo`03ool00?oooooooooo03Oooooo00?o0000oooooooo
ool00_ooool001;ooooo00?o0000ooooooooool07?ooool3ool001Wooooo00?oo`00ooooooooool0
TOooool00ooo003oooooooooo`0gooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`000?oo
oooooooo01cooooo0ooo000Iooooo`03ool00?oooooooooo097ooooo00?oo`00ooooooooool0=ooo
ool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`0Looooo`?oo`006Oooool0
0ooo003oooooooooo`2Aooooo`03ool00?oooooooooo03Oooooo00?o0000ooooooooool00_ooool0
01;ooooo0_l0000gooooo`?oo`00TOooool3ool003Sooooo0_l00004ooooo`004_ooool00ol0003o
ooooooooo`0fooooo`?oo`00TOooool3ool003Wooooo00?o0000ooooooooool00_ooool001;ooooo
00?o0000ooooooooool0=_ooool3ool0097ooooo0ooo000iooooo`03o`000?oooooooooo00;ooooo
000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool0
0ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool001;ooooo0_l0003ooooo
o`Oooooo0_l00004ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000oooooooo
ool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo
000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_ooool0
0ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000oooo
ooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000Booooo`;o0000ooooool7ooooo`;o
00001?ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo
0009ooooo`Go00001?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_oo
ool000[ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o
0000ooooooooool00_ooool000_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
ooooo`Oooooo00?o0000ooooooooool00_ooool000cooooo00?o0000ooooooooool00oooool3o`00
0?oooooo1Oooool3o`0000Cooooo0009ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool000Wooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02oooo
o`002_ooool3o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;o
oooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_oo
ool2o`000?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool0
0ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000oooo
ooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;o
oooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_oo
ool2o`000?oooooo1oooool2o`0000Cooooo000Booooo`03o`000?oooooooooo0?oooooo1oooool0
0ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000oooo
ooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;o
oooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_oo
ool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool001;ooooo0_l0003o
ooooo`Oooooo0_l00004ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000oooo
ooooool00_ooool001;ooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;o
oooo000Booooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`02ooooo`004_oo
ool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool00_ooool001;ooooo0_l0003o
ooooo`Oooooo0_l00004ooooo`004_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000oooo
ooooool00_ooool000[ooooo0ol00005ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003o
ooooooooo`02ooooo`002Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000=ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo000;ooooo`;o00001Ooo
ool3o`000?oooooo1Oooool3o`0000Cooooo000=ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0ooooool7ooooo`03o`000?oooooooooo00;ooooo0009ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00;ooooo000:oooo
o`?o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo000Boooooooo
00002ol00004ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.85793, -3.6139, 0.114882, \
0.0383558}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Rearrange and scale DFT result", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g5 = 
        DiscreteListPlot[FourierRearrange[Abs[Last\  /@ \ fft], fs], Red, 
          PlotRange \[Rule] All, ImageSize \[Rule] 504, \ 
          Frame \[Rule] True, \ Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g6\  = \ Show[g1, g5];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.0147151 0.00959021 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11062 -12 -4.5 ]
[-0.0125 .11062 0 4.5 ]
[-0.0125 .20652 -12 -4.5 ]
[-0.0125 .20652 0 4.5 ]
[-0.0125 .30242 -12 -4.5 ]
[-0.0125 .30242 0 4.5 ]
[-0.0125 .39832 -12 -4.5 ]
[-0.0125 .39832 0 4.5 ]
[-0.0125 .49423 -12 -4.5 ]
[-0.0125 .49423 0 4.5 ]
[-0.0125 .59013 -12 -4.5 ]
[-0.0125 .59013 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11062 m
.00625 .11062 L
s
[(10)] -0.0125 .11062 1 0 Mshowa
0 .20652 m
.00625 .20652 L
s
[(20)] -0.0125 .20652 1 0 Mshowa
0 .30242 m
.00625 .30242 L
s
[(30)] -0.0125 .30242 1 0 Mshowa
0 .39832 m
.00625 .39832 L
s
[(40)] -0.0125 .39832 1 0 Mshowa
0 .49423 m
.00625 .49423 L
s
[(50)] -0.0125 .49423 1 0 Mshowa
0 .59013 m
.00625 .59013 L
s
[(60)] -0.0125 .59013 1 0 Mshowa
.125 Mabswid
0 .0339 m
.00375 .0339 L
s
0 .05308 m
.00375 .05308 L
s
0 .07226 m
.00375 .07226 L
s
0 .09144 m
.00375 .09144 L
s
0 .1298 m
.00375 .1298 L
s
0 .14898 m
.00375 .14898 L
s
0 .16816 m
.00375 .16816 L
s
0 .18734 m
.00375 .18734 L
s
0 .2257 m
.00375 .2257 L
s
0 .24488 m
.00375 .24488 L
s
0 .26406 m
.00375 .26406 L
s
0 .28324 m
.00375 .28324 L
s
0 .3216 m
.00375 .3216 L
s
0 .34078 m
.00375 .34078 L
s
0 .35996 m
.00375 .35996 L
s
0 .37914 m
.00375 .37914 L
s
0 .4175 m
.00375 .4175 L
s
0 .43668 m
.00375 .43668 L
s
0 .45586 m
.00375 .45586 L
s
0 .47505 m
.00375 .47505 L
s
0 .51341 m
.00375 .51341 L
s
0 .53259 m
.00375 .53259 L
s
0 .55177 m
.00375 .55177 L
s
0 .57095 m
.00375 .57095 L
s
0 .60931 m
.00375 .60931 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11062 m
1 .11062 L
s
.99375 .20652 m
1 .20652 L
s
.99375 .30242 m
1 .30242 L
s
.99375 .39832 m
1 .39832 L
s
.99375 .49423 m
1 .49423 L
s
.99375 .59013 m
1 .59013 L
s
.125 Mabswid
.99625 .0339 m
1 .0339 L
s
.99625 .05308 m
1 .05308 L
s
.99625 .07226 m
1 .07226 L
s
.99625 .09144 m
1 .09144 L
s
.99625 .1298 m
1 .1298 L
s
.99625 .14898 m
1 .14898 L
s
.99625 .16816 m
1 .16816 L
s
.99625 .18734 m
1 .18734 L
s
.99625 .2257 m
1 .2257 L
s
.99625 .24488 m
1 .24488 L
s
.99625 .26406 m
1 .26406 L
s
.99625 .28324 m
1 .28324 L
s
.99625 .3216 m
1 .3216 L
s
.99625 .34078 m
1 .34078 L
s
.99625 .35996 m
1 .35996 L
s
.99625 .37914 m
1 .37914 L
s
.99625 .4175 m
1 .4175 L
s
.99625 .43668 m
1 .43668 L
s
.99625 .45586 m
1 .45586 L
s
.99625 .47505 m
1 .47505 L
s
.99625 .51341 m
1 .51341 L
s
.99625 .53259 m
1 .53259 L
s
.99625 .55177 m
1 .55177 L
s
.99625 .57095 m
1 .57095 L
s
.99625 .60931 m
1 .60931 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .07226 m
.02395 .07225 L
.02408 .07224 L
.02423 .07221 L
.02437 .07217 L
.02462 .07208 L
.02489 .07194 L
.02519 .07174 L
.02551 .07147 L
.02608 .07086 L
.02722 .06914 L
.02847 .06647 L
.02973 .06301 L
.03109 .05851 L
.03355 .04862 L
.03593 .03763 L
.03718 .03179 L
.03787 .02883 L
.03821 .02752 L
.03852 .02645 L
.03882 .02558 L
.03898 .02519 L
.03915 .02485 L
.03924 .0247 L
.03932 .02458 L
.03948 .02442 L
.03956 .02436 L
.03966 .02432 L
.03974 .02432 L
.03982 .02433 L
.03997 .02441 L
.0401 .02454 L
.04024 .02474 L
.0404 .02503 L
.04071 .0258 L
.04101 .0267 L
.04331 .03667 L
.04579 .04826 L
.04809 .0578 L
.05031 .06513 L
.05156 .06827 L
.05269 .07045 L
.05327 .07132 L
.05389 .07205 L
.05442 .0725 L
.05472 .07269 L
.055 .07283 L
.05516 .07288 L
.05524 .0729 L
.05532 .07293 L
Mistroke
.05541 .07294 L
.05548 .07295 L
.05563 .07297 L
.05577 .07297 L
.05593 .07296 L
.05608 .07294 L
.05621 .07291 L
.05637 .07286 L
.05651 .0728 L
.05684 .07263 L
.05716 .0724 L
.05751 .0721 L
.05815 .07136 L
.05874 .07049 L
.06007 .06784 L
.06125 .06476 L
.0625 .06079 L
.06706 .04146 L
.0683 .0355 L
.0696 .02953 L
.07013 .02739 L
.07043 .02637 L
.07071 .02557 L
.07086 .02519 L
.07103 .02486 L
.07119 .02463 L
.07133 .02448 L
.07147 .02441 L
.07162 .0244 L
.07177 .02447 L
.07192 .02461 L
.07207 .02483 L
.07221 .02509 L
.07252 .02587 L
.0731 .02782 L
.07417 .03251 L
.07659 .04432 L
.07903 .05551 L
.08132 .06424 L
.08239 .06754 L
.08351 .07042 L
.0841 .07167 L
.08474 .07283 L
.08528 .07364 L
.08587 .07433 L
.0862 .07463 L
.08651 .07486 L
.0868 .07502 L
.08694 .07509 L
.08711 .07515 L
Mistroke
.08725 .07518 L
.08739 .07521 L
.08754 .07523 L
.08769 .07523 L
.08782 .07522 L
.08795 .0752 L
.08809 .07517 L
.08823 .07513 L
.0884 .07507 L
.08856 .07499 L
.08891 .07477 L
.08923 .07451 L
.08956 .07419 L
.09013 .07347 L
.09076 .07247 L
.09199 .06989 L
.09311 .06685 L
.09564 .05782 L
.09813 .04646 L
.10044 .03482 L
.1016 .0293 L
.10217 .02702 L
.10241 .02619 L
.10269 .02544 L
.10281 .02516 L
.10295 .02491 L
.1031 .02472 L
.10323 .0246 L
.10339 .02456 L
.10354 .0246 L
.10367 .02471 L
.10382 .0249 L
.10397 .02517 L
.10413 .02555 L
.10447 .02655 L
.10507 .02888 L
.10994 .05359 L
.11218 .06361 L
.11462 .07211 L
.11595 .07545 L
.11659 .07673 L
.11718 .07768 L
.11778 .07845 L
.11835 .07897 L
.11866 .07918 L
.11895 .07931 L
.1191 .07937 L
.11919 .07939 L
.11927 .07941 L
.11935 .07942 L
Mistroke
.11944 .07943 L
.11952 .07943 L
.1196 .07944 L
.11974 .07943 L
.11989 .07941 L
.12003 .07937 L
.12016 .07933 L
.12031 .07927 L
.12047 .07919 L
.12077 .079 L
.12108 .07874 L
.12141 .0784 L
.12201 .07763 L
.12317 .07549 L
.12423 .07286 L
.12655 .06496 L
.12906 .05354 L
.13142 .04095 L
.13267 .03407 L
.13336 .0305 L
.13401 .02755 L
.13431 .02644 L
.13462 .02553 L
.13479 .02519 L
.13488 .02504 L
.13497 .02493 L
.13513 .02482 L
.13521 .02481 L
.13529 .02482 L
.13544 .02491 L
.13557 .02508 L
.13571 .02533 L
.13587 .0257 L
.13618 .02668 L
.13647 .0278 L
.13877 .04012 L
.14127 .05457 L
.14359 .06648 L
.14584 .07587 L
.14698 .0796 L
.14762 .08137 L
.14823 .08282 L
.14881 .08399 L
.14945 .08502 L
.14973 .08539 L
.15003 .08573 L
.15031 .08599 L
.15057 .08618 L
.15073 .08627 L
.1509 .08636 L
Mistroke
.15107 .08642 L
.15116 .08645 L
.15125 .08647 L
.15133 .08648 L
.15141 .08649 L
.15156 .08649 L
.15172 .08648 L
.15181 .08647 L
.15189 .08645 L
.15203 .08641 L
.15217 .08636 L
.15247 .08619 L
.15277 .08597 L
.15309 .08567 L
.15369 .08491 L
.15425 .08398 L
.15551 .08111 L
.15674 .07732 L
.15806 .07224 L
.16046 .0605 L
.16306 .04504 L
.16429 .03733 L
.16495 .03323 L
.16558 .0297 L
.16611 .02718 L
.16626 .02659 L
.16641 .02612 L
.16654 .02576 L
.16668 .02545 L
.16683 .02524 L
.16698 .02514 L
.16712 .02517 L
.16726 .02529 L
.16742 .02556 L
.16756 .02591 L
.16789 .02703 L
.16846 .02977 L
.16907 .03335 L
.17017 .04056 L
.17267 .05744 L
.17506 .07225 L
.17633 .07906 L
.17766 .08534 L
.17886 .08999 L
.17949 .09208 L
.18017 .09401 L
.18079 .09549 L
.18136 .09658 L
.18194 .09744 L
.1822 .09774 L
Mistroke
.18248 .09801 L
.18264 .09814 L
.18279 .09823 L
.18293 .09831 L
.18309 .09837 L
.18323 .09842 L
.18336 .09844 L
.18349 .09845 L
.18364 .09845 L
.1838 .09843 L
.18389 .0984 L
.18397 .09838 L
.18412 .09832 L
.18428 .09823 L
.18456 .09803 L
.18487 .09774 L
.18542 .09702 L
.18601 .09598 L
.18709 .09338 L
.18824 .08958 L
.18951 .08427 L
.19205 .07021 L
.19461 .05234 L
.19694 .03462 L
.19751 .03069 L
.19782 .0288 L
.19811 .0273 L
.19827 .02662 L
.19842 .02613 L
.1985 .02592 L
.19858 .02576 L
.19867 .02564 L
.19876 .02557 L
.19891 .0256 L
.199 .02569 L
.19908 .02582 L
.19923 .02619 L
.19937 .02668 L
.19965 .02797 L
.19994 .02969 L
.20047 .03336 L
.20165 .04295 L
.20624 .08097 L
.2088 .09856 L
.21112 .1107 L
.21228 .11509 L
.21289 .11692 L
.21354 .11848 L
.2141 .11952 L
.21442 .11997 L
Mistroke
.21473 .1203 L
.21487 .12042 L
.215 .12052 L
.21512 .12059 L
.21525 .12065 L
.21539 .1207 L
.21553 .12073 L
.21568 .12074 L
.21582 .12072 L
.21597 .12069 L
.2161 .12064 L
.21625 .12056 L
.21641 .12045 L
.21673 .12014 L
.21703 .11977 L
.2176 .11879 L
.21814 .11755 L
.21934 .11372 L
.22065 .10786 L
.22303 .09288 L
.22557 .07149 L
.22794 .04763 L
.22898 .03684 L
.22957 .03124 L
.22985 .02896 L
.23012 .02727 L
.23025 .02664 L
.2304 .0262 L
.23054 .02604 L
.23067 .02612 L
.2308 .02643 L
.23095 .02703 L
.23111 .02791 L
.23125 .02893 L
.23183 .03418 L
.23245 .04096 L
.23496 .07142 L
.23734 .10005 L
.23994 .12827 L
.24245 .15058 L
.24355 .15829 L
.24473 .16503 L
.24537 .16792 L
.24595 .1701 L
.24651 .17173 L
.24682 .17244 L
.2471 .17297 L
.24741 .1734 L
.24757 .17359 L
.24773 .17372 L
Mistroke
.24787 .17381 L
.24801 .17386 L
.24816 .17389 L
.24831 .17389 L
.24847 .17384 L
.24856 .1738 L
.24864 .17375 L
.24878 .17364 L
.24894 .17348 L
.24927 .17302 L
.24964 .17231 L
.25027 .17054 L
.25088 .16827 L
.252 .16241 L
.25322 .15373 L
.25453 .14156 L
.25693 .112 L
.25947 .07113 L
.26061 .05023 L
.26124 .03862 L
.26155 .03329 L
.2617 .03096 L
.26183 .02912 L
.26197 .02764 L
.2621 .02676 L
.26224 .0265 L
.26238 .02707 L
.26254 .02847 L
.26261 .02943 L
.2627 .03063 L
.26299 .03557 L
.26404 .05813 L
.26893 .18278 L
.27363 .31114 L
.27863 .43771 L
.28113 .49162 L
.28344 .53342 L
.28569 .56545 L
.28682 .57808 L
.28807 .58911 L
.2887 .59347 L
.2893 .59688 L
.28983 .59934 L
.29041 .60135 L
.29075 .60218 L
.29105 .60273 L
.29121 .60296 L
.2913 .60306 L
.29139 .60315 L
.29147 .60321 L
Mistroke
.29156 .60326 L
.29172 .60331 L
.29188 .60331 L
.29202 .60327 L
.2921 .60323 L
.29219 .60317 L
.29235 .60302 L
.29249 .60283 L
.29265 .60258 L
.29293 .60202 L
.29322 .60127 L
.29352 .60031 L
.29406 .59813 L
.29464 .59513 L
.29528 .59109 L
.29642 .58188 L
.29748 .57113 L
.29995 .53855 L
.30219 .50067 L
.30701 .39881 L
.31165 .28616 L
.31659 .16685 L
.31904 .1126 L
.32134 .06707 L
.32247 .04714 L
.32302 .03819 L
.32354 .03079 L
.32383 .0274 L
.32399 .0259 L
.32413 .0249 L
.32422 .02452 L
.32429 .02431 L
.32438 .02424 L
.32446 .02434 L
.32461 .02491 L
.3247 .02542 L
.32478 .02599 L
.32532 .03147 L
.32591 .03836 L
.3283 .06462 L
.32956 .0757 L
.3309 .08517 L
.33209 .0916 L
.33272 .09428 L
.3334 .09661 L
.33402 .09825 L
.3343 .09882 L
.33459 .09935 L
.33486 .09973 L
.33514 .10005 L
Mistroke
.33529 .10019 L
.33544 .10029 L
.33558 .10037 L
.33571 .10042 L
.33585 .10046 L
.336 .10048 L
.33614 .10048 L
.33627 .10045 L
.33642 .1004 L
.33651 .10037 L
.33659 .10032 L
.33689 .10011 L
.33717 .09982 L
.33749 .09941 L
.33813 .09829 L
.33868 .09704 L
.33928 .0954 L
.34036 .09174 L
.34277 .08087 L
.34531 .06665 L
.34991 .0391 L
.35112 .03263 L
.35172 .02985 L
.35227 .02768 L
.35257 .02671 L
.3529 .02587 L
.35307 .02555 L
.35324 .02532 L
.35333 .02522 L
.35341 .02516 L
.3535 .0251 L
.35359 .02508 L
.35373 .02509 L
.35389 .02517 L
.35403 .02531 L
.35417 .02548 L
.35449 .02607 L
.35479 .02683 L
.35597 .03091 L
.35722 .03616 L
.35944 .04652 L
.36403 .07274 L
.36638 .09047 L
.3689 .11326 L
.37389 .16784 L
.3787 .22509 L
.38332 .27442 L
.38571 .29449 L
.38693 .30282 L
.38824 .31014 L
Mistroke
.38884 .31286 L
.38947 .3153 L
.39005 .31716 L
.39059 .31853 L
.3911 .31951 L
.39139 .31992 L
.39165 .32021 L
.39179 .32033 L
.39193 .32044 L
.39201 .32048 L
.39209 .32052 L
.39224 .32057 L
.39238 .32059 L
.39253 .32059 L
.39267 .32056 L
.3928 .32051 L
.39296 .32043 L
.3931 .32032 L
.39338 .32005 L
.39367 .31965 L
.39399 .3191 L
.39457 .31779 L
.3951 .31622 L
.39631 .31129 L
.3976 .30413 L
.39997 .28579 L
.40218 .26321 L
.40688 .2011 L
.41188 .12324 L
.41438 .08455 L
.41548 .06882 L
.41607 .06111 L
.41669 .05361 L
.4173 .04753 L
.41759 .0452 L
.41785 .04345 L
.41812 .04215 L
.41826 .04167 L
.41841 .04131 L
.41856 .04112 L
.41869 .04108 L
.41881 .04116 L
.41894 .04137 L
.41909 .04174 L
.41923 .04222 L
.41955 .0437 L
.41985 .04561 L
.42018 .04802 L
.42133 .05804 L
.42371 .08 L
Mistroke
.42497 .09018 L
.42631 .09935 L
.4275 .10589 L
.42813 .10873 L
.42881 .11129 L
.42943 .11315 L
.43 .11447 L
.43054 .11538 L
.43082 .1157 L
.43096 .11584 L
.43112 .11596 L
.43127 .11606 L
.43142 .11612 L
.43158 .11615 L
.43167 .11616 L
.43175 .11616 L
.4319 .11614 L
.43204 .1161 L
.43212 .11607 L
.4322 .11603 L
.43235 .11593 L
.43264 .11568 L
.43294 .11531 L
.43348 .11441 L
.43416 .11281 L
.4348 .11086 L
.436 .10611 L
.43843 .09258 L
.44066 .07649 L
.44312 .0568 L
.44433 .04788 L
.4449 .04433 L
.44543 .0417 L
.44569 .04069 L
.44597 .0399 L
.44612 .03961 L
.44625 .03941 L
.4464 .03929 L
.44649 .03927 L
.44656 .03927 L
.44669 .03933 L
.44681 .03945 L
.44695 .03965 L
.44709 .03995 L
.44738 .04079 L
.44764 .04181 L
.44822 .0448 L
.44886 .04886 L
.45001 .05741 L
.45236 .07588 L
Mistroke
.45495 .09367 L
.45613 .1002 L
.45741 .1058 L
.45802 .10793 L
.45861 .10959 L
.45913 .11075 L
.45943 .11128 L
.4597 .11167 L
.45998 .11199 L
.46013 .11212 L
.46029 .11222 L
.46042 .1123 L
.46055 .11234 L
.46069 .11237 L
.46084 .11238 L
.46092 .11237 L
.461 .11236 L
.46108 .11233 L
.46117 .1123 L
.46132 .11222 L
.46149 .11209 L
.4618 .11178 L
.46208 .11138 L
.46272 .11014 L
.4633 .10856 L
.46398 .10622 L
.46462 .10347 L
.46577 .09721 L
.46701 .08876 L
.46922 .06923 L
.47163 .04334 L
.47229 .03645 L
.47265 .03325 L
.47283 .03197 L
.47299 .03103 L
.47314 .03041 L
.47328 .03005 L
.47342 .02996 L
.47351 .03004 L
.47359 .0302 L
.47374 .03075 L
.47382 .03118 L
.4739 .03167 L
.47424 .03443 L
.47483 .04116 L
.47545 .04967 L
.47656 .06667 L
.47907 .1088 L
.48367 .18998 L
.48856 .26943 L
Mistroke
.49082 .30001 L
.49327 .32698 L
.49461 .33859 L
.49584 .34717 L
.49702 .35337 L
.49762 .35574 L
.49793 .35677 L
.49827 .35774 L
.4986 .3585 L
.4989 .35906 L
.49919 .35947 L
.49935 .35965 L
.4995 .35978 L
.49964 .35987 L
.49978 .35993 L
.49992 .35996 L
.50008 .35996 L
.50021 .35993 L
.50034 .35988 L
.50047 .3598 L
.50062 .35968 L
.50079 .3595 L
.50094 .3593 L
.5013 .3587 L
.50161 .35803 L
.50194 .35716 L
.50251 .35527 L
.50314 .35263 L
.50436 .3459 L
.50548 .33792 L
.50799 .31394 L
.51278 .24916 L
.51738 .17153 L
.51995 .12597 L
.52228 .08562 L
.52345 .06649 L
.52471 .04738 L
.52529 .03969 L
.5256 .03603 L
.5259 .03317 L
.52603 .03215 L
.52615 .03134 L
.52629 .03062 L
.52642 .03018 L
.52657 .02997 L
.5267 .03002 L
.52684 .03034 L
.527 .03097 L
.52713 .03173 L
.52728 .03277 L
Mistroke
.52759 .0353 L
.52813 .04072 L
.52934 .05412 L
.53155 .0766 L
.53391 .0952 L
.53523 .10274 L
.53582 .10538 L
.53643 .10772 L
.53701 .10946 L
.53731 .11021 L
.53764 .1109 L
.53794 .11141 L
.53821 .11179 L
.53834 .11193 L
.53848 .11207 L
.53861 .11217 L
.53875 .11226 L
.53883 .1123 L
.53892 .11233 L
.53899 .11235 L
.53908 .11237 L
.53922 .11238 L
.53938 .11236 L
.53946 .11234 L
.53954 .11231 L
.53963 .11227 L
.53972 .11222 L
.53988 .11211 L
.54005 .11196 L
.54035 .1116 L
.54067 .11111 L
.54125 .10993 L
.54184 .10834 L
.54238 .10657 L
.5436 .10149 L
.54581 .08891 L
.54829 .07088 L
.55059 .05283 L
.55114 .04888 L
.55173 .04504 L
.55201 .04351 L
.5523 .04209 L
.55255 .04107 L
.55281 .0402 L
.55297 .03981 L
.55312 .03954 L
.55327 .03936 L
.55341 .03927 L
.55349 .03926 L
.55357 .03928 L
Mistroke
.55372 .03938 L
.55381 .03949 L
.5539 .03963 L
.55406 .03997 L
.55434 .0408 L
.5546 .04181 L
.55519 .04483 L
.55637 .05288 L
.55747 .0615 L
.55996 .08122 L
.56221 .09663 L
.5634 .10326 L
.56466 .10892 L
.5653 .1112 L
.566 .11322 L
.5663 .11395 L
.56663 .11462 L
.56694 .11514 L
.56723 .11553 L
.56754 .11585 L
.56771 .11597 L
.56779 .11602 L
.56788 .11607 L
.56797 .11611 L
.56805 .11613 L
.5682 .11616 L
.56835 .11616 L
.5685 .11614 L
.56864 .1161 L
.56878 .11602 L
.56892 .11593 L
.56905 .11583 L
.56936 .1155 L
.56966 .11508 L
.57021 .11403 L
.57082 .11246 L
.57206 .10794 L
.5732 .10221 L
.57428 .09552 L
.57651 .07808 L
.57777 .06656 L
.57895 .05553 L
.57955 .05022 L
.58011 .04584 L
.58043 .04386 L
.58059 .04299 L
.58077 .04223 L
.58091 .04172 L
.58099 .04151 L
.58108 .04133 L
Mistroke
.58122 .04113 L
.58136 .04108 L
.58144 .04112 L
.58153 .04121 L
.58169 .04153 L
.58178 .04181 L
.58187 .04214 L
.58204 .0429 L
.58235 .04479 L
.58269 .04745 L
.58391 .06076 L
.58886 .13494 L
.59362 .20854 L
.59821 .26757 L
.60056 .29049 L
.60188 .30062 L
.60309 .3082 L
.60432 .31407 L
.60497 .31642 L
.60565 .31834 L
.60594 .31897 L
.60625 .31953 L
.60654 .31995 L
.60681 .32024 L
.60696 .32037 L
.60711 .32046 L
.60726 .32054 L
.60735 .32057 L
.60743 .32058 L
.60751 .32059 L
.60759 .32059 L
.60768 .32059 L
.60777 .32057 L
.60792 .32052 L
.608 .32048 L
.60808 .32043 L
.60823 .32032 L
.60839 .32017 L
.60868 .31983 L
.609 .31935 L
.60934 .31868 L
.60995 .31714 L
.61053 .31529 L
.61161 .31085 L
.61277 .30465 L
.61518 .28753 L
.61773 .26423 L
.62232 .21312 L
.6272 .15505 L
.63191 .10552 L
Mistroke
.63431 .08496 L
.63691 .06662 L
.64172 .04096 L
.64412 .03056 L
.6447 .02842 L
.64532 .02652 L
.64551 .02608 L
.64568 .02573 L
.64585 .02545 L
.64601 .02526 L
.64616 .02514 L
.64632 .02508 L
.64641 .02508 L
.64649 .0251 L
.64665 .0252 L
.64679 .02535 L
.64694 .02558 L
.64722 .02614 L
.64754 .02704 L
.64783 .02804 L
.64908 .03361 L
.6513 .04615 L
.65611 .07488 L
.65831 .08614 L
.65956 .09143 L
.66074 .09544 L
.66129 .09698 L
.66188 .09832 L
.66219 .0989 L
.66253 .09944 L
.66283 .09983 L
.66312 .10012 L
.66328 .10024 L
.66345 .10035 L
.66361 .10042 L
.66376 .10046 L
.66391 .10048 L
.664 .10048 L
.66409 .10047 L
.66417 .10046 L
.66425 .10044 L
.66435 .1004 L
.66443 .10036 L
.66458 .10028 L
.66474 .10016 L
.66502 .09988 L
.66535 .09943 L
.66566 .09892 L
.66625 .0976 L
.66687 .09576 L
Mistroke
.66798 .09127 L
.66918 .08466 L
.67049 .07525 L
.67285 .05272 L
.67417 .0375 L
.67474 .03074 L
.67507 .02731 L
.67523 .02593 L
.67538 .02496 L
.67553 .02437 L
.67567 .02425 L
.67581 .02464 L
.6759 .02507 L
.67597 .0256 L
.67614 .02702 L
.67628 .0286 L
.67661 .0328 L
.67795 .05419 L
.68037 .10045 L
.6852 .20904 L
.68985 .32331 L
.69479 .4396 L
.69725 .49024 L
.69955 .53078 L
.70176 .56224 L
.70299 .57618 L
.70413 .58663 L
.70535 .59512 L
.706 .59841 L
.70633 .59977 L
.70669 .601 L
.707 .60185 L
.70728 .60246 L
.70755 .6029 L
.70769 .60306 L
.70784 .60319 L
.70793 .60325 L
.70801 .60328 L
.70816 .60332 L
.70824 .60332 L
.70832 .6033 L
.70841 .60327 L
.7085 .60323 L
.70865 .60311 L
.70879 .60296 L
.70895 .60274 L
.70911 .60246 L
.70942 .60179 L
.70975 .60086 L
.71033 .59864 L
Mistroke
.71103 .59509 L
.71167 .59102 L
.71291 .58064 L
.71409 .5681 L
.71651 .53414 L
.71874 .49414 L
.72351 .38607 L
.72809 .26433 L
.73297 .13224 L
.73522 .07551 L
.73641 .04805 L
.73672 .04137 L
.73706 .03475 L
.73721 .03204 L
.73738 .02956 L
.73751 .02791 L
.73767 .02677 L
.73783 .02653 L
.73791 .02683 L
.738 .02735 L
.73815 .02893 L
.7383 .03091 L
.739 .04293 L
.74023 .06574 L
.74266 .10602 L
.74508 .13735 L
.74615 .14821 L
.7473 .15774 L
.74791 .16189 L
.74847 .16514 L
.74904 .16791 L
.74957 .17 L
.75018 .17186 L
.7505 .1726 L
.75067 .17291 L
.75085 .1732 L
.75102 .17343 L
.75117 .1736 L
.75132 .17373 L
.75148 .17382 L
.75162 .17387 L
.75176 .1739 L
.7519 .17389 L
.75206 .17384 L
.75221 .17376 L
.75229 .17371 L
.75237 .17364 L
.7527 .17327 L
.75298 .17282 L
.75329 .1722 L
Mistroke
.75399 .17029 L
.75463 .16794 L
.75587 .16182 L
.75706 .15422 L
.75944 .13429 L
.76166 .11137 L
.76638 .05491 L
.76762 .04017 L
.76827 .03315 L
.76863 .02987 L
.7688 .02852 L
.76896 .02749 L
.76911 .02674 L
.76925 .02627 L
.7694 .02605 L
.76949 .02605 L
.76957 .02615 L
.76972 .02654 L
.76981 .02689 L
.76989 .02729 L
.77023 .02957 L
.77079 .03456 L
.7714 .04068 L
.77377 .06507 L
.77636 .08822 L
.77755 .09707 L
.77883 .10507 L
.78003 .11113 L
.78114 .11542 L
.78174 .11723 L
.78237 .11873 L
.78268 .11931 L
.78301 .11982 L
.7832 .12006 L
.78337 .12025 L
.78353 .1204 L
.78371 .12053 L
.78387 .12062 L
.78402 .12068 L
.78417 .12072 L
.78431 .12074 L
.78439 .12074 L
.78447 .12073 L
.78462 .1207 L
.7847 .12067 L
.78478 .12064 L
.78496 .12054 L
.78511 .12044 L
.78526 .12031 L
.78553 .12003 L
Mistroke
.78614 .11911 L
.7867 .11797 L
.78731 .11636 L
.78855 .11208 L
.79077 .10114 L
.79311 .08582 L
.79562 .0661 L
.798 .04591 L
.79925 .03553 L
.79994 .03046 L
.80028 .02837 L
.80043 .02759 L
.80059 .02685 L
.80075 .02628 L
.80089 .02588 L
.80105 .02563 L
.80114 .02557 L
.80122 .02556 L
.8013 .02561 L
.80138 .0257 L
.80147 .02586 L
.80156 .02608 L
.80172 .02658 L
.80189 .02729 L
.8025 .03074 L
.80307 .03473 L
.80538 .05227 L
.8076 .06797 L
.81004 .08206 L
.8112 .0874 L
.81245 .09199 L
.81314 .09402 L
.81377 .09553 L
.8144 .09674 L
.81471 .09721 L
.815 .09759 L
.81529 .0979 L
.81555 .09812 L
.81569 .09822 L
.81585 .0983 L
.81593 .09834 L
.81601 .09837 L
.81617 .09842 L
.81624 .09843 L
.81633 .09845 L
.81648 .09845 L
.81663 .09844 L
.81677 .09842 L
.81691 .09837 L
.81708 .0983 L
Mistroke
.81725 .09821 L
.81741 .0981 L
.81769 .09785 L
.81797 .09755 L
.81848 .09684 L
.81903 .09585 L
.81963 .09452 L
.82076 .09128 L
.82202 .08667 L
.82455 .07442 L
.82708 .05909 L
.8294 .04347 L
.83058 .03557 L
.83168 .02903 L
.83196 .02765 L
.83223 .02657 L
.83238 .02608 L
.83254 .02565 L
.83268 .02537 L
.83282 .02521 L
.83297 .02514 L
.83311 .02519 L
.83326 .02536 L
.83335 .02551 L
.83343 .02567 L
.83376 .02666 L
.83407 .02796 L
.83523 .03434 L
.83646 .04207 L
.83868 .05567 L
.8411 .06846 L
.84237 .07399 L
.84371 .07881 L
.84491 .08219 L
.84559 .08368 L
.84623 .08479 L
.84682 .08556 L
.84709 .08585 L
.84735 .08607 L
.84765 .08627 L
.8478 .08634 L
.84797 .08641 L
.84811 .08645 L
.84824 .08648 L
.84839 .08649 L
.84855 .08649 L
.84863 .08649 L
.84871 .08647 L
.84885 .08644 L
.84901 .08639 L
Mistroke
.84918 .08632 L
.84949 .08614 L
.84977 .08592 L
.85041 .08521 L
.8511 .08416 L
.85225 .08171 L
.85352 .07807 L
.85587 .06896 L
.85839 .05639 L
.86078 .04277 L
.86204 .03546 L
.86273 .03166 L
.86338 .02846 L
.86366 .02729 L
.86395 .02624 L
.8641 .02578 L
.86427 .02537 L
.86442 .02509 L
.86456 .02491 L
.86465 .02485 L
.86473 .02481 L
.86482 .02481 L
.8649 .02483 L
.86504 .02494 L
.8652 .02516 L
.86528 .02531 L
.86536 .0255 L
.86552 .0259 L
.86587 .02708 L
.86708 .03273 L
.86818 .03874 L
.87067 .05218 L
.87298 .06302 L
.87521 .07122 L
.87646 .07464 L
.87759 .07698 L
.87818 .07789 L
.8785 .0783 L
.8788 .07863 L
.87908 .07888 L
.87933 .07907 L
.87961 .07923 L
.87976 .0793 L
.87991 .07936 L
.88006 .07939 L
.88021 .07942 L
.88029 .07943 L
.88038 .07943 L
.88054 .07943 L
.88068 .07941 L
Mistroke
.88084 .07938 L
.88097 .07934 L
.88112 .07929 L
.88144 .07911 L
.88179 .07886 L
.88242 .07821 L
.88307 .07731 L
.88366 .07626 L
.885 .07316 L
.88618 .06963 L
.88743 .06515 L
.89201 .04373 L
.89331 .03685 L
.89455 .03061 L
.89509 .02821 L
.89567 .02612 L
.89596 .02532 L
.89613 .02498 L
.89621 .02485 L
.89629 .02475 L
.89644 .02461 L
.89657 .02456 L
.89672 .02458 L
.89688 .02469 L
.89703 .02488 L
.89711 .02502 L
.89719 .02517 L
.89749 .02591 L
.89805 .02784 L
.8993 .03356 L
.90156 .04496 L
.90401 .05635 L
.90631 .06504 L
.90744 .06842 L
.90851 .07103 L
.9091 .07222 L
.90974 .07329 L
.91033 .07406 L
.91087 .0746 L
.91119 .07484 L
.91149 .07501 L
.91164 .07508 L
.91181 .07514 L
.91189 .07517 L
.91198 .07519 L
.91207 .07521 L
.91215 .07522 L
.9123 .07523 L
.91244 .07523 L
.9126 .07521 L
Mistroke
.91268 .0752 L
.91277 .07518 L
.91291 .07514 L
.91307 .07508 L
.91335 .07495 L
.91362 .07477 L
.91392 .07453 L
.91452 .07389 L
.91508 .07312 L
.91559 .07226 L
.91686 .06953 L
.91806 .06622 L
.9203 .05826 L
.92494 .03679 L
.92618 .03088 L
.92679 .02828 L
.92734 .02628 L
.92764 .02544 L
.92778 .02512 L
.92792 .02484 L
.92808 .02462 L
.92822 .02448 L
.92831 .02442 L
.92839 .0244 L
.92855 .02442 L
.92863 .02445 L
.92871 .02452 L
.9288 .02461 L
.92888 .02472 L
.92903 .02497 L
.92919 .02531 L
.92955 .0263 L
.92988 .02743 L
.93469 .04961 L
.93689 .05863 L
.93815 .06294 L
.93932 .06634 L
.94047 .06903 L
.94171 .07117 L
.94236 .07196 L
.94271 .0723 L
.94303 .07255 L
.94331 .07272 L
.94361 .07285 L
.94378 .0729 L
.94387 .07293 L
.94395 .07294 L
.94409 .07296 L
.94425 .07297 L
.9444 .07297 L
Mistroke
.94454 .07295 L
.94467 .07293 L
.94481 .07289 L
.94496 .07284 L
.94513 .07277 L
.94542 .07261 L
.94594 .07221 L
.94651 .0716 L
.94713 .07074 L
.9478 .06959 L
.94901 .06694 L
.95142 .05959 L
.95396 .04936 L
.95637 .0382 L
.95742 .03324 L
.95856 .0283 L
.95886 .02715 L
.95919 .02608 L
.95949 .02528 L
.95964 .02496 L
.95977 .02472 L
.95991 .02453 L
.96003 .02441 L
.96017 .02433 L
.96032 .02432 L
.96047 .02438 L
.96055 .02444 L
.96063 .02452 L
.96078 .02473 L
.96092 .02498 L
.96123 .0257 L
.96155 .02669 L
.96213 .02885 L
.96345 .03468 L
.96803 .0552 L
.97038 .06336 L
.9717 .06688 L
.97291 .06935 L
.97372 .07061 L
.97448 .07146 L
.97487 .07179 L
.9751 .07193 L
.97531 .07205 L
.97553 .07214 L
.97564 .07217 L
.97576 .07221 L
.97587 .07223 L
.97597 .07224 L
.97608 .07225 L
.97619 .07226 L
Mistroke
Mfstroke
1 0 0 r
[ ] 0 setdash
.05556 .01472 m
.05556 .07296 L
s
.0873 .01472 m
.0873 .07519 L
s
.11905 .01472 m
.11905 .07935 L
s
.15079 .01472 m
.15079 .08631 L
s
.18254 .01472 m
.18254 .09806 L
s
.21429 .01472 m
.21429 .11979 L
s
.24603 .01472 m
.24603 .17035 L
s
.27778 .01472 m
.27778 .41774 L
s
.30952 .01472 m
.30952 .33869 L
s
.34127 .01472 m
.34127 .08802 L
s
.37302 .01472 m
.37302 .15759 L
s
.40476 .01472 m
.40476 .23116 L
s
.43651 .01472 m
.43651 .10371 L
s
.46825 .01472 m
.46825 .07841 L
s
.5 .01472 m
.5 .35996 L
s
.53175 .01472 m
.53175 .07841 L
s
.56349 .01472 m
.56349 .10371 L
s
.59524 .01472 m
.59524 .23116 L
s
.62698 .01472 m
.62698 .15759 L
s
.65873 .01472 m
.65873 .08802 L
s
.69048 .01472 m
.69048 .33869 L
s
.72222 .01472 m
.72222 .41774 L
s
.75397 .01472 m
.75397 .17035 L
s
.78571 .01472 m
.78571 .11979 L
s
.81746 .01472 m
.81746 .09806 L
s
.84921 .01472 m
.84921 .08631 L
s
.88095 .01472 m
.88095 .07935 L
s
.9127 .01472 m
.9127 .07519 L
s
.94444 .01472 m
.94444 .07296 L
s
.97619 .01472 m
.97619 .07226 L
s
.015 w
.05556 .07296 Mdot
.0873 .07519 Mdot
.11905 .07935 Mdot
.15079 .08631 Mdot
.18254 .09806 Mdot
.21429 .11979 Mdot
.24603 .17035 Mdot
.27778 .41774 Mdot
.30952 .33869 Mdot
.34127 .08802 Mdot
.37302 .15759 Mdot
.40476 .23116 Mdot
.43651 .10371 Mdot
.46825 .07841 Mdot
.5 .35996 Mdot
.53175 .07841 Mdot
.56349 .10371 Mdot
.59524 .23116 Mdot
.62698 .15759 Mdot
.65873 .08802 Mdot
.69048 .33869 Mdot
.72222 .41774 Mdot
.75397 .17035 Mdot
.78571 .11979 Mdot
.81746 .09806 Mdot
.84921 .08631 Mdot
.88095 .07935 Mdot
.9127 .07519 Mdot
.94444 .07296 Mdot
.97619 .07226 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<oooool3o`0002kooooo1Ol0000]ooooo`;o0000;_ooool5o`00033ooooo0ol0000Roooo
o`00=?ooool00ol0003oooooooooo`0^ooooo`04o`000?ooooooooooo`0002cooooo00Co0000oooo
oooooooo0000;_ooool01?l0003oooooooooool0000aooooo`03o`000?oooooooooo027ooooo000[
ooooo`Go000000?oooooo`000?l000000ol0000Xooooo`Go00000oooool00ol0003oooooooooo`0/
ooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool0;_ooool5o`0002;ooooo000a
ooooo`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool0:oooool01?l0003ooooooooo
ool0000`ooooo`03o`000?oooooooooo02gooooo00Co0000oooooooooooo00008oooool003;ooooo
00?o0000ooooool00000;oooool01Ol0003ooooooooooooooooo000002cooooo00Co0000oooooooo
oooo0000;Oooool01Ol0003ooooooooooooooooo000002oooooo00?o0000ooooool000008oooool0
03?ooooo0_l0000_ooooo`05o`000?ooooooooooooooool00000;?ooool01?l0003oooooooooool0
000]ooooo`05o`000?ooooooooooooooool00000<?ooool2o`0002?ooooo000dooooo`03o`000?oo
oooooooo02kooooo0ol0000^ooooo`;o0000;oooool3o`0003;ooooo00?o0000ooooooooool08Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0017oooooool0
000=o`0000?ooooo000:ooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo007ooooo0009ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00Oooool0
00Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`23ooooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool3
o`0000cooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00;ooooo0ol00003ooooo`002Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00cooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00Cooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0<ooooo`04ool00?ooooooooooooooo`;o003o0oooool00ooo003ooooooooo
o`05ooooo`05ool00?ooooooooooooooool00?l01?ooool00ooo003oooooooooo`05ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`05ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Gooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool01Ooo003ooooooooooooooooo003o00?o
oooo00Goo`00ooooooooooooooooo`00o`03ooooo`03ool00?oooooooooo00Cooooo00?o0000oooo
ooooool00Oooool000[ooooo0_l00005ooooo`03o`000?oooooooooo00Sooooo00Go003ooooooooo
ooooooooool00003ooooo`;o003o0oooool01Ooo003ooooooooooooooooo003o00?ooooo00Coo`00
oooooooooooooooo0_l00?l3ooooo`05ool00?ooooooooooooooool00?l00oooool00ooo003ooooo
ooooo`02ooooo`05o`00oooooooooooooooooooo00000oooool01Ol00?ooooooooooooooooooo`00
00?ooooo00Go003oooooooooooooooooool00008ooooo`05ool00?ooooooooooooooool00?l00ooo
ool00ooo003oooooooooo`02o`00o`Cooooo00?oo`00ooooooooool01Oooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003ooooooooo
o`05ooooo`03ool00?oooooooooo00;ooooo0_l00?l2ooooo`05ool00?ooooooooooooooool00?l0
0oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00Goo`00oooooooooooo
ooooo`00o`04ooooo`05ool00?ooooooooooooooool00?l00oooool01?oo003oooooooooooooool2
o`00o`?ooooo00?oo`00ooooooooool00_l00?l3ooooo`04ool00?ooooooooooooooo`;o003o0ooo
ool00ooo003oooooooooo`02o`00o`?ooooo00Coo`00oooooooooooooooo0_l00?l2ooooo`03ool0
0?oooooooooo00Cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01ooo
ool2o`00o`?ooooo00?oo`00ooooooooool00_ooool01Ol00?ooooooooooooooooooo`0000?ooooo
00Go003oooooooooooooooooool00003ooooo`;o003o0oooool01Ooo003ooooooooooooooooo003o
00?ooooo00?oo`00ooooooooool00_ooool01Ol00?ooooooooooooooooooo`0000?ooooo00Go003o
ooooooooooooooooool00003ooooo`05o`00oooooooooooooooooooo00002?ooool01Ooo003ooooo
oooooooooooo003o00?ooooo00Goo`00ooooooooooooooooo`00o`04ooooo`03ool00?oooooooooo
00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01?ooool00ol00?ooo`00ooooo`07ooooo`03ool00?oooooooooo
00Gooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`03ooooo`04o`00oooooooooooo
ool000?ooooo0_l00?l2ooooo`03ool00?oooooooooo00Kooooo00Goo`00ooooooooooooooooo`00
o`03ooooo`03ool00?oooooooooo00;ooooo00Go003oooooooooooooooooool00003ooooo`05o`00
oooooooooooooooooooo00001?ooool01Ol00?ooooooooooooooooooo`0000;ooooo00?o003ooooo
ool00?l00_ooool00ooo003oooooooooo`02ooooo`05o`00oooooooooooooooooooo00000oooool0
1Ol00?ooooooooooooooooooo`0000Cooooo00Co003oooooooooooooo`001_ooool00ol0003ooooo
ooooo`01ooooo`004Oooool2o`0000Sooooo00?o003oooooool00?l00_ooool00ooo003ooooooooo
o`06ooooo`06ool00?ooooooooooo`00oooooooo003o0_ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00;o003o0oooool01?oo003oooooooooooooool2o`00o`?ooooo00Goo`00oooo
ooooooooooooo`00o`03ooooo`05ool00?ooooooooooooooool00?l00oooool00ooo003ooooooooo
o`06ooooo`05ool00?ooooooooooooooool00?l00oooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool0
0?oooooo003o00Kooooo00?oo`00ooooooooool00oooool2o`00o`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool01Oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo
00Coo`00oooooooooooooooo0_l00?l2ooooo`03ool00?oooooooooo00Kooooo00Goo`00oooooooo
ooooooooo`00o`03ooooo`04ool00?ooooooooooooooo`;o003o0oooool00ooo003oooooooooo`02
o`00o`?ooooo00Coo`00oooooooooooooooo0_l00?l3ooooo`03ool00?oooooooooo00;o003o0ooo
ool01?oo003oooooooooooooool2o`00o`?ooooo00Coo`00oooooooooooo003o1?ooool00ooo003o
ooooooooo`05ooooo`03ool00?oooooooooo00?ooooo0_l00003ooooo`004Oooool00ol0003ooooo
ooooo`07ooooo`03o`00oooooooo003o00;ooooo00Coo`00oooooooooooo003o0_ooool01?l00?oo
oooooooooooo0002ooooo`03o`00oooooooooooo00;ooooo00Koo`00oooooooooooo003oooooool0
0?l3ooooo`03ool00?oooooooooo00;o003o0oooool01?oo003oooooooooooooool2o`00o`?ooooo
00Goo`00ooooooooooooooooo`00o`03ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`02o`00o`?ooooo00Coo`00oooooooooooo003o1Oooool00ooo
003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooool00?l01Oooool00ooo
003o003oo`00o`06ooooo`03ool00?oooooooooo00Cooooo00?o003oool00?ooool01oooool00ooo
003oooooooooo`05ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool00_ooool01Ol0
0?ooooooooooooooooooo`0000?ooooo0_l00?l2ooooo`03ool00?oooooooooo00Kooooo00Goo`00
ooooooooooooooooo`00o`03ooooo`04ool00?ooooooooooooooo`;o003o0oooool00ooo003ooooo
ooooo`02o`00o`?ooooo00Goo`00ooooooooooooooooo`00o`04ooooo`03ool00?oooooooooo00;o
oooo00Co003oooooooooooooo`000_ooool00ol00?ooooooooooo`03ooooo`04ool00?oooooooooo
o`00o`Cooooo00Koo`00oooooooooooo003oooooool00?l2ooooo`03ool00?oooooooooo00Cooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool03?ooool01?oo003ooooooooo
ool00?l2ooooo`04o`00ooooooooooooool000;ooooo00?o003oooooooooool00_ooool01_oo003o
ooooooooool00?ooooooo`00o`?ooooo00?oo`00ooooooooool00_ooool01?l00?oooooooooooooo
0003ooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool00_l00?l3ooooo`04ool00?oo
ooooooooooooo`;o003o0_ooool00ooo003oooooooooo`06ooooo`04ool00?ooooooooooo`00o`Co
oooo00Koo`00oooooooooooo003oooooool00?l3ooooo`03ool00?oooooooooo00Gooooo00Goo`00
ooooooooooooooooo`00o`04ooooo`04ool00?oooooo003oo`00o`Cooooo00?oo`00o`00ool00?l0
1_ooool00ooo003oooooooooo`04ooooo`03o`00oooo003ooooo00Oooooo00Goo`00oooooooooooo
ooooo`00o`03ooooo`03ool00?oooooooooo00Gooooo00Goo`00ooooooooooooooooo`00o`02oooo
o`03o`00ooooooooo`0000Cooooo00Co003oooooooooooooo`002?ooool01Ooo003ooooooooooooo
oooo003o00?ooooo00Goo`00ooooooooooooooooo`00o`04ooooo`04ool00?ooooooooooo`00o`Co
oooo00Coo`00oooooooooooo003o1Oooool00ooo003oooooooooo`02ooooo`04o`00oooooooooooo
ool000;ooooo00?o003oooooooooool00oooool01_oo003oooooooooool00?ooooooo`00o`;ooooo
00Koo`00oooooooooooo003oooooool00?l2ooooo`03ool00?oooooooooo00Cooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool02_ooool00ol00?ooooooool00002ooooo`04
o`00ooooooooooooo`00o`;ooooo00?oo`00ooooooooool00_ooool01?l00?oooooooooooooo0002
ooooo`03o`00oooooooo003o00?ooooo00Coo`00oooooooooooo003o1?ooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00;o003o0oooool01?oo003oooooooooooooool2o`00o`;ooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo003o00;ooooo
00Go003oooooooooooooooooool00007ooooo`05ool00?ooooooooooooooool00?l01?ooool00ooo
003oooooo`00o`05ooooo`03ool00?l00?oooooo00Kooooo00?oo`00ooooooooool00oooool2o`00
o`03ool00?oooooooooo00;ooooo0_l00?l2ooooo`04ool00?ooooooooooooooo`;o003o0_ooool0
0ooo003oooooooooo`05ooooo`05ool00?ooooooooooooooool00?l00_ooool00ol00?ooooooool0
0003ooooo`05o`00oooooooooooooooooooo00002?ooool01Ooo003ooooooooooooooooo003o00?o
oooo00?oo`00ooooooooool01_ooool01_oo003oooooooooool00?ooooooo`00o`;ooooo00Koo`00
oooooooooooo003oooooool00?l3ooooo`04ool00?ooooooooooo`00o`Cooooo00?oo`00oooooooo
ool00oooool01_l00?oooooooooooooo003oooooo`00o`;ooooo00Co003oooooooooooooo`000_oo
ool01_l00?ooooooooooool00?ooooooool000Kooooo00?o0000ooooooooool00Oooool0017ooooo
00?o0000ooooooooool01_ooool01ol00?oooooooooooooooooo003ooooooooo00000_ooool01?l0
0?ooooooooooool00?l2ooooo`03ool00?oooooooooo00;ooooo00Co003oooooooooooooo`000_oo
ool01?l00?ooooooooooool00?l2ooooo`04ool00?ooooooooooo`00o`Cooooo00?oo`00oooooooo
ool00_ooool01Ol00?ooooooooooooooooooo`0000;ooooo0_l00?l3ooooo`04ool00?oooooooooo
ooooo`;o003o0_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00;o003o0oooool0
0ooo003oooooooooo`02ooooo`05o`00oooooooooooooooooooo00001oooool00ooo003ooooooooo
o`02o`00o`Cooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00?ooooo00?o003ooooooooo00001?ooool2o`00o`;ooooo00Coo`00oooooooooooooooo
0_l00?l2ooooo`03ool00?oooooooooo00Gooooo00Goo`00ooooooooooooooooo`00o`02ooooo`03
o`00ooooooooo`0000?ooooo00Go003oooooooooooooooooool00008ooooo`05ool00?oooooooooo
ooooool00?l00oooool00ooo003oooooooooo`02ooooo`05o`00oooooooooooooooooooo00001?oo
ool01?l00?oooooooooooooo0004ooooo`05o`00oooooooooooooooooooo00000_ooool00ol00?oo
ooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00Co003oooooooooooooo`001?ooool01?l0
0?oooooooooooooo0002ooooo`06o`00ooooooooooooo`00ooooooooo`001_ooool00ol0003ooooo
ooooo`01ooooo`004Oooool2o`0000Oooooo00Oo003oooooooooooooooooo`00ooooooooo`0000So
oooo00?oo`00ooooool00?l00oooool00ol00?ooooooool00008ooooo`03ool00?oooooo003o00;o
oooo00Co003oooooooooooooo`000_ooool00ol00?ooooooo`00o`03ooooo`04ool00?oooooooooo
o`00o`Cooooo00Goo`00ooooooooooooooooo`00o`03ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool00_l00?l3ooooo`03ool00?oooooooooo00;ooooo00Go003ooooooooooooooooo
ool00007ooooo`05ool00?ooooooooooooooool00?l01?ooool01?oo003oooooooooool00?l4oooo
o`03ool00?oooooo003o00Kooooo00?oo`00ooooooooool00oooool2o`00o`03ool00?oooooooooo
00;ooooo00Go003oooooool00?ooooooool00003ooooo`;o003o0_ooool00ooo003oooooooooo`05
ooooo`03ool00?oooooooooo00Kooooo00Coo`00oooooooooooooooo0_l00?l2ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool00_l00?l3ooooo`04ool00?ooooooooooooooo`;o003o
0oooool01_oo003oooooooooool00?ooooooo`00o`;ooooo00Coo`00oooooooooooo003o0_ooool0
1_l00?oooooooooooooo003oooooo`00o`;ooooo00Co003oooooooooooooo`000_ooool01?l00?oo
ooooooooool00?l2ooooo`03ool00?oooooo003o00?ooooo00?o003ooooooooo00001oooool00ooo
003oooooooooo`03ooooo`;o00000oooool0017ooooo00?o0000ooooooooool01_ooool02Ol00?oo
oooooooooooooooo003ooooooooo003oooooo`00o`06ooooo`03ool00?oooooo003o00Gooooo00?o
o`00ooooooooool00oooool01_l00?oooooooooooooo003oooooo`00o`;ooooo00Co003ooooooooo
ooooo`000_ooool01?l00?ooooooooooool00?l2ooooo`03ool00?oooooooooo00Gooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`06ooooo`06ool00?ooooooooooo`00oooooooo003o
0_ooool00ooo003oooooo`00o`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0
0_ooool02?l00?ooooooooooooooooooo`00o`00oooooooo003o1?ooool00ooo003o003oo`00o`06
ooooo`03ool00?oooooooooo00?ooooo0_l00?l00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00;ooooo00Co003oooooooooooooo`001oooool01Ooo003ooooooooooooooooo003o00Cooooo
00Coo`00oooooooooooooooo0_l00?l2ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool00_l00?l3ooooo`04ool00?ooooooooooooooo`;o003o0oooool01_oo003oooooooooool00?oo
ooooo`00o`;ooooo00Coo`00oooooooooooo003o0_ooool01_l00?oooooooooooooo003oooooo`00
o`;ooooo00Co003oooooooooooooo`000_ooool01?l00?ooooooooooool00?l2ooooo`03ool00?oo
oooo003o00Gooooo00?oo`00ooooool00?l00oooool00ol00?ooooooool00006ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool00oooool0
0ooo003oooooo`00o`04ooooo`05o`00ooooooooo`00ooooool00?l01Oooool00ooo003oooooo`00
o`03ooooo`04o`00ooooooooooooool000Gooooo00?o003ooooooooo00000_ooool00ol00?oooooo
ooooo`03ooooo`03ool00?oooooooooo00;ooooo00Co003oooooooooooooo`000oooool2o`00o`;o
oooo00?oo`00ooooooooool01_ooool01?oo003oooooooooool00?l4ooooo`03ool00?oooooo003o
00?ooooo00Co003oooooooooooooo`001oooool01_oo003oooooooooool00?ooooooo`00o`?ooooo
00Coo`00o`00oooooooo003o1?ooool00ooo003o003oo`00o`06ooooo`03ool00?oooooooooo00Go
oooo00?oo`00ooooooooool01_ooool01?oo003oooooooooool00?l4ooooo`03ool00?oooooooooo
00Gooooo00Goo`00ooooooooooooooooo`00o`03ooooo`03o`00oooo003ooooo00?ooooo00Co003o
ooooooooooooo`002?ooool00ooo003oooooooooo`02o`00o`?ooooo00Goo`00oooooooooooooooo
o`00o`04ooooo`03ool00?oooooo003o00Gooooo00Coo`00oooooooooooo003o1Oooool00ooo003o
ooooooooo`03ooooo`05o`00ooooooooo`00ooooool00?l01_ooool00ooo003oooooo`00o`03oooo
o`05o`00ooooooooo`00ooooool00?l00oooool00ol00?ooooooool00006ooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo00cooooo00?oo`00ooooool00?l01?ooool00ol0
0?ooooooool00005ooooo`05o`00ooooooooo`00ooooool00?l01?ooool00ol00?ooooooool00007
ooooo`04ool00?ooooooooooo`00o`Gooooo00Koo`00oooooooooooo003oooooool00?l2ooooo`04
ool00?ooooooooooooooo`;o003o0_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Gooooo00?oo`00o`00ooooool00oooool01?l00?oooooooooooooo0007ooooo`04ool00?oooooo
ooooo`00o`Gooooo00?oo`00o`00ooooool01Oooool00ooo003oooooo`00o`06ooooo`03ool00?oo
oooooooo00?ooooo00?o003ooooooooo00001?ooool01Ol00?ooooooo`00ooooooooo`0000;ooooo
00?o003oooooool00?l00_ooool00ooo003oooooooooo`05ooooo`04ool00?ooooooooooo`00o`Co
oooo00?o003oool00?ooool01_ooool00ooo003oooooooooo`06ooooo`04ool00?ooooooooooo`00
o`Cooooo00Coo`00oooooooooooo003o1Oooool00ooo003oooooo`00o`05ooooo`03ool00?oooooo
003o00?ooooo00Ko003oooooooooooooo`00ooooool00?l5ooooo`03ool00?oooooooooo00Cooooo
00Co003ooooooooo003o003o1?ooool01Ol00?ooooooool00?oooooo003o00Cooooo00?o003oool0
0?ooool01Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`05ooooo`03
o`00oooooooooooo00?ooooo00Co003oool00?oooooo003o1?ooool00ol00?ooooooool00005oooo
o`05o`00ooooooooo`00ooooool00?l01?ooool01Ol00?ooooooool00?oooooo003o00Gooooo00?o
o`00ooooooooool00oooool01?l00?oooooooooooooo0002ooooo`03o`00oooooooo003o00;ooooo
00Coo`00oooooooooooooooo0_l00?l2ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool00_ooool01Ol00?oooooooooooooo003o003o00Cooooo00Co003oooooooooooooo`001oooool0
1?oo003oooooooooool00?l5ooooo`03ool00?l00?oooooo00Gooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`03ooooo`03o`00ooooooooo`0000Cooooo00Go003oooooool00?oooooo
ool00002ooooo`03o`00oooooooo003o00;ooooo00?oo`00ooooooooool01Oooool01?oo003ooooo
ooooool00?l4ooooo`05o`00oooo003oooooooooool00?l01?ooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00;ooooo00Co003oooooooooooooo`001Oooool01?l00?oooooooooooooo
0004ooooo`;o003o00?oooooool00?ooool01?ooool01Ol00?oooooooooooooo003o003o00Kooooo
00?oo`00ooooooooool01?ooool00ol00?ooooooool00006ooooo`03o`00oooo003o003o00Gooooo
00?o003oool00?ooool01Oooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000Gooooo00?o
003oooooooooool01?ooool3ool000Gooooo0ooo00000ol00?ooooooooooo`03ooooo`03o`00oooo
003ooooo00Oooooo00?oo`00ooooool00?l00oooool01Ol00?ooooooool00?oooooo003o00?ooooo
00Go003oooooooooooooo`00ooooo`02o`00o`Cooooo00?oo`00ooooooooool00ol00?l2ooooo`03
ool00?oooooooooo00Kooooo00Koo`00oooooooooooo003oooooool00?l2ooooo`03ool00?oooooo
oooo00?ooooo00Co003oooooooooooooo`001oooool01_oo003oooooooooool00?ooooooo`00o`?o
oooo00Goo`00ooooooooooooooooo`00o`03ooooo`03ool00?oooooo003o00Kooooo00?oo`00oooo
ooooool00oooool00ol00?ooooooool00003ooooo`06o`00ooooooooooooo`00ooooooooo`000_oo
ool00ol00?ooooooo`00o`02ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Ooo
ool01ol00?ooo`00oooooooooooo003oooooool00?l00_ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00;ooooo00Co003oooooooooooooo`000_ooool01?l00?ooooooooooool00?l2
ooooo`03ool00?oooooooooo00?ooooo00Go003ooooooooo003oooooo`00o`03ooooo`05o`00oooo
ooooooooool00?l00?l01Oooool00ol00?ooo`00o`00o`05ooooo`?oo`001_ooool3ool000Gooooo
0ooo0004ooooo`;o00000oooool0017ooooo00?o0000ooooooooool02oooool3ool000Gooooo0ooo
0006ooooo`?oo`001oooool00ooo003o003oooooo`03ooooo`05o`00ooooooooo`00ooooool00?l0
0oooool01?l00?oooooooooooooo0007ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo
ool01_ooool01_oo003oooooooooool00?ooooooo`00o`;ooooo00?oo`00o`00ooooool01_ooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo00;ooooo00Ko003oooooooooooooooooool0
0?l00?l2ooooo`03o`00oooooooooooo00?oo`0000?o003oooooooooool01?ooool00ooo003ooooo
ooooo`03ooooo`04o`00oooo003oo`00ool000;ooooo00Ko003ooooooooooooo003ooooooooo0004
ooooo`04o`00ooooooooooooool000Oooooo00Coo`00oooooooooooo003o1Oooool01_oo003ooooo
ooooool00?ooooooo`00o`;ooooo00?oo`00ooooooooool01_ooool01_oo003oooooooooool00?oo
ooooo`00o`;ooooo00Coo`00oooooooooooo003o0_ooool01_l00?oooooooooooooo003oooooo`00
o`?ooooo00Go003ooooooooo003oooooo`00o`04ooooo`04o`00ooooooooo`00o`00o`Gooooo0ooo
0005ooooo`?oo`001_ooool3ool000Gooooo0ooo0005ooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo00_ooooo0ooo0005ooooo`?oo`001_ooool3ool000Gooooo0_l00?l0
0ooo003oooooooooo`03ooooo`05o`00ooooooooo`00ooooool00?l01_ooool00ooo003ooooooooo
o`02ooooo`04o`00ooooooooooooool000Cooooo00Co003oooooooooooooo`002?ooool01?oo003o
ooooooooool00?l4ooooo`03ool00?l00?oooooo00Kooooo00?oo`00ooooooooool01Oooool01_oo
003oooooooooool00?ooooooo`00o`?ooooo00?oo`00o`00ooooool01?ooool3ool00003ooooool0
0?oooooo00Cooooo00?oo`00ooooooooool01?ooool3ool000Oooooo00?oo`00ooooooooool01Ooo
ool00ooo003oooooooooo`05ooooo`04ool00?ooooooooooo`00o`Cooooo00?o003oool00?ooool0
0oooool01?l00?oooooooooooooo0008ooooo`06ool00?ooooooooooo`00oooooooo003o0_ooool0
1?oo003oooooooooool00?l2ooooo`06o`00ooooooooooooool00?oooooo003o1Oooool00ooo003o
ooooo`00o`06ooooo`03ool00?oooooooooo00Cooooo0ooo0005ooooo`?oo`001_ooool3ool000Go
oooo0ooo0005ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01cooooo
0ooo0005ooooo`?oo`001_ooool01?l00?ooo`00ooooool00?l6ooooo`03ool00?oooooo003o00;o
oooo00Co003oooooooooooooo`000_ooool00ol00?ooooooo`00o`02ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01Oooool00ooo003o003oooooo`04ooooo`03o`00ooooooooo`00
00Oooooo00Coo`00oooooooooooo003o1Oooool01Ooo003ooooooooooooooooo003o00;ooooo0ooo
00000ooooooo003oooooo`04ooooo`03ool00?oooooooooo00Cooooo0ooo0002ooooo`06o`00oooo
ooooooooooooool00?ooo`000_ooool00ol00?ooooooooooo`02ooooo`03ool00?oooooooooo00Go
oooo00?oo`00ooooool00?l01Oooool00ol00?ooo`00ooooo`03ooooo`04o`00ooooooooooooool0
00Sooooo00Coo`00oooooooooooo003o1?ooool01?oo003oooooooooool00?l5ooooo`03ool00?oo
oooo003o00Gooooo00?oo`00ooooool00?l01?ooool3ool000Kooooo0ooo000Nooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo02Cooooo0ooo0007ooooo`03ool00?oooooo
oooo00Cooooo00Go003ooooooooo003oooooo`00o`02ooooo`04o`00ooooooooooooool000;ooooo
00?o003oooooool00?l00_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00?ooooo
00Co003oool00?oo003oo`001Oooool00ol00?ooooooool00007ooooo`04ool00?ooooooooooo`00
o`Gooooo00Goo`00ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Kooooo00?oo`00
ooooooooool00oooool00ol00?ooooooooooo`03ooooo`06o`00ooooooooooooooooool00?ooo`00
0_ooool00ol00?ooooooo`00o`02ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooool00?l0
1?ooool3ool000;ooooo00?o003oooooooooool00_ooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Gooooo00?oo`00ooooooooool00oooool01?l00?oooooooooooooo0005ooooo`03
o`00ooooooooo`0000Kooooo0ooo000Wooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000
9Oooool3ool000Kooooo00?o003oool00?l00?l01Oooool01Ol00?ooooooool00?oooooo003o00;o
oooo00Co003oooooooooooooo`000_ooool00ol00?ooooooo`00o`02ooooo`03ool00?oooooooooo
00Kooooo00Coo`00oooooooooooo003o0_ooool01?l00?ooo`00ool00?oo0005ooooo`03o`00oooo
ooooo`0000Oooooo00Coo`00oooooooooooo003o0_ooool01?l00?oooooooooooooo0004ooooo`03
o`00oooooooooooo00Wooooo00?oo`00ooooooooool00oooool00ol00?ooooooooooo`03ooooo`06
o`00ooooooooooooooooool00?ooo`000_ooool00ol00?ooooooo`00o`02ooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool01?ooool3ool00005ooooool00?ooooooooooool00?l00_oo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00;ooooo00Co003oooooooooooooo`00
1Oooool01?l00?oooooooooooooo0006ooooo`03o`00oooo003ooooo00Gooooo0ooo000Vooooo`;o
00000oooool0017ooooo00?o0000ooooooooool0;Oooool3ool000Gooooo00Go003ooooooooo003o
ooooo`00o`05ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool01?oo003o
ooooooooool00?l2ooooo`04o`00oooo003oo`00ool000Oooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooooooo`03ooooo`04o`00ooooooooooooool000Oooooo00Co003ooooooooooooo003o
1Oooool00ooo003oooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00_ooool01_l00?oo
oooooooooooooooo003oool000Gooooo00?o003ooooooooo00001oooool00ooo003oooooooooo`04
ooooo`?oo`0000Goooooo`00ooooooooooooo`00o`02ooooo`03ool00?oooooooooo00Kooooo00Ko
o`00oooooooooooo003oooooool00?l2ooooo`04ool00?ooooooooooo`00o`?ooooo00Co003ooooo
oooo003o003o1Oooool3ool002oooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool0;Oooool3ool000Gooooo00?o003ooooooooo00001Oooool00ol00?ooooooool00007oooo
o`03ool00?oooooooooo00Kooooo00Coo`00oooooooooooo003o0_ooool3o`00o`Sooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`03ooooo`04o`00ooooooooooooool000Kooooo00Go
003oooooooooooooooooo`00o`05ooooo`03ool00?oooooooooo00Kooooo00?o003oooooooooool0
1Oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooool00?l0
1oooool2o`00o`?ooooo00?o003ooooooooo00002?ooool01_oo003oooooooooool00?ooooooo`00
o`;ooooo00Coo`00oooooooooooo003o0oooool01?l00?ooooooool00?l00?l5ooooo`?oo`00;ooo
ool00ol0003oooooooooo`01ooooo`000oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooo
oooo02gooooo0ooo0007ooooo`03ool00?l00?oooooo00?ooooo00?o003ooooooooo00000_ooool0
0ol00?ooooooo`00o`02ooooo`03ool00?oooooooooo00Kooooo00Coo`00oooooooooooo003o0ooo
ool00ol00?ooooooooooo`05ooooo`03o`00ooooooooo`0000Oooooo00?oo`00ooooool00?l01?oo
ool3ool000Cooooo00?o003oooooool00?l00oooool00ol00?ooooooooooo`03ooooo`03ool00?oo
oooooooo00Kooooo00?o003oooooooooool00oooool3ool00003ooooool00?oooooo00Cooooo00?o
o`00ooooooooool01Oooool00ooo003oooooo`00o`07ooooo`03o`00oooooooooooo00;ooooo00?o
003ooooooooo00002?ooool01?oo003oooooooooool00?l4ooooo`03ool00?oooooo003o00Kooooo
00?oo`00o`00ooooool01?ooool3ool002oooooo00?o0000ooooooooool00Oooool000Cooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03Gooooo
00Co003ooooooooo003o003o1?ooool00ol00?ooooooool00002ooooo`03o`00oooooooo003o00;o
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0<ooooo`03o`00ooooooooo`0000Oo
oooo00?oo`00ooooool00?l01?ooool3ool000Cooooo00?o003oooooool00?l02Oooool00ooo003o
ooooooooo`02ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`03ooooo`?oo`0000?ooooo
o`00ooooool00_ooool00ol00?ooooooool00007ooooo`03ool00?oooooo003o00kooooo00?oo`00
ooooooooool01_ooool01?oo003oooooooooool00?l4ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool0=_ooool00ol0003oooooooooo`01ooooo`001?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Cooooo0ol0000fooooo`03o`00oooo003o003o00Cooooo00?o
003ooooooooo00000_ooool00ol00?ooooooo`00o`02ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooool00?l03Oooool00ol00?ooo`00ooooo`06ooooo`03ool00?oooooo003o00?ooooo00Co
003oool00?oo003oo`001?ooool2o`00o`[ooooo00?oo`00ooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`;o003o0oooool3ool00003ooooool00?oooooo00;ooooo00?o003ooooooooo0000
1oooool00ooo003oooooo`00o`0>ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
0_ooool01?l00?oooooooooooooo0006ooooo`03o`00ooooooooo`0003Kooooo0ol00003ooooo`00
1?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0=_ooool00ol00?ooo`00o`00o`06ooooo`04ool00?ooooooooooo`00o`Cooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooo`00o`0=ooooo`03o`00oooo003ooooo00Kooooo00?oo`00oooo
ooooool01?ooool2o`00o`Kooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`03oooo
o`03ool00?oooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooo003o00?ooooo00?o003ooooooooo00001oooool00ooo003oooooo`00o`0<oooo
o`03o`00ooooooooo`0000Sooooo00Koo`00oooooooooooo003oooooool00?l2ooooo`03ool00?oo
oooo003o00Cooooo00?o003ooooooooo0000>?ooool00ol0003oooooooooo`01ooooo`001?ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0=Ooo
ool3ool000Oooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooo003o00kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`04ooooo`;o003o2ooo
ool00ol00?ooooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?o003oooooooooool03ooo
ool00ol00?ooooooool00007ooooo`03ool00?l00?oooooo00cooooo00?o003ooooooooo00002?oo
ool01_oo003oooooooooool00?ooooooo`00o`;ooooo00?oo`00ooooool00?l01?ooool3ool003So
oooo00?o0000ooooooooool00Oooool000?ooooo0_l00004ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0=Oooool3ool000Gooooo00?o003ooooooooo00000_ooool00ol00?oo
ooooo`00o`02ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooool00?l03Oooool00ol00?oo
o`00ooooo`06ooooo`03ool00?oooooo003o017ooooo00?o003oooooooooool00oooool00ooo003o
ooooooooo`0Fooooo`03ool00?oooooooooo00Gooooo00?oo`00o`00ooooool03?ooool00ol00?oo
ooooool00008ooooo`06ool00?ooooooooooo`00oooooooo003o0_ooool00ooo003oooooo`00o`04
ooooo`?oo`00>?ooool00ol0003oooooooooo`01ooooo`001?ooool00ol0003oooooooooo`03oooo
o`;o00001Oooool00ol0003oooooooooo`0eooooo`?oo`001Oooool00ol00?ooooooool00002oooo
o`03o`00oooooooo003o00;ooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0=oooo
o`03o`00oooo003ooooo00Kooooo00?oo`00ooooool00?l04Oooool00ol00?ooooooooooo`03oooo
o`03ool00?oooooooooo00;ooooo00?o003oooooooooool03oooool00ol00?ooooooool00007oooo
o`03ool00?oooooooooo00kooooo00?oo`00ooooooooool01_ooool01?oo003oooooooooool00?l4
ooooo`03ool00?oooooo003o00Cooooo0ooo000hooooo`03o`000?oooooooooo007ooooo000Aoooo
o`;o0000?_ooool01Ol00?ooooooool00?oooooo003o00;ooooo00Co003oooooooooooooo`002?oo
ool00ooo003oooooooooo`0=ooooo`03o`00oooo003ooooo00Kooooo00?oo`00ooooool00?l05ooo
ool00ooo003oooooooooo`02ooooo`03o`00oooooooooooo00oooooo00?o003ooooooooo00001ooo
ool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool00ooo
ool00ol00?ooooooool00010ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0?oooool0
0ooo003oooooo`00o`02ooooo`04o`00ooooooooooooool000Sooooo00?oo`00ooooool00?l03Ooo
ool00ol00?ooo`00ooooo`06ooooo`03ool00?oooooo003o017ooooo00?o003oooooooooool00ooo
ool00ooo003oooooooooo`02ooooo`03o`00oooooooooooo00oooooo00?o003ooooooooo00001ooo
ool00ooo003o003oooooo`0<ooooo`03o`00ooooooooo`0000Sooooo00?oo`00ooooooooool00ooo
ool01Ol00?ooooooool00?oooooo003o03oooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool0?oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooool00?l03_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo017ooooo00?o
003oooooooooool00oooool00ooo003oooooooooo`02ooooo`03o`00oooooooooooo00oooooo00?o
003ooooooooo00001oooool00ooo003o003oooooo`0<ooooo`03o`00ooooooooo`0000Sooooo00Co
o`00oooooooooooo003o0_ooool01Ol00?ooooooool00?oooooo003o03oooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool0?_ooool00ol00?ooo`00ooooo`04ooooo`03o`00
ooooooooo`0000Sooooo00?oo`00ooooool00?l03Oooool00ol00?ooo`00ooooo`06ooooo`03ool0
0?oooooo003o01;ooooo00?o003oooooooooool00_ooool00ooo003oooooooooo`0Fooooo`03ool0
0?oooooooooo00Gooooo00?oo`00o`00ooooool03?ooool00ol00?ooooooool00008ooooo`04ool0
0?ooooooooooo`00o`;ooooo00Go003ooooooooo003oooooo`00o`0oooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo03kooooo00Co003oool00?oooooo003o0oooool00ol0
0?ooooooool00008ooooo`03ool00?oooooooooo00gooooo00?o003oool00?ooool01_ooool00ooo
003oooooo`00o`0Booooo`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ol0
0?ooooooooooo`0Aooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool03?ooool00ol0
0?ooooooool00008ooooo`04ool00?ooooooooooo`00o`Cooooo00?oo`00o`00ooooool0?oooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0nooooo`04o`00oooo003ooooo
o`00o`?ooooo00?o003ooooooooo00002?ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooool00?l05oooool00ooo003oooooooooo`02ooooo`03o`00oooooooo
oooo00oooooo00?o003ooooooooo00001oooool00ooo003oooooooooo`0>ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0oooooo`03o`000?oooooo
oooo007ooooo000Aooooo`;o0000@?ooool00ooo003oooooo`00o`03ooooo`03o`00ooooooooo`00
00Sooooo00?oo`00ooooool00?l03_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo003o
01Oooooo00Goo`00ooooooooooooooooo`00o`0Booooo`03o`00ooooooooo`0000Oooooo00?oo`00
o`00ooooool03?ooool00ol00?ooooooool00008ooooo`03ool00?oooooooooo00?ooooo00?o003o
oooooooo0000@?ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo03oooooo00?oo`00oooo
ooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo003o00cooooo0ooo0007oooo
o`03ool00?oooooooooo01;ooooo00?o003oooooooooool00_ooool01Ooo003ooooooooooooooooo
003o01?ooooo00?o003oool00?ooool01Oooool3ool000gooooo00?o003ooooooooo00002?ooool0
0ooo003oooooo`00o`03ooooo`04o`00ooooooooo`00o`00od3ooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0?_ooool00ol00?ooo`00ooooo`06ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooool00?l03?ooool3ool000Oooooo00?oo`00ooooooooool04_ooool0
0ol00?ooooooooooo`02ooooo`03ool00?oooooooooo01Kooooo00?oo`00ooooooooool01?ooool3
ool000gooooo00?o003ooooooooo00002?ooool00ooo003oooooo`00o`03ooooo`04o`00oooooooo
o`00o`00od3ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0?_ooool0
1?l00?ooo`00ooooool00?l3ooooo`03o`00ooooooooo`0000Sooooo00?oo`00ooooool00?l03?oo
ool3ool000Oooooo00?oo`00o`00ooooool04_ooool00ol00?ooooooooooo`02ooooo`03ool00?oo
oooooooo01Kooooo00?oo`00ooooooooool01?ooool3ool000gooooo00?o003ooooooooo00002?oo
ool00ooo003oooooo`00o`05ooooo`03ool00?l00?oooooo03oooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0?oooool00ooo003oooooo`00o`03ooooo`03o`00oooooooo
o`0000Sooooo00?oo`00ooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03ool00?l00?oo
oooo01Oooooo00Goo`00ooooooooooooooooo`00o`0Cooooo`03o`00oooo003ooooo01Oooooo00?o
o`00ooooooooool01_ooool00ooo003oooooo`00o`05ooooo`03ool00?oooooooooo03oooooo00?o
0000ooooooooool00Oooool0017ooooo0_l0000oooooo`?oo`001?ooool00ol00?ooooooool00008
ooooo`03ool00?oooooo003o00kooooo00?o003oooooooooool01Oooool00ooo003o003oooooo`0G
ooooo`05ool00?ooooooooooooooool00?l04oooool00ol00?ooo`00ooooo`06ooooo`03o`00oooo
oooooooo00kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`04ooooo`?oo`00?ooo
ool2o`0000?ooooo000Aooooo`03o`000?oooooooooo03kooooo0ooo0006ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooool00?l05_ooool00ooo003oooooooooo`0Booooo`03o`00oooooooo
oooo00;ooooo00Goo`00ooooooooooooooooo`00o`0Cooooo`03o`00oooo003ooooo00Kooooo00?o
003oooooooooool03?ooool00ol00?ooooooool00008ooooo`03ool00?oooooo003o00Cooooo0ooo
0010ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo03kooooo0ooo0006
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooool00?l05_ooool00ooo003oooooooooo`0B
ooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool05Oooool00ol00?ooo`00ooooo`06
ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo00002?ooool00ooo003oooooo`00o`04
ooooo`?oo`00@?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`15oooo
o`03o`00ooooooooo`0000Sooooo00?oo`00ooooool00?l03_ooool00ol00?ooooooooooo`05oooo
o`03ool00?l00?oooooo01;ooooo00?o003oooooooooool00_ooool00ooo003oooooooooo`0Foooo
o`03ool00?oooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooo`00ooooo`07oooo
o`03ool00?oooooo003o04Oooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0AOooool00ol00?ooooooool00008ooooo`03ool00?oooooooooo00kooooo00?o003ooooooooo
ool01Oooool00ooo003o003oooooo`0Booooo`03o`00oooooooooooo00;ooooo00Goo`00oooooooo
ooooooooo`00o`0Cooooo`03o`00oooo003ooooo01Oooooo00?oo`00ooooooooool01_ooool00ooo
003oooooo`00o`17ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000A_ooool00ol00?oo
ooooool00008ooooo`03ool00?oooooooooo00oooooo00?o003oooooooooool01?ooool00ooo003o
003oooooo`0Gooooo`05ool00?ooooooooooooooool00?l04oooool00ol00?ooo`00ooooo`0Goooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0A_ooool2o`0000?ooooo000Aooooo`03
o`000?oooooooooo04Gooooo00?o003ooooooooo00002?ooool00ooo003o003oooooo`0?ooooo`03
o`00oooooooooooo00Cooooo00?oo`00o`00ooooool04_ooool00ol00?ooooooooooo`02ooooo`05
ool00?ooooooooooooooool00?l04oooool00ol00?ooo`00ooooo`06ooooo`03o`00oooooooooooo
00gooooo00?o003oool00?ooool01oooool00ooo003oooooooooo`17ooooo`03o`000?oooooooooo
007ooooo0002ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0Aoooool00ooo003o
ooooooooo`06ooooo`03ool00?l00?oooooo01Kooooo00?oo`00ooooooooool04_ooool00ol00?oo
ooooooooo`02ooooo`05ool00?ooooooooooooooool00?l04oooool00ol00?ooo`00ooooo`06oooo
o`03o`00oooooooooooo00gooooo00?o003oool00?ooool01oooool00ooo003oooooo`00o`17oooo
o`03o`000?oooooooooo007ooooo0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`15ooooo`03o`00ooooooooo`0000Sooooo00?oo`00
o`00ooooool03oooool00ol00?ooooooooooo`04ooooo`03ool00?l00?oooooo01;ooooo00?o003o
ooooooooool00_ooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo00Cooooo00?o003o
ooooooooool03_ooool00ol00?ooo`00ooooo`07ooooo`03ool00?oooooo003o04Oooooo00?o0000
ooooooooool00Oooool000Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo04Gooooo00?o003ooooooooo00002?ooool00ooo003oooooooooo`0?
ooooo`03o`00oooooooooooo00Cooooo00?oo`00o`00ooooool04_ooool00ol00?ooooooooooo`02
ooooo`05ool00?ooooooooooooooool00?l05?ooool00ooo003oooooooooo`0Eooooo`03o`00oooo
003ooooo00Oooooo00?oo`00ooooool00?l0Aoooool00ol0003oooooooooo`01ooooo`001Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool3o`0004Gooooo00?o
003ooooooooo00002?ooool00ooo003oooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o
o`00o`00ooooool05oooool01Ooo003ooooooooooooooooo003o01?ooooo00?o003oool00?ooool0
5oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo04Gooooo0ol00003ooooo`000_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`15ooooo`03o`00ooooooooo`0000Sooooo00?oo`00o`00ooooool03oooool00ol00?oo
ooooooooo`04ooooo`03ool00?l00?oooooo01Oooooo00Goo`00ooooooooooooooooo`00o`0Doooo
o`03ool00?oooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooo`00ooooo`07oooo
o`03ool00?oooooooooo04Oooooo00?o0000ooooooooool00Oooool000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Aoooool0
0ooo003oooooooooo`06ooooo`03ool00?l00?oooooo01Kooooo00?oo`00ooooooooool04oooool0
1Ol00?ooooooooooooooooooo`0000?ooooo00?o003oooooooooool04_ooool00ooo003ooooooooo
o`04ooooo`03o`00oooooooooooo00kooooo00?o003oool00?ooool01oooool00ooo003oooooo`00
o`17ooooo`03o`000?oooooooooo007ooooo0003ooooo`?o00001?ooool2o`0000Gooooo00?o0000
ooooooooool0Aoooool00ooo003oooooooooo`06ooooo`03ool00?l00?oooooo01Kooooo00?oo`00
ooooooooool04oooool01Ol00?ooooooooooooooooooo`0001Sooooo00?oo`00ooooooooool01?oo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooo003ooooo00Oooooo00?oo`00ooooool00?l0Aooo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`15ooooo`03o`00oooooooo
o`0000Sooooo00?oo`00o`00ooooool03oooool00ol00?ooooooooooo`04ooooo`03ool00?oooooo
oooo01?ooooo00Go003oooooooooooooooooool0000Hooooo`03ool00?oooooooooo01Gooooo00?o
003oool00?ooool01oooool00ooo003oooooo`00o`17ooooo`03o`000?oooooooooo007ooooo000A
ooooo`;o0000A_ooool00ol00?ooooooool00008ooooo`03ool00?oooooooooo00oooooo00?o003o
ooooooooool01?ooool00ooo003oooooooooo`0Gooooo`04ool00?ooooooooooo`00oaGooooo00?o
o`00ooooooooool05_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo003o04Kooooo0_l0
0003ooooo`004Oooool00ol0003oooooooooo`15ooooo`03o`00ooooooooo`0000Sooooo00?oo`00
o`00ooooool03oooool00ol00?ooooooooooo`03ooooo`?oo`006?ooool01?oo003oooooooooool0
0?lDooooo`?oo`001Oooool00ol00?ooooooooooo`0?ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool0Aoooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`17
ooooo`03ool00?oooooooooo00Kooooo00?oo`00o`00ooooool05Oooool3ool001Cooooo00Go003o
ooooooooooooooooool00002ooooo`03o`00oooooooooooo01;ooooo0ooo0005ooooo`03o`00oooo
oooooooo00kooooo00?o003oool00?ooool01oooool00ooo003oooooo`00o`17ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo04Oooooo00?oo`00ooooooooool01_ooool0
0ooo003o003oooooo`0Eooooo`?oo`005?ooool01Ol00?ooooooooooooooooooo`0001Oooooo0ooo
0005ooooo`03o`00oooooooooooo00kooooo00?o003oool00?ooool01oooool00ooo003oooooo`00
o`17ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04Kooooo00?o003o
ool00?ooool01oooool00ooo003o003oooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool04oooool01Ol00?ooooooooooooooooooo`0001oooooo00?o003oooooooooool03_oo
ool00ol00?ooo`00ooooo`07ooooo`03ool00?oooooo003o04Oooooo00?o0000ooooooooool00Ooo
ool0017ooooo0_l00017ooooo`03o`00oooo003ooooo00Oooooo00?oo`00ooooooooool04?ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01?ooooo00Go003oooooooooooooooooool0
0002ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool05_ooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooo003o04Kooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`16
ooooo`03o`00oooo003ooooo00Oooooo00?oo`00ooooooooool04?ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo01Oooooo00Coo`00oooooooooooo003o5Oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo013ooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`17ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04Kooooo00?o003o
ool00?ooool01oooool00ooo003o003oooooo`0@ooooo`03o`00oooooooooooo01Wooooo00Go003o
ooooooooooooooooool00002ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooo003ooooo00Oooooo00?oo`00o`00ooooool0Aooo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`17ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00o`00ooooool0;?ooool01Ol00?ooooooooooooooooooo`0000;ooooo00?o
003oooooooooool04oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o
003oool00?ooool01oooool00ooo003o003oooooo`17ooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo04Kooooo00?o003oool00?ooool01oooool00ooo003o003oooooo`0@
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04oooool01Ol00?oooooooooooooo
ooooo`0001kooooo00?o003oooooooooool03oooool00ol00?ooo`00ooooo`07ooooo`03ool00?l0
0?oooooo04Oooooo00?o0000ooooooooool00Oooool0017ooooo0_l00017ooooo`03o`00oooo003o
oooo00Oooooo00?oo`00ooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo01?ooooo00Go003oooooooooooooooooool00002ooooo`03o`00oooooooooooo02_ooooo00?o
003oool00?ooool01oooool00ooo003o003oooooo`16ooooo`;o00000oooool0017ooooo00?o0000
ooooooooool0A_ooool00ol00?ooo`00ooooo`07ooooo`03ool00?oooooooooo013ooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0Gooooo`04ool00?ooooooooooo`00oaKooooo00?o
003oooooooooool05Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo04Oooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0A_ooool00ol00?ooo`00ooooo`07
ooooo`03ool00?l00?oooooo013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0E
ooooo`06o`00ooooooooooooool00?oooooo003o5oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo013ooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`17ooooo`03o`00
0?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04Oooooo00?oo`00ooooooooool01_oo
ool00ooo003o003oooooo`0]ooooo`06o`00ooooooooooooool00?oooooo003o5oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?oo`00ooooooooool01_ooool00ooo003o
003oooooo`17ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04Oooooo
00?oo`00ooooooooool01_ooool00ooo003o003oooooo`0Eooooo`03o`00oooooooooooo01Gooooo
00Co003oooooooooooooo`007Oooool00ol00?ooooooooooo`0Aooooo`03ool00?oooooooooo00Ko
oooo00?oo`00o`00ooooool0Aoooool00ol0003oooooooooo`01ooooo`004Oooool2o`0004Oooooo
00?o003oool00?ooool01oooool00ooo003o003oooooo`0Aooooo`05o`00ooooooooooooooooool0
0?l06_ooool00ooo003oooooooooo`0_ooooo`03ool00?oooooooooo00Kooooo00?oo`00o`00oooo
ool0A_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo04Kooooo00?o003oool00?ooool0
1oooool00ooo003oooooooooo`0Aooooo`05o`00ooooooooooooooooool00?l06_ooool00ooo003o
ooooo`00o`0Gooooo`03o`00oooooooooooo01Gooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`17ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04Kooooo
00?o003oool00?ooool01oooool00ooo003oooooooooo`0Aooooo`05o`00ooooooooooooooooool0
0?l05oooool01_l00?oooooooooooooo003oooooo`00oaOooooo00Go003oooooooooooooooooo`00
o`0Cooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0Aoooool00ol0003ooooooooo
o`01ooooo`000oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo04Oooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`0]ooooo`06o`00ooooooooooooool00?oooooo003o
6?ooool01?l00?ooooooooooool00?lCooooo`03ool00?oooooooooo00Kooooo00?oo`00o`00oooo
ool0Aoooool00ol0003oooooooooo`01ooooo`000_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`17ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool0;Oooool01?l00?oooooooooooooo000Mooooo`03o`00oooooooo
oooo017ooooo00?oo`00ooooooooool01_ooool00ooo003o003oooooo`17ooooo`03o`000?oooooo
oooo007ooooo0006ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool3
o`0004Kooooo00?o003oool00?ooool01oooool00ooo003oooooooooo`0Aooooo`04o`00oooooooo
ooooo`00oa_ooooo00?oo`00ooooooooool06oooool00ol00?ooooooooooo`0Aooooo`03ool00?oo
oooooooo00Kooooo00?oo`00o`00ooooool0AOooool3o`0000?ooooo0004ooooo`;o00000oooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo04Kooooo00?o003oool00?ooool01ooo
ool00ooo003oooooooooo`0Aooooo`04o`00ooooooooooooo`00oa_ooooo00?oo`00ooooool00?l0
6?ooool00ol00?ooooooooooo`0Dooooo`03ool00?oooooooooo00Kooooo00?oo`00o`00ooooool0
Aoooool00ol0003oooooooooo`01ooooo`001_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0A_ooool00ol00?ooo`00ooooo`07ooooo`03ool0
0?oooooooooo01;ooooo00?o003oooooool00?l06?ooool01_l00?oooooooooooooo003oooooo`00
oaSooooo00?o003oooooool00?l05?ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
04Oooooo00?o0000ooooooooool00Oooool000;ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0A_ooool00ol00?ooo`00ooooo`07
ooooo`03ool00?oooooooooo02gooooo00Ko003oooooooooooooo`00ooooool00?lHooooo`03o`00
oooooooo003o01Cooooo00?oo`00ooooooooool01_ooool00ooo003o003oooooo`17ooooo`03o`00
0?oooooooooo007ooooo0003ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0Aooo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01;ooooo00?o003oooooooooool06Ooo
ool01Ol00?ooooooool00?oooooo003o01Sooooo00?o003oooooool00?l05?ooool00ooo003ooooo
ooooo`06ooooo`03ool00?l00?oooooo04Oooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool0A_ooool00ol00?ooo`00ooooo`07ooooo`03ool00?oooooooooo01;ooooo0ol0
0?lIooooo`03o`00ooooooooo`0001cooooo00?o003oooooooooool04_ooool00ooo003ooooooooo
o`06ooooo`03ool00?l00?oooooo04Oooooo00?o0000ooooooooool00Oooool0017ooooo0_l00017
ooooo`03o`00oooo003ooooo00Oooooo00?oo`00ooooooooool0<?ooool00ooo003o003oooooo`0_
ooooo`03ool00?oooooooooo00Kooooo00?oo`00o`00ooooool0A_ooool2o`0000?ooooo000Aoooo
o`03o`000?oooooooooo04Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0^oooo
o`04o`00ooooooooo`00o`00oc3ooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`17
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04Oooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`0^ooooo`04o`00ooooooooo`00o`00oc3ooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`17ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo04Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0^oooo
o`04o`00ooooooooo`00o`00oc3ooooo00?oo`00ooooooooool01_ooool00ooo003o003oooooo`17
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04Oooooo00?oo`00oooo
ooooool01?ooool3ool0033ooooo00?o003ooooooooo0000<?ooool3ool000Oooooo00?oo`00o`00
ooooool0Aoooool00ol0003oooooooooo`01ooooo`004Oooool2o`0004Sooooo00?oo`00oooooooo
ool01?ooool3ool003;ooooo00?oo`00ooooooooool0;_ooool3ool000Oooooo00?oo`00o`00oooo
ool0A_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo04Oooooo00?oo`00ooooooooool0
1?ooool3ool003;ooooo00?oo`00o`00ooooool0;_ooool3ool000Oooooo00?oo`00ooooooooool0
Aoooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`17ooooo`03ool00?oo
oooooooo00Kooooo00?o003oooooooooool0;_ooool01?l00?ooooooool00?l00?liooooo`03ool0
0?oooooooooo04Oooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Aooo
ool00ooo003oooooooooo`06ooooo`03o`00oooooooooooo02oooooo00?o003oool00?ooool0<?oo
ool00ol00?ooooooooooo`06ooooo`03ool00?oooooooooo04Oooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0Aoooool00ooo003oooooooooo`06ooooo`03o`00oooooooo
oooo02kooooo0ooo000aooooo`03o`00oooooooooooo00Kooooo00?oo`00ooooooooool0Aoooool0
0ol0003oooooooooo`01ooooo`004Oooool2o`0004Sooooo00?oo`00ooooooooool01_ooool00ol0
0?ooooooooooo`0^ooooo`?oo`00<_ooool00ol00?ooooooooooo`05ooooo`03ool00?oooooooooo
04Kooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`17ooooo`03ool00?oooooooooo03Oo
oooo0ooo000jooooo`03ool00?oooooooooo04Oooooo00?o0000ooooooooool00Oooool0017ooooo
00?o0000ooooooooool0Aoooool00ooo003oooooooooo`0iooooo`03o`000?oooooooooo03Sooooo
00?oo`00ooooooooool0Aoooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`17ooooo`03ool00?oooooooooo00Kooooo00?o003oooooooooool0<?ooool00ol0003ooooooooo
o`0`ooooo`03o`00oooooooooooo00Gooooo00?oo`00ooooooooool0Aoooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`17ooooo`03ool00?oooooooooo00Kooooo00?o003o
ooooooooool0<?ooool00ol0003oooooooooo`0`ooooo`03o`00oooooooooooo00Gooooo00?oo`00
ooooooooool0Aoooool00ol0003oooooooooo`01ooooo`004Oooool2o`0004Sooooo00?oo`00oooo
ooooool01Oooool00ol00?ooooooooooo`0aooooo`03o`000?oooooooooo033ooooo00?o003ooooo
ooooool01Oooool00ooo003oooooooooo`16ooooo`;o00000oooool0017ooooo00?o0000oooooooo
ool0Aoooool00ooo003oooooooooo`0iooooo`03o`000?oooooooooo033ooooo00?o003ooooooooo
ool01Oooool00ooo003oooooooooo`17ooooo`03o`000?oooooooooo007ooooo0004ooooo`?o0000
0oooool2o`0000Gooooo00?o0000ooooooooool0Aoooool00ooo003oooooooooo`0iooooo`03o`00
0?oooooooooo03Sooooo00?oo`00ooooooooool0Aoooool00ol0003oooooooooo`01ooooo`001Ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`17ooooo`03ool00?oooooooooo00Gooooo00?o003oooooooooool0<Oooool00ol0003ooooo
ooooo`0`ooooo`03o`00oooooooooooo00Gooooo00?oo`00ooooooooool0Aoooool00ol0003ooooo
ooooo`01ooooo`000_ooool5o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`17ooooo`03ool00?oooooooooo00Gooooo00?o003oooooooooool0<Oooool00ol0003ooooo
ooooo`0`ooooo`03o`00oooooooooooo00Gooooo00?oo`00ooooooooool0Aoooool00ol0003ooooo
ooooo`01ooooo`000_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000Co
oooo0ol00017ooooo`03ool00?oooooooooo00Gooooo00?o003oooooooooool0<Oooool00ol0003o
ooooooooo`0`ooooo`03o`00oooooooooooo00Gooooo00?oo`00ooooooooool0AOooool3o`0000?o
oooo0003ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`17ooooo`03ool00?oooooooooo00Gooooo00?o003oooooooooool0<Oooool00ol0003o
ooooooooo`0`ooooo`03o`00oooooooooooo00Gooooo00?oo`00ooooooooool0Aoooool00ol0003o
ooooooooo`01ooooo`001?ooool2o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`17ooooo`03ool00?oooooooooo03Wooooo00?o0000ooooooooool0>?ooool00ooo003o
ooooooooo`17ooooo`03o`000?oooooooooo007ooooo0005ooooo`03o`000?oooooooooo00;ooooo
0_l00005ooooo`03o`000?oooooooooo04Oooooo00?oo`00ooooooooool01Oooool00ol00?oooooo
ooooo`0aooooo`03o`000?oooooooooo03Sooooo00?oo`00ooooooooool0Aoooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`17ooooo`03ool00?oooooooooo00Gooooo00?o
003oooooooooool0<Oooool00ol0003oooooooooo`0`ooooo`03o`00oooooooooooo00Gooooo00?o
o`00ooooooooool0Aoooool00ol0003oooooooooo`01ooooo`004Oooool2o`0004Oooooo0ooo0006
ooooo`03o`00oooooooooooo037ooooo00?o0000ooooooooool0<?ooool00ol00?ooooooooooo`03
ooooo`?oo`00B?ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo04Kooooo0ooo0006oooo
o`03o`00oooooooooooo037ooooo00?o0000ooooooooool0<?ooool00ol00?ooooooooooo`03oooo
o`?oo`00BOooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`16ooooo`?o
o`00>_ooool00ol0003oooooooooo`0fooooo`?oo`00BOooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`18ooooo`03o`00oooooooooooo03Sooooo00?o0000ooooooooool0
P_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`18ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool0<Oooool00ol0003oooooooooo`0`ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool0Aoooool00ol0003oooooooooo`01ooooo`004Oooool2
o`00053ooooo00?o003oooooooooool0<Oooool00ol0003oooooooooo`0`ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool0A_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo
04Sooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0aooooo`03o`000?oooooooooo
033ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`18ooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo04Sooooo00?o003oooooooooool0>?ooool00ol0003o
ooooooooo`0`ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0B?ooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`18ooooo`03o`00oooooooooooo03Sooooo
00?o0000ooooooooool0P_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`18ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0<Oooool00ol0003ooooooooo
o`0aooooo`03o`00oooooooooooo04kooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001@
ooooo`03o`00oooooooooooo037ooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo04Oooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1>oooo
o`03o`00oooooooooooo03;ooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo04Sooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0B?ooool00ol00?ooooooooooo`0hooooo`03o`000?oooooooooo037ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`18ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo04Sooooo00?o003oooooooooool0>?ooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04Sooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0booooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0C_oo
ool00ol0003oooooooooo`01ooooo`004Oooool2o`0004oooooo00?o003oooooooooool0<_ooool0
0ol0003oooooooooo`0aooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0Aoooool2
o`0000?ooooo000Aooooo`03o`000?oooooooooo04kooooo00?o003oooooooooool0<_ooool00ol0
003oooooooooo`0aooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0B?ooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`18ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool0<_ooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool0B?ooool00ol0003oooooooooo`01ooooo`000oooool3o`0000Cooooo
0_l00005ooooo`03o`000?oooooooooo04Sooooo00?o003oooooooooool0>?ooool00ol0003ooooo
ooooo`0gooooo`03o`00oooooooooooo04Sooooo00?o0000ooooooooool00Oooool000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0B?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo03;ooooo00?o0000oooooooo
ool0P_ooool00ol0003oooooooooo`01ooooo`001_ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0B?ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo03;ooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo04Sooooo00?o0000ooooooooool00Oooool000Kooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`02ooooo`?o0000C_ooool00ol00?ooooooooooo`0booooo`03
o`000?oooooooooo037ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`16ooooo`?o
00000oooool000;ooooo1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0B?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo03;ooooo00?o0000oooooooo
ool0<Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo04Sooooo00?o0000oooooooo
ool00Oooool000;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo04Sooooo00?o003oooooooooool0>?ooool00ol0003oooooooooo`0gooooo`03
o`00oooooooooooo04Sooooo00?o0000ooooooooool00Oooool000;ooooo1Ol00003ooooo`;o0000
1Oooool00ol0003oooooooooo`19ooooo`03o`00oooooooooooo03Oooooo00?o0000ooooooooool0
P_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`19ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool0<_ooool00ol0003oooooooooo`0aooooo`03o`00oooo
oooooooo04kooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001?ooooo`03o`00oooooooo
oooo03;ooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo04Oooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`19ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool0<_ooool00ol0003oooooooooo`0booooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool0B?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`19ooooo`03o`00oooooooooooo03Oooooo00?o0000ooooooooool0<_ooool01Ol00?oo
oooooooooooooooo003o04_ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0BOooool00ol00?ooooooooooo`0gooooo`03o`000?oooooooooo08;ooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool0BOooool01Ol00?oooooooooooooooooo003o03Go
oooo00?o0000ooooooooool0<_ooool00ol00?ooooooooooo`1=ooooo`03o`000?oooooooooo007o
oooo000Aooooo`;o0000C_ooool00ol00?ooooooooooo`0cooooo`03o`000?oooooooooo03;ooooo
00Go003oooooooooooooooooo`00o`1:ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0
COooool00ol00?ooooooooooo`0cooooo`03o`000?oooooooooo03;ooooo00Go003ooooooooooooo
ooooo`00o`1;ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04Wooooo
00Go003oooooooooooooooooo`00o`0eooooo`03o`000?oooooooooo03;ooooo00Go003ooooooooo
ooooooooo`00o`1;ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04Wo
oooo00?o003oooooooooool0=oooool00ol0003oooooooooo`0fooooo`03o`00oooooooooooo04Wo
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0BOooool01Ol00?oooooo
oooooooooooo003o03Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`01ooooo`00
4Oooool2o`0004kooooo00?o003oooooooooool0<oooool00ol0003oooooooooo`0booooo`05o`00
ooooooooooooooooool00?l0B_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo04gooooo
00?o003oooooooooool0<oooool00ol0003oooooooooo`0booooo`05o`00ooooooooooooooooool0
0?l0Boooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`19ooooo`05o`00
ooooooooooooooooool00?l0=Oooool00ol0003oooooooooo`0booooo`05o`00oooooooooooooooo
ool00?l0Boooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1:ooooo`03
o`00oooooooooooo03Kooooo00?o0000ooooooooool0=_ooool00ol00?ooooooooooo`19ooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04[ooooo00?o003oooooooooool0
=_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000Booo
ool01?l00?ooooooooooool00?leooooo`03o`000?oooooooooo03?ooooo00?o003oooooooooool0
Boooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo04gooooo00?o003oooooooooool0<ooo
ool00ol0003oooooooooo`0cooooo`03o`00oooooooo003o04cooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0B_ooool00ol00?ooooooo`00o`0fooooo`03o`000?oooooo
oooo03?ooooo00?o003oooooool00?l0C?ooool00ol0003oooooooooo`01ooooo`000oooool3o`00
00Cooooo0_l00005ooooo`03o`000?oooooooooo04[ooooo00?o003oooooooooool0=_ooool00ol0
003oooooooooo`0cooooo`03o`00oooooooo003o04cooooo00?o0000ooooooooool00Oooool000;o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool0B_ooool00ol00?ooooooooooo`0fooooo`03o`000?oooooooooo08;ooooo00?o0000
ooooooooool00Oooool000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000Cooooo0ol0001:ooooo`03o`00oooooooo003o03Kooooo00?o0000ooooooooool0<ooo
ool00ol00?ooooooooooo`1:ooooo`?o00000oooool000;ooooo1?l00003ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0C?ooool00ol00?ooooooooooo`0dooooo`03o`000?oo
oooooooo03?ooooo00?o003oooooool00?l0C?ooool00ol0003oooooooooo`01ooooo`000_ooool0
0ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0C?oo
ool00ol00?ooooooooooo`0dooooo`03o`000?oooooooooo03?ooooo00?o003oooooool00?l0C?oo
ool00ol0003oooooooooo`01ooooo`000oooool00ol0003oooooooooo`03ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0Boooool2o`00ocKooooo00?o0000ooooooooool0=?oo
ool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo007ooooo0004ooooo`;o00001?ooool2
o`0000Gooooo00?o0000ooooooooool0Boooool00ol00?ooooooooooo`0eooooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool00Oooool0017ooooo0_l00024ooooo`03o`000?oooooooooo
087ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo007o
oooo000Aoooooooo00003Ol00003ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.95693, -6.36165, \
0.0394232, 0.391502}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g7 = 
        DiscreteListPlot[
          FourierRearrange[Arg[\(\((Last[#] +  .0000001)\) &\)\  /@ \ fft], 
            fs], Red, PlotRange \[Rule] All, ImageSize \[Rule] 504, \ 
          Frame \[Rule] True, \ Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g8 = \ Show[g2, g7];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309473 0.0938566 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0279 -12 -4.5 ]
[-0.0125 .0279 0 4.5 ]
[-0.0125 .12176 -12 -4.5 ]
[-0.0125 .12176 0 4.5 ]
[-0.0125 .21562 -12 -4.5 ]
[-0.0125 .21562 0 4.5 ]
[-0.0125 .30947 -6 -4.5 ]
[-0.0125 .30947 0 4.5 ]
[-0.0125 .40333 -6 -4.5 ]
[-0.0125 .40333 0 4.5 ]
[-0.0125 .49719 -6 -4.5 ]
[-0.0125 .49719 0 4.5 ]
[-0.0125 .59104 -6 -4.5 ]
[-0.0125 .59104 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0279 m
.00625 .0279 L
s
[(-3)] -0.0125 .0279 1 0 Mshowa
0 .12176 m
.00625 .12176 L
s
[(-2)] -0.0125 .12176 1 0 Mshowa
0 .21562 m
.00625 .21562 L
s
[(-1)] -0.0125 .21562 1 0 Mshowa
0 .30947 m
.00625 .30947 L
s
[(0)] -0.0125 .30947 1 0 Mshowa
0 .40333 m
.00625 .40333 L
s
[(1)] -0.0125 .40333 1 0 Mshowa
0 .49719 m
.00625 .49719 L
s
[(2)] -0.0125 .49719 1 0 Mshowa
0 .59104 m
.00625 .59104 L
s
[(3)] -0.0125 .59104 1 0 Mshowa
.125 Mabswid
0 .04667 m
.00375 .04667 L
s
0 .06545 m
.00375 .06545 L
s
0 .08422 m
.00375 .08422 L
s
0 .10299 m
.00375 .10299 L
s
0 .14053 m
.00375 .14053 L
s
0 .1593 m
.00375 .1593 L
s
0 .17807 m
.00375 .17807 L
s
0 .19685 m
.00375 .19685 L
s
0 .23439 m
.00375 .23439 L
s
0 .25316 m
.00375 .25316 L
s
0 .27193 m
.00375 .27193 L
s
0 .2907 m
.00375 .2907 L
s
0 .32824 m
.00375 .32824 L
s
0 .34702 m
.00375 .34702 L
s
0 .36579 m
.00375 .36579 L
s
0 .38456 m
.00375 .38456 L
s
0 .4221 m
.00375 .4221 L
s
0 .44087 m
.00375 .44087 L
s
0 .45964 m
.00375 .45964 L
s
0 .47841 m
.00375 .47841 L
s
0 .51596 m
.00375 .51596 L
s
0 .53473 m
.00375 .53473 L
s
0 .5535 m
.00375 .5535 L
s
0 .57227 m
.00375 .57227 L
s
0 .00913 m
.00375 .00913 L
s
0 .60981 m
.00375 .60981 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0279 m
1 .0279 L
s
.99375 .12176 m
1 .12176 L
s
.99375 .21562 m
1 .21562 L
s
.99375 .30947 m
1 .30947 L
s
.99375 .40333 m
1 .40333 L
s
.99375 .49719 m
1 .49719 L
s
.99375 .59104 m
1 .59104 L
s
.125 Mabswid
.99625 .04667 m
1 .04667 L
s
.99625 .06545 m
1 .06545 L
s
.99625 .08422 m
1 .08422 L
s
.99625 .10299 m
1 .10299 L
s
.99625 .14053 m
1 .14053 L
s
.99625 .1593 m
1 .1593 L
s
.99625 .17807 m
1 .17807 L
s
.99625 .19685 m
1 .19685 L
s
.99625 .23439 m
1 .23439 L
s
.99625 .25316 m
1 .25316 L
s
.99625 .27193 m
1 .27193 L
s
.99625 .2907 m
1 .2907 L
s
.99625 .32824 m
1 .32824 L
s
.99625 .34702 m
1 .34702 L
s
.99625 .36579 m
1 .36579 L
s
.99625 .38456 m
1 .38456 L
s
.99625 .4221 m
1 .4221 L
s
.99625 .44087 m
1 .44087 L
s
.99625 .45964 m
1 .45964 L
s
.99625 .47841 m
1 .47841 L
s
.99625 .51596 m
1 .51596 L
s
.99625 .53473 m
1 .53473 L
s
.99625 .5535 m
1 .5535 L
s
.99625 .57227 m
1 .57227 L
s
.99625 .00913 m
1 .00913 L
s
.99625 .60981 m
1 .60981 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30947 m
1 .30947 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .30947 m
.02847 .27609 L
.03089 .26002 L
.03218 .25241 L
.03288 .24865 L
.03355 .2455 L
.03417 .24303 L
.0345 .24196 L
.03484 .24104 L
.03514 .24046 L
.03522 .24034 L
.0353 .24023 L
.03546 .24008 L
.03561 .24001 L
.03575 .24001 L
.03588 .24007 L
.03602 .24021 L
.03618 .24047 L
.03632 .24082 L
.03646 .24123 L
.0366 .24178 L
.03676 .24253 L
.03692 .2435 L
.03722 .24579 L
.03749 .24864 L
.03774 .25206 L
.03802 .25685 L
.03832 .26339 L
.03948 .30507 L
.04012 .33436 L
.04071 .35757 L
.04102 .36677 L
.04135 .37459 L
.04172 .3811 L
.04206 .38544 L
.04235 .38816 L
.04267 .3903 L
.04283 .3911 L
.043 .39177 L
.04316 .39225 L
.04331 .39258 L
.04345 .39279 L
.04361 .39294 L
.04369 .39297 L
.04378 .39298 L
.04393 .39294 L
.04408 .39283 L
.04423 .39266 L
.04436 .39246 L
.0445 .39219 L
Mistroke
.04482 .39141 L
.04516 .39036 L
.04578 .388 L
.04812 .37567 L
.05314 .34164 L
.05798 .30651 L
.06263 .27448 L
.06504 .26082 L
.06563 .25819 L
.06625 .25587 L
.06661 .25484 L
.06694 .25413 L
.0671 .25388 L
.06718 .25377 L
.06727 .25368 L
.06735 .25362 L
.06743 .25358 L
.06758 .25356 L
.06773 .25362 L
.06787 .25375 L
.06802 .25399 L
.0681 .25417 L
.06818 .25436 L
.06833 .25485 L
.0685 .25553 L
.0688 .25725 L
.06909 .25951 L
.06939 .26275 L
.06964 .26637 L
.06992 .27142 L
.07025 .27906 L
.07055 .2879 L
.07122 .31462 L
.07181 .34242 L
.07244 .3686 L
.07301 .38542 L
.07333 .39219 L
.07363 .39703 L
.07391 .40041 L
.07416 .40278 L
.07444 .40472 L
.07458 .40547 L
.07474 .40614 L
.07491 .40671 L
.07507 .40712 L
.07521 .40737 L
.07536 .40755 L
.07544 .4076 L
.07553 .40763 L
.07563 .40763 L
Mistroke
.07571 .4076 L
.07587 .40749 L
.07595 .4074 L
.07603 .4073 L
.07633 .40677 L
.07665 .40597 L
.07724 .40401 L
.07849 .39835 L
.07961 .39205 L
.08214 .37577 L
.08698 .34121 L
.09163 .30748 L
.09399 .29134 L
.09524 .28345 L
.09658 .27588 L
.09724 .27265 L
.09787 .27006 L
.09843 .26823 L
.09859 .26783 L
.09875 .26747 L
.0989 .26719 L
.09904 .26698 L
.09918 .26684 L
.09931 .26675 L
.09945 .26672 L
.09961 .26677 L
.09974 .26689 L
.09988 .26711 L
.10002 .2674 L
.10014 .26774 L
.10029 .2683 L
.10043 .26895 L
.10059 .2698 L
.10076 .27096 L
.10104 .27348 L
.10134 .27711 L
.10164 .28196 L
.10197 .28895 L
.10228 .29754 L
.10257 .30744 L
.10369 .35947 L
.10399 .37327 L
.10432 .38608 L
.10461 .39533 L
.10491 .40311 L
.10527 .41 L
.10559 .41463 L
.10589 .41769 L
.10606 .41905 L
.10621 .42008 L
Mistroke
.10636 .42088 L
.10651 .42159 L
.10668 .42215 L
.10676 .4224 L
.10685 .42259 L
.10699 .42285 L
.10708 .42295 L
.10716 .42302 L
.10729 .42309 L
.10745 .42307 L
.10759 .42299 L
.10773 .42285 L
.10788 .42263 L
.10803 .42236 L
.10857 .42095 L
.1092 .41864 L
.10978 .41604 L
.11109 .40901 L
.11586 .37719 L
.12043 .34363 L
.12531 .30868 L
.12755 .29426 L
.12874 .2877 L
.12939 .28463 L
.13 .28222 L
.13033 .28117 L
.13063 .2804 L
.13079 .28007 L
.13097 .2798 L
.13106 .2797 L
.13114 .27962 L
.13123 .27956 L
.13133 .27953 L
.13149 .27955 L
.13158 .27961 L
.13166 .2797 L
.13181 .27993 L
.13189 .2801 L
.13197 .28031 L
.13212 .28078 L
.13228 .28143 L
.13256 .28305 L
.13272 .28427 L
.13287 .28563 L
.13321 .28967 L
.13351 .29458 L
.13383 .30157 L
.13414 .31061 L
.13443 .32138 L
.13498 .34719 L
Mistroke
.1356 .37924 L
.13616 .40397 L
.13645 .41329 L
.13676 .42111 L
.1371 .42758 L
.13741 .43187 L
.1377 .43475 L
.13796 .43668 L
.1381 .43746 L
.13825 .43816 L
.13841 .43873 L
.13856 .43913 L
.13869 .43939 L
.13883 .43957 L
.13895 .43965 L
.13908 .43968 L
.13922 .43964 L
.13937 .43952 L
.13951 .43935 L
.13964 .43914 L
.13992 .43854 L
.14023 .43768 L
.14085 .43542 L
.14196 .43013 L
.14447 .41487 L
.14934 .38014 L
.15402 .34525 L
.15641 .32794 L
.15901 .31037 L
.16021 .30313 L
.16088 .29959 L
.1615 .29665 L
.16207 .29442 L
.16232 .29362 L
.16259 .29289 L
.16273 .2926 L
.16288 .29234 L
.16303 .29213 L
.16318 .29201 L
.16326 .29197 L
.16335 .29196 L
.16343 .29197 L
.16351 .29201 L
.16365 .29217 L
.16381 .29244 L
.16395 .29282 L
.16411 .29338 L
.16426 .29407 L
.1644 .29486 L
.16466 .29685 L
Mistroke
.16494 .29979 L
.16527 .30467 L
.16558 .31107 L
.16586 .31872 L
.16616 .32947 L
.1673 .39088 L
.16759 .40629 L
.16786 .41873 L
.16813 .42862 L
.16837 .43594 L
.16863 .44219 L
.16892 .44734 L
.16921 .45111 L
.16952 .45397 L
.16967 .45501 L
.16983 .45591 L
.16998 .45658 L
.17011 .45706 L
.17027 .45745 L
.17036 .45762 L
.17044 .45774 L
.17052 .45783 L
.1706 .45788 L
.17069 .45791 L
.17078 .4579 L
.17092 .45783 L
.17101 .45776 L
.17108 .45767 L
.17124 .45743 L
.17141 .4571 L
.17172 .45632 L
.17199 .45543 L
.17332 .44957 L
.17561 .43579 L
.17811 .4184 L
.18302 .38172 L
.18775 .3462 L
.19016 .329 L
.19143 .32062 L
.19277 .3127 L
.19335 .30973 L
.19397 .30702 L
.19433 .30575 L
.19466 .30484 L
.19481 .30449 L
.19489 .30434 L
.19498 .3042 L
.19506 .3041 L
.19514 .30401 L
.19529 .30391 L
Mistroke
.19545 .30391 L
.19559 .30401 L
.19572 .3042 L
.19587 .30451 L
.19602 .305 L
.19619 .30572 L
.19635 .30661 L
.19649 .30762 L
.19677 .31026 L
.19692 .31223 L
.19707 .31439 L
.19733 .31947 L
.19761 .32676 L
.19884 .39232 L
.19913 .4125 L
.19944 .4312 L
.19971 .44397 L
.2 .45476 L
.20026 .46186 L
.20054 .46753 L
.20081 .47142 L
.20105 .47403 L
.20131 .47605 L
.20146 .47689 L
.2016 .4775 L
.20175 .47798 L
.20188 .4783 L
.20204 .47854 L
.20219 .47865 L
.20232 .47866 L
.20247 .47858 L
.20263 .47841 L
.20277 .47818 L
.20303 .4776 L
.20331 .47679 L
.20395 .47435 L
.20454 .47158 L
.20706 .45626 L
.21185 .42126 L
.21646 .38565 L
.22136 .34837 L
.22363 .33247 L
.22483 .32502 L
.22609 .31855 L
.2264 .31732 L
.22673 .31623 L
.22692 .31574 L
.22709 .31539 L
.22718 .31526 L
.22727 .31514 L
Mistroke
.22735 .31507 L
.22743 .31503 L
.22758 .31504 L
.22772 .31515 L
.22787 .31541 L
.22796 .31562 L
.22803 .31587 L
.22818 .31648 L
.22835 .31739 L
.22851 .31866 L
.22867 .3202 L
.22882 .32208 L
.22899 .32464 L
.22914 .32745 L
.22929 .33111 L
.22943 .33513 L
.22958 .34051 L
.22985 .35301 L
.23016 .37364 L
.2305 .40275 L
.23082 .43203 L
.23111 .45447 L
.23141 .47202 L
.23158 .47914 L
.23174 .48453 L
.23202 .49169 L
.23218 .49465 L
.23233 .49684 L
.23248 .49865 L
.23264 .50018 L
.23281 .50145 L
.23298 .50233 L
.23307 .5027 L
.23316 .50302 L
.23325 .50326 L
.23334 .50343 L
.23349 .50362 L
.23357 .50366 L
.23366 .50367 L
.23374 .50364 L
.23382 .50358 L
.23398 .5034 L
.23413 .50314 L
.23427 .50282 L
.23458 .50191 L
.23491 .50067 L
.23609 .49486 L
.2411 .46001 L
.24593 .42214 L
.25058 .38508 L
Mistroke
.25294 .36655 L
.25553 .347 L
.25671 .33865 L
.25799 .33068 L
.25861 .32749 L
.25891 .32618 L
.25919 .32519 L
.25932 .32482 L
.25945 .32453 L
.25957 .3243 L
.25972 .32414 L
.25986 .3241 L
.25999 .32419 L
.26014 .32445 L
.26029 .32494 L
.26044 .3257 L
.26052 .32627 L
.2606 .32689 L
.26074 .32836 L
.26089 .33045 L
.26103 .33293 L
.26115 .33592 L
.26129 .34018 L
.26144 .34627 L
.2616 .3551 L
.26177 .36864 L
.26193 .38641 L
.26208 .40766 L
.26238 .45648 L
.26253 .4769 L
.26267 .4917 L
.2628 .50268 L
.26294 .51146 L
.26308 .51807 L
.26323 .52347 L
.26336 .52688 L
.2635 .5297 L
.26362 .53176 L
.26374 .53322 L
.26389 .53461 L
.26402 .53555 L
.26417 .53627 L
.26433 .53676 L
.26446 .53698 L
.26459 .53706 L
.26473 .53701 L
.26488 .53683 L
.26504 .53654 L
.26517 .53619 L
.26548 .53516 L
Mistroke
.26604 .53266 L
.2673 .52524 L
.26985 .50703 L
.27468 .46882 L
.27932 .4307 L
.28426 .38969 L
.28902 .35002 L
.2936 .31182 L
.29847 .27116 L
.30316 .23204 L
.30814 .1904 L
.31294 .14996 L
.31756 .1095 L
.31989 .08655 L
.32053 .07935 L
.32122 .07065 L
.32182 .06176 L
.32214 .0562 L
.32247 .04921 L
.3228 .04088 L
.32309 .03116 L
.32324 .02536 L
.32339 .01793 L
.32354 .59919 L
.32367 .58975 L
.32397 .5619 L
.32413 .54052 L
.32429 .51732 L
.32462 .46725 L
.32479 .44731 L
.32494 .43239 L
.32521 .41265 L
.32536 .40481 L
.32551 .39783 L
.32603 .38078 L
.32635 .37338 L
.32665 .36757 L
.3272 .35862 L
.32838 .34395 L
.32963 .33135 L
.33186 .3119 L
.33644 .2774 L
.33899 .26042 L
.34131 .24651 L
.34375 .2341 L
.34482 .22964 L
.34544 .22746 L
.34601 .22569 L
.34659 .22424 L
.34685 .22372 L
Mistroke
.34712 .22325 L
.3474 .2229 L
.34755 .22275 L
.3477 .22265 L
.34785 .22258 L
.34799 .22256 L
.34807 .22256 L
.34816 .22258 L
.34831 .22265 L
.34847 .22278 L
.34861 .22295 L
.34877 .2232 L
.34894 .22354 L
.34929 .22453 L
.34961 .22581 L
.34991 .22736 L
.35023 .22954 L
.35082 .23516 L
.35112 .23922 L
.35146 .24469 L
.35175 .25063 L
.35206 .25824 L
.35265 .27713 L
.35319 .29968 L
.35442 .35513 L
.3551 .37816 L
.35573 .39292 L
.35631 .40284 L
.35695 .41069 L
.35755 .41623 L
.3581 .42024 L
.35917 .42605 L
.36031 .43039 L
.36145 .4335 L
.36208 .43482 L
.36267 .43579 L
.36321 .43648 L
.36349 .43677 L
.3638 .43702 L
.36409 .43721 L
.36436 .43732 L
.36448 .43736 L
.36462 .4374 L
.36475 .43741 L
.36487 .43742 L
.36503 .43742 L
.36517 .4374 L
.3653 .43737 L
.36544 .43733 L
.36559 .43727 L
Mistroke
.36576 .43719 L
.36605 .437 L
.36657 .43653 L
.36714 .43582 L
.36776 .43482 L
.36843 .43349 L
.36963 .43043 L
.37205 .42207 L
.37459 .41058 L
.37919 .38471 L
.38408 .35234 L
.38878 .31813 L
.39379 .27946 L
.39861 .24032 L
.40324 .20078 L
.40818 .15543 L
.41063 .13026 L
.41293 .1029 L
.41406 .08666 L
.41513 .06783 L
.41572 .05509 L
.41636 .03817 L
.41665 .02936 L
.4168 .02409 L
.41695 .01882 L
.41709 .60332 L
.41724 .59734 L
.41749 .58602 L
.41863 .52439 L
.41985 .46086 L
.42056 .43484 L
.42119 .41656 L
.42244 .38989 L
.42362 .37081 L
.42489 .35338 L
.42721 .32599 L
.43213 .27412 L
.43687 .22399 L
.43925 .19602 L
.44143 .16561 L
.44255 .14628 L
.44377 .11939 L
.44499 .08166 L
.44566 .0549 L
.44598 .04019 L
.44613 .03348 L
.44628 .02599 L
.44643 .01879 L
.44657 .60175 L
.44672 .59463 L
Mistroke
.44688 .58706 L
.44752 .55796 L
.44865 .51711 L
.44933 .49834 L
.44997 .48346 L
.45118 .46071 L
.45358 .4261 L
.4558 .39973 L
.46053 .34991 L
.46507 .30354 L
.4676 .2758 L
.4687 .26213 L
.46991 .24466 L
.47048 .23477 L
.47109 .22196 L
.47166 .20618 L
.47218 .18619 L
.47249 .17028 L
.47277 .15171 L
.47341 .09499 L
.47398 .04337 L
.47411 .03305 L
.47426 .02309 L
.47435 .01789 L
.47442 .60316 L
.47457 .59518 L
.47515 .57199 L
.47547 .56236 L
.47576 .55494 L
.47686 .53351 L
.47815 .51504 L
.47936 .50043 L
.48401 .45307 L
.48896 .40746 L
.49372 .3649 L
.4983 .32444 L
.50318 .28147 L
.50787 .23991 L
.51286 .19498 L
.51766 .14965 L
.51986 .12708 L
.52111 .11298 L
.52229 .09807 L
.52344 .08034 L
.52408 .06761 L
.52467 .05251 L
.52526 .03136 L
.52542 .02385 L
.52551 .01931 L
.5256 .01472 L
Mistroke
.52567 .59986 L
.52576 .59457 L
.52591 .58442 L
.52658 .52486 L
.52691 .49353 L
.52721 .46879 L
.52776 .43558 L
.52806 .42253 L
.52835 .41244 L
.52895 .3961 L
.5296 .38258 L
.53092 .36187 L
.53214 .34625 L
.53687 .29544 L
.54189 .24422 L
.54441 .2169 L
.54673 .18893 L
.54899 .1553 L
.55013 .13319 L
.55078 .11793 L
.55138 .10077 L
.55198 .08079 L
.55262 .0549 L
.5529 .04218 L
.5532 .02805 L
.55333 .02212 L
.55346 .01571 L
.5536 .59837 L
.55374 .59179 L
.55495 .53949 L
.55627 .49874 L
.55752 .47139 L
.55869 .4515 L
.56123 .41692 L
.56595 .36468 L
.57096 .31272 L
.57347 .28522 L
.57579 .25656 L
.57696 .23929 L
.57805 .21962 L
.57919 .19203 L
.57979 .17224 L
.58044 .14501 L
.58166 .0774 L
.582 .05855 L
.58235 .04016 L
.58266 .02614 L
.58274 .02257 L
.58283 .01886 L
.58292 .01548 L
Mistroke
.58299 .60219 L
.58314 .597 L
.58329 .59176 L
.58356 .58308 L
.58418 .56636 L
.58542 .54094 L
.58665 .52177 L
.58799 .50444 L
.59042 .47756 L
.59535 .43062 L
.6001 .38943 L
.60467 .35185 L
.60953 .31362 L
.61421 .27879 L
.61918 .24458 L
.62397 .21582 L
.62639 .20363 L
.62858 .19442 L
.62972 .19046 L
.63096 .18692 L
.63164 .18532 L
.63226 .18409 L
.63285 .18314 L
.63318 .1827 L
.63349 .18236 L
.63378 .18208 L
.6341 .18184 L
.63424 .18176 L
.63439 .18168 L
.63452 .18163 L
.63466 .18158 L
.6348 .18155 L
.63493 .18153 L
.63505 .18152 L
.63518 .18153 L
.63533 .18154 L
.63546 .18157 L
.6356 .18161 L
.63576 .18167 L
.63608 .18184 L
.63643 .18211 L
.63676 .18243 L
.63707 .18279 L
.63764 .18364 L
.63825 .18479 L
.63942 .18773 L
.64052 .19157 L
.64119 .19461 L
.64182 .19818 L
.64239 .20218 L
Mistroke
.64301 .20777 L
.64365 .21556 L
.64426 .22566 L
.6448 .2381 L
.64539 .25639 L
.64659 .30946 L
.64723 .33749 L
.64759 .35021 L
.64792 .36022 L
.64823 .36798 L
.64857 .37481 L
.64917 .38357 L
.64946 .38673 L
.64977 .38942 L
.65006 .39142 L
.65033 .39287 L
.65063 .39415 L
.65079 .39468 L
.65095 .39516 L
.65111 .39552 L
.65125 .3958 L
.65139 .396 L
.65154 .39617 L
.65163 .39625 L
.65171 .39631 L
.6518 .39635 L
.6519 .39638 L
.65198 .39639 L
.65206 .39638 L
.65215 .39636 L
.65224 .39633 L
.65232 .39628 L
.65241 .39622 L
.65257 .39608 L
.65287 .3957 L
.65315 .39523 L
.65346 .39461 L
.65401 .39322 L
.65526 .389 L
.65779 .3773 L
.66275 .34713 L
.66753 .31203 L
.66993 .29165 L
.67212 .26918 L
.67271 .26161 L
.67334 .25164 L
.67363 .24606 L
.67394 .23902 L
.67422 .23083 L
.67449 .22126 L
Mistroke
.67479 .20636 L
.67495 .19534 L
.67511 .1822 L
.67539 .15048 L
.67569 .10499 L
.67602 .05835 L
.67621 .03904 L
.67638 .02546 L
.67653 .01533 L
.67662 .60021 L
.6767 .5962 L
.67701 .58393 L
.67731 .57505 L
.67758 .56852 L
.67819 .55703 L
.67929 .54174 L
.68178 .51562 L
.68659 .47298 L
.69122 .43391 L
.69614 .39276 L
.70088 .3532 L
.70544 .31515 L
.7103 .27463 L
.71497 .23567 L
.71993 .1944 L
.72472 .15504 L
.72932 .11828 L
.73189 .09919 L
.7331 .09115 L
.73363 .08803 L
.73422 .08505 L
.73449 .0839 L
.73478 .08289 L
.73494 .08245 L
.73509 .08215 L
.73524 .08196 L
.73538 .08189 L
.73553 .08196 L
.73561 .08206 L
.73569 .08224 L
.73584 .08273 L
.73598 .08343 L
.73606 .08396 L
.73615 .08464 L
.7363 .0862 L
.73646 .08852 L
.73664 .09207 L
.7368 .09631 L
.73694 .1017 L
.73707 .1081 L
Mistroke
.73721 .1173 L
.73737 .13088 L
.73753 .15037 L
.73783 .19645 L
.73808 .23377 L
.73822 .24932 L
.73835 .26022 L
.7385 .26982 L
.73865 .27653 L
.73878 .28118 L
.73893 .28503 L
.73909 .28818 L
.73924 .29032 L
.7394 .29203 L
.73948 .29269 L
.73957 .29329 L
.73972 .29404 L
.73981 .29434 L
.73988 .29454 L
.74003 .29479 L
.74017 .29485 L
.74031 .29479 L
.74046 .2946 L
.74058 .29436 L
.74071 .29403 L
.74102 .29304 L
.7413 .29187 L
.74252 .28526 L
.74383 .27653 L
.7488 .2388 L
.75358 .20072 L
.75817 .16451 L
.76074 .14521 L
.76307 .12919 L
.76423 .12235 L
.76484 .11933 L
.76518 .11792 L
.76549 .11682 L
.76576 .11606 L
.76592 .11573 L
.76606 .1155 L
.76621 .11534 L
.7663 .11529 L
.76638 .11528 L
.76652 .11534 L
.76668 .11555 L
.76682 .11588 L
.76698 .11641 L
.76712 .11711 L
.76725 .11795 L
Mistroke
.76751 .12016 L
.76764 .12165 L
.76778 .12363 L
.76808 .12957 L
.76825 .13419 L
.76841 .13953 L
.7687 .15274 L
.76885 .16146 L
.76901 .17285 L
.7696 .22503 L
.76985 .24657 L
.77013 .26503 L
.7703 .27347 L
.77046 .27984 L
.77076 .28914 L
.77093 .29289 L
.77109 .2956 L
.77127 .29806 L
.77144 .29986 L
.77159 .30109 L
.77174 .30209 L
.77188 .30274 L
.77202 .30327 L
.77218 .30365 L
.77227 .30379 L
.77235 .30387 L
.77251 .30393 L
.77266 .30387 L
.7728 .30373 L
.77294 .30349 L
.77308 .3032 L
.77321 .30288 L
.77382 .30077 L
.77442 .29801 L
.77506 .29458 L
.77728 .28027 L
.78187 .24618 L
.78676 .20834 L
.79147 .17298 L
.79387 .15662 L
.79513 .14913 L
.79582 .14561 L
.79647 .1429 L
.79676 .14191 L
.79705 .14115 L
.7972 .14082 L
.79728 .14068 L
.79737 .14054 L
.79752 .14037 L
.79766 .14029 L
Mistroke
.79775 .14028 L
.79783 .14031 L
.79792 .14037 L
.79802 .14048 L
.79818 .14078 L
.79827 .14101 L
.79835 .14128 L
.79851 .14192 L
.79865 .14269 L
.79882 .14381 L
.79898 .14515 L
.79926 .14832 L
.7994 .15039 L
.79955 .15312 L
.79983 .15929 L
.80008 .16705 L
.80039 .17923 L
.80066 .19374 L
.80129 .23555 L
.80186 .27098 L
.80218 .28513 L
.80247 .29458 L
.80275 .30107 L
.80304 .30617 L
.80332 .30958 L
.80357 .3118 L
.80372 .31273 L
.80387 .31352 L
.80402 .3141 L
.80415 .31449 L
.80431 .3148 L
.8044 .31492 L
.80448 .31499 L
.80463 .31505 L
.80479 .31499 L
.80487 .31492 L
.80495 .31483 L
.80514 .31456 L
.80529 .31423 L
.80546 .31381 L
.80607 .31175 L
.80722 .3063 L
.80845 .29909 L
.81066 .28423 L
.81566 .24723 L
.82047 .21091 L
.82511 .17852 L
.82634 .1712 L
.8275 .16548 L
.82808 .16326 L
Mistroke
.82841 .16229 L
.82871 .16161 L
.82879 .16146 L
.82888 .16133 L
.82903 .16115 L
.82913 .16108 L
.82922 .16104 L
.8293 .16104 L
.82939 .16106 L
.82947 .16111 L
.82955 .1612 L
.82964 .16132 L
.82973 .16148 L
.82988 .16186 L
.83004 .16241 L
.83018 .16308 L
.83034 .164 L
.8305 .16513 L
.83067 .16663 L
.83098 .17017 L
.83126 .17475 L
.8316 .18226 L
.83196 .19326 L
.83226 .20568 L
.8326 .22254 L
.83325 .26065 L
.83357 .27769 L
.83387 .29072 L
.83413 .30002 L
.83442 .30799 L
.83471 .31403 L
.83502 .31872 L
.83518 .32057 L
.83533 .32204 L
.83561 .32415 L
.83577 .32503 L
.83592 .32567 L
.83608 .32621 L
.83616 .32644 L
.83625 .32661 L
.83639 .32684 L
.83647 .32692 L
.83655 .32697 L
.83669 .32699 L
.83685 .32693 L
.83698 .3268 L
.83713 .3266 L
.83726 .32636 L
.83739 .32609 L
.83801 .32424 L
Mistroke
.83869 .32147 L
.83992 .31509 L
.84484 .28203 L
.84958 .24686 L
.85414 .21361 L
.85667 .19675 L
.85778 .19023 L
.85837 .18713 L
.859 .1842 L
.85961 .18179 L
.85991 .18087 L
.86018 .18018 L
.86045 .17966 L
.86059 .17947 L
.86074 .17933 L
.86087 .17927 L
.86099 .17927 L
.86113 .17934 L
.86127 .1795 L
.86135 .17963 L
.86143 .17979 L
.86158 .18018 L
.86174 .18074 L
.86192 .18155 L
.86207 .18242 L
.86223 .18358 L
.86252 .18634 L
.86281 .19005 L
.86312 .19531 L
.86338 .20115 L
.86367 .20926 L
.86498 .2701 L
.8653 .28581 L
.86563 .30011 L
.86594 .3108 L
.86623 .31869 L
.86648 .32419 L
.86676 .3288 L
.86706 .33263 L
.86734 .33518 L
.86764 .3371 L
.86781 .33789 L
.86796 .33845 L
.86811 .33886 L
.86825 .33912 L
.86841 .33932 L
.86855 .33941 L
.8687 .33941 L
.86883 .33935 L
.86897 .33922 L
Mistroke
.86913 .33901 L
.86929 .33871 L
.86944 .33838 L
.86973 .3376 L
.87025 .33581 L
.87082 .33341 L
.87326 .3197 L
.87818 .28549 L
.88292 .25064 L
.88747 .21879 L
.88981 .20496 L
.89045 .20183 L
.89112 .19905 L
.8917 .19723 L
.89185 .19684 L
.89202 .19649 L
.89218 .19623 L
.89232 .19604 L
.89247 .19591 L
.89255 .19587 L
.89264 .19586 L
.89273 .19586 L
.89281 .1959 L
.89297 .19605 L
.89311 .19628 L
.89325 .19659 L
.8934 .19704 L
.89356 .19767 L
.89373 .19855 L
.89392 .19974 L
.89426 .20271 L
.8946 .20681 L
.8949 .21191 L
.89519 .21828 L
.89546 .22576 L
.89608 .24899 L
.89733 .30764 L
.89763 .31844 L
.89794 .32771 L
.89828 .33554 L
.8986 .34096 L
.89889 .34473 L
.89916 .34738 L
.89947 .34947 L
.89964 .35034 L
.89979 .35097 L
.89993 .3514 L
.90008 .35176 L
.90022 .35199 L
.90034 .35213 L
Mistroke
.90049 .35222 L
.90057 .35222 L
.90065 .35221 L
.90079 .35213 L
.90094 .35199 L
.90107 .3518 L
.90121 .35156 L
.90146 .351 L
.90203 .34925 L
.90267 .3467 L
.90326 .3439 L
.90459 .33651 L
.90702 .32086 L
.91175 .28702 L
.9163 .25399 L
.91883 .23664 L
.92115 .22253 L
.92233 .21671 L
.9229 .21442 L
.92342 .21277 L
.92371 .2121 L
.92384 .21185 L
.92397 .21164 L
.92412 .21146 L
.92426 .21136 L
.9244 .21132 L
.92449 .21132 L
.92456 .21135 L
.92464 .2114 L
.92473 .21149 L
.92488 .21172 L
.92503 .21205 L
.92517 .21246 L
.92533 .21309 L
.92548 .2138 L
.92581 .21599 L
.9261 .21859 L
.9264 .22242 L
.92673 .22777 L
.92703 .23429 L
.92756 .25042 L
.92814 .27426 L
.92877 .30411 L
.92912 .31901 L
.92944 .33084 L
.92974 .33973 L
.93002 .34628 L
.93032 .352 L
.93065 .35665 L
.93094 .35966 L
Mistroke
.93125 .36206 L
.93141 .36297 L
.93158 .36375 L
.93174 .36433 L
.93188 .36474 L
.93196 .36492 L
.93205 .36508 L
.93221 .36528 L
.9323 .36534 L
.93238 .36538 L
.93247 .36539 L
.93257 .36537 L
.93265 .36532 L
.93274 .36525 L
.93283 .36516 L
.93291 .36506 L
.93322 .36451 L
.9335 .3638 L
.93378 .36298 L
.93439 .36067 L
.93564 .35463 L
.9403 .3247 L
.94526 .2889 L
.95003 .25513 L
.95244 .24 L
.95349 .23433 L
.95462 .22933 L
.95493 .22828 L
.95526 .22733 L
.95553 .2267 L
.95569 .22641 L
.95584 .22621 L
.95599 .22606 L
.95613 .22598 L
.95625 .22596 L
.95639 .22601 L
.95654 .22614 L
.9567 .22639 L
.95685 .22673 L
.95699 .22714 L
.95714 .22774 L
.95731 .22855 L
.95761 .23049 L
.95793 .23345 L
.95829 .23798 L
.95859 .24325 L
.95892 .25061 L
.95951 .26925 L
.96074 .32363 L
.96107 .33711 L
Mistroke
.96143 .34894 L
.96174 .35697 L
.96207 .36386 L
.96239 .36873 L
.96267 .3721 L
.96299 .37483 L
.96315 .37588 L
.96332 .37682 L
.96348 .37747 L
.96362 .37796 L
.96378 .37839 L
.96393 .37867 L
.96407 .37884 L
.9642 .37892 L
.96435 .37895 L
.9645 .37889 L
.96465 .37877 L
.9648 .37857 L
.96495 .37833 L
.96509 .37804 L
.96564 .37656 L
.96623 .37438 L
.96686 .37156 L
.96907 .35915 L
.97409 .32471 L
.97619 .30947 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.05556 .30947 m
.05556 .3241 L
s
.0873 .30947 m
.0873 .33885 L
s
.11905 .30947 m
.11905 .35385 L
s
.15079 .30947 m
.15079 .36928 L
s
.18254 .30947 m
.18254 .38538 L
s
.21429 .30947 m
.21429 .40251 L
s
.24603 .30947 m
.24603 .42136 L
s
.27778 .30947 m
.27778 .44346 L
s
.30952 .30947 m
.30952 .1788 L
s
.34127 .30947 m
.34127 .24676 L
s
.37302 .30947 m
.37302 .418 L
s
.40476 .30947 m
.40476 .1873 L
s
.43651 .30947 m
.43651 .22803 L
s
.46825 .30947 m
.46825 .26786 L
s
.5 .30947 m
.5 .30947 L
s
.53175 .30947 m
.53175 .35108 L
s
.56349 .30947 m
.56349 .39092 L
s
.59524 .30947 m
.59524 .43165 L
s
.62698 .30947 m
.62698 .20095 L
s
.65873 .30947 m
.65873 .37219 L
s
.69048 .30947 m
.69048 .44014 L
s
.72222 .30947 m
.72222 .17549 L
s
.75397 .30947 m
.75397 .19759 L
s
.78571 .30947 m
.78571 .21644 L
s
.81746 .30947 m
.81746 .23357 L
s
.84921 .30947 m
.84921 .24966 L
s
.88095 .30947 m
.88095 .26509 L
s
.9127 .30947 m
.9127 .2801 L
s
.94444 .30947 m
.94444 .29485 L
s
.97619 .30947 m
.97619 .30947 L
s
.015 w
.05556 .3241 Mdot
.0873 .33885 Mdot
.11905 .35385 Mdot
.15079 .36928 Mdot
.18254 .38538 Mdot
.21429 .40251 Mdot
.24603 .42136 Mdot
.27778 .44346 Mdot
.30952 .1788 Mdot
.34127 .24676 Mdot
.37302 .418 Mdot
.40476 .1873 Mdot
.43651 .22803 Mdot
.46825 .26786 Mdot
.5 .30947 Mdot
.53175 .35108 Mdot
.56349 .39092 Mdot
.59524 .43165 Mdot
.62698 .20095 Mdot
.65873 .37219 Mdot
.69048 .44014 Mdot
.72222 .17549 Mdot
.75397 .19759 Mdot
.78571 .21644 Mdot
.81746 .23357 Mdot
.84921 .24966 Mdot
.88095 .26509 Mdot
.9127 .2801 Mdot
.94444 .29485 Mdot
.97619 .30947 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<oooool3o`0002kooooo1Ol0000]ooooo`;o0000;_ooool5o`00033ooooo0ol0000Roooo
o`00=?ooool00ol0003oooooooooo`0^ooooo`04o`000?ooooooooooo`0002cooooo00Co0000oooo
oooooooo0000;_ooool01?l0003oooooooooool0000aooooo`03o`000?oooooooooo027ooooo000[
ooooo`Go000000?oooooo`000?l000000ol0000Xooooo`Go00000oooool00ol0003oooooooooo`0/
ooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool0;_ooool5o`0002;ooooo000a
ooooo`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool0:oooool01?l0003ooooooooo
ool0000`ooooo`03o`000?oooooooooo02gooooo00Co0000oooooooooooo00008oooool003;ooooo
00?o0000ooooool00000;oooool01Ol0003ooooooooooooooooo000002cooooo00Co0000oooooooo
oooo0000;Oooool01Ol0003ooooooooooooooooo000002oooooo00?o0000ooooool000008oooool0
03?ooooo0_l0000_ooooo`05o`000?ooooooooooooooool00000;?ooool01?l0003oooooooooool0
000]ooooo`05o`000?ooooooooooooooool00000<?ooool2o`0002?ooooo000dooooo`03o`000?oo
oooooooo02kooooo0ol0000^ooooo`;o0000;oooool3o`0003;ooooo00?o0000ooooooooool08Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0017oooooool0
000=o`0000?ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00Oooool0
017ooooo0_l0000Nooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool07?ooool2o`00
00?ooooo000Aooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0P_ooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo00?ooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo05?ooooo
00?o0000ooooooooool00Oooool000Wooooo0ol00005ooooo`03o`000?oooooooooo06cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool05_ooool00ol00?ooooooooooo`1Cooooo`03o`000?oooooooooo007ooooo0008
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1Dooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Cooooo00?o0000ooooooooool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo01Kooooo00?o003oooooooooool0Doooool00ol0003oooooooooo`01ooooo`000_ooool5
o`0000Gooooo00?o0000ooooooooool00_ooool3o`0005Cooooo00?o003oooooooooool05Oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool07_ooool0
0ol00?ooooooooooo`1Aooooo`?o00000oooool000[ooooo0_l00005ooooo`03o`000?oooooooooo
05?ooooo0_l00?lGooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0Doooool00ol0
003oooooooooo`01ooooo`003?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05?o
oooo0_l00?lGooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0Doooool00ol0003o
ooooooooo`01ooooo`002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool0K?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo05?ooooo00?o0000oooooooo
ool00Oooool000Wooooo0ol00005ooooo`03o`000?oooooooooo05?ooooo0_l00?lGooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo01Kooooo00?o003oooooooooool0Doooool00ol0003oooooooooo`01ooooo`004Ooo
ool2o`0005Cooooo0_l00?lGooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`1cooooo`;o00000oooool0017ooooo00?o0000ooooooooool0Doooool2
o`00oaOooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`1Dooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo05?ooooo0_l00?lGooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`;o003o5oooool2o`00
oeGooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0K?ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool2o`00oaOo
oooo0_l00?mEooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06cooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo
0_l00?lHooooo`03o`00oooooooooooo05?ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0
001Dooooo`;o003o5oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`00oooooooooooo01kooooo00?o
003oooooooooool0D_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo05?ooooo0_l00?lG
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0M
ooooo`03o`00oooooooooooo05Cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool0Doooool2o`00oaOooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Gooooo0_l00?lGooooo`;o003oEOooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`1/ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`05ooooo`;o003o5oooool2o`00oeGooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool0K?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01?ooool2o`00oaOooooo0_l00?mEooooo`03o`00
0?oooooooooo007ooooo000Aooooo`;o0000E?ooool2o`00oaOooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool02_oo
ool2o`00o`Oooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo04?ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1Cooooo`;o003o5oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`00oooooooooooo00Cooooo0_l00?lOooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool0A?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`1Booooo`03o`00oooooooo003o01Oooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo0_l00?lGooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool0A?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`1Dooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Gooooo0_l00?lGooooo`;o003o3oooool00ol00?oo
ooooooooo`13ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06_ooooo
0_l00?l7ooooo`03o`00oooooooooooo00Cooooo0_l00?l6ooooo`03o`000?oooooooooo00?ooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`;o003o5oooool2o`00o`oooooo
00?o003oooooooooool0@oooool00ol0003oooooooooo`01ooooo`004Oooool2o`0005?ooooo00?o
003oooooool00?l05oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01?ooool2o`00oaSooooo00?o003oooooooooool02oooool00ol00?ooooooo`00
o`14ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0D_ooool00ol00?ooooooo`00o`0G
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool01?ooool2o`00oaoooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`15ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo05;ooooo00?o003oooooool00?l05_ooool2o`00o`Oooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l00?l6oooo
o`;o003o1_ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ool00?l0AOooool00ol0003oooooooooo`01ooooo`002?ooool5o`0000Cooooo00?o0000oooooooo
ool0D_ooool00ol00?ooooooo`00o`0Fooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l00?l6ooooo`03
o`00oooooooooooo00Gooooo0_l00?lGooooo`;o003oEOooool00ol0003oooooooooo`01ooooo`00
2Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo06_ooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`04ooooo`;o003o1_ooool00ol0003oooooooooo`02ooooo`;o
003o1oooool00ol00?ooooooooooo`04ooooo`;o003o5oooool2o`00oaOooooo00?o003ooooooooo
ool0>oooool00ol0003oooooooooo`01ooooo`000_ooool5o`0000?ooooo00?o0000ooooooooool0
1?ooool3o`0005;ooooo00?o003oooooooooool05_ooool2o`00o`Oooooo00?o003oooooooooool0
1?ooool2o`00o`Kooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00Cooooo0_l00?lHooooo`03o`00oooooooooooo00_ooooo00?o003oooooool00?l0
1_ooool2o`00oc_ooooo0ol00003ooooo`002oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo05;ooooo00?o003oooooool00?l05oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`0:ooooo`;o003o8?oo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo003o00Kooooo0_l00?lmooooo`03o`000?oo
oooooooo007ooooo0008ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`1Aooooo`04o`00ooooooooooooo`00oaKooooo0_l00?l6ooooo`;o003o1_ooool2o`00o`Kooooo
00?o0000ooooooooool00_ooool2o`00o`Kooooo0_l00?lOooooo`03o`00oooooooooooo00_ooooo
00Co003ooooooooooooo003o1_ooool2o`00ocgooooo00?o0000ooooooooool00Oooool000Sooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo057ooooo00Co003ooooooooo
oooo003o5_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`;o003o1_ooool00ol00?ooooooooooo`05oooo
o`;o003o5oooool2o`00o`cooooo00Co003ooooooooooooo003o1_ooool00ol00?ooooooooooo`0l
ooooo`03o`000?oooooooooo007ooooo0009ooooo`?o00001Oooool00ol0003oooooooooo`1[oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01?ooool2o`00o`Kooooo00?o0000oooo
ooooool00_ooool2o`00o`Kooooo00?o003oooooooooool01Oooool2o`00oaOooooo0_l00?lGoooo
o`03o`00oooooooooooo03_ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001/ooooo`;o
003o1_ooool2o`00o`Kooooo0_l00?l6ooooo`03o`000?oooooooooo00;ooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`04ooooo`;o003o6?ooool00ol00?ooooooooooo`0:ooooo`04
o`00ooooooooooooo`00o`Oooooo00?o003oooooooooool0>_ooool2o`0000?ooooo000Aooooo`03
o`000?oooooooooo057ooooo00Co003ooooooooooooo003o5oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`0:oooo
o`;o003o1oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00[ooooo00Co003ooooo
oooooooo003o1Oooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo03?ooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0DOooool01?l00?ooooooooooool00?lG
ooooo`03o`00oooooooooooo00Cooooo0_l00?l6ooooo`03o`00oooooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol00?ooooooooooo`04ooooo`;o003o7oooool00ol00?ooooooooooo`0;
ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01_ooool00ol00?oooooooooo
o`0dooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo057ooooo00Co003o
oooooooooooo003o5Oooool00ol00?ooooooo`00o`06ooooo`;o003o1oooool00ol00?oooooooooo
o`04ooooo`07o`000?ooooooooooooooool00?ooooooo`00o`06ooooo`03o`00oooooooooooo00Go
oooo0_l00?lGooooo`03o`00oooooooooooo00_ooooo00Co003ooooooooooooo003o1Oooool00ol0
0?ooooooooooo`06ooooo`;o003o=Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`1Dooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00Oo0000ooooooooooooooooo`00oooooooo
003o00Kooooo00?o003oooooooooool01Oooool2o`00oaOooooo0_l00?lNooooo`;o003o=Oooool0
0ol0003oooooooooo`01ooooo`004Oooool2o`0006_ooooo00?o003oooooool00?l01_ooool2o`00
o`Kooooo0_l00?l6ooooo`07o`000?ooooooooooooooool00?ooooooo`00o`07ooooo`03o`00oooo
oooooooo00Cooooo0_l00?lGooooo`;o003o5oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo03;ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1@ooooo`05o`00oooooooo
ooooooooool00?l05oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`00oooooooooooo00Cooooo0_l0
0?lHooooo`03o`00oooooooooooo00Wooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00
ooooooooooooo`00o`Kooooo00?o003oooooooooool01_ooool2o`00obcooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool0D?ooool01Ol00?oooooooooooooooooo003o01Oo
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o01oo
oooo00?o003oooooooooool02_ooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooo
oooooooo003o1_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02[ooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0D?ooool01Ol00?oooooooooooooooooo
003o01Gooooo00?o003oooooool00?l01_ooool2o`00o`Oooooo00?o003oooooooooool01?ooool0
1ol0003ooooooooooooooooo003oooooool00?l01Oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo01Kooooo00?o003oooooooooool02_ooool01Ol00?oooooooooooooooooo003o00Co
oooo00?o003oooooooooool01_ooool01?l00?ooooooooooool00?ldooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo053ooooo00Go003oooooooooooooooooo`00o`0Eoooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04oooo
o`07o`000?ooooooooooooooool00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Kooooo0_l0
0?lGooooo`;o003o2Oooool3ool000Sooooo00?o003oooooooooool01_ooool01?l00?oooooooooo
ool00?l5ooooo`03o`00oooooooo003o02cooooo00?o0000ooooooooool00Oooool0017ooooo0_l0
001?ooooo`?oo`006?ooool01?l00?ooooooooooool00?l7ooooo`03o`00oooooooooooo00Cooooo
0_l00?l6ooooo`04o`000?ooooooooooo`00o`;ooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`04ooooo`;o003o5oooool2o`00o`Wooooo0ooo000;ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`0[ooooo`;o00000oooool0017ooooo
00?o0000ooooooooool0C_ooool3ool001_ooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`05ooooo`;o003o1_ooool01?l0003oooooooooool00?l:ooooo`03o`00oooooooooooo00Co
oooo0_l00?lHooooo`03o`00oooooooooooo00Oooooo0ooo0003ooooo`03o`00oooooooooooo00;o
oooo00Co003ooooooooooooo003o2?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o
00Oooooo00?o003oooooooooool08_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`1>ooooo`?oo`000oooool00ol00?ooooooooooo`0Aooooo`?oo`0000?oooooo`00oooo
ool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o0000oooooooo
ool02Oooool00ol00?ooooooo`00o`0Dooooo`;o003o2_ooool00ol00?ooooooooooo`09ooooo`05
ool00?ooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooool00?l01oooool00ol00?ooooooooooo`0Rooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo053ooooo00Goo`00ooooooooooooooooo`00o`0C
ooooo`?oo`0000?oooooo`00ooooool01Oooool2o`00o`Kooooo0_l00?l6ooooo`04o`000?oooooo
ooooo`00o`;ooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`0Cooooo`04o`00oooo
ooooooooo`00o`Sooooo00?o003oooooooooool02Oooool00ol00?ooo`00ooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00
o`kooooo0_l00?lTooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04oo
oooo00?o003oool00?ooool00_ooool00ol00?ooooooooooo`0Aooooo`?oo`002Oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00Co0000oooooooooooo003o0_ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00Kooooo0_l00?l;ooooo`04o`00oooooooooooo
o`00o`Sooooo0_l00?l;ooooo`05ool00?ooooooooooooooool00?l00oooool00ol00?oooooooooo
o`06ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo02?ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001Aooooo`03ool00?oo
oooooooo01Kooooo00?oo`00ooooooooool02?ooool00ol00?ooooooooooo`04ooooo`;o003o1_oo
ool01?l0003oooooooooool00?l2ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l0
1_ooool2o`00o`_ooooo00?o003oooooooooool02Oooool2o`00o`_ooooo00?oo`00ooooooooool0
1?ooool3ool000;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooo003o00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Iooooo`;o0000
0oooool0017ooooo00?o0000ooooooooool0D?ooool00ooo003oooooooooo`0Fooooo`04ool00?oo
ooooooooo`00o`Gooooo00?o003oooooool00?l01_ooool2o`00o`Kooooo00Co0000oooooooooooo
003o2_ooool00ol00?ooooooooooo`04ooooo`;o003o2Oooool3ool000cooooo00?o003ooooooooo
ool02?ooool00ol00?ooo`00ooooo`02ooooo`03o`00oooooooooooo00?oo`000_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1_ooool2o`00
o`Oooooo0_l00?lKooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04oo
oooo00?o003oool00?ooool00_ooool00ol00?ooooooooooo`0Booooo`04ool00?ooooooooooo`00
o`Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo
00Wooooo00?o003oooooool00?l01oooool00ol00?ooooooooooo`07ooooo`?oo`003?ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooo003ooooo00;ooooo00?o003oooooooooool00ooo0002oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool01_ooool01?l00?ooooooooooool00?l7
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool06Oooool00ol0003oooooooooo`01
ooooo`002Oooool3o`0000Gooooo00?o0000ooooooooool0Coooool00ol00?ooo`00ooooo`02oooo
o`03o`00oooooooooooo01;ooooo00Coo`00oooooooooooo003o1Oooool00ol00?ooooooo`00o`06
ooooo`03o`00oooooooooooo00Gooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooo003o017ooooo0ooo0003ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool02Oooool00ol00?ooo`00ooooo`02ooooo`05o`00oooooooooooooooooooo00000ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00oooooo00?o003oooooool00?l01_oo
ool00ol00?ooooooooooo`0Kooooo`03o`000?oooooooooo007ooooo000:ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0Coooool00ol00?ooo`00ooooo`02ooooo`03o`00oooooooo
oooo01;ooooo00?oo`00ooooooooool01_ooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooo
oooo00Cooooo00Co0000oooooooooooo003o0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooool00?l02_ooool00ooo003oooooooooo`02ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool02Oooool00ol00?ooo`00ooooo`02ooooo`05o`00oooo
oooooooooooooooo00002?ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo01_ooooo00?o0000oooooooo
ool00Oooool000;ooooo1Ol00003ooooo`03o`000?oooooooooo00Cooooo0ol0001@ooooo`05ool0
0?ooooooooooooooool00?l04oooool00ol00?ooo`00ooooo`09ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01?ooool01?l0003oooooooooool00?l2ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool01_ooool00ol00?ooooooo`00o`0:ooooo`03ool00?oooooooooo
00;ooooo00?o003oooooooooool01Oooool2o`00o`_ooooo00?oo`00ooooooooool01Oooool00ooo
003oooooooooo`04ooooo`?oo`000oooool00ol00?ooooooooooo`02ooooo`04o`00oooooooooooo
o`00o`Gooooo00?o003oooooooooool01_ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo
oooo013ooooo0ol00003ooooo`002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
053ooooo00?oo`00ooooooooool05Oooool01Ol00?ooo`00oooooooooooo003o00Gooooo00?o003o
ooooool00?l01_ooool2o`00o`Kooooo00?o0000ooooool00?l00oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l02_ooool00ooo003oooooooooo`0:
ooooo`;o003o2Oooool00ol00?ooooooool00007ooooo`05ool00?ooooooooooooooool00?l00_oo
ool3ool000?ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l5ooooo`04o`00
ooooooooooooo`00o`Oooooo00?o003oooooooooool01?ooool2o`00oa?ooooo00?o0000oooooooo
ool00Oooool000[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1>ooooo`03o`00
ooooooooo`0000?ooooo00?o003oooooooooool04_ooool01?oo003oooooooooool00?l5ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooool00?l02_ooool00ooo003oooooooooo`0:ooooo`;o
003o2Oooool00ol00?ooooooool00003ooooo`05o`00ooooooooooooo`00oooo00000oooool00ol0
0?ooooooooooo`03ool000Sooooo00Co003ooooooooooooo003o2?ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Cooooo0_l00?lCooooo`03o`000?oooooooooo007ooooo0009oooo
o`;o00001_ooool00ol0003oooooooooo`1>ooooo`03o`00ooooooooo`0000?ooooo00?o003ooooo
ooooool00_ooool3o`00o`gooooo00Coo`00oooooooooooo003o0oooool3ool000Sooooo00?o003o
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00;ooooo00Co003o
oooooooooooo003o4Oooool00ol00?ooo`00ooooo`03ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool02?ooool00ol00?ooooooool00003ooooo`05o`00ooooooooooooo`00oooo0000
0oooool01_l00?oooooooooooooooooo003oool000_ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1oooool00ol00?oooooooooo
o`0Aooooo`03o`000?oooooooooo007ooooo000:ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0C_ooool00ol00?ooooooool00003ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooool00?l03?ooool01Ol00?ooo`00oooooooooooo003o00?ooooo0ooo00000ooooooo003ooooo
o`06ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02Oooool00ol00?ooo`00oooo
o`03ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02?ooool00ol00?ooooooool0
0003ooooo`05o`00ooooooooooooo`00oooo00001oooool00ol00?ooo`00ooooo`02ooooo`03o`00
oooooooooooo00[ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo007o
oooo000Aooooo`;o0000Coooool00ol00?ooooooool00003ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooool00?l03?ooool00ol00?ooo`00ooooo`05ooooo`?oo`0000?oooooo`00ooooool0
1_ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooo003o00?ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo003o00Wooooo00?o003oool00?ooool0
0oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Wooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`05ooooo`03o`00oooo003ooooo00;ooooo00?o003oooooooooool0
0ooo0002ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01_ooool01?l00?oooooo
ooooool00?l5ooooo`03o`00oooooooooooo00Kooooo00?o003oooooool00?l02Oooool2o`0000?o
oooo000Aooooo`03o`000?oooooooooo053ooooo00?oo`00ooooooooool01_ooool00ol00?oooooo
o`00o`0<ooooo`05o`00oooo003oooooooooool00?l01Oooool00ooo003oooooo`00o`06ooooo`;o
003o1_ooool00ol0003oooooo`00o`03ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool00oooool00ol00?ooooooo`00o`0:ooooo`03ool00?oooooooooo00;ooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`09ooooo`03ool00?oooooooooo00Gooooo00Goo`00oooooooo
ooooooooo`00o`04ooooo`05ool00?ooooooooooooooool00?l00_ooool3ool000;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`06ooooo`04o`00ooooooooooooo`00o`Gooooo00?o
003oooooool00?l01_ooool00ol00?ooooooo`00o`0:ooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo04kooooo00?o003ooooooooo00006?ooool01?oo003oooooooooool0
0?l4ooooo`03o`00oooo003ooooo00Oooooo0_l00?l6ooooo`03o`000?oooooo003o00_ooooo00?o
003oooooooooool00oooool00ol00?ooooooo`00o`0:ooooo`03ool00?oooooooooo00[ooooo0_l0
0?l9ooooo`03o`00ooooooooo`0000?ooooo00Go003ooooooooooooo003oool00003ooooo`06o`00
ooooooooooooooooool00?ooo`000oooool00ol00?ooooooooooo`03ool000;ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ool00?l01_ooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo00Oooooo00?o003oooooooooool0A?ooool00ol00?ooooooool00003ooooo`03
o`00oooooooooooo00?oo`0000?oooooo`00ooooool03?ooool01?oo003oooooooooool00?l4oooo
o`03o`00oooo003ooooo00Oooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`08oooo
o`04o`00ooooooooooooo`00oa3ooooo0_l00?l00ooo003oooooooooo`02ooooo`03o`00oooooooo
oooo00Gooooo0_l00?l9ooooo`03o`00ooooooooo`0000?ooooo00Go003ooooooooooooo003oool0
0003ooooo`06o`00ooooooooooooooooool00?ooo`001oooool01Ooo003ooooooooooooooooo003o
00Sooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo
003o00Kooooo00?o003oooooooooool02_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`06ooooo`;o003oA_ooool00ol00?ooooooool00003ooooo`03o`00oooooooooooo
00?oo`0000?oooooo`00ooooool02_ooool00ol00?ooooooool00002ooooo`03o`00oooooooooooo
00;ooooo00Co003oool00?oooooo003o1_ooool2o`00o`Kooooo00?o0000o`00ooooool00oooool0
0ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00oa3ooooo00?o003ooooooooo00001?oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Oooooo00Co003oooooooooooooo`00
0oooool01Ol00?ooooooo`00ooooooooo`0000?ooooo00Ko003oooooooooooooooooo`00oooo0003
ooooo`05o`00oooooooooooooooooooo00001_ooool3ool000?ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02?oo
ool00ol0003oooooooooo`01ooooo`004Oooool2o`0000Oooooo0_l00?l7ooooo`;o003o?Oooool0
0ol00?ooooooool00003ooooo`03o`00oooooooooooo00?oo`0000?oooooo`00ooooool02_ooool0
0ol00?ooooooool00008ooooo`03ool00?oooooo003o00Oooooo00?o003oooooooooool01?ooool0
0ol0003o003oooooo`03ooooo`05o`00ooooooooooooooooool00?l02Oooool00ol00?ooooooo`00
o`08ooooo`03o`00ooooooooo`0000Cooooo00?o003oooooooooool01Oooool2o`00o`_ooooo00Wo
o`00ooooooooooooooooo`00oooooooo003ooooooooo00001_ooool00ol00?ooooooool00003oooo
o`05o`00ooooooooooooo`00oooo00001_ooool3ool000Sooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooo003o00Wooooo0_l00003ooooo`004Oooool00ol0
003oooooooooo`06ooooo`03o`00oooooooooooo00Kooooo0_l00?loooooo`03ool00?oooooooooo
00Gooooo00Coo`00oooooooooooo003o2oooool00ol00?ooooooool00008ooooo`03ool00?oooooo
003o00Gooooo00?o003oooooool00?l01_ooool00ol0003o003oooooo`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Sooooo00?o
003ooooooooo00001?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Wooooo00?o
o`00ooooooooool01Oooool01Ooo003ooooooooooooooooo003o00Cooooo00Goo`00oooooooooooo
ooooo`00o`02ooooo`03o`00oooo003ooooo00;ooooo00?o003oooooooooool00ooo0007ooooo`05
o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`06ooooo`04o`00oooooooooooo
o`00o`[ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool04?ooool00ol0
0?ooooooooooo`0jooooo`04o`00ooooooooooooool000Oooooo00?oo`00ooooooooool03?ooool0
0ol00?ooooooool00002ooooo`03o`00oooooooooooo00;ooooo00Co003oool00?oooooo003o1Ooo
ool00ol00?ooooooo`00o`06ooooo`03o`000?l00?oooooo00_ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooo`00o`0:ooooo`03ool00?oooooooooo00[ooooo0_l00?l8ooooo`04o`00oooo
ooooooooool000?ooooo00Go003oooooool00?ooooooool00003ooooo`03o`00oooooooooooo00;o
oooo00Goo`00ooooooooooooooooo`00o`02ooooo`03o`00oooo003ooooo00;ooooo00?o003ooooo
ooooool00_ooool01Ooo003ooooooooooooooooo003o00Oooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o2_ooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo04;ooooo00Co
003oooooooooooooo`000oooool01Ol00?ooooooooooooooooooo`00013ooooo00Coo`00oooooooo
oooo003o1?ooool00ol00?ooo`00ooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o0000oooo
ooooool01oooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003oooooooooool01_ooool0
0ol00?ooooooool0000<ooooo`;o003o2?ooool01?l00?oooooooooooooo0003ooooo`05o`00oooo
oooo003ooooooooo00001?ooool01Ol00?ooooooo`00ooooooooo`0000Kooooo00?o003oool00?oo
ool00_ooool00ol00?ooooooooooo`02ooooo`05ool00?ooooooooooooooool00?l00_ooool3ool0
00;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003o
ooooooooool02oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`05oooo
o`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0b
ooooo`04o`00ooooooooooooool000?ooooo00Go003ooooooooooooo003oool00002ooooo`03o`00
oooooooooooo00Wooooo00?o003ooooooooo00000_ooool00ol00?ooooooooooo`02ooooo`04o`00
oooo003oooooo`00o`Cooooo0ooo0007ooooo`03o`000?oooooooooo00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo00001?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Oooooo00Co003oooooooooooooo`000oooool0
1Ol00?ooooooo`00ooooooooo`0000Cooooo00Go003oooooool00?ooooooool00007ooooo`03ool0
0?oooooooooo00Gooooo00?o003oool00?ooool00_ooool00ol00?ooooooooooo`03ool000_ooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo007ooooo
000Aooooo`;o00001_ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Oooooo
00?o003oooooooooool0<_ooool01?l00?oooooooooooooo0003ooooo`05o`00ooooooooooooo`00
oooo00000_ooool00ol00?ooooooooooo`09ooooo`03o`00ooooooooo`0000Sooooo00?oo`00oooo
ool00?l01?ooool3ool00003o`00oooooooooooo00Cooooo00?o0000o`00ooooool00oooool01Ol0
0?oooooooooooooooooo003o00Sooooo00Co003ooooooooooooo003o1oooool01?l00?oooooooooo
oooo0004ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02?ooool01?l00?oooooo
oooooooo0003ooooo`05o`00oooooooo003ooooooooo00001_ooool00ol00?ooooooool00003oooo
o`05o`00ooooooooooooo`00oooo00001oooool00ol00?ooo`00ooooo`02ooooo`03o`00oooooooo
oooo00?oo`004oooool00ol00?ooooooooooo`07ooooo`;o00000oooool0017ooooo00?o0000oooo
ooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo003o00Oooooo00?o003ooooo
ooooool0=Oooool01Ooo003ooooooooooooooooo003o00;ooooo00Go003oool00?ooooooooooo`00
o`0:ooooo`04o`00ooooooooooooool000Sooooo00?oo`00ooooool00?l01?ooool3ool00003o`00
oooooooooooo00Cooooo00?o0000o`00ooooool00oooool01Ol00?oooooooooooooooooo003o00So
oooo00Co003ooooooooooooo003o1oooool01?l00?oooooooooooooo0004ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool02Oooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00Kooooo00Goo`00ooooooooooooooooo`00o`02ooooo`03o`00oooo003ooooo00;ooooo00Ko
003oooooooooooooooooo`00oooo0007ooooo`05ool00?ooooooooooooooool00?l01?ooool00ol0
0?ooooooooooo`06ooooo`04o`00ooooooooooooo`00o`[ooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Kooooo0_l00?l^ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool02oooool01?l0
0?oooooooooooooo0002ooooo`09o`00ooooooooooooooooool00?ooooooool00?oooooo003o00Go
oooo00?oo`00ooooool00?l01_ooool00ol0003o003oooooo`03ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l:ooooo`03ool00?oooooooooo
00_ooooo00?o003oooooooooool01Oooool01Ol00?ooooooooooooooooooo`0000Oooooo00?oo`00
ooooooooool00_ooool01Ol00?ooooooooooooooooooo`0000?ooooo00Go003oooooool00?oooooo
ool00003ooooo`06o`00ooooooooooooooooool00?ooo`000oooool01Ol00?oooooooooooooooooo
o`0000?ooooo00?o003oooooooooool00ooo0003ooooo`03o`00oooooooooooo00;ooooo00Co003o
oooooooooooo003o2_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`08
ooooo`03o`00oooooooooooo00cooooo00?o003oooooool00?l01_ooool2o`00ob_ooooo00Co003o
ooooooooooooo`000oooool01Ol00?ooooooooooooooooooo`00013ooooo00Coo`00oooooooooooo
003o0oooool00ol00?ooooooool00007ooooo`03ool00?oooooooooo00Kooooo00?o0000oooooooo
ool01oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o2_ooool0
0ooo003oooooooooo`09ooooo`03o`00oooooooo003o00Oooooo00Go003oooooooooooooooooool0
0003ooooo`;o003o0_ooool00ooo003oooooooooo`02ooooo`;o003o0_ooool00ooo003ooooooooo
o`03ooooo`03o`00ooooooooo`0000?ooooo00?o003oooooooooool00_ooool01Ooo003ooooooooo
oooooooo003o00?ooooo00Goo`00ooooooooooooooooo`00o`02ooooo`?oo`000oooool01Ol00?oo
oooooooooooooooo003o00kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool01Oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ool00?l01_ooool00ol00?ooooooooooo`0Zooooo`04o`00ooooooooooooool000?ooooo00Go003o
oooooooooooo003oool00002ooooo`03o`00oooooooooooo00_ooooo00Coo`00oooooooooooo003o
0oooool00ol00?ooooooool00007ooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool03Oooool01?l00?oo
oooooooooooo0004ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01oooool01Ol0
0?ooooooooooooooooooo`0000?ooooo0_l00?l2ooooo`03ool00?oooooooooo00;ooooo0_l00?l2
ooooo`03ool00?oooooooooo00Gooooo00Goo`00ooooooooooooooooo`00o`02ooooo`03o`00oooo
ooooo`0000?ooooo00Go003ooooooooooooo003oool00003ooooo`03o`00oooooooooooo00?oo`00
0oooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00001_oo
ool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l0
1oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo023ooooo00Go003ooooooooooooo
ooooool00003ooooo`05o`00ooooooooooooo`00oooo00000_ooool00ol00?ooooooooooo`08oooo
o`04o`00ooooooooooooool000;ooooo00Wo003oooooooooooooooooo`00ooooooooo`00ooooool0
0?l01Oooool00ooo003oooooo`00o`06ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooo
oooo003o2Oooool00ol00?ooooooooooo`08ooooo`04o`00ooooooooooooool000Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`07ooooo`05o`00oooooooooooooooooooo00000ooo
ool2o`00o`;ooooo00?oo`00ooooooooool00oooool01?l00?oooooooooooooo0003ooooo`05o`00
oooooooooooooooooooo00001_ooool00ol00?ooooooool00003ooooo`05o`00ooooooooooooo`00
oooo00002?ooool01Ooo003ooooooooooooooooo003o00Oooooo00?o003oooooooooool01oooool2
o`0000?ooooo000Aooooo`03o`000?oooooooooo00Cooooo00Go003oooooooooooooooooo`00o`04
ooooo`04o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo02Cooooo00Woo`00ooooooooooooooooo`00oooooooo003ooooo
oooo00000_ooool00ol00?ooooooooooo`08ooooo`04o`00ooooooooooooool000Sooooo00?oo`00
ooooool00?l01Oooool00ooo003oooooo`00o`06ooooo`03o`00oooooooooooo00?ooooo00Co003o
oooooooooooo003o2Oooool01?l00?ooooooooooool00?l6ooooo`05o`00oooooooooooooooooooo
00001Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Wooooo00?oo`00oooooooo
ool01Oooool00ooo003oooooooooo`03ooooo`04o`00ooooooooooooool000?ooooo00Go003ooooo
ool00?ooooooool00004ooooo`05o`00oooooooo003ooooooooo00001_ooool00ol00?ooo`00oooo
o`02ooooo`06o`00ooooooooooooooooool00?ooo`001_ooool3ool000;ooooo00?o003ooooooooo
ool02?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03o`00
oooooooooooo00Kooooo00Co003ooooooooooooo003o3_ooool00ol00?ooooooo`00o`06ooooo`;o
003o9_ooool00ooo003oooooooooo`03ooooo`03o`00ooooooooo`0000;ooooo00?o003ooooooooo
ool02?ooool01?l00?oooooooooooooo0002ooooo`09o`00ooooooooooooooooool00?ooooooool0
0?oooooo003o00Cooooo00Co003oool00?oooooo003o1_ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l:oooo
o`03ool00?oooooooooo00?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`09oooo
o`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool00_ooool01Ol00?oooooooooooooooooo
o`0000?ooooo00Go003oooooool00?ooooooool00004ooooo`05o`00oooooooo003ooooooooo0000
1_ooool00ol00?ooo`00ooooo`02ooooo`06o`00ooooooooooooooooool00?ooo`000oooool00ol0
0?ooooooooooo`03ool000;ooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`01oooo
o`002_ooool2o`0000Gooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`06oooo
o`;o003o8_ooool01Ol00?ooooooooooooooooooo`0000Oooooo00?oo`00ooooooooool03_ooool0
1?oo003oooooooooool00?l3ooooo`03o`00ooooooooo`0000Kooooo00Co003oool00?oooooo003o
1_ooool00ol0003oooooooooo`0;ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo
003o2_ooool00ooo003oooooooooo`09ooooo`03o`00oooooooo003o00Oooooo00Go003ooooooooo
ooooooooool00007ooooo`03ool00?oooooooooo00;ooooo00Go003oooooooooooooooooool00003
ooooo`05o`00oooooooo003ooooooooo00001?ooool01Ol00?ooooooooooooooooooo`0000?ooooo
00Go003oooooooooooooooooool00003ooooo`06o`00ooooooooooooooooool00?ooo`000oooool0
0ol00?ooooooooooo`03ool000gooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`04ooooo`05o`00ooooooooooooooooool00?l01?oo
ool00ol00?ooooooooooo`06ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool0
3oooool2o`00oaWooooo00Go003oooooooooooooooooool00003ooooo`05o`00oooooooo003ooooo
oooo00000oooool00ol00?ooooooooooo`0:ooooo`04ool00?ooooooooooo`00o`?ooooo00?o003o
oooooooo00001_ooool00ol00?ooo`00ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0<ooooo`05o`00oooooooooooooooooooo00001Ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Oooooo00Go003ooooooooooooooooo
ool00007ooooo`03ool00?oooooooooo00;ooooo00Go003oooooooooooooooooool00007ooooo`03
ool00?oooooooooo00;ooooo00Go003oooooooooooooooooool00003ooooo`05o`00oooooooooooo
o`00oooo00000oooool00ol00?ooooooooooo`02ooooo`05ool00?ooooooooooooooool00?l00ooo
ool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo007ooooo0009ooooo`04o`000?oooooo
ooooo`0000Cooooo1ol000001Ol00?oo0000o`000?l0003o003o00?o000000Goo`00o`00ool0003o
0000o`00o`04o`000005ool00?l00?oo0000o`000?l00?l00ol000000ooo003o0000o`00o`06o`00
0003ool00?l0003o000000Go000000?oo`00o`000?l000000_l00?l4o`000003ool00?l0003o0000
00Go000000?oo`00o`000?l000001Ol000000ooo003o0000o`000002o`000005o`00ool0003o0000
o`000?oo00000ol000001Ol00?oo0000o`00ool0003oo`0000?o000000?o003oo`000?l000000_l0
00001Ooo003o0000o`000?l0003o003o00?o000000Coo`00o`000?l0003o003o0ol000001Ol00?oo
0000ool00?l0003o003o00Co000000Co003oool00?l0003o003o1?l00003ool000Go000000Co003o
o`000?oo003o003o1?l000001?l00?oo0000o`000?oo0007o`000005ool00?l0003o0000o`000?l0
0?l00ol000000ooo003o0000o`000003o`000006o`00ool0003o0000ool00?l0003o003o1Ol00000
0ooo003o0000o`000002o`000005o`00ool0003o0000o`000?oo00001ol000000ooo003o0000o`00
0006o`000005ool00?l0003o0000o`000?l00?l00ol000000ooo003o0000o`000003o`000004o`00
ool0003o0000ool000?o000000Go003oo`000?l0003o003oool00008o`000005ool00?l0003o0000
o`000?l00?l00ol000001Ooo003o0000o`000?l0003o003o00;o00000ooo0006o`0000?ooooo0009
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool02?ooool01_l00?oooooooooo
ooooooooo`00o`00o`;ooooo00?o003oooooooooool00_ooool01Ooo003ooooooooooooooooo003o
00?ooooo00Goo`00ooooooooooooooooo`00o`04ooooo`05ool00?oooooo003oooooool00?l00ooo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Ooo
ool00ooo003oooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l01Ooo
ool00ol00?ooooooooooo`02ooooo`05ool00?ooooooooooooooool00?l03_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00;ooooo0ooo0005ooooo`04o`00ooooooooo`00o`00o`Oo
oooo00?oo`00ooooool00?l00_ooool01?l00?oooooooooooooo0003ooooo`03o`00oooooooooooo
00Oooooo00Co003oooooooooooooo`001?ooool01?l00?oooooooooooooo000Mooooo`;o003o2?oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?oo`001Oooool00ol0003ooooooooo
o`01ooooo`002Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00cooooo00Go
o`00o`00ooooooooooooo`00o`04ooooo`03ool00?oooooooooo00Gooooo00Goo`00o`00oooooooo
ooooo`00o`04ooooo`05ool00?oooooo003oooooool00?l00oooool00ooo003oooooooooo`02o`00
o`Cooooo00?oo`00ooooooooool00_l00?l3ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooo
ooooool03?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;ooooo00Goo`00oooo
ooooooooooooo`00o`0>ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?oo
ool3ool000Gooooo00?o003ooooooooo00001Oooool01_l00?oooooooooooooo003oooooo`00o`;o
oooo00Co003oooooooooooooo`000oooool00ol00?ooooooooooo`07ooooo`04o`00oooooooooooo
ool000Cooooo00Co003oooooooooooooo`007_ooool00ol00?ooooooooooo`05ooooo`;o003o2?oo
ool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`03ool000Gooooo00?o0000ooooooooool00Oooool000Wooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0<ooooo`05ool00?ooooooooooooooool0
0?l01?ooool00ooo003oooooooooo`05ooooo`05ool00?l00?ooooooooooool00?l01?ooool01Ooo
003o003ooooooooooooo003o00?ooooo00Goo`00ooooool00?ooooooo`00o`04ooooo`04ool00?oo
ooooooooo`00o`Cooooo00?oo`00ooooooooool01Oooool01Ooo003ooooooooooooooooo003o01Go
oooo00?oo`00ooooooooool02?ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo
00;ooooo00Co003ooooooooooooo003o1Oooool00ol00?oo0000ooooo`06ooooo`03ool00?oooooo
oooo00?ooooo00Go003oooooooooooooo`00o`00o`03ooooo`04o`00ooooooooooooool0013ooooo
00?oo`00ooooool00?l00_ooool01?l00?oooooooooooooo0003ooooo`03o`00oooooooooooo023o
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo003o00Go
oooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo
007ooooo000:ooooo`;o00001Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00?o
o`001oooool01Ooo003ooooooooooooooooo003o00?ooooo00?oo`00o`00ooooool01_ooool01Ooo
003ooooooooooooooooo003o00?ooooo00Goo`00ooooool00?ooooooo`00o`04ooooo`04ool00?oo
oooo003oo`00o`Cooooo00?oo`00ooooooooool01Oooool01Ooo003ooooooooooooooooo003o00So
oooo00?o003oooooooooool02_ooool00ooo003oooooooooo`08ooooo`04o`00ooooooooooooo`00
o`Wooooo00?o003oooooooooool01oooool00ol0003oooooooooo`05ooooo`03ool00?l00?oooooo
00?ooooo00Co003oooooooooooooo`001?ooool01?l00?oooooooooooooo0002ooooo`03o`00oooo
oooooooo00_ooooo00?oo`00ooooool00?l00_ooool01?l00?oooooooooooooo0003ooooo`03o`00
oooooooooooo023ooooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`06ooooo`03o`00
oooooooo003o00Gooooo00Co003ooooooooooooo003o2?ooool00ol00?ooooooooooo`04ooooo`03
o`000?oooooooooo007ooooo000Aooooo`;o00002Oooool00ol00?ooooooooooo`03ool000Oooooo
00Goo`00ooooooooooooooooo`00o`03ooooo`03ool00?l00?oooooo00Kooooo00?oo`00oooooooo
ool01Oooool01Ooo003oooooo`00oooooooo003o00Cooooo00Coo`00oooooooooooo003o1?ooool0
1Ooo003ooooooooooooooooo003o00?ooooo00Goo`00ooooooooooooooooo`00o`08ooooo`;o003o
1_ooool00ol00?ooooooooooo`02ooooo`05ool00?ooooooooooooooool00?l01_ooool01?l00?oo
ooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01_ooool00ol0
0?oo0000ooooo`04ooooo`04o`00ooooooooo`00o`00o`Cooooo00Co003oooooooooooooo`001ooo
ool01?oo003oooooooooool00?l:ooooo`06o`00ooooooooooooool00?oooooo003o1Oooool01Ooo
003ooooooooooooooooo003o02[ooooo00?o003oooooool00?l03_ooool00ol00?ooooooooooo`05
ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`0000?ooooo000Aooooo`03o`000?oooooo
oooo00Sooooo00?o003oooooooooool00ooo0002ooooo`03o`00oooooooooooo00;ooooo00Goo`00
ooooooooooooooooo`00o`03ooooo`05ool00?ooooooooooooooool00?l01?ooool01Ooo003o003o
oooooooooooo003o00?ooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo00;o003o0oooool01Ooo003ooooooooooooooooo003o00Sooooo0_l00?l6oooo
o`03o`00oooooooooooo00;ooooo00Goo`00ooooooooooooooooo`00o`0>ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool00oooool00ol00?oo0000ooooo`04ooooo`03o`00oooooooo
o`0000Sooooo00?oo`00o`00ooooool00_ooool01?l00?oooooooooooooo0002ooooo`03o`00oooo
oooooooo00Sooooo00Ko003oooooooooooooo`00ooooool00?l5ooooo`03ool00?oooooooooo02co
oooo0_l00?l9ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00Kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool03?ooool01Ol00?oooooooooooooooooo003o00Cooooo00?oo`00ooooooooool01Oooool01Ooo
003ooooooooooooooooo003o00Cooooo00Goo`00o`00ooooooooooooo`00o`03ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooool00?l01Oooool00ooo003oooooooooo`02o`00o`?ooooo00?o
o`00ooooooooool02_ooool2o`00o`Kooooo00?o003oooooooooool00_ooool01?oo003ooooooooo
ool00?l?ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00oooool00ol00?oo0000
ooooo`04ooooo`03o`00ooooooooo`0000Sooooo00?oo`00o`00ooooool00_ooool01?l00?oooooo
oooooooo0002ooooo`03o`00oooooooooooo00Sooooo00Co003oooooooooooooo`001?ooool01?l0
0?oooooooooooooo000_ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l02?ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`03ool000Oooooo00Goo`00o`00
ooooooooooooo`00o`04ooooo`05ool00?l00?ooooooooooool00?l00oooool01Ooo003oooooo`00
oooooooo003o00Cooooo00Goo`00ooooool00?ooooooo`00o`03ooooo`03ool00?oooooooooo00;o
003o0oooool00ooo003oooooooooo`0Gooooo`04ool00?ooooooooooo`00o`Oooooo00Co003ooooo
oooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00ooo
ool00ol00?oo0000ooooo`04ooooo`03o`00ooooooooo`0000Gooooo00Go003oooooooooooooo`00
o`00o`03ooooo`04o`00ooooooooooooool0013ooooo00?oo`00o`00ooooool00_ooool01?l00?oo
oooooooooooo0003ooooo`03o`00oooooooooooo02Wooooo00?o003oooooooooool01Oooool2o`00
o`Kooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool02?ooool3ool000?o
oooo00Ko003oooooooooooooooooool00?l00?l2ooooo`03o`00oooooooooooo00;ooooo00Goo`00
o`00ooooooooooooo`00o`03ooooo`05ool00?oooooo003oooooool00?l01?ooool01Ooo003ooooo
o`00oooooooo003o00?ooooo00Coo`00oooooooooooo003o1?ooool01Ooo003ooooooooooooooooo
003o00Sooooo00?o003oooooooooool02_ooool00ooo003oooooooooo`08ooooo`04o`00oooooooo
ooooo`00o`Sooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`05ooooo`03ool00?oo
oooooooo00?ooooo00Co003oooooooooooooo`001?ooool01?l00?oooooooooooooo0002ooooo`03
o`00oooooooooooo00_ooooo00?oo`00o`00ooooool00_ooool01?l00?oooooooooooooo0003oooo
o`03o`00oooooooooooo037ooooo0_l00?l6ooooo`03o`00oooooooo003o00Sooooo00?o003ooooo
ooooool01Oooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000Wooooo00Co003ooooooooo
oooo003o1oooool3ool000?ooooo00Go003oooooooooooooooooool00003ooooo`03o`00oooooooo
oooo00;ooooo00?oo`00ooooooooool01Oooool01Ooo003o003ooooooooooooo003o00Cooooo00Go
o`00ooooooooooooooooo`00o`03ooooo`05ool00?ooooooooooooooool00?l00oooool01Ooo003o
oooooooooooooooo003o00Sooooo0_l00?l6ooooo`03o`00oooooooooooo00;ooooo00Coo`00oooo
oooooooo003o1oooool01?l00?ooooooooooool00?l8ooooo`03o`00oooooooooooo00Sooooo00?o
0000ooooooooool00oooool00ol00?ooooooool00005ooooo`04o`00ooooooooooooool000Oooooo
00Coo`00oooooooooooo003o2_ooool01Ol00?oooooooooooooo003o003o00Kooooo00Coo`00oooo
oooooooo003o=?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool01?ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo00Sooooo00Co003ooooo
oooooooo003o1Oooool01?l00?ooooooooooool00?l4ooooo`05o`00oooooooooooooooooooo0000
0oooool00ol00?ooooooooooo`02ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`05ooooo`05ool00?oooooo003oooooool00?l00oooool01?oo003o
ooooooooool00?l9ooooo`;o003o1_ooool00ol00?ooooooooooo`02ooooo`04ool00?oooooooooo
o`00o`Oooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooool000001Oooool01?l00?ooo`00ool00?oo0007ooooo`03ool0
0?l00?oooooo00Gooooo00?oo`00ooooool00?l02oooool01Ol00?oooooooooooooo003o003o00Ko
oooo00Coo`00oooooooooooo003o=Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Gooooo0_l00?l00ooooooo003oooooo`06ooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo00Sooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00?oo`001oooool01Ooo003ooooooooooooooooo003o00?ooooo00?oo`00
ooooooooool01_ooool00ooo003o003oooooo`05ooooo`05ool00?oooooo003oooooool00?l00ooo
ool00ooo003oooooooooo`0:ooooo`;o003o1_ooool00ol00?ooooooooooo`02ooooo`04ool00?oo
ooooooooo`00o`oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooo000000Gooooo00Co003oool00?oo003oo`001oooool00ooo003o003oooooo`02ooooo`06
o`00ooooooooooooool00?oooooo003o2oooool01?l00?oooooooooooooo0004ooooo`04o`00oooo
ooooooooool003Oooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Oooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool02ooo
ool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`Oooooo0ooo0007ooooo`05ool0
0?ooooooooooooooool00?l00oooool01Ooo003o003ooooooooooooo003o00Cooooo00Goo`00o`00
ooooooooooooo`00o`03ooooo`05ool00?oooooo003oooooool00?l00oooool00ooo003ooooooooo
o`0Booooo`03o`00oooooooooooo00;ooooo00?oo`00ooooool00?l02?ooool00ol00?ooooooo`00
o`05ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooo000000Gooooo00Co003oool00?oo003oo`001?ooool01?l00?oooooooooooooo0004oooo
o`04o`00ooooooooooooool000gooooo00Co003oooooooooooooo`001?ooool01?l00?oooooooooo
oooo0002ooooo`03o`00oooooooooooo03[ooooo00?o003oooooool00?l01_ooool00ol00?oooooo
ooooo`07ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Sooooo00?o
003oooooooooool01_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00?oo`00
0_ooool00ol00?ooooooooooo`02ooooo`05ool00?ooooooooooooooool00?l00oooool01Ooo003o
003ooooooooooooo003o00Cooooo00Goo`00o`00ooooooooooooo`00o`03ooooo`03ool00?oooooo
003o00Gooooo00Coo`00oooooooooooo003o5_ooool00ooo003oooooooooo`08ooooo`03o`00oooo
oooo003o00Wooooo00Go003oooooooooooooooooo`00o`06ooooo`03o`000?oooooooooo00_ooooo
00Co003oooooooooooooo`001?ooool01?l00?oooooooooooooo000@ooooo`03ool00?oooooooooo
00;ooooo00Co003oooooooooooooo`000_ooool00ol00?ooooooooooo`0jooooo`;o003o2?ooool0
0ol00?ooooooooooo`06ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00002Oooool01?l0
0?ooooooooooool00?l8ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool01Oooool01Ooo003o003ooooo
oooooooo003o00Cooooo00Goo`00o`00ooooooooooooo`00o`03ooooo`03ool00?oooooooooo00Go
oooo00Coo`00oooooooooooo003o2Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00;ooooo00?oo`00ooooooooool02?ooool00ol00?ooooooo`00o`09ooooo`03o`00oooooooooooo
00Sooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`03ooooo`04o`00oooooooooooo
ool000Oooooo00?oo`00ooooool00?l02oooool01?l00?oooooooooooooo0004ooooo`04o`00oooo
ooooooooool000;ooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`05ooooo`;o0000
0oooool0017ooooo00?o0000ooooooooool02?ooool01?l00?ooooooooooool00?l5ooooo`04o`00
ooooooooooooo`00o`Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`03ool000Oo
oooo00Goo`00ooooooooooooooooo`00o`04ooooo`05ool00?ooooooooooooooool00?l00oooool0
1Ooo003oooooo`00oooooooo003o00?ooooo00Coo`00oooooooooooo003o2Oooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooool00?l02?ooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool00ol00?oooooo
o`000005ooooo`03o`00oooooooo003o00Gooooo00Co003oooooooooooooo`001oooool00ooo003o
ooooo`00o`0;ooooo`04o`00oooo003oo`00ool000Oooooo00Coo`00oooooooooooo003oAOooool2
o`00o`Sooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool02?ooool00ol0
0?ooooooo`00o`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`03ool000?ooooo00Go003oooooooooooooooooool00008ooooo`03ool00?l00?oo
oooo00Gooooo00Goo`00ooooool00?ooooooo`00o`03ooooo`04ool00?ooooooooooo`00o`Wooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03ool00?oooooo003o013ooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo000000Gooooo
00?o003oooooool00?l02?ooool00ooo003oooooooooo`02ooooo`06o`00ooooooooooooool00?oo
oooo003o2oooool01?l00?ooo`00ool00?oo0004ooooo`04o`00ooooooooooooool004Sooooo0_l0
0?l8ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00[ooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Gooooo0ooo0003
ooooo`05o`00oooooooooooooooooooo00000oooool00ol00?ooooooooooo`02ooooo`05ool00?l0
0?ooooooooooool00?l00oooool01Ooo003o003ooooooooooooo003o00?ooooo00?oo`00oooooooo
ool02_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooool0
0?l04?ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00_ooool0
0ol0003oooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00Co003oooooooooooooo`001?oo
ool01?l00?oooooooooooooo000=ooooo`04o`00oooo003oo`00ool000Cooooo00Co003ooooooooo
ooooo`00B?ooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo017ooooo00?o003oooooool00?l02?ooool00ol00?ooooooooooo`03ooooo`04
o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooool00003ooooo`03o`00oooooooo
oooo00;ooooo00Goo`00ooooooooooooooooo`00o`03ooooo`03ool00?l00?oooooo00Gooooo00?o
o`00ooooool00?l05oooool00ooo003oooooooooo`08ooooo`03o`00oooooooo003o00Gooooo00Co
003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o0000oooooooo
ool02oooool01?l00?oooooooooooooo0004ooooo`04o`00ooooooooooooool0013ooooo00?o003o
ooooooooool00_ooool01_l00?oooooooooooooo003oooooo`00odKooooo00?o003oooooooooool0
1oooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000[ooooo0_l00?l8ooooo`03o`00oooo
oooooooo00?ooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00?oo`000_ooool00ol00?ooooooooooo`02ooooo`05ool00?ooooooooooooooool0
0?l00oooool00ooo003o003oooooo`05ooooo`03ool00?oooooo003o00[ooooo00?o003ooooooooo
ool02_ooool00ooo003oooooooooo`08ooooo`03o`00oooooooo003o00Sooooo00?o003ooooooooo
ool02Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00Co003ooooooooo
ooooo`001?ooool01Ol00?oooooooooooooo003o003o00oooooo00?o003oooooooooool00_ooool0
1_l00?oooooooooooooo003oooooo`00odoooooo0_l00003ooooo`004Oooool00ol0003ooooooooo
o`09ooooo`;o003o2?ooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`Gooooo
00?o003oooooooooool02?ooool3ool000;ooooo00?o003oooooooooool00_ooool01Ooo003ooooo
oooooooooooo003o00?ooooo00Goo`00o`00ooooooooooooo`00o`03ooooo`03ool00?oooooo003o
00[ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03ool00?l00?oooooo
00Sooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`05o`00oooooooo
ooooooooool00?l00_ooool00ol0003oooooooooo`03ooooo`;o003o1_ooool01?l00?ooo`00ool0
0?oo0007ooooo`03ool00?l00?oooooo00_ooooo00?o003oooooool00?l02?ooool00ooo003ooooo
o`00o`1@ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Wooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00Co
003ooooooooooooo003o1?ooool00ol00?ooooooooooo`03ool000Oooooo00?oo`00ooooooooool0
1Oooool01Ooo003o003ooooooooooooo003o00?ooooo00?oo`00ooooool00?l02_ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?oo`00o`00ooooool04?ooool00ol00?oo
ooooooooo`05ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol0003oooooooooo`03oooo
o`;o003o1oooool3ool000Cooooo00Go003oooooooooooooo`00o`00o`0<ooooo`?o003o2?ooool0
0ooo003oooooooooo`1@ooooo`03o`000?oooooooooo007ooooo0009ooooo`?o00001Oooool00ol0
003oooooooooo`0Aooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l02?ooool00ooo003oooooooooo`05
ooooo`05ool00?ooooooooooooooool00?l00oooool00ooo003oooooooooo`0:ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool00_ooool00ooo003o003oooooo`0@ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`000?oooooooooo00?o
oooo0_l00?l7ooooo`?oo`001?ooool01Ol00?oooooooooooooo003o003o00gooooo00?o003ooooo
ooooool01?ooool01?l00?oooooooooooooo001Booooo`03o`000?oooooooooo007ooooo000:oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Oooool2o`00o`Wooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05ool00?ooooooooooooooool00?l00oooool01Ooo003ooooooooo
oooooooo003o00?ooooo00?oo`00ooooool00?l05oooool00ooo003o003oooooo`08ooooo`03o`00
oooooooo003o00Gooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o
00;ooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo003o
00Gooooo00Co003oooooooooooooo`005Oooool01_l00?oooooooooooooo003oooooo`00oe3ooooo
00?o0000ooooooooool00Oooool000[ooooo00?o0000ooooooooool01?ooool3o`0001;ooooo00?o
003oooooooooool01?ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Gooooo00Co
003ooooooooooooo003o1?ooool00ol00?ooooooooooo`03ool000?ooooo00Ko003ooooooooooooo
ooooool00?l00?l6ooooo`03ool00?oooooo003o00[ooooo00?o003oooooooooool02_ooool00ooo
003oooooooooo`08ooooo`03o`00oooooooo003o00Sooooo00?o003oooooooooool02Oooool00ol0
003oooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool01Ol0
0?oooooooooooooo003o003o01Cooooo00Ko003oooooooooooooo`00ooooool00?m>ooooo`?o0000
0oooool000[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03o`00oooo
oooooooo00Cooooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00ooo0003ooooo`06o`00oooooooooooooooooooo003o
003o0_ooool01_l00?ooooooooooooooooooo`00o`00o`_ooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`02ooooo`03ool00?oooooooooo00Sooooo00?o003oooooool00?l02?ooool0
0ol00?ooooooooooo`09ooooo`03o`000?oooooooooo00?ooooo0_l00?l6ooooo`03o`00oooooooo
oooo00Sooooo00?oo`00o`00ooooool05_ooool00ooo003o003oooooo`1@ooooo`03o`000?oooooo
oooo007ooooo000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooo003o013ooooo0ooo0007ooooo`05ool00?oooooooooo
ooooool00?l00oooool00ooo003o003oooooo`0:ooooo`03o`00oooooooooooo00Kooooo00Go003o
ooooooooooooooooool0000:ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool01Ooo
ool01Ol00?oooooooooooooooooo003o00;ooooo00?o0000ooooooooool00oooool2o`00o`Sooooo
00?o003oooooooooool01_ooool00ooo003oooooooooo`0Fooooo`03ool00?l00?oooooo053ooooo
00?o0000ooooooooool00Oooool000Wooooo0_l00006ooooo`03o`000?oooooooooo01Wooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool01_ooool01Ooo003ooooooooooooooooo003o00?ooooo00?oo`00ooooooooool0
2_ooool00ol00?ooooooooooo`06ooooo`05o`00oooooooooooooooooooo00004_ooool00ol00?oo
ooooooooo`05ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol0003oooooooooo`03oooo
o`;o003o2?ooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooool001Gooooo00Co003o
ooooooooooooo`00D_ooool00ol0003oooooooooo`01ooooo`002_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`03
ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00
oooooooooooooooooooo00000oooool01Ol00?ooooooooooooooooooo`0001Gooooo00?o003ooooo
oooo00000_oo000:ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l0
0?ooooooooooool00?l3ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool01Oooool0
0ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooool001Gooooo00Go003oooooooooooooo`00
o`00o`1Aooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00006oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooo
oooooooooooo003o00Cooooo00?o003oooooooooool00ooo0006ooooo`03ool00?l00?oooooo01Go
oooo0ooo000:ooooo`03o`00oooooooo003o00Oooooo00?o003oooooooooool02_ooool00ol0003o
ooooooooo`0;ooooo`03o`00oooooooo003o00Gooooo00Co003oooooooooooooo`005Oooool01Ol0
0?oooooooooooooo003o003o053ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`0Joooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool00ooo0006ooooo`03ool00?l00?oooooo
00[ooooo00?o003oooooooooool01_ooool00ol00?ooooooool00002ool000[ooooo0_l00?l8oooo
o`03o`00oooooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Sooooo00?oo`00ooooooooool04oooool01Ol00?oooooooooooooo003o
003o057ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool08_ooool2o`00
o`kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`03ool000;ooooo00Ko003ooooo
ooooooooooooool00?l00?l;ooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooooooo003o
2oooool2o`00o`Kooooo00?o003oooooooooool01Oooool01?l00?ooooooooooool00?l3ooooo`03
o`000?oooooooooo00?ooooo0_l00?l6ooooo`03o`00oooooooo003o00Oooooo0ooo000Gooooo`03
ool00?l00?oooooo053ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
8_ooool2o`00o`Kooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`07ooooo`05o`00
ooooooooooooooooool00?l00oooool00ooo003oooooooooo`0:ooooo`03o`00oooooooooooo00Ko
oooo0_l00?l00ooooooo003oooooo`0Booooo`03o`00oooooooooooo00Gooooo00Co003ooooooooo
oooo003o0oooool00ol0003oooooooooo`03ooooo`;o003o2?ooool00ol00?ooooooooooo`03oooo
o`03o`00ooooooooo`0000;oo`005?ooool01?l00?oooooooooooooo001Booooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo02?ooooo00?o003oooooooooool01?ooool00ol0
0?ooooooo`00o`06ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool01Oooool01Ol0
0?ooooooooooooooooooo`0000cooooo00?o003oooooooooool01oooool2o`00oaCooooo00?o003o
ooooool00?l01Oooool01?l00?ooooooooooool00?l3ooooo`03o`000?oooooooooo00?ooooo00?o
003oooooooooool01Oooool2o`00o`Kooooo00?o003ooooooooo00000_oo000Dooooo`04o`00oooo
ooooooooool005;ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0000Tooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooo
oooooooo00Sooooo0ooo000Sooooo`;o003o1_ooool00ol00?ooooooo`00o`05ooooo`04o`00oooo
ooooooooo`00o`?ooooo00?o0000ooooooooool02oooool2o`00o`Kooooo00?o003oooooooooool0
5_ooool00ol00?ooooooool00002ool0053ooooo0_l00003ooooo`004Oooool00ol0003ooooooooo
o`0Zooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l01Oooool01?l00?oooooooooo
ool00?l7ooooo`?oo`002oooool00ol00?ooooooooooo`0Eooooo`;o003o2?ooool00ol00?oooooo
ooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`05ooooo`04o`00ooooooooooooo`00oaGooooo00?o003ooooooooo00000_oo001Aooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo02cooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`05ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003ooooooooo
ool00ooo000;ooooo`03o`00oooooooooooo01Gooooo0_l00?l6ooooo`03o`00oooooooo003o00Go
oooo00?o003oooooool00?l01?ooool00ol0003oooooooooo`03ooooo`;o003o1_ooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo01Gooooo0ooo001Aooooo`03o`000?oooooooooo007o
oooo000Aooooo`03o`000?oooooooooo02_ooooo00?o003oooooooooool01oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0<ooooo`03
o`00oooooooooooo01gooooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`04ooooo`03
o`000?oooooooooo00?ooooo0_l00?l7ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool0
0?l0K?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0[ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0>ooooo`03o`00
oooooooooooo01gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`04ooooo`03o`00
0?oooooooooo00?ooooo0_l00?l7ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l0
5_ooool00ol00?ooooooooooo`1Cooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000;?oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool01Ooo
ool01Ol00?oooooooooooooooooo003o02Cooooo0_l00?l6ooooo`03o`00oooooooo003o00Gooooo
00?o003oooooool00?l01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00Gooooo
0_l00?l6ooooo`03o`00oooooooooooo01Kooooo00Co003ooooooooooooo003oDOooool2o`0000?o
oooo000Aooooo`03o`000?oooooooooo03?ooooo0_l00?l6ooooo`04o`00ooooooooooooo`00o`So
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Eooooo`;o003o2?ooool00ol00?oo
ooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooo003o01Kooooo00Co003ooooooooooooo003oD_ooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0cooooo`03o`00oooooooooooo00Go
oooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00cooooo00?o003o
ooooooooool05Oooool2o`00o`Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo0_l00?l6ooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool05_ooool00ol00?ooooooooooo`1Aooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo03gooooo00?o003oooooooooool00oooool01Ol00?oooooooooooooooooo
003o00cooooo00?o003oooooooooool05Oooool2o`00o`Kooooo00?o003oooooooooool01Oooool0
0ol00?ooooooo`00o`04ooooo`03o`000?oooooooooo00?ooooo0_l00?l7ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`1Aooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo03Cooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooo`00o`04ooooo`03o`000?oooooooooo00?ooooo0_l00?l7ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooool00?l05_ooool00ol00?ooooooooooo`1Cooooo`03o`000?oooooooooo
007ooooo000Aooooo`;o0000=?ooool2o`00o`Kooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0Vooooo`;o003o1_ooool2o`00o`Kooooo00?o003oooooool00?l01?ooool00ol0003o
ooooooooo`03ooooo`03o`00oooooooooooo00Gooooo0_l00?l6ooooo`03o`00oooooooooooo01Ko
oooo00?o003oooooool00?l0D_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo03_ooooo
00?o003oooooool00?l02?ooool00ol00?ooooooooooo`0Sooooo`;o003o1oooool00ol00?oooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo0_l00?l6ooooo`03o`00oooooooo003o01Kooooo
00?o003oooooool00?l0Doooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`0kooooo`03o`00oooooooo003o00Sooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`0Eooooo`;o003o1oooool00ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo0_l0
0?l6ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool05?ooool00ol00?ooooooo`00
o`1Cooooo`03o`000?oooooooooo007ooooo0008ooooo`Go00001?ooool00ol0003oooooooooo`0k
ooooo`;o003o1_ooool01?l00?ooooooooooool00?l=ooooo`03o`00oooooooooooo01Gooooo0_l0
0?l6ooooo`03o`00oooooooooooo00Gooooo0_l00?l5ooooo`03o`000?oooooooooo00?ooooo0_l0
0?l6ooooo`;o003o1oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo057ooooo00?o
0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`0looooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?oooooooooo
o`0Mooooo`03o`00oooooooooooo00Gooooo0_l00?l5ooooo`03o`000?oooooooooo00?ooooo0_l0
0?l7ooooo`03o`00oooooooooooo00Cooooo0_l00?lGooooo`03o`00oooooooooooo05?ooooo00?o
0000ooooooooool00Oooool000[ooooo00?o0000ooooooooool01?ooool3o`0003_ooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01gooooo0_l00?l6
ooooo`;o003o1Oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00Gooooo0_l00?l6
ooooo`03o`00oooooooooooo01Kooooo00?o003oooooool00?l0DOooool3o`0000?ooooo000;oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0>oooool2o`00o`Wooooo00?o003ooooo
ooooool08oooool2o`00o`Kooooo0_l00?l6ooooo`03o`00oooooooooooo00Cooooo00?o0000oooo
ooooool02oooool2o`00o`Kooooo00?o003oooooooooool05_ooool00ol00?ooooooo`00o`1Coooo
o`03o`000?oooooooooo007ooooo0008ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`0kooooo`;o003o2Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
01Gooooo0_l00?l7ooooo`03o`00oooooooooooo00_ooooo00?o0000ooooooooool01?ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo0_l00?lGooooo`;o003oE?ooool00ol0
003oooooooooo`01ooooo`002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool0@oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooooooo01Gooooo0_l00?l6oooo
o`;o003o1_ooool2o`00o`Gooooo00?o0000ooooooooool00oooool2o`00o`Kooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo05;ooooo00?o0000oooo
ooooool00Oooool000Wooooo0ol00005ooooo`03o`000?oooooooooo04?ooooo00?o003oooooool0
0?l03_ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Gooooo0_l00?l5ooooo`03
o`000?oooooooooo00?ooooo0_l00?l6ooooo`03o`00oooooooooooo00Gooooo0_l00?m]ooooo`03
o`000?oooooooooo007ooooo000Aooooo`;o0000A?ooool00ol00?ooooooooooo`0>ooooo`03o`00
oooooooooooo01gooooo0_l00?l6ooooo`;o003o1Oooool00ol0003oooooooooo`03ooooo`;o003o
1_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0
D_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo04?ooooo00?o003oooooool00?l09_oo
ool2o`00o`Kooooo0_l00?l6ooooo`;o003o1Oooool00ol0003oooooooooo`0;ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool05_ooool2o`00oeCooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0AOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo01Gooooo0_l00?l7ooooo`03o`00oooooooooooo00_ooooo00?o0000ooooooooool01?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo0_l00?lGooooo`;o003oE?ooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`14ooooo`;o003o3_ooool00ol0
0?ooooooooooo`0Eooooo`;o003o1oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00?ooooo00?o0000ooooooooool00oooool2o`00o`Kooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0Fooooo`03o`00oooooooooooo05;ooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool0A?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01Go
oooo0_l00?l6ooooo`03o`00oooooooooooo00Gooooo0_l00?l5ooooo`03o`000?oooooooooo00?o
oooo0_l00?l6ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0K?ooool00ol0003o
ooooooooo`01ooooo`004Oooool2o`0004Gooooo00?o003oooooooooool03Oooool00ol00?oooooo
ooooo`0Mooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`;o003o1_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Kooooo
00?o003oooooooooool0D_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo04Cooooo00?o
003oooooooooool09Oooool2o`00o`Kooooo0_l00?l6ooooo`03o`00oooooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool05_ooool00ol00?ooooooooooo`1Cooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo06cooooo0_l00?l7ooooo`03o`00oooooooooooo00_ooooo00?o0000
ooooooooool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Kooooo00?o003o
ooooooooool0Doooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Doooo
o`03o`00oooooooooooo01Gooooo0_l00?l7ooooo`03o`00oooooooooooo00_ooooo00?o0000oooo
ooooool00oooool2o`00o`Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Foooo
o`03o`00oooooooooooo05?ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0E?ooool00ol00?ooooooooooo`0Eooooo`;o003o1_ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool2o`00o`Kooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo05?ooooo00?o0000oooooooo
ool00Oooool0017ooooo0_l0001Eooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0_l00?l6ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`1Booooo`;o0000
0oooool0017ooooo00?o0000ooooooooool0E?ooool00ol00?ooooooooooo`0Mooooo`;o003o1_oo
ool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0Dooo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1/ooooo`;o003o1_ooool2
o`00o`Kooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`1Cooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo05Cooooo00?o003oooooooooool05Oooool2o`00
o`Oooooo00?o003oooooooooool02oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo
05?ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0E?ooool00ol00?oo
ooooooooo`0Eooooo`;o003o1_ooool2o`00o`Kooooo00?o003oooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`;o003o1_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Ko
oooo00?o003oooooooooool0Doooool00ol0003oooooooooo`01ooooo`004Oooool2o`0005Gooooo
00?o003oooooooooool07Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo
00?o0000ooooooooool00oooool2o`00o`Kooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`1[ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0E?ooool00ol00?oooooooooo
o`0Mooooo`;o003o1_ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0_l0
0?l6ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool05_ooool00ol00?oooooooooo
o`1Cooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06cooooo0_l00?l6
ooooo`;o003o1_ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo05?ooooo00?o0000
ooooooooool00Oooool000Wooooo0ol00005ooooo`03o`000?oooooooooo05Cooooo00?o003ooooo
ooooool05Oooool2o`00o`Kooooo00?o003oooooooooool03?ooool00ol0003oooooooooo`04oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Foooo
o`03o`00oooooooooooo05?ooooo00?o0000ooooooooool00Oooool000Sooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo05Cooooo00?o003oooooooooool05_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0
003oooooooooo`03ooooo`;o003o1_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
01Kooooo00?o003oooooooooool0Doooool00ol0003oooooooooo`01ooooo`003?ooool00ol0003o
ooooooooo`02ooooo`?o0000E?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo0_l00?l6ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0J_ooool3o`0000?o
oooo000:ooooo`;o00001Oooool00ol0003oooooooooo`1Dooooo`03o`00oooooooooooo01gooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Kooooo
00?o003oooooooooool0Doooool00ol0003oooooooooo`01ooooo`003?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo06gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool05_ooool00ol00?oooooooooo
o`1Cooooo`03o`000?oooooooooo007ooooo0008ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`1]ooooo`03o`00oooooooooooo01?ooooo00?o0000ooooooooool04ooo
ool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo05?ooooo00?o0000ooooooooool00Ooo
ool000Wooooo0ol00005ooooo`03o`000?oooooooooo06gooooo00?o003oooooooooool04oooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000Q?ooool00ol0
003oooooooooo`21ooooo`;o00000oooool0017ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`01ooooo`004Oooooooo`0000go00000oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.95693, -3.79054, \
0.0394232, 0.0400035}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Show all", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{{g3, g4}, {g6, g8}}], \ 
        ImageSize \[Rule] 504];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 504 311.489 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.0147151 0.00959021 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11062 -12 -4.5 ]
[-0.0125 .11062 0 4.5 ]
[-0.0125 .20652 -12 -4.5 ]
[-0.0125 .20652 0 4.5 ]
[-0.0125 .30242 -12 -4.5 ]
[-0.0125 .30242 0 4.5 ]
[-0.0125 .39832 -12 -4.5 ]
[-0.0125 .39832 0 4.5 ]
[-0.0125 .49423 -12 -4.5 ]
[-0.0125 .49423 0 4.5 ]
[-0.0125 .59013 -12 -4.5 ]
[-0.0125 .59013 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11062 m
.00625 .11062 L
s
[(10)] -0.0125 .11062 1 0 Mshowa
0 .20652 m
.00625 .20652 L
s
[(20)] -0.0125 .20652 1 0 Mshowa
0 .30242 m
.00625 .30242 L
s
[(30)] -0.0125 .30242 1 0 Mshowa
0 .39832 m
.00625 .39832 L
s
[(40)] -0.0125 .39832 1 0 Mshowa
0 .49423 m
.00625 .49423 L
s
[(50)] -0.0125 .49423 1 0 Mshowa
0 .59013 m
.00625 .59013 L
s
[(60)] -0.0125 .59013 1 0 Mshowa
.125 Mabswid
0 .0339 m
.00375 .0339 L
s
0 .05308 m
.00375 .05308 L
s
0 .07226 m
.00375 .07226 L
s
0 .09144 m
.00375 .09144 L
s
0 .1298 m
.00375 .1298 L
s
0 .14898 m
.00375 .14898 L
s
0 .16816 m
.00375 .16816 L
s
0 .18734 m
.00375 .18734 L
s
0 .2257 m
.00375 .2257 L
s
0 .24488 m
.00375 .24488 L
s
0 .26406 m
.00375 .26406 L
s
0 .28324 m
.00375 .28324 L
s
0 .3216 m
.00375 .3216 L
s
0 .34078 m
.00375 .34078 L
s
0 .35996 m
.00375 .35996 L
s
0 .37914 m
.00375 .37914 L
s
0 .4175 m
.00375 .4175 L
s
0 .43668 m
.00375 .43668 L
s
0 .45586 m
.00375 .45586 L
s
0 .47505 m
.00375 .47505 L
s
0 .51341 m
.00375 .51341 L
s
0 .53259 m
.00375 .53259 L
s
0 .55177 m
.00375 .55177 L
s
0 .57095 m
.00375 .57095 L
s
0 .60931 m
.00375 .60931 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11062 m
1 .11062 L
s
.99375 .20652 m
1 .20652 L
s
.99375 .30242 m
1 .30242 L
s
.99375 .39832 m
1 .39832 L
s
.99375 .49423 m
1 .49423 L
s
.99375 .59013 m
1 .59013 L
s
.125 Mabswid
.99625 .0339 m
1 .0339 L
s
.99625 .05308 m
1 .05308 L
s
.99625 .07226 m
1 .07226 L
s
.99625 .09144 m
1 .09144 L
s
.99625 .1298 m
1 .1298 L
s
.99625 .14898 m
1 .14898 L
s
.99625 .16816 m
1 .16816 L
s
.99625 .18734 m
1 .18734 L
s
.99625 .2257 m
1 .2257 L
s
.99625 .24488 m
1 .24488 L
s
.99625 .26406 m
1 .26406 L
s
.99625 .28324 m
1 .28324 L
s
.99625 .3216 m
1 .3216 L
s
.99625 .34078 m
1 .34078 L
s
.99625 .35996 m
1 .35996 L
s
.99625 .37914 m
1 .37914 L
s
.99625 .4175 m
1 .4175 L
s
.99625 .43668 m
1 .43668 L
s
.99625 .45586 m
1 .45586 L
s
.99625 .47505 m
1 .47505 L
s
.99625 .51341 m
1 .51341 L
s
.99625 .53259 m
1 .53259 L
s
.99625 .55177 m
1 .55177 L
s
.99625 .57095 m
1 .57095 L
s
.99625 .60931 m
1 .60931 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .07226 m
.02395 .07225 L
.02408 .07224 L
.02423 .07221 L
.02437 .07217 L
.02462 .07208 L
.02489 .07194 L
.02519 .07174 L
.02551 .07147 L
.02608 .07086 L
.02722 .06914 L
.02847 .06647 L
.02973 .06301 L
.03109 .05851 L
.03355 .04862 L
.03593 .03763 L
.03718 .03179 L
.03787 .02883 L
.03821 .02752 L
.03852 .02645 L
.03882 .02558 L
.03898 .02519 L
.03915 .02485 L
.03924 .0247 L
.03932 .02458 L
.03948 .02442 L
.03956 .02436 L
.03966 .02432 L
.03974 .02432 L
.03982 .02433 L
.03997 .02441 L
.0401 .02454 L
.04024 .02474 L
.0404 .02503 L
.04071 .0258 L
.04101 .0267 L
.04331 .03667 L
.04579 .04826 L
.04809 .0578 L
.05031 .06513 L
.05156 .06827 L
.05269 .07045 L
.05327 .07132 L
.05389 .07205 L
.05442 .0725 L
.05472 .07269 L
.055 .07283 L
.05516 .07288 L
.05524 .0729 L
.05532 .07293 L
Mistroke
.05541 .07294 L
.05548 .07295 L
.05563 .07297 L
.05577 .07297 L
.05593 .07296 L
.05608 .07294 L
.05621 .07291 L
.05637 .07286 L
.05651 .0728 L
.05684 .07263 L
.05716 .0724 L
.05751 .0721 L
.05815 .07136 L
.05874 .07049 L
.06007 .06784 L
.06125 .06476 L
.0625 .06079 L
.06706 .04146 L
.0683 .0355 L
.0696 .02953 L
.07013 .02739 L
.07043 .02637 L
.07071 .02557 L
.07086 .02519 L
.07103 .02486 L
.07119 .02463 L
.07133 .02448 L
.07147 .02441 L
.07162 .0244 L
.07177 .02447 L
.07192 .02461 L
.07207 .02483 L
.07221 .02509 L
.07252 .02587 L
.0731 .02782 L
.07417 .03251 L
.07659 .04432 L
.07903 .05551 L
.08132 .06424 L
.08239 .06754 L
.08351 .07042 L
.0841 .07167 L
.08474 .07283 L
.08528 .07364 L
.08587 .07433 L
.0862 .07463 L
.08651 .07486 L
.0868 .07502 L
.08694 .07509 L
.08711 .07515 L
Mistroke
.08725 .07518 L
.08739 .07521 L
.08754 .07523 L
.08769 .07523 L
.08782 .07522 L
.08795 .0752 L
.08809 .07517 L
.08823 .07513 L
.0884 .07507 L
.08856 .07499 L
.08891 .07477 L
.08923 .07451 L
.08956 .07419 L
.09013 .07347 L
.09076 .07247 L
.09199 .06989 L
.09311 .06685 L
.09564 .05782 L
.09813 .04646 L
.10044 .03482 L
.1016 .0293 L
.10217 .02702 L
.10241 .02619 L
.10269 .02544 L
.10281 .02516 L
.10295 .02491 L
.1031 .02472 L
.10323 .0246 L
.10339 .02456 L
.10354 .0246 L
.10367 .02471 L
.10382 .0249 L
.10397 .02517 L
.10413 .02555 L
.10447 .02655 L
.10507 .02888 L
.10994 .05359 L
.11218 .06361 L
.11462 .07211 L
.11595 .07545 L
.11659 .07673 L
.11718 .07768 L
.11778 .07845 L
.11835 .07897 L
.11866 .07918 L
.11895 .07931 L
.1191 .07937 L
.11919 .07939 L
.11927 .07941 L
.11935 .07942 L
Mistroke
.11944 .07943 L
.11952 .07943 L
.1196 .07944 L
.11974 .07943 L
.11989 .07941 L
.12003 .07937 L
.12016 .07933 L
.12031 .07927 L
.12047 .07919 L
.12077 .079 L
.12108 .07874 L
.12141 .0784 L
.12201 .07763 L
.12317 .07549 L
.12423 .07286 L
.12655 .06496 L
.12906 .05354 L
.13142 .04095 L
.13267 .03407 L
.13336 .0305 L
.13401 .02755 L
.13431 .02644 L
.13462 .02553 L
.13479 .02519 L
.13488 .02504 L
.13497 .02493 L
.13513 .02482 L
.13521 .02481 L
.13529 .02482 L
.13544 .02491 L
.13557 .02508 L
.13571 .02533 L
.13587 .0257 L
.13618 .02668 L
.13647 .0278 L
.13877 .04012 L
.14127 .05457 L
.14359 .06648 L
.14584 .07587 L
.14698 .0796 L
.14762 .08137 L
.14823 .08282 L
.14881 .08399 L
.14945 .08502 L
.14973 .08539 L
.15003 .08573 L
.15031 .08599 L
.15057 .08618 L
.15073 .08627 L
.1509 .08636 L
Mistroke
.15107 .08642 L
.15116 .08645 L
.15125 .08647 L
.15133 .08648 L
.15141 .08649 L
.15156 .08649 L
.15172 .08648 L
.15181 .08647 L
.15189 .08645 L
.15203 .08641 L
.15217 .08636 L
.15247 .08619 L
.15277 .08597 L
.15309 .08567 L
.15369 .08491 L
.15425 .08398 L
.15551 .08111 L
.15674 .07732 L
.15806 .07224 L
.16046 .0605 L
.16306 .04504 L
.16429 .03733 L
.16495 .03323 L
.16558 .0297 L
.16611 .02718 L
.16626 .02659 L
.16641 .02612 L
.16654 .02576 L
.16668 .02545 L
.16683 .02524 L
.16698 .02514 L
.16712 .02517 L
.16726 .02529 L
.16742 .02556 L
.16756 .02591 L
.16789 .02703 L
.16846 .02977 L
.16907 .03335 L
.17017 .04056 L
.17267 .05744 L
.17506 .07225 L
.17633 .07906 L
.17766 .08534 L
.17886 .08999 L
.17949 .09208 L
.18017 .09401 L
.18079 .09549 L
.18136 .09658 L
.18194 .09744 L
.1822 .09774 L
Mistroke
.18248 .09801 L
.18264 .09814 L
.18279 .09823 L
.18293 .09831 L
.18309 .09837 L
.18323 .09842 L
.18336 .09844 L
.18349 .09845 L
.18364 .09845 L
.1838 .09843 L
.18389 .0984 L
.18397 .09838 L
.18412 .09832 L
.18428 .09823 L
.18456 .09803 L
.18487 .09774 L
.18542 .09702 L
.18601 .09598 L
.18709 .09338 L
.18824 .08958 L
.18951 .08427 L
.19205 .07021 L
.19461 .05234 L
.19694 .03462 L
.19751 .03069 L
.19782 .0288 L
.19811 .0273 L
.19827 .02662 L
.19842 .02613 L
.1985 .02592 L
.19858 .02576 L
.19867 .02564 L
.19876 .02557 L
.19891 .0256 L
.199 .02569 L
.19908 .02582 L
.19923 .02619 L
.19937 .02668 L
.19965 .02797 L
.19994 .02969 L
.20047 .03336 L
.20165 .04295 L
.20624 .08097 L
.2088 .09856 L
.21112 .1107 L
.21228 .11509 L
.21289 .11692 L
.21354 .11848 L
.2141 .11952 L
.21442 .11997 L
Mistroke
.21473 .1203 L
.21487 .12042 L
.215 .12052 L
.21512 .12059 L
.21525 .12065 L
.21539 .1207 L
.21553 .12073 L
.21568 .12074 L
.21582 .12072 L
.21597 .12069 L
.2161 .12064 L
.21625 .12056 L
.21641 .12045 L
.21673 .12014 L
.21703 .11977 L
.2176 .11879 L
.21814 .11755 L
.21934 .11372 L
.22065 .10786 L
.22303 .09288 L
.22557 .07149 L
.22794 .04763 L
.22898 .03684 L
.22957 .03124 L
.22985 .02896 L
.23012 .02727 L
.23025 .02664 L
.2304 .0262 L
.23054 .02604 L
.23067 .02612 L
.2308 .02643 L
.23095 .02703 L
.23111 .02791 L
.23125 .02893 L
.23183 .03418 L
.23245 .04096 L
.23496 .07142 L
.23734 .10005 L
.23994 .12827 L
.24245 .15058 L
.24355 .15829 L
.24473 .16503 L
.24537 .16792 L
.24595 .1701 L
.24651 .17173 L
.24682 .17244 L
.2471 .17297 L
.24741 .1734 L
.24757 .17359 L
.24773 .17372 L
Mistroke
.24787 .17381 L
.24801 .17386 L
.24816 .17389 L
.24831 .17389 L
.24847 .17384 L
.24856 .1738 L
.24864 .17375 L
.24878 .17364 L
.24894 .17348 L
.24927 .17302 L
.24964 .17231 L
.25027 .17054 L
.25088 .16827 L
.252 .16241 L
.25322 .15373 L
.25453 .14156 L
.25693 .112 L
.25947 .07113 L
.26061 .05023 L
.26124 .03862 L
.26155 .03329 L
.2617 .03096 L
.26183 .02912 L
.26197 .02764 L
.2621 .02676 L
.26224 .0265 L
.26238 .02707 L
.26254 .02847 L
.26261 .02943 L
.2627 .03063 L
.26299 .03557 L
.26404 .05813 L
.26893 .18278 L
.27363 .31114 L
.27863 .43771 L
.28113 .49162 L
.28344 .53342 L
.28569 .56545 L
.28682 .57808 L
.28807 .58911 L
.2887 .59347 L
.2893 .59688 L
.28983 .59934 L
.29041 .60135 L
.29075 .60218 L
.29105 .60273 L
.29121 .60296 L
.2913 .60306 L
.29139 .60315 L
.29147 .60321 L
Mistroke
.29156 .60326 L
.29172 .60331 L
.29188 .60331 L
.29202 .60327 L
.2921 .60323 L
.29219 .60317 L
.29235 .60302 L
.29249 .60283 L
.29265 .60258 L
.29293 .60202 L
.29322 .60127 L
.29352 .60031 L
.29406 .59813 L
.29464 .59513 L
.29528 .59109 L
.29642 .58188 L
.29748 .57113 L
.29995 .53855 L
.30219 .50067 L
.30701 .39881 L
.31165 .28616 L
.31659 .16685 L
.31904 .1126 L
.32134 .06707 L
.32247 .04714 L
.32302 .03819 L
.32354 .03079 L
.32383 .0274 L
.32399 .0259 L
.32413 .0249 L
.32422 .02452 L
.32429 .02431 L
.32438 .02424 L
.32446 .02434 L
.32461 .02491 L
.3247 .02542 L
.32478 .02599 L
.32532 .03147 L
.32591 .03836 L
.3283 .06462 L
.32956 .0757 L
.3309 .08517 L
.33209 .0916 L
.33272 .09428 L
.3334 .09661 L
.33402 .09825 L
.3343 .09882 L
.33459 .09935 L
.33486 .09973 L
.33514 .10005 L
Mistroke
.33529 .10019 L
.33544 .10029 L
.33558 .10037 L
.33571 .10042 L
.33585 .10046 L
.336 .10048 L
.33614 .10048 L
.33627 .10045 L
.33642 .1004 L
.33651 .10037 L
.33659 .10032 L
.33689 .10011 L
.33717 .09982 L
.33749 .09941 L
.33813 .09829 L
.33868 .09704 L
.33928 .0954 L
.34036 .09174 L
.34277 .08087 L
.34531 .06665 L
.34991 .0391 L
.35112 .03263 L
.35172 .02985 L
.35227 .02768 L
.35257 .02671 L
.3529 .02587 L
.35307 .02555 L
.35324 .02532 L
.35333 .02522 L
.35341 .02516 L
.3535 .0251 L
.35359 .02508 L
.35373 .02509 L
.35389 .02517 L
.35403 .02531 L
.35417 .02548 L
.35449 .02607 L
.35479 .02683 L
.35597 .03091 L
.35722 .03616 L
.35944 .04652 L
.36403 .07274 L
.36638 .09047 L
.3689 .11326 L
.37389 .16784 L
.3787 .22509 L
.38332 .27442 L
.38571 .29449 L
.38693 .30282 L
.38824 .31014 L
Mistroke
.38884 .31286 L
.38947 .3153 L
.39005 .31716 L
.39059 .31853 L
.3911 .31951 L
.39139 .31992 L
.39165 .32021 L
.39179 .32033 L
.39193 .32044 L
.39201 .32048 L
.39209 .32052 L
.39224 .32057 L
.39238 .32059 L
.39253 .32059 L
.39267 .32056 L
.3928 .32051 L
.39296 .32043 L
.3931 .32032 L
.39338 .32005 L
.39367 .31965 L
.39399 .3191 L
.39457 .31779 L
.3951 .31622 L
.39631 .31129 L
.3976 .30413 L
.39997 .28579 L
.40218 .26321 L
.40688 .2011 L
.41188 .12324 L
.41438 .08455 L
.41548 .06882 L
.41607 .06111 L
.41669 .05361 L
.4173 .04753 L
.41759 .0452 L
.41785 .04345 L
.41812 .04215 L
.41826 .04167 L
.41841 .04131 L
.41856 .04112 L
.41869 .04108 L
.41881 .04116 L
.41894 .04137 L
.41909 .04174 L
.41923 .04222 L
.41955 .0437 L
.41985 .04561 L
.42018 .04802 L
.42133 .05804 L
.42371 .08 L
Mistroke
.42497 .09018 L
.42631 .09935 L
.4275 .10589 L
.42813 .10873 L
.42881 .11129 L
.42943 .11315 L
.43 .11447 L
.43054 .11538 L
.43082 .1157 L
.43096 .11584 L
.43112 .11596 L
.43127 .11606 L
.43142 .11612 L
.43158 .11615 L
.43167 .11616 L
.43175 .11616 L
.4319 .11614 L
.43204 .1161 L
.43212 .11607 L
.4322 .11603 L
.43235 .11593 L
.43264 .11568 L
.43294 .11531 L
.43348 .11441 L
.43416 .11281 L
.4348 .11086 L
.436 .10611 L
.43843 .09258 L
.44066 .07649 L
.44312 .0568 L
.44433 .04788 L
.4449 .04433 L
.44543 .0417 L
.44569 .04069 L
.44597 .0399 L
.44612 .03961 L
.44625 .03941 L
.4464 .03929 L
.44649 .03927 L
.44656 .03927 L
.44669 .03933 L
.44681 .03945 L
.44695 .03965 L
.44709 .03995 L
.44738 .04079 L
.44764 .04181 L
.44822 .0448 L
.44886 .04886 L
.45001 .05741 L
.45236 .07588 L
Mistroke
.45495 .09367 L
.45613 .1002 L
.45741 .1058 L
.45802 .10793 L
.45861 .10959 L
.45913 .11075 L
.45943 .11128 L
.4597 .11167 L
.45998 .11199 L
.46013 .11212 L
.46029 .11222 L
.46042 .1123 L
.46055 .11234 L
.46069 .11237 L
.46084 .11238 L
.46092 .11237 L
.461 .11236 L
.46108 .11233 L
.46117 .1123 L
.46132 .11222 L
.46149 .11209 L
.4618 .11178 L
.46208 .11138 L
.46272 .11014 L
.4633 .10856 L
.46398 .10622 L
.46462 .10347 L
.46577 .09721 L
.46701 .08876 L
.46922 .06923 L
.47163 .04334 L
.47229 .03645 L
.47265 .03325 L
.47283 .03197 L
.47299 .03103 L
.47314 .03041 L
.47328 .03005 L
.47342 .02996 L
.47351 .03004 L
.47359 .0302 L
.47374 .03075 L
.47382 .03118 L
.4739 .03167 L
.47424 .03443 L
.47483 .04116 L
.47545 .04967 L
.47656 .06667 L
.47907 .1088 L
.48367 .18998 L
.48856 .26943 L
Mistroke
.49082 .30001 L
.49327 .32698 L
.49461 .33859 L
.49584 .34717 L
.49702 .35337 L
.49762 .35574 L
.49793 .35677 L
.49827 .35774 L
.4986 .3585 L
.4989 .35906 L
.49919 .35947 L
.49935 .35965 L
.4995 .35978 L
.49964 .35987 L
.49978 .35993 L
.49992 .35996 L
.50008 .35996 L
.50021 .35993 L
.50034 .35988 L
.50047 .3598 L
.50062 .35968 L
.50079 .3595 L
.50094 .3593 L
.5013 .3587 L
.50161 .35803 L
.50194 .35716 L
.50251 .35527 L
.50314 .35263 L
.50436 .3459 L
.50548 .33792 L
.50799 .31394 L
.51278 .24916 L
.51738 .17153 L
.51995 .12597 L
.52228 .08562 L
.52345 .06649 L
.52471 .04738 L
.52529 .03969 L
.5256 .03603 L
.5259 .03317 L
.52603 .03215 L
.52615 .03134 L
.52629 .03062 L
.52642 .03018 L
.52657 .02997 L
.5267 .03002 L
.52684 .03034 L
.527 .03097 L
.52713 .03173 L
.52728 .03277 L
Mistroke
.52759 .0353 L
.52813 .04072 L
.52934 .05412 L
.53155 .0766 L
.53391 .0952 L
.53523 .10274 L
.53582 .10538 L
.53643 .10772 L
.53701 .10946 L
.53731 .11021 L
.53764 .1109 L
.53794 .11141 L
.53821 .11179 L
.53834 .11193 L
.53848 .11207 L
.53861 .11217 L
.53875 .11226 L
.53883 .1123 L
.53892 .11233 L
.53899 .11235 L
.53908 .11237 L
.53922 .11238 L
.53938 .11236 L
.53946 .11234 L
.53954 .11231 L
.53963 .11227 L
.53972 .11222 L
.53988 .11211 L
.54005 .11196 L
.54035 .1116 L
.54067 .11111 L
.54125 .10993 L
.54184 .10834 L
.54238 .10657 L
.5436 .10149 L
.54581 .08891 L
.54829 .07088 L
.55059 .05283 L
.55114 .04888 L
.55173 .04504 L
.55201 .04351 L
.5523 .04209 L
.55255 .04107 L
.55281 .0402 L
.55297 .03981 L
.55312 .03954 L
.55327 .03936 L
.55341 .03927 L
.55349 .03926 L
.55357 .03928 L
Mistroke
.55372 .03938 L
.55381 .03949 L
.5539 .03963 L
.55406 .03997 L
.55434 .0408 L
.5546 .04181 L
.55519 .04483 L
.55637 .05288 L
.55747 .0615 L
.55996 .08122 L
.56221 .09663 L
.5634 .10326 L
.56466 .10892 L
.5653 .1112 L
.566 .11322 L
.5663 .11395 L
.56663 .11462 L
.56694 .11514 L
.56723 .11553 L
.56754 .11585 L
.56771 .11597 L
.56779 .11602 L
.56788 .11607 L
.56797 .11611 L
.56805 .11613 L
.5682 .11616 L
.56835 .11616 L
.5685 .11614 L
.56864 .1161 L
.56878 .11602 L
.56892 .11593 L
.56905 .11583 L
.56936 .1155 L
.56966 .11508 L
.57021 .11403 L
.57082 .11246 L
.57206 .10794 L
.5732 .10221 L
.57428 .09552 L
.57651 .07808 L
.57777 .06656 L
.57895 .05553 L
.57955 .05022 L
.58011 .04584 L
.58043 .04386 L
.58059 .04299 L
.58077 .04223 L
.58091 .04172 L
.58099 .04151 L
.58108 .04133 L
Mistroke
.58122 .04113 L
.58136 .04108 L
.58144 .04112 L
.58153 .04121 L
.58169 .04153 L
.58178 .04181 L
.58187 .04214 L
.58204 .0429 L
.58235 .04479 L
.58269 .04745 L
.58391 .06076 L
.58886 .13494 L
.59362 .20854 L
.59821 .26757 L
.60056 .29049 L
.60188 .30062 L
.60309 .3082 L
.60432 .31407 L
.60497 .31642 L
.60565 .31834 L
.60594 .31897 L
.60625 .31953 L
.60654 .31995 L
.60681 .32024 L
.60696 .32037 L
.60711 .32046 L
.60726 .32054 L
.60735 .32057 L
.60743 .32058 L
.60751 .32059 L
.60759 .32059 L
.60768 .32059 L
.60777 .32057 L
.60792 .32052 L
.608 .32048 L
.60808 .32043 L
.60823 .32032 L
.60839 .32017 L
.60868 .31983 L
.609 .31935 L
.60934 .31868 L
.60995 .31714 L
.61053 .31529 L
.61161 .31085 L
.61277 .30465 L
.61518 .28753 L
.61773 .26423 L
.62232 .21312 L
.6272 .15505 L
.63191 .10552 L
Mistroke
.63431 .08496 L
.63691 .06662 L
.64172 .04096 L
.64412 .03056 L
.6447 .02842 L
.64532 .02652 L
.64551 .02608 L
.64568 .02573 L
.64585 .02545 L
.64601 .02526 L
.64616 .02514 L
.64632 .02508 L
.64641 .02508 L
.64649 .0251 L
.64665 .0252 L
.64679 .02535 L
.64694 .02558 L
.64722 .02614 L
.64754 .02704 L
.64783 .02804 L
.64908 .03361 L
.6513 .04615 L
.65611 .07488 L
.65831 .08614 L
.65956 .09143 L
.66074 .09544 L
.66129 .09698 L
.66188 .09832 L
.66219 .0989 L
.66253 .09944 L
.66283 .09983 L
.66312 .10012 L
.66328 .10024 L
.66345 .10035 L
.66361 .10042 L
.66376 .10046 L
.66391 .10048 L
.664 .10048 L
.66409 .10047 L
.66417 .10046 L
.66425 .10044 L
.66435 .1004 L
.66443 .10036 L
.66458 .10028 L
.66474 .10016 L
.66502 .09988 L
.66535 .09943 L
.66566 .09892 L
.66625 .0976 L
.66687 .09576 L
Mistroke
.66798 .09127 L
.66918 .08466 L
.67049 .07525 L
.67285 .05272 L
.67417 .0375 L
.67474 .03074 L
.67507 .02731 L
.67523 .02593 L
.67538 .02496 L
.67553 .02437 L
.67567 .02425 L
.67581 .02464 L
.6759 .02507 L
.67597 .0256 L
.67614 .02702 L
.67628 .0286 L
.67661 .0328 L
.67795 .05419 L
.68037 .10045 L
.6852 .20904 L
.68985 .32331 L
.69479 .4396 L
.69725 .49024 L
.69955 .53078 L
.70176 .56224 L
.70299 .57618 L
.70413 .58663 L
.70535 .59512 L
.706 .59841 L
.70633 .59977 L
.70669 .601 L
.707 .60185 L
.70728 .60246 L
.70755 .6029 L
.70769 .60306 L
.70784 .60319 L
.70793 .60325 L
.70801 .60328 L
.70816 .60332 L
.70824 .60332 L
.70832 .6033 L
.70841 .60327 L
.7085 .60323 L
.70865 .60311 L
.70879 .60296 L
.70895 .60274 L
.70911 .60246 L
.70942 .60179 L
.70975 .60086 L
.71033 .59864 L
Mistroke
.71103 .59509 L
.71167 .59102 L
.71291 .58064 L
.71409 .5681 L
.71651 .53414 L
.71874 .49414 L
.72351 .38607 L
.72809 .26433 L
.73297 .13224 L
.73522 .07551 L
.73641 .04805 L
.73672 .04137 L
.73706 .03475 L
.73721 .03204 L
.73738 .02956 L
.73751 .02791 L
.73767 .02677 L
.73783 .02653 L
.73791 .02683 L
.738 .02735 L
.73815 .02893 L
.7383 .03091 L
.739 .04293 L
.74023 .06574 L
.74266 .10602 L
.74508 .13735 L
.74615 .14821 L
.7473 .15774 L
.74791 .16189 L
.74847 .16514 L
.74904 .16791 L
.74957 .17 L
.75018 .17186 L
.7505 .1726 L
.75067 .17291 L
.75085 .1732 L
.75102 .17343 L
.75117 .1736 L
.75132 .17373 L
.75148 .17382 L
.75162 .17387 L
.75176 .1739 L
.7519 .17389 L
.75206 .17384 L
.75221 .17376 L
.75229 .17371 L
.75237 .17364 L
.7527 .17327 L
.75298 .17282 L
.75329 .1722 L
Mistroke
.75399 .17029 L
.75463 .16794 L
.75587 .16182 L
.75706 .15422 L
.75944 .13429 L
.76166 .11137 L
.76638 .05491 L
.76762 .04017 L
.76827 .03315 L
.76863 .02987 L
.7688 .02852 L
.76896 .02749 L
.76911 .02674 L
.76925 .02627 L
.7694 .02605 L
.76949 .02605 L
.76957 .02615 L
.76972 .02654 L
.76981 .02689 L
.76989 .02729 L
.77023 .02957 L
.77079 .03456 L
.7714 .04068 L
.77377 .06507 L
.77636 .08822 L
.77755 .09707 L
.77883 .10507 L
.78003 .11113 L
.78114 .11542 L
.78174 .11723 L
.78237 .11873 L
.78268 .11931 L
.78301 .11982 L
.7832 .12006 L
.78337 .12025 L
.78353 .1204 L
.78371 .12053 L
.78387 .12062 L
.78402 .12068 L
.78417 .12072 L
.78431 .12074 L
.78439 .12074 L
.78447 .12073 L
.78462 .1207 L
.7847 .12067 L
.78478 .12064 L
.78496 .12054 L
.78511 .12044 L
.78526 .12031 L
.78553 .12003 L
Mistroke
.78614 .11911 L
.7867 .11797 L
.78731 .11636 L
.78855 .11208 L
.79077 .10114 L
.79311 .08582 L
.79562 .0661 L
.798 .04591 L
.79925 .03553 L
.79994 .03046 L
.80028 .02837 L
.80043 .02759 L
.80059 .02685 L
.80075 .02628 L
.80089 .02588 L
.80105 .02563 L
.80114 .02557 L
.80122 .02556 L
.8013 .02561 L
.80138 .0257 L
.80147 .02586 L
.80156 .02608 L
.80172 .02658 L
.80189 .02729 L
.8025 .03074 L
.80307 .03473 L
.80538 .05227 L
.8076 .06797 L
.81004 .08206 L
.8112 .0874 L
.81245 .09199 L
.81314 .09402 L
.81377 .09553 L
.8144 .09674 L
.81471 .09721 L
.815 .09759 L
.81529 .0979 L
.81555 .09812 L
.81569 .09822 L
.81585 .0983 L
.81593 .09834 L
.81601 .09837 L
.81617 .09842 L
.81624 .09843 L
.81633 .09845 L
.81648 .09845 L
.81663 .09844 L
.81677 .09842 L
.81691 .09837 L
.81708 .0983 L
Mistroke
.81725 .09821 L
.81741 .0981 L
.81769 .09785 L
.81797 .09755 L
.81848 .09684 L
.81903 .09585 L
.81963 .09452 L
.82076 .09128 L
.82202 .08667 L
.82455 .07442 L
.82708 .05909 L
.8294 .04347 L
.83058 .03557 L
.83168 .02903 L
.83196 .02765 L
.83223 .02657 L
.83238 .02608 L
.83254 .02565 L
.83268 .02537 L
.83282 .02521 L
.83297 .02514 L
.83311 .02519 L
.83326 .02536 L
.83335 .02551 L
.83343 .02567 L
.83376 .02666 L
.83407 .02796 L
.83523 .03434 L
.83646 .04207 L
.83868 .05567 L
.8411 .06846 L
.84237 .07399 L
.84371 .07881 L
.84491 .08219 L
.84559 .08368 L
.84623 .08479 L
.84682 .08556 L
.84709 .08585 L
.84735 .08607 L
.84765 .08627 L
.8478 .08634 L
.84797 .08641 L
.84811 .08645 L
.84824 .08648 L
.84839 .08649 L
.84855 .08649 L
.84863 .08649 L
.84871 .08647 L
.84885 .08644 L
.84901 .08639 L
Mistroke
.84918 .08632 L
.84949 .08614 L
.84977 .08592 L
.85041 .08521 L
.8511 .08416 L
.85225 .08171 L
.85352 .07807 L
.85587 .06896 L
.85839 .05639 L
.86078 .04277 L
.86204 .03546 L
.86273 .03166 L
.86338 .02846 L
.86366 .02729 L
.86395 .02624 L
.8641 .02578 L
.86427 .02537 L
.86442 .02509 L
.86456 .02491 L
.86465 .02485 L
.86473 .02481 L
.86482 .02481 L
.8649 .02483 L
.86504 .02494 L
.8652 .02516 L
.86528 .02531 L
.86536 .0255 L
.86552 .0259 L
.86587 .02708 L
.86708 .03273 L
.86818 .03874 L
.87067 .05218 L
.87298 .06302 L
.87521 .07122 L
.87646 .07464 L
.87759 .07698 L
.87818 .07789 L
.8785 .0783 L
.8788 .07863 L
.87908 .07888 L
.87933 .07907 L
.87961 .07923 L
.87976 .0793 L
.87991 .07936 L
.88006 .07939 L
.88021 .07942 L
.88029 .07943 L
.88038 .07943 L
.88054 .07943 L
.88068 .07941 L
Mistroke
.88084 .07938 L
.88097 .07934 L
.88112 .07929 L
.88144 .07911 L
.88179 .07886 L
.88242 .07821 L
.88307 .07731 L
.88366 .07626 L
.885 .07316 L
.88618 .06963 L
.88743 .06515 L
.89201 .04373 L
.89331 .03685 L
.89455 .03061 L
.89509 .02821 L
.89567 .02612 L
.89596 .02532 L
.89613 .02498 L
.89621 .02485 L
.89629 .02475 L
.89644 .02461 L
.89657 .02456 L
.89672 .02458 L
.89688 .02469 L
.89703 .02488 L
.89711 .02502 L
.89719 .02517 L
.89749 .02591 L
.89805 .02784 L
.8993 .03356 L
.90156 .04496 L
.90401 .05635 L
.90631 .06504 L
.90744 .06842 L
.90851 .07103 L
.9091 .07222 L
.90974 .07329 L
.91033 .07406 L
.91087 .0746 L
.91119 .07484 L
.91149 .07501 L
.91164 .07508 L
.91181 .07514 L
.91189 .07517 L
.91198 .07519 L
.91207 .07521 L
.91215 .07522 L
.9123 .07523 L
.91244 .07523 L
.9126 .07521 L
Mistroke
.91268 .0752 L
.91277 .07518 L
.91291 .07514 L
.91307 .07508 L
.91335 .07495 L
.91362 .07477 L
.91392 .07453 L
.91452 .07389 L
.91508 .07312 L
.91559 .07226 L
.91686 .06953 L
.91806 .06622 L
.9203 .05826 L
.92494 .03679 L
.92618 .03088 L
.92679 .02828 L
.92734 .02628 L
.92764 .02544 L
.92778 .02512 L
.92792 .02484 L
.92808 .02462 L
.92822 .02448 L
.92831 .02442 L
.92839 .0244 L
.92855 .02442 L
.92863 .02445 L
.92871 .02452 L
.9288 .02461 L
.92888 .02472 L
.92903 .02497 L
.92919 .02531 L
.92955 .0263 L
.92988 .02743 L
.93469 .04961 L
.93689 .05863 L
.93815 .06294 L
.93932 .06634 L
.94047 .06903 L
.94171 .07117 L
.94236 .07196 L
.94271 .0723 L
.94303 .07255 L
.94331 .07272 L
.94361 .07285 L
.94378 .0729 L
.94387 .07293 L
.94395 .07294 L
.94409 .07296 L
.94425 .07297 L
.9444 .07297 L
Mistroke
.94454 .07295 L
.94467 .07293 L
.94481 .07289 L
.94496 .07284 L
.94513 .07277 L
.94542 .07261 L
.94594 .07221 L
.94651 .0716 L
.94713 .07074 L
.9478 .06959 L
.94901 .06694 L
.95142 .05959 L
.95396 .04936 L
.95637 .0382 L
.95742 .03324 L
.95856 .0283 L
.95886 .02715 L
.95919 .02608 L
.95949 .02528 L
.95964 .02496 L
.95977 .02472 L
.95991 .02453 L
.96003 .02441 L
.96017 .02433 L
.96032 .02432 L
.96047 .02438 L
.96055 .02444 L
.96063 .02452 L
.96078 .02473 L
.96092 .02498 L
.96123 .0257 L
.96155 .02669 L
.96213 .02885 L
.96345 .03468 L
.96803 .0552 L
.97038 .06336 L
.9717 .06688 L
.97291 .06935 L
.97372 .07061 L
.97448 .07146 L
.97487 .07179 L
.9751 .07193 L
.97531 .07205 L
.97553 .07214 L
.97564 .07217 L
.97576 .07221 L
.97587 .07223 L
.97597 .07224 L
.97608 .07225 L
.97619 .07226 L
Mistroke
Mfstroke
1 0 0 r
[ ] 0 setdash
.05556 .01472 m
.05556 .07296 L
s
.0873 .01472 m
.0873 .07519 L
s
.11905 .01472 m
.11905 .07935 L
s
.15079 .01472 m
.15079 .08631 L
s
.18254 .01472 m
.18254 .09806 L
s
.21429 .01472 m
.21429 .11979 L
s
.24603 .01472 m
.24603 .17035 L
s
.27778 .01472 m
.27778 .41774 L
s
.30952 .01472 m
.30952 .33869 L
s
.34127 .01472 m
.34127 .08802 L
s
.37302 .01472 m
.37302 .15759 L
s
.40476 .01472 m
.40476 .23116 L
s
.43651 .01472 m
.43651 .10371 L
s
.46825 .01472 m
.46825 .07841 L
s
.5 .01472 m
.5 .35996 L
s
.53175 .01472 m
.53175 .07841 L
s
.56349 .01472 m
.56349 .10371 L
s
.59524 .01472 m
.59524 .23116 L
s
.62698 .01472 m
.62698 .15759 L
s
.65873 .01472 m
.65873 .08802 L
s
.69048 .01472 m
.69048 .33869 L
s
.72222 .01472 m
.72222 .41774 L
s
.75397 .01472 m
.75397 .17035 L
s
.78571 .01472 m
.78571 .11979 L
s
.81746 .01472 m
.81746 .09806 L
s
.84921 .01472 m
.84921 .08631 L
s
.88095 .01472 m
.88095 .07935 L
s
.9127 .01472 m
.9127 .07519 L
s
.94444 .01472 m
.94444 .07296 L
s
.97619 .01472 m
.97619 .07226 L
s
.015 w
.05556 .07296 Mdot
.0873 .07519 Mdot
.11905 .07935 Mdot
.15079 .08631 Mdot
.18254 .09806 Mdot
.21429 .11979 Mdot
.24603 .17035 Mdot
.27778 .41774 Mdot
.30952 .33869 Mdot
.34127 .08802 Mdot
.37302 .15759 Mdot
.40476 .23116 Mdot
.43651 .10371 Mdot
.46825 .07841 Mdot
.5 .35996 Mdot
.53175 .07841 Mdot
.56349 .10371 Mdot
.59524 .23116 Mdot
.62698 .15759 Mdot
.65873 .08802 Mdot
.69048 .33869 Mdot
.72222 .41774 Mdot
.75397 .17035 Mdot
.78571 .11979 Mdot
.81746 .09806 Mdot
.84921 .08631 Mdot
.88095 .07935 Mdot
.9127 .07519 Mdot
.94444 .07296 Mdot
.97619 .07226 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309473 0.0938566 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0279 -12 -4.5 ]
[-0.0125 .0279 0 4.5 ]
[-0.0125 .12176 -12 -4.5 ]
[-0.0125 .12176 0 4.5 ]
[-0.0125 .21562 -12 -4.5 ]
[-0.0125 .21562 0 4.5 ]
[-0.0125 .30947 -6 -4.5 ]
[-0.0125 .30947 0 4.5 ]
[-0.0125 .40333 -6 -4.5 ]
[-0.0125 .40333 0 4.5 ]
[-0.0125 .49719 -6 -4.5 ]
[-0.0125 .49719 0 4.5 ]
[-0.0125 .59104 -6 -4.5 ]
[-0.0125 .59104 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0279 m
.00625 .0279 L
s
[(-3)] -0.0125 .0279 1 0 Mshowa
0 .12176 m
.00625 .12176 L
s
[(-2)] -0.0125 .12176 1 0 Mshowa
0 .21562 m
.00625 .21562 L
s
[(-1)] -0.0125 .21562 1 0 Mshowa
0 .30947 m
.00625 .30947 L
s
[(0)] -0.0125 .30947 1 0 Mshowa
0 .40333 m
.00625 .40333 L
s
[(1)] -0.0125 .40333 1 0 Mshowa
0 .49719 m
.00625 .49719 L
s
[(2)] -0.0125 .49719 1 0 Mshowa
0 .59104 m
.00625 .59104 L
s
[(3)] -0.0125 .59104 1 0 Mshowa
.125 Mabswid
0 .04667 m
.00375 .04667 L
s
0 .06545 m
.00375 .06545 L
s
0 .08422 m
.00375 .08422 L
s
0 .10299 m
.00375 .10299 L
s
0 .14053 m
.00375 .14053 L
s
0 .1593 m
.00375 .1593 L
s
0 .17807 m
.00375 .17807 L
s
0 .19685 m
.00375 .19685 L
s
0 .23439 m
.00375 .23439 L
s
0 .25316 m
.00375 .25316 L
s
0 .27193 m
.00375 .27193 L
s
0 .2907 m
.00375 .2907 L
s
0 .32824 m
.00375 .32824 L
s
0 .34702 m
.00375 .34702 L
s
0 .36579 m
.00375 .36579 L
s
0 .38456 m
.00375 .38456 L
s
0 .4221 m
.00375 .4221 L
s
0 .44087 m
.00375 .44087 L
s
0 .45964 m
.00375 .45964 L
s
0 .47841 m
.00375 .47841 L
s
0 .51596 m
.00375 .51596 L
s
0 .53473 m
.00375 .53473 L
s
0 .5535 m
.00375 .5535 L
s
0 .57227 m
.00375 .57227 L
s
0 .00913 m
.00375 .00913 L
s
0 .60981 m
.00375 .60981 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0279 m
1 .0279 L
s
.99375 .12176 m
1 .12176 L
s
.99375 .21562 m
1 .21562 L
s
.99375 .30947 m
1 .30947 L
s
.99375 .40333 m
1 .40333 L
s
.99375 .49719 m
1 .49719 L
s
.99375 .59104 m
1 .59104 L
s
.125 Mabswid
.99625 .04667 m
1 .04667 L
s
.99625 .06545 m
1 .06545 L
s
.99625 .08422 m
1 .08422 L
s
.99625 .10299 m
1 .10299 L
s
.99625 .14053 m
1 .14053 L
s
.99625 .1593 m
1 .1593 L
s
.99625 .17807 m
1 .17807 L
s
.99625 .19685 m
1 .19685 L
s
.99625 .23439 m
1 .23439 L
s
.99625 .25316 m
1 .25316 L
s
.99625 .27193 m
1 .27193 L
s
.99625 .2907 m
1 .2907 L
s
.99625 .32824 m
1 .32824 L
s
.99625 .34702 m
1 .34702 L
s
.99625 .36579 m
1 .36579 L
s
.99625 .38456 m
1 .38456 L
s
.99625 .4221 m
1 .4221 L
s
.99625 .44087 m
1 .44087 L
s
.99625 .45964 m
1 .45964 L
s
.99625 .47841 m
1 .47841 L
s
.99625 .51596 m
1 .51596 L
s
.99625 .53473 m
1 .53473 L
s
.99625 .5535 m
1 .5535 L
s
.99625 .57227 m
1 .57227 L
s
.99625 .00913 m
1 .00913 L
s
.99625 .60981 m
1 .60981 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30947 m
1 .30947 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .30947 m
.02847 .27609 L
.03089 .26002 L
.03218 .25241 L
.03288 .24865 L
.03355 .2455 L
.03417 .24303 L
.0345 .24196 L
.03484 .24104 L
.03514 .24046 L
.03522 .24034 L
.0353 .24023 L
.03546 .24008 L
.03561 .24001 L
.03575 .24001 L
.03588 .24007 L
.03602 .24021 L
.03618 .24047 L
.03632 .24082 L
.03646 .24123 L
.0366 .24178 L
.03676 .24253 L
.03692 .2435 L
.03722 .24579 L
.03749 .24864 L
.03774 .25206 L
.03802 .25685 L
.03832 .26339 L
.03948 .30507 L
.04012 .33436 L
.04071 .35757 L
.04102 .36677 L
.04135 .37459 L
.04172 .3811 L
.04206 .38544 L
.04235 .38816 L
.04267 .3903 L
.04283 .3911 L
.043 .39177 L
.04316 .39225 L
.04331 .39258 L
.04345 .39279 L
.04361 .39294 L
.04369 .39297 L
.04378 .39298 L
.04393 .39294 L
.04408 .39283 L
.04423 .39266 L
.04436 .39246 L
.0445 .39219 L
Mistroke
.04482 .39141 L
.04516 .39036 L
.04578 .388 L
.04812 .37567 L
.05314 .34164 L
.05798 .30651 L
.06263 .27448 L
.06504 .26082 L
.06563 .25819 L
.06625 .25587 L
.06661 .25484 L
.06694 .25413 L
.0671 .25388 L
.06718 .25377 L
.06727 .25368 L
.06735 .25362 L
.06743 .25358 L
.06758 .25356 L
.06773 .25362 L
.06787 .25375 L
.06802 .25399 L
.0681 .25417 L
.06818 .25436 L
.06833 .25485 L
.0685 .25553 L
.0688 .25725 L
.06909 .25951 L
.06939 .26275 L
.06964 .26637 L
.06992 .27142 L
.07025 .27906 L
.07055 .2879 L
.07122 .31462 L
.07181 .34242 L
.07244 .3686 L
.07301 .38542 L
.07333 .39219 L
.07363 .39703 L
.07391 .40041 L
.07416 .40278 L
.07444 .40472 L
.07458 .40547 L
.07474 .40614 L
.07491 .40671 L
.07507 .40712 L
.07521 .40737 L
.07536 .40755 L
.07544 .4076 L
.07553 .40763 L
.07563 .40763 L
Mistroke
.07571 .4076 L
.07587 .40749 L
.07595 .4074 L
.07603 .4073 L
.07633 .40677 L
.07665 .40597 L
.07724 .40401 L
.07849 .39835 L
.07961 .39205 L
.08214 .37577 L
.08698 .34121 L
.09163 .30748 L
.09399 .29134 L
.09524 .28345 L
.09658 .27588 L
.09724 .27265 L
.09787 .27006 L
.09843 .26823 L
.09859 .26783 L
.09875 .26747 L
.0989 .26719 L
.09904 .26698 L
.09918 .26684 L
.09931 .26675 L
.09945 .26672 L
.09961 .26677 L
.09974 .26689 L
.09988 .26711 L
.10002 .2674 L
.10014 .26774 L
.10029 .2683 L
.10043 .26895 L
.10059 .2698 L
.10076 .27096 L
.10104 .27348 L
.10134 .27711 L
.10164 .28196 L
.10197 .28895 L
.10228 .29754 L
.10257 .30744 L
.10369 .35947 L
.10399 .37327 L
.10432 .38608 L
.10461 .39533 L
.10491 .40311 L
.10527 .41 L
.10559 .41463 L
.10589 .41769 L
.10606 .41905 L
.10621 .42008 L
Mistroke
.10636 .42088 L
.10651 .42159 L
.10668 .42215 L
.10676 .4224 L
.10685 .42259 L
.10699 .42285 L
.10708 .42295 L
.10716 .42302 L
.10729 .42309 L
.10745 .42307 L
.10759 .42299 L
.10773 .42285 L
.10788 .42263 L
.10803 .42236 L
.10857 .42095 L
.1092 .41864 L
.10978 .41604 L
.11109 .40901 L
.11586 .37719 L
.12043 .34363 L
.12531 .30868 L
.12755 .29426 L
.12874 .2877 L
.12939 .28463 L
.13 .28222 L
.13033 .28117 L
.13063 .2804 L
.13079 .28007 L
.13097 .2798 L
.13106 .2797 L
.13114 .27962 L
.13123 .27956 L
.13133 .27953 L
.13149 .27955 L
.13158 .27961 L
.13166 .2797 L
.13181 .27993 L
.13189 .2801 L
.13197 .28031 L
.13212 .28078 L
.13228 .28143 L
.13256 .28305 L
.13272 .28427 L
.13287 .28563 L
.13321 .28967 L
.13351 .29458 L
.13383 .30157 L
.13414 .31061 L
.13443 .32138 L
.13498 .34719 L
Mistroke
.1356 .37924 L
.13616 .40397 L
.13645 .41329 L
.13676 .42111 L
.1371 .42758 L
.13741 .43187 L
.1377 .43475 L
.13796 .43668 L
.1381 .43746 L
.13825 .43816 L
.13841 .43873 L
.13856 .43913 L
.13869 .43939 L
.13883 .43957 L
.13895 .43965 L
.13908 .43968 L
.13922 .43964 L
.13937 .43952 L
.13951 .43935 L
.13964 .43914 L
.13992 .43854 L
.14023 .43768 L
.14085 .43542 L
.14196 .43013 L
.14447 .41487 L
.14934 .38014 L
.15402 .34525 L
.15641 .32794 L
.15901 .31037 L
.16021 .30313 L
.16088 .29959 L
.1615 .29665 L
.16207 .29442 L
.16232 .29362 L
.16259 .29289 L
.16273 .2926 L
.16288 .29234 L
.16303 .29213 L
.16318 .29201 L
.16326 .29197 L
.16335 .29196 L
.16343 .29197 L
.16351 .29201 L
.16365 .29217 L
.16381 .29244 L
.16395 .29282 L
.16411 .29338 L
.16426 .29407 L
.1644 .29486 L
.16466 .29685 L
Mistroke
.16494 .29979 L
.16527 .30467 L
.16558 .31107 L
.16586 .31872 L
.16616 .32947 L
.1673 .39088 L
.16759 .40629 L
.16786 .41873 L
.16813 .42862 L
.16837 .43594 L
.16863 .44219 L
.16892 .44734 L
.16921 .45111 L
.16952 .45397 L
.16967 .45501 L
.16983 .45591 L
.16998 .45658 L
.17011 .45706 L
.17027 .45745 L
.17036 .45762 L
.17044 .45774 L
.17052 .45783 L
.1706 .45788 L
.17069 .45791 L
.17078 .4579 L
.17092 .45783 L
.17101 .45776 L
.17108 .45767 L
.17124 .45743 L
.17141 .4571 L
.17172 .45632 L
.17199 .45543 L
.17332 .44957 L
.17561 .43579 L
.17811 .4184 L
.18302 .38172 L
.18775 .3462 L
.19016 .329 L
.19143 .32062 L
.19277 .3127 L
.19335 .30973 L
.19397 .30702 L
.19433 .30575 L
.19466 .30484 L
.19481 .30449 L
.19489 .30434 L
.19498 .3042 L
.19506 .3041 L
.19514 .30401 L
.19529 .30391 L
Mistroke
.19545 .30391 L
.19559 .30401 L
.19572 .3042 L
.19587 .30451 L
.19602 .305 L
.19619 .30572 L
.19635 .30661 L
.19649 .30762 L
.19677 .31026 L
.19692 .31223 L
.19707 .31439 L
.19733 .31947 L
.19761 .32676 L
.19884 .39232 L
.19913 .4125 L
.19944 .4312 L
.19971 .44397 L
.2 .45476 L
.20026 .46186 L
.20054 .46753 L
.20081 .47142 L
.20105 .47403 L
.20131 .47605 L
.20146 .47689 L
.2016 .4775 L
.20175 .47798 L
.20188 .4783 L
.20204 .47854 L
.20219 .47865 L
.20232 .47866 L
.20247 .47858 L
.20263 .47841 L
.20277 .47818 L
.20303 .4776 L
.20331 .47679 L
.20395 .47435 L
.20454 .47158 L
.20706 .45626 L
.21185 .42126 L
.21646 .38565 L
.22136 .34837 L
.22363 .33247 L
.22483 .32502 L
.22609 .31855 L
.2264 .31732 L
.22673 .31623 L
.22692 .31574 L
.22709 .31539 L
.22718 .31526 L
.22727 .31514 L
Mistroke
.22735 .31507 L
.22743 .31503 L
.22758 .31504 L
.22772 .31515 L
.22787 .31541 L
.22796 .31562 L
.22803 .31587 L
.22818 .31648 L
.22835 .31739 L
.22851 .31866 L
.22867 .3202 L
.22882 .32208 L
.22899 .32464 L
.22914 .32745 L
.22929 .33111 L
.22943 .33513 L
.22958 .34051 L
.22985 .35301 L
.23016 .37364 L
.2305 .40275 L
.23082 .43203 L
.23111 .45447 L
.23141 .47202 L
.23158 .47914 L
.23174 .48453 L
.23202 .49169 L
.23218 .49465 L
.23233 .49684 L
.23248 .49865 L
.23264 .50018 L
.23281 .50145 L
.23298 .50233 L
.23307 .5027 L
.23316 .50302 L
.23325 .50326 L
.23334 .50343 L
.23349 .50362 L
.23357 .50366 L
.23366 .50367 L
.23374 .50364 L
.23382 .50358 L
.23398 .5034 L
.23413 .50314 L
.23427 .50282 L
.23458 .50191 L
.23491 .50067 L
.23609 .49486 L
.2411 .46001 L
.24593 .42214 L
.25058 .38508 L
Mistroke
.25294 .36655 L
.25553 .347 L
.25671 .33865 L
.25799 .33068 L
.25861 .32749 L
.25891 .32618 L
.25919 .32519 L
.25932 .32482 L
.25945 .32453 L
.25957 .3243 L
.25972 .32414 L
.25986 .3241 L
.25999 .32419 L
.26014 .32445 L
.26029 .32494 L
.26044 .3257 L
.26052 .32627 L
.2606 .32689 L
.26074 .32836 L
.26089 .33045 L
.26103 .33293 L
.26115 .33592 L
.26129 .34018 L
.26144 .34627 L
.2616 .3551 L
.26177 .36864 L
.26193 .38641 L
.26208 .40766 L
.26238 .45648 L
.26253 .4769 L
.26267 .4917 L
.2628 .50268 L
.26294 .51146 L
.26308 .51807 L
.26323 .52347 L
.26336 .52688 L
.2635 .5297 L
.26362 .53176 L
.26374 .53322 L
.26389 .53461 L
.26402 .53555 L
.26417 .53627 L
.26433 .53676 L
.26446 .53698 L
.26459 .53706 L
.26473 .53701 L
.26488 .53683 L
.26504 .53654 L
.26517 .53619 L
.26548 .53516 L
Mistroke
.26604 .53266 L
.2673 .52524 L
.26985 .50703 L
.27468 .46882 L
.27932 .4307 L
.28426 .38969 L
.28902 .35002 L
.2936 .31182 L
.29847 .27116 L
.30316 .23204 L
.30814 .1904 L
.31294 .14996 L
.31756 .1095 L
.31989 .08655 L
.32053 .07935 L
.32122 .07065 L
.32182 .06176 L
.32214 .0562 L
.32247 .04921 L
.3228 .04088 L
.32309 .03116 L
.32324 .02536 L
.32339 .01793 L
.32354 .59919 L
.32367 .58975 L
.32397 .5619 L
.32413 .54052 L
.32429 .51732 L
.32462 .46725 L
.32479 .44731 L
.32494 .43239 L
.32521 .41265 L
.32536 .40481 L
.32551 .39783 L
.32603 .38078 L
.32635 .37338 L
.32665 .36757 L
.3272 .35862 L
.32838 .34395 L
.32963 .33135 L
.33186 .3119 L
.33644 .2774 L
.33899 .26042 L
.34131 .24651 L
.34375 .2341 L
.34482 .22964 L
.34544 .22746 L
.34601 .22569 L
.34659 .22424 L
.34685 .22372 L
Mistroke
.34712 .22325 L
.3474 .2229 L
.34755 .22275 L
.3477 .22265 L
.34785 .22258 L
.34799 .22256 L
.34807 .22256 L
.34816 .22258 L
.34831 .22265 L
.34847 .22278 L
.34861 .22295 L
.34877 .2232 L
.34894 .22354 L
.34929 .22453 L
.34961 .22581 L
.34991 .22736 L
.35023 .22954 L
.35082 .23516 L
.35112 .23922 L
.35146 .24469 L
.35175 .25063 L
.35206 .25824 L
.35265 .27713 L
.35319 .29968 L
.35442 .35513 L
.3551 .37816 L
.35573 .39292 L
.35631 .40284 L
.35695 .41069 L
.35755 .41623 L
.3581 .42024 L
.35917 .42605 L
.36031 .43039 L
.36145 .4335 L
.36208 .43482 L
.36267 .43579 L
.36321 .43648 L
.36349 .43677 L
.3638 .43702 L
.36409 .43721 L
.36436 .43732 L
.36448 .43736 L
.36462 .4374 L
.36475 .43741 L
.36487 .43742 L
.36503 .43742 L
.36517 .4374 L
.3653 .43737 L
.36544 .43733 L
.36559 .43727 L
Mistroke
.36576 .43719 L
.36605 .437 L
.36657 .43653 L
.36714 .43582 L
.36776 .43482 L
.36843 .43349 L
.36963 .43043 L
.37205 .42207 L
.37459 .41058 L
.37919 .38471 L
.38408 .35234 L
.38878 .31813 L
.39379 .27946 L
.39861 .24032 L
.40324 .20078 L
.40818 .15543 L
.41063 .13026 L
.41293 .1029 L
.41406 .08666 L
.41513 .06783 L
.41572 .05509 L
.41636 .03817 L
.41665 .02936 L
.4168 .02409 L
.41695 .01882 L
.41709 .60332 L
.41724 .59734 L
.41749 .58602 L
.41863 .52439 L
.41985 .46086 L
.42056 .43484 L
.42119 .41656 L
.42244 .38989 L
.42362 .37081 L
.42489 .35338 L
.42721 .32599 L
.43213 .27412 L
.43687 .22399 L
.43925 .19602 L
.44143 .16561 L
.44255 .14628 L
.44377 .11939 L
.44499 .08166 L
.44566 .0549 L
.44598 .04019 L
.44613 .03348 L
.44628 .02599 L
.44643 .01879 L
.44657 .60175 L
.44672 .59463 L
Mistroke
.44688 .58706 L
.44752 .55796 L
.44865 .51711 L
.44933 .49834 L
.44997 .48346 L
.45118 .46071 L
.45358 .4261 L
.4558 .39973 L
.46053 .34991 L
.46507 .30354 L
.4676 .2758 L
.4687 .26213 L
.46991 .24466 L
.47048 .23477 L
.47109 .22196 L
.47166 .20618 L
.47218 .18619 L
.47249 .17028 L
.47277 .15171 L
.47341 .09499 L
.47398 .04337 L
.47411 .03305 L
.47426 .02309 L
.47435 .01789 L
.47442 .60316 L
.47457 .59518 L
.47515 .57199 L
.47547 .56236 L
.47576 .55494 L
.47686 .53351 L
.47815 .51504 L
.47936 .50043 L
.48401 .45307 L
.48896 .40746 L
.49372 .3649 L
.4983 .32444 L
.50318 .28147 L
.50787 .23991 L
.51286 .19498 L
.51766 .14965 L
.51986 .12708 L
.52111 .11298 L
.52229 .09807 L
.52344 .08034 L
.52408 .06761 L
.52467 .05251 L
.52526 .03136 L
.52542 .02385 L
.52551 .01931 L
.5256 .01472 L
Mistroke
.52567 .59986 L
.52576 .59457 L
.52591 .58442 L
.52658 .52486 L
.52691 .49353 L
.52721 .46879 L
.52776 .43558 L
.52806 .42253 L
.52835 .41244 L
.52895 .3961 L
.5296 .38258 L
.53092 .36187 L
.53214 .34625 L
.53687 .29544 L
.54189 .24422 L
.54441 .2169 L
.54673 .18893 L
.54899 .1553 L
.55013 .13319 L
.55078 .11793 L
.55138 .10077 L
.55198 .08079 L
.55262 .0549 L
.5529 .04218 L
.5532 .02805 L
.55333 .02212 L
.55346 .01571 L
.5536 .59837 L
.55374 .59179 L
.55495 .53949 L
.55627 .49874 L
.55752 .47139 L
.55869 .4515 L
.56123 .41692 L
.56595 .36468 L
.57096 .31272 L
.57347 .28522 L
.57579 .25656 L
.57696 .23929 L
.57805 .21962 L
.57919 .19203 L
.57979 .17224 L
.58044 .14501 L
.58166 .0774 L
.582 .05855 L
.58235 .04016 L
.58266 .02614 L
.58274 .02257 L
.58283 .01886 L
.58292 .01548 L
Mistroke
.58299 .60219 L
.58314 .597 L
.58329 .59176 L
.58356 .58308 L
.58418 .56636 L
.58542 .54094 L
.58665 .52177 L
.58799 .50444 L
.59042 .47756 L
.59535 .43062 L
.6001 .38943 L
.60467 .35185 L
.60953 .31362 L
.61421 .27879 L
.61918 .24458 L
.62397 .21582 L
.62639 .20363 L
.62858 .19442 L
.62972 .19046 L
.63096 .18692 L
.63164 .18532 L
.63226 .18409 L
.63285 .18314 L
.63318 .1827 L
.63349 .18236 L
.63378 .18208 L
.6341 .18184 L
.63424 .18176 L
.63439 .18168 L
.63452 .18163 L
.63466 .18158 L
.6348 .18155 L
.63493 .18153 L
.63505 .18152 L
.63518 .18153 L
.63533 .18154 L
.63546 .18157 L
.6356 .18161 L
.63576 .18167 L
.63608 .18184 L
.63643 .18211 L
.63676 .18243 L
.63707 .18279 L
.63764 .18364 L
.63825 .18479 L
.63942 .18773 L
.64052 .19157 L
.64119 .19461 L
.64182 .19818 L
.64239 .20218 L
Mistroke
.64301 .20777 L
.64365 .21556 L
.64426 .22566 L
.6448 .2381 L
.64539 .25639 L
.64659 .30946 L
.64723 .33749 L
.64759 .35021 L
.64792 .36022 L
.64823 .36798 L
.64857 .37481 L
.64917 .38357 L
.64946 .38673 L
.64977 .38942 L
.65006 .39142 L
.65033 .39287 L
.65063 .39415 L
.65079 .39468 L
.65095 .39516 L
.65111 .39552 L
.65125 .3958 L
.65139 .396 L
.65154 .39617 L
.65163 .39625 L
.65171 .39631 L
.6518 .39635 L
.6519 .39638 L
.65198 .39639 L
.65206 .39638 L
.65215 .39636 L
.65224 .39633 L
.65232 .39628 L
.65241 .39622 L
.65257 .39608 L
.65287 .3957 L
.65315 .39523 L
.65346 .39461 L
.65401 .39322 L
.65526 .389 L
.65779 .3773 L
.66275 .34713 L
.66753 .31203 L
.66993 .29165 L
.67212 .26918 L
.67271 .26161 L
.67334 .25164 L
.67363 .24606 L
.67394 .23902 L
.67422 .23083 L
.67449 .22126 L
Mistroke
.67479 .20636 L
.67495 .19534 L
.67511 .1822 L
.67539 .15048 L
.67569 .10499 L
.67602 .05835 L
.67621 .03904 L
.67638 .02546 L
.67653 .01533 L
.67662 .60021 L
.6767 .5962 L
.67701 .58393 L
.67731 .57505 L
.67758 .56852 L
.67819 .55703 L
.67929 .54174 L
.68178 .51562 L
.68659 .47298 L
.69122 .43391 L
.69614 .39276 L
.70088 .3532 L
.70544 .31515 L
.7103 .27463 L
.71497 .23567 L
.71993 .1944 L
.72472 .15504 L
.72932 .11828 L
.73189 .09919 L
.7331 .09115 L
.73363 .08803 L
.73422 .08505 L
.73449 .0839 L
.73478 .08289 L
.73494 .08245 L
.73509 .08215 L
.73524 .08196 L
.73538 .08189 L
.73553 .08196 L
.73561 .08206 L
.73569 .08224 L
.73584 .08273 L
.73598 .08343 L
.73606 .08396 L
.73615 .08464 L
.7363 .0862 L
.73646 .08852 L
.73664 .09207 L
.7368 .09631 L
.73694 .1017 L
.73707 .1081 L
Mistroke
.73721 .1173 L
.73737 .13088 L
.73753 .15037 L
.73783 .19645 L
.73808 .23377 L
.73822 .24932 L
.73835 .26022 L
.7385 .26982 L
.73865 .27653 L
.73878 .28118 L
.73893 .28503 L
.73909 .28818 L
.73924 .29032 L
.7394 .29203 L
.73948 .29269 L
.73957 .29329 L
.73972 .29404 L
.73981 .29434 L
.73988 .29454 L
.74003 .29479 L
.74017 .29485 L
.74031 .29479 L
.74046 .2946 L
.74058 .29436 L
.74071 .29403 L
.74102 .29304 L
.7413 .29187 L
.74252 .28526 L
.74383 .27653 L
.7488 .2388 L
.75358 .20072 L
.75817 .16451 L
.76074 .14521 L
.76307 .12919 L
.76423 .12235 L
.76484 .11933 L
.76518 .11792 L
.76549 .11682 L
.76576 .11606 L
.76592 .11573 L
.76606 .1155 L
.76621 .11534 L
.7663 .11529 L
.76638 .11528 L
.76652 .11534 L
.76668 .11555 L
.76682 .11588 L
.76698 .11641 L
.76712 .11711 L
.76725 .11795 L
Mistroke
.76751 .12016 L
.76764 .12165 L
.76778 .12363 L
.76808 .12957 L
.76825 .13419 L
.76841 .13953 L
.7687 .15274 L
.76885 .16146 L
.76901 .17285 L
.7696 .22503 L
.76985 .24657 L
.77013 .26503 L
.7703 .27347 L
.77046 .27984 L
.77076 .28914 L
.77093 .29289 L
.77109 .2956 L
.77127 .29806 L
.77144 .29986 L
.77159 .30109 L
.77174 .30209 L
.77188 .30274 L
.77202 .30327 L
.77218 .30365 L
.77227 .30379 L
.77235 .30387 L
.77251 .30393 L
.77266 .30387 L
.7728 .30373 L
.77294 .30349 L
.77308 .3032 L
.77321 .30288 L
.77382 .30077 L
.77442 .29801 L
.77506 .29458 L
.77728 .28027 L
.78187 .24618 L
.78676 .20834 L
.79147 .17298 L
.79387 .15662 L
.79513 .14913 L
.79582 .14561 L
.79647 .1429 L
.79676 .14191 L
.79705 .14115 L
.7972 .14082 L
.79728 .14068 L
.79737 .14054 L
.79752 .14037 L
.79766 .14029 L
Mistroke
.79775 .14028 L
.79783 .14031 L
.79792 .14037 L
.79802 .14048 L
.79818 .14078 L
.79827 .14101 L
.79835 .14128 L
.79851 .14192 L
.79865 .14269 L
.79882 .14381 L
.79898 .14515 L
.79926 .14832 L
.7994 .15039 L
.79955 .15312 L
.79983 .15929 L
.80008 .16705 L
.80039 .17923 L
.80066 .19374 L
.80129 .23555 L
.80186 .27098 L
.80218 .28513 L
.80247 .29458 L
.80275 .30107 L
.80304 .30617 L
.80332 .30958 L
.80357 .3118 L
.80372 .31273 L
.80387 .31352 L
.80402 .3141 L
.80415 .31449 L
.80431 .3148 L
.8044 .31492 L
.80448 .31499 L
.80463 .31505 L
.80479 .31499 L
.80487 .31492 L
.80495 .31483 L
.80514 .31456 L
.80529 .31423 L
.80546 .31381 L
.80607 .31175 L
.80722 .3063 L
.80845 .29909 L
.81066 .28423 L
.81566 .24723 L
.82047 .21091 L
.82511 .17852 L
.82634 .1712 L
.8275 .16548 L
.82808 .16326 L
Mistroke
.82841 .16229 L
.82871 .16161 L
.82879 .16146 L
.82888 .16133 L
.82903 .16115 L
.82913 .16108 L
.82922 .16104 L
.8293 .16104 L
.82939 .16106 L
.82947 .16111 L
.82955 .1612 L
.82964 .16132 L
.82973 .16148 L
.82988 .16186 L
.83004 .16241 L
.83018 .16308 L
.83034 .164 L
.8305 .16513 L
.83067 .16663 L
.83098 .17017 L
.83126 .17475 L
.8316 .18226 L
.83196 .19326 L
.83226 .20568 L
.8326 .22254 L
.83325 .26065 L
.83357 .27769 L
.83387 .29072 L
.83413 .30002 L
.83442 .30799 L
.83471 .31403 L
.83502 .31872 L
.83518 .32057 L
.83533 .32204 L
.83561 .32415 L
.83577 .32503 L
.83592 .32567 L
.83608 .32621 L
.83616 .32644 L
.83625 .32661 L
.83639 .32684 L
.83647 .32692 L
.83655 .32697 L
.83669 .32699 L
.83685 .32693 L
.83698 .3268 L
.83713 .3266 L
.83726 .32636 L
.83739 .32609 L
.83801 .32424 L
Mistroke
.83869 .32147 L
.83992 .31509 L
.84484 .28203 L
.84958 .24686 L
.85414 .21361 L
.85667 .19675 L
.85778 .19023 L
.85837 .18713 L
.859 .1842 L
.85961 .18179 L
.85991 .18087 L
.86018 .18018 L
.86045 .17966 L
.86059 .17947 L
.86074 .17933 L
.86087 .17927 L
.86099 .17927 L
.86113 .17934 L
.86127 .1795 L
.86135 .17963 L
.86143 .17979 L
.86158 .18018 L
.86174 .18074 L
.86192 .18155 L
.86207 .18242 L
.86223 .18358 L
.86252 .18634 L
.86281 .19005 L
.86312 .19531 L
.86338 .20115 L
.86367 .20926 L
.86498 .2701 L
.8653 .28581 L
.86563 .30011 L
.86594 .3108 L
.86623 .31869 L
.86648 .32419 L
.86676 .3288 L
.86706 .33263 L
.86734 .33518 L
.86764 .3371 L
.86781 .33789 L
.86796 .33845 L
.86811 .33886 L
.86825 .33912 L
.86841 .33932 L
.86855 .33941 L
.8687 .33941 L
.86883 .33935 L
.86897 .33922 L
Mistroke
.86913 .33901 L
.86929 .33871 L
.86944 .33838 L
.86973 .3376 L
.87025 .33581 L
.87082 .33341 L
.87326 .3197 L
.87818 .28549 L
.88292 .25064 L
.88747 .21879 L
.88981 .20496 L
.89045 .20183 L
.89112 .19905 L
.8917 .19723 L
.89185 .19684 L
.89202 .19649 L
.89218 .19623 L
.89232 .19604 L
.89247 .19591 L
.89255 .19587 L
.89264 .19586 L
.89273 .19586 L
.89281 .1959 L
.89297 .19605 L
.89311 .19628 L
.89325 .19659 L
.8934 .19704 L
.89356 .19767 L
.89373 .19855 L
.89392 .19974 L
.89426 .20271 L
.8946 .20681 L
.8949 .21191 L
.89519 .21828 L
.89546 .22576 L
.89608 .24899 L
.89733 .30764 L
.89763 .31844 L
.89794 .32771 L
.89828 .33554 L
.8986 .34096 L
.89889 .34473 L
.89916 .34738 L
.89947 .34947 L
.89964 .35034 L
.89979 .35097 L
.89993 .3514 L
.90008 .35176 L
.90022 .35199 L
.90034 .35213 L
Mistroke
.90049 .35222 L
.90057 .35222 L
.90065 .35221 L
.90079 .35213 L
.90094 .35199 L
.90107 .3518 L
.90121 .35156 L
.90146 .351 L
.90203 .34925 L
.90267 .3467 L
.90326 .3439 L
.90459 .33651 L
.90702 .32086 L
.91175 .28702 L
.9163 .25399 L
.91883 .23664 L
.92115 .22253 L
.92233 .21671 L
.9229 .21442 L
.92342 .21277 L
.92371 .2121 L
.92384 .21185 L
.92397 .21164 L
.92412 .21146 L
.92426 .21136 L
.9244 .21132 L
.92449 .21132 L
.92456 .21135 L
.92464 .2114 L
.92473 .21149 L
.92488 .21172 L
.92503 .21205 L
.92517 .21246 L
.92533 .21309 L
.92548 .2138 L
.92581 .21599 L
.9261 .21859 L
.9264 .22242 L
.92673 .22777 L
.92703 .23429 L
.92756 .25042 L
.92814 .27426 L
.92877 .30411 L
.92912 .31901 L
.92944 .33084 L
.92974 .33973 L
.93002 .34628 L
.93032 .352 L
.93065 .35665 L
.93094 .35966 L
Mistroke
.93125 .36206 L
.93141 .36297 L
.93158 .36375 L
.93174 .36433 L
.93188 .36474 L
.93196 .36492 L
.93205 .36508 L
.93221 .36528 L
.9323 .36534 L
.93238 .36538 L
.93247 .36539 L
.93257 .36537 L
.93265 .36532 L
.93274 .36525 L
.93283 .36516 L
.93291 .36506 L
.93322 .36451 L
.9335 .3638 L
.93378 .36298 L
.93439 .36067 L
.93564 .35463 L
.9403 .3247 L
.94526 .2889 L
.95003 .25513 L
.95244 .24 L
.95349 .23433 L
.95462 .22933 L
.95493 .22828 L
.95526 .22733 L
.95553 .2267 L
.95569 .22641 L
.95584 .22621 L
.95599 .22606 L
.95613 .22598 L
.95625 .22596 L
.95639 .22601 L
.95654 .22614 L
.9567 .22639 L
.95685 .22673 L
.95699 .22714 L
.95714 .22774 L
.95731 .22855 L
.95761 .23049 L
.95793 .23345 L
.95829 .23798 L
.95859 .24325 L
.95892 .25061 L
.95951 .26925 L
.96074 .32363 L
.96107 .33711 L
Mistroke
.96143 .34894 L
.96174 .35697 L
.96207 .36386 L
.96239 .36873 L
.96267 .3721 L
.96299 .37483 L
.96315 .37588 L
.96332 .37682 L
.96348 .37747 L
.96362 .37796 L
.96378 .37839 L
.96393 .37867 L
.96407 .37884 L
.9642 .37892 L
.96435 .37895 L
.9645 .37889 L
.96465 .37877 L
.9648 .37857 L
.96495 .37833 L
.96509 .37804 L
.96564 .37656 L
.96623 .37438 L
.96686 .37156 L
.96907 .35915 L
.97409 .32471 L
.97619 .30947 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.05556 .30947 m
.05556 .3241 L
s
.0873 .30947 m
.0873 .33885 L
s
.11905 .30947 m
.11905 .35385 L
s
.15079 .30947 m
.15079 .36928 L
s
.18254 .30947 m
.18254 .38538 L
s
.21429 .30947 m
.21429 .40251 L
s
.24603 .30947 m
.24603 .42136 L
s
.27778 .30947 m
.27778 .44346 L
s
.30952 .30947 m
.30952 .1788 L
s
.34127 .30947 m
.34127 .24676 L
s
.37302 .30947 m
.37302 .418 L
s
.40476 .30947 m
.40476 .1873 L
s
.43651 .30947 m
.43651 .22803 L
s
.46825 .30947 m
.46825 .26786 L
s
.5 .30947 m
.5 .30947 L
s
.53175 .30947 m
.53175 .35108 L
s
.56349 .30947 m
.56349 .39092 L
s
.59524 .30947 m
.59524 .43165 L
s
.62698 .30947 m
.62698 .20095 L
s
.65873 .30947 m
.65873 .37219 L
s
.69048 .30947 m
.69048 .44014 L
s
.72222 .30947 m
.72222 .17549 L
s
.75397 .30947 m
.75397 .19759 L
s
.78571 .30947 m
.78571 .21644 L
s
.81746 .30947 m
.81746 .23357 L
s
.84921 .30947 m
.84921 .24966 L
s
.88095 .30947 m
.88095 .26509 L
s
.9127 .30947 m
.9127 .2801 L
s
.94444 .30947 m
.94444 .29485 L
s
.97619 .30947 m
.97619 .30947 L
s
.015 w
.05556 .3241 Mdot
.0873 .33885 Mdot
.11905 .35385 Mdot
.15079 .36928 Mdot
.18254 .38538 Mdot
.21429 .40251 Mdot
.24603 .42136 Mdot
.27778 .44346 Mdot
.30952 .1788 Mdot
.34127 .24676 Mdot
.37302 .418 Mdot
.40476 .1873 Mdot
.43651 .22803 Mdot
.46825 .26786 Mdot
.5 .30947 Mdot
.53175 .35108 Mdot
.56349 .39092 Mdot
.59524 .43165 Mdot
.62698 .20095 Mdot
.65873 .37219 Mdot
.69048 .44014 Mdot
.72222 .17549 Mdot
.75397 .19759 Mdot
.78571 .21644 Mdot
.81746 .23357 Mdot
.84921 .24966 Mdot
.88095 .26509 Mdot
.9127 .2801 Mdot
.94444 .29485 Mdot
.97619 .30947 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0328407 0.0147151 0.0140063 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18801 -0.0125 -3 -9 ]
[.18801 -0.0125 3 0 ]
[.35222 -0.0125 -6 -9 ]
[.35222 -0.0125 6 0 ]
[.51642 -0.0125 -6 -9 ]
[.51642 -0.0125 6 0 ]
[.68062 -0.0125 -6 -9 ]
[.68062 -0.0125 6 0 ]
[.84483 -0.0125 -6 -9 ]
[.84483 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15478 -12 -4.5 ]
[-0.0125 .15478 0 4.5 ]
[-0.0125 .29484 -12 -4.5 ]
[-0.0125 .29484 0 4.5 ]
[-0.0125 .4349 -12 -4.5 ]
[-0.0125 .4349 0 4.5 ]
[-0.0125 .57497 -12 -4.5 ]
[-0.0125 .57497 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18801 0 m
.18801 .00625 L
s
[(5)] .18801 -0.0125 0 1 Mshowa
.35222 0 m
.35222 .00625 L
s
[(10)] .35222 -0.0125 0 1 Mshowa
.51642 0 m
.51642 .00625 L
s
[(15)] .51642 -0.0125 0 1 Mshowa
.68062 0 m
.68062 .00625 L
s
[(20)] .68062 -0.0125 0 1 Mshowa
.84483 0 m
.84483 .00625 L
s
[(25)] .84483 -0.0125 0 1 Mshowa
.125 Mabswid
.05665 0 m
.05665 .00375 L
s
.08949 0 m
.08949 .00375 L
s
.12233 0 m
.12233 .00375 L
s
.15517 0 m
.15517 .00375 L
s
.22085 0 m
.22085 .00375 L
s
.25369 0 m
.25369 .00375 L
s
.28654 0 m
.28654 .00375 L
s
.31938 0 m
.31938 .00375 L
s
.38506 0 m
.38506 .00375 L
s
.4179 0 m
.4179 .00375 L
s
.45074 0 m
.45074 .00375 L
s
.48358 0 m
.48358 .00375 L
s
.54926 0 m
.54926 .00375 L
s
.5821 0 m
.5821 .00375 L
s
.61494 0 m
.61494 .00375 L
s
.64778 0 m
.64778 .00375 L
s
.71346 0 m
.71346 .00375 L
s
.74631 0 m
.74631 .00375 L
s
.77915 0 m
.77915 .00375 L
s
.81199 0 m
.81199 .00375 L
s
.87767 0 m
.87767 .00375 L
s
.91051 0 m
.91051 .00375 L
s
.94335 0 m
.94335 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15478 m
.00625 .15478 L
s
[(10)] -0.0125 .15478 1 0 Mshowa
0 .29484 m
.00625 .29484 L
s
[(20)] -0.0125 .29484 1 0 Mshowa
0 .4349 m
.00625 .4349 L
s
[(30)] -0.0125 .4349 1 0 Mshowa
0 .57497 m
.00625 .57497 L
s
[(40)] -0.0125 .57497 1 0 Mshowa
.125 Mabswid
0 .04273 m
.00375 .04273 L
s
0 .07074 m
.00375 .07074 L
s
0 .09875 m
.00375 .09875 L
s
0 .12677 m
.00375 .12677 L
s
0 .18279 m
.00375 .18279 L
s
0 .2108 m
.00375 .2108 L
s
0 .23882 m
.00375 .23882 L
s
0 .26683 m
.00375 .26683 L
s
0 .32285 m
.00375 .32285 L
s
0 .35087 m
.00375 .35087 L
s
0 .37888 m
.00375 .37888 L
s
0 .40689 m
.00375 .40689 L
s
0 .46292 m
.00375 .46292 L
s
0 .49093 m
.00375 .49093 L
s
0 .51894 m
.00375 .51894 L
s
0 .54695 m
.00375 .54695 L
s
0 .60298 m
.00375 .60298 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18801 .61178 m
.18801 .61803 L
s
.35222 .61178 m
.35222 .61803 L
s
.51642 .61178 m
.51642 .61803 L
s
.68062 .61178 m
.68062 .61803 L
s
.84483 .61178 m
.84483 .61803 L
s
.125 Mabswid
.05665 .61428 m
.05665 .61803 L
s
.08949 .61428 m
.08949 .61803 L
s
.12233 .61428 m
.12233 .61803 L
s
.15517 .61428 m
.15517 .61803 L
s
.22085 .61428 m
.22085 .61803 L
s
.25369 .61428 m
.25369 .61803 L
s
.28654 .61428 m
.28654 .61803 L
s
.31938 .61428 m
.31938 .61803 L
s
.38506 .61428 m
.38506 .61803 L
s
.4179 .61428 m
.4179 .61803 L
s
.45074 .61428 m
.45074 .61803 L
s
.48358 .61428 m
.48358 .61803 L
s
.54926 .61428 m
.54926 .61803 L
s
.5821 .61428 m
.5821 .61803 L
s
.61494 .61428 m
.61494 .61803 L
s
.64778 .61428 m
.64778 .61803 L
s
.71346 .61428 m
.71346 .61803 L
s
.74631 .61428 m
.74631 .61803 L
s
.77915 .61428 m
.77915 .61803 L
s
.81199 .61428 m
.81199 .61803 L
s
.87767 .61428 m
.87767 .61803 L
s
.91051 .61428 m
.91051 .61803 L
s
.94335 .61428 m
.94335 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15478 m
1 .15478 L
s
.99375 .29484 m
1 .29484 L
s
.99375 .4349 m
1 .4349 L
s
.99375 .57497 m
1 .57497 L
s
.125 Mabswid
.99625 .04273 m
1 .04273 L
s
.99625 .07074 m
1 .07074 L
s
.99625 .09875 m
1 .09875 L
s
.99625 .12677 m
1 .12677 L
s
.99625 .18279 m
1 .18279 L
s
.99625 .2108 m
1 .2108 L
s
.99625 .23882 m
1 .23882 L
s
.99625 .26683 m
1 .26683 L
s
.99625 .32285 m
1 .32285 L
s
.99625 .35087 m
1 .35087 L
s
.99625 .37888 m
1 .37888 L
s
.99625 .40689 m
1 .40689 L
s
.99625 .46292 m
1 .46292 L
s
.99625 .49093 m
1 .49093 L
s
.99625 .51894 m
1 .51894 L
s
.99625 .54695 m
1 .54695 L
s
.99625 .60298 m
1 .60298 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .51894 L
s
.05665 .01472 m
.05665 .10775 L
s
.08949 .01472 m
.08949 .14469 L
s
.12233 .01472 m
.12233 .33083 L
s
.15517 .01472 m
.15517 .22338 L
s
.18801 .01472 m
.18801 .12178 L
s
.22085 .01472 m
.22085 .48788 L
s
.25369 .01472 m
.25369 .60332 L
s
.28654 .01472 m
.28654 .24202 L
s
.31938 .01472 m
.31938 .16817 L
s
.35222 .01472 m
.35222 .13644 L
s
.38506 .01472 m
.38506 .11927 L
s
.4179 .01472 m
.4179 .10911 L
s
.45074 .01472 m
.45074 .10304 L
s
.48358 .01472 m
.48358 .09978 L
s
.51642 .01472 m
.51642 .09875 L
s
.54926 .01472 m
.54926 .09978 L
s
.5821 .01472 m
.5821 .10304 L
s
.61494 .01472 m
.61494 .10911 L
s
.64778 .01472 m
.64778 .11927 L
s
.68062 .01472 m
.68062 .13644 L
s
.71346 .01472 m
.71346 .16817 L
s
.74631 .01472 m
.74631 .24202 L
s
.77915 .01472 m
.77915 .60332 L
s
.81199 .01472 m
.81199 .48788 L
s
.84483 .01472 m
.84483 .12178 L
s
.87767 .01472 m
.87767 .22338 L
s
.91051 .01472 m
.91051 .33083 L
s
.94335 .01472 m
.94335 .14469 L
s
.97619 .01472 m
.97619 .10775 L
s
.015 w
.02381 .51894 Mdot
.05665 .10775 Mdot
.08949 .14469 Mdot
.12233 .33083 Mdot
.15517 .22338 Mdot
.18801 .12178 Mdot
.22085 .48788 Mdot
.25369 .60332 Mdot
.28654 .24202 Mdot
.31938 .16817 Mdot
.35222 .13644 Mdot
.38506 .11927 Mdot
.4179 .10911 Mdot
.45074 .10304 Mdot
.48358 .09978 Mdot
.51642 .09875 Mdot
.54926 .09978 Mdot
.5821 .10304 Mdot
.61494 .10911 Mdot
.64778 .11927 Mdot
.68062 .13644 Mdot
.71346 .16817 Mdot
.74631 .24202 Mdot
.77915 .60332 Mdot
.81199 .48788 Mdot
.84483 .12178 Mdot
.87767 .22338 Mdot
.91051 .33083 Mdot
.94335 .14469 Mdot
.97619 .10775 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0328407 0.309017 0.0983632 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18801 -0.0125 -3 -9 ]
[.18801 -0.0125 3 0 ]
[.35222 -0.0125 -6 -9 ]
[.35222 -0.0125 6 0 ]
[.51642 -0.0125 -6 -9 ]
[.51642 -0.0125 6 0 ]
[.68062 -0.0125 -6 -9 ]
[.68062 -0.0125 6 0 ]
[.84483 -0.0125 -6 -9 ]
[.84483 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01393 -12 -4.5 ]
[-0.0125 .01393 0 4.5 ]
[-0.0125 .11229 -12 -4.5 ]
[-0.0125 .11229 0 4.5 ]
[-0.0125 .21065 -12 -4.5 ]
[-0.0125 .21065 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40738 -6 -4.5 ]
[-0.0125 .40738 0 4.5 ]
[-0.0125 .50574 -6 -4.5 ]
[-0.0125 .50574 0 4.5 ]
[-0.0125 .60411 -6 -4.5 ]
[-0.0125 .60411 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18801 0 m
.18801 .00625 L
s
[(5)] .18801 -0.0125 0 1 Mshowa
.35222 0 m
.35222 .00625 L
s
[(10)] .35222 -0.0125 0 1 Mshowa
.51642 0 m
.51642 .00625 L
s
[(15)] .51642 -0.0125 0 1 Mshowa
.68062 0 m
.68062 .00625 L
s
[(20)] .68062 -0.0125 0 1 Mshowa
.84483 0 m
.84483 .00625 L
s
[(25)] .84483 -0.0125 0 1 Mshowa
.125 Mabswid
.05665 0 m
.05665 .00375 L
s
.08949 0 m
.08949 .00375 L
s
.12233 0 m
.12233 .00375 L
s
.15517 0 m
.15517 .00375 L
s
.22085 0 m
.22085 .00375 L
s
.25369 0 m
.25369 .00375 L
s
.28654 0 m
.28654 .00375 L
s
.31938 0 m
.31938 .00375 L
s
.38506 0 m
.38506 .00375 L
s
.4179 0 m
.4179 .00375 L
s
.45074 0 m
.45074 .00375 L
s
.48358 0 m
.48358 .00375 L
s
.54926 0 m
.54926 .00375 L
s
.5821 0 m
.5821 .00375 L
s
.61494 0 m
.61494 .00375 L
s
.64778 0 m
.64778 .00375 L
s
.71346 0 m
.71346 .00375 L
s
.74631 0 m
.74631 .00375 L
s
.77915 0 m
.77915 .00375 L
s
.81199 0 m
.81199 .00375 L
s
.87767 0 m
.87767 .00375 L
s
.91051 0 m
.91051 .00375 L
s
.94335 0 m
.94335 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01393 m
.00625 .01393 L
s
[(-3)] -0.0125 .01393 1 0 Mshowa
0 .11229 m
.00625 .11229 L
s
[(-2)] -0.0125 .11229 1 0 Mshowa
0 .21065 m
.00625 .21065 L
s
[(-1)] -0.0125 .21065 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .40738 m
.00625 .40738 L
s
[(1)] -0.0125 .40738 1 0 Mshowa
0 .50574 m
.00625 .50574 L
s
[(2)] -0.0125 .50574 1 0 Mshowa
0 .60411 m
.00625 .60411 L
s
[(3)] -0.0125 .60411 1 0 Mshowa
.125 Mabswid
0 .0336 m
.00375 .0336 L
s
0 .05327 m
.00375 .05327 L
s
0 .07295 m
.00375 .07295 L
s
0 .09262 m
.00375 .09262 L
s
0 .13196 m
.00375 .13196 L
s
0 .15164 m
.00375 .15164 L
s
0 .17131 m
.00375 .17131 L
s
0 .19098 m
.00375 .19098 L
s
0 .23033 m
.00375 .23033 L
s
0 .25 m
.00375 .25 L
s
0 .26967 m
.00375 .26967 L
s
0 .28934 m
.00375 .28934 L
s
0 .32869 m
.00375 .32869 L
s
0 .34836 m
.00375 .34836 L
s
0 .36803 m
.00375 .36803 L
s
0 .38771 m
.00375 .38771 L
s
0 .42705 m
.00375 .42705 L
s
0 .44673 m
.00375 .44673 L
s
0 .4664 m
.00375 .4664 L
s
0 .48607 m
.00375 .48607 L
s
0 .52542 m
.00375 .52542 L
s
0 .54509 m
.00375 .54509 L
s
0 .56476 m
.00375 .56476 L
s
0 .58443 m
.00375 .58443 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18801 .61178 m
.18801 .61803 L
s
.35222 .61178 m
.35222 .61803 L
s
.51642 .61178 m
.51642 .61803 L
s
.68062 .61178 m
.68062 .61803 L
s
.84483 .61178 m
.84483 .61803 L
s
.125 Mabswid
.05665 .61428 m
.05665 .61803 L
s
.08949 .61428 m
.08949 .61803 L
s
.12233 .61428 m
.12233 .61803 L
s
.15517 .61428 m
.15517 .61803 L
s
.22085 .61428 m
.22085 .61803 L
s
.25369 .61428 m
.25369 .61803 L
s
.28654 .61428 m
.28654 .61803 L
s
.31938 .61428 m
.31938 .61803 L
s
.38506 .61428 m
.38506 .61803 L
s
.4179 .61428 m
.4179 .61803 L
s
.45074 .61428 m
.45074 .61803 L
s
.48358 .61428 m
.48358 .61803 L
s
.54926 .61428 m
.54926 .61803 L
s
.5821 .61428 m
.5821 .61803 L
s
.61494 .61428 m
.61494 .61803 L
s
.64778 .61428 m
.64778 .61803 L
s
.71346 .61428 m
.71346 .61803 L
s
.74631 .61428 m
.74631 .61803 L
s
.77915 .61428 m
.77915 .61803 L
s
.81199 .61428 m
.81199 .61803 L
s
.87767 .61428 m
.87767 .61803 L
s
.91051 .61428 m
.91051 .61803 L
s
.94335 .61428 m
.94335 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01393 m
1 .01393 L
s
.99375 .11229 m
1 .11229 L
s
.99375 .21065 m
1 .21065 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .40738 m
1 .40738 L
s
.99375 .50574 m
1 .50574 L
s
.99375 .60411 m
1 .60411 L
s
.125 Mabswid
.99625 .0336 m
1 .0336 L
s
.99625 .05327 m
1 .05327 L
s
.99625 .07295 m
1 .07295 L
s
.99625 .09262 m
1 .09262 L
s
.99625 .13196 m
1 .13196 L
s
.99625 .15164 m
1 .15164 L
s
.99625 .17131 m
1 .17131 L
s
.99625 .19098 m
1 .19098 L
s
.99625 .23033 m
1 .23033 L
s
.99625 .25 m
1 .25 L
s
.99625 .26967 m
1 .26967 L
s
.99625 .28934 m
1 .28934 L
s
.99625 .32869 m
1 .32869 L
s
.99625 .34836 m
1 .34836 L
s
.99625 .36803 m
1 .36803 L
s
.99625 .38771 m
1 .38771 L
s
.99625 .42705 m
1 .42705 L
s
.99625 .44673 m
1 .44673 L
s
.99625 .4664 m
1 .4664 L
s
.99625 .48607 m
1 .48607 L
s
.99625 .52542 m
1 .52542 L
s
.99625 .54509 m
1 .54509 L
s
.99625 .56476 m
1 .56476 L
s
.99625 .58443 m
1 .58443 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .30902 m
.02381 .30902 L
s
.05665 .30902 m
.05665 .35262 L
s
.08949 .30902 m
.08949 .39437 L
s
.12233 .30902 m
.12233 .43706 L
s
.15517 .30902 m
.15517 .19528 L
s
.18801 .30902 m
.18801 .37475 L
s
.22085 .30902 m
.22085 .44596 L
s
.25369 .30902 m
.25369 .1686 L
s
.28654 .30902 m
.28654 .19176 L
s
.31938 .30902 m
.31938 .21151 L
s
.35222 .30902 m
.35222 .22947 L
s
.38506 .30902 m
.38506 .24633 L
s
.4179 .30902 m
.4179 .26251 L
s
.45074 .30902 m
.45074 .27823 L
s
.48358 .30902 m
.48358 .29369 L
s
.51642 .30902 m
.51642 .30902 L
s
.54926 .30902 m
.54926 .32435 L
s
.5821 .30902 m
.5821 .3398 L
s
.61494 .30902 m
.61494 .35553 L
s
.64778 .30902 m
.64778 .3717 L
s
.68062 .30902 m
.68062 .38857 L
s
.71346 .30902 m
.71346 .40652 L
s
.74631 .30902 m
.74631 .42628 L
s
.77915 .30902 m
.77915 .44943 L
s
.81199 .30902 m
.81199 .17207 L
s
.84483 .30902 m
.84483 .24329 L
s
.87767 .30902 m
.87767 .42275 L
s
.91051 .30902 m
.91051 .18098 L
s
.94335 .30902 m
.94335 .22366 L
s
.97619 .30902 m
.97619 .26541 L
s
.015 w
.02381 .30902 Mdot
.05665 .35262 Mdot
.08949 .39437 Mdot
.12233 .43706 Mdot
.15517 .19528 Mdot
.18801 .37475 Mdot
.22085 .44596 Mdot
.25369 .1686 Mdot
.28654 .19176 Mdot
.31938 .21151 Mdot
.35222 .22947 Mdot
.38506 .24633 Mdot
.4179 .26251 Mdot
.45074 .27823 Mdot
.48358 .29369 Mdot
.51642 .30902 Mdot
.54926 .32435 Mdot
.5821 .3398 Mdot
.61494 .35553 Mdot
.64778 .3717 Mdot
.68062 .38857 Mdot
.71346 .40652 Mdot
.74631 .42628 Mdot
.77915 .44943 Mdot
.81199 .17207 Mdot
.84483 .24329 Mdot
.87767 .42275 Mdot
.91051 .18098 Mdot
.94335 .22366 Mdot
.97619 .26541 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 311.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0001=b000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00=oooool3o`0002?ooooo1Ol0000Rooooo`;o0000
9?ooool5o`0002Gooooo0ol0001Kooooo`?o00008oooool5o`0002;ooooo0_l0000Sooooo`Go0000
9Oooool3o`0002Oooooo000hooooo`03o`000?oooooooooo02?ooooo00Co0000oooooooooooo0000
8Oooool01?l0003oooooooooool0000Tooooo`04o`000?ooooooooooo`0002Kooooo00?o0000oooo
ooooool0Foooool00ol0003oooooooooo`0Sooooo`04o`000?ooooooooooo`00027ooooo00Co0000
oooooooooooo00008oooool01?l0003oooooooooool0000Vooooo`03o`000?oooooooooo02Kooooo
000_ooooo`Go000000?oooooo`000?l000000ol0000Mooooo`Go00000oooool00ol0003ooooooooo
o`0Qooooo`04o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool08oooool5o`0005?ooooo
1Ol000000ooooooo0000o`000003o`0001gooooo1Ol00003ooooo`03o`000?oooooooooo027ooooo
00Co0000oooooooooooo00009?ooool00ol0003oooooooooo`0Sooooo`Go00009oooool003Gooooo
00Co0000oooooooooooo00009oooool00ol0003oooooooooo`0Pooooo`04o`000?ooooooooooo`00
02Kooooo00?o0000ooooooooool08_ooool01?l0003oooooooooool0001Jooooo`04o`000?oooooo
ooooo`0002Oooooo00?o0000ooooooooool08?ooool01?l0003oooooooooool0000Uooooo`03o`00
0?oooooooooo02;ooooo00Co0000oooooooooooo0000:?ooool003Kooooo00?o0000ooooool00000
9?ooool01Ol0003ooooooooooooooooo0000027ooooo00Co0000oooooooooooo00008oooool01Ol0
003ooooooooooooooooo000002Cooooo00?o0000ooooool00000Foooool00ol0003oooooo`00000T
ooooo`05o`000?ooooooooooooooool000008Oooool01?l0003oooooooooool0000Rooooo`05o`00
0?ooooooooooooooool000009?ooool00ol0003oooooo`00000Xooooo`00=oooool2o`0002Cooooo
00Go0000ooooooooooooooooo`00000Qooooo`04o`000?ooooooooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000Uooooo`;o0000G?ooool2o`0002Cooooo00Go0000ooooooooooooooooo`00
000Qooooo`04o`000?ooooooooooo`0002;ooooo00Go0000ooooooooooooooooo`00000Uooooo`;o
0000:?ooool003Sooooo00?o0000ooooooooool08oooool3o`0002?ooooo0_l0000Uooooo`?o0000
9oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo02?ooooo0ol0000Sooooo`;o0000
9?ooool3o`0002Oooooo00?o0000ooooooooool09_ooool00?oooooonOooool00?oooooonOooool0
0?oooooonOooool00?oooooonOooool001coooood_l0000Yooooom;o00003oooool001Kooooo0_l0
0004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00gooooo000Eooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool0I_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo02Oooooo0_l0
001Wooooo`03o`000?oooooooooo06Cooooo0_l0000?ooooo`005Oooool01?l0003oooooooooool0
0003ooooo`?o00002Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00Co
o`00oooooooooooooooo0_l0000Qooooo`?o00001Oooool00ol0003oooooooooo`1Vooooo`03o`00
0?oooooooooo00;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo013ooooo00?o003oooooooooool0@Oooool00ol0003oooooooooo`0=ooooo`005Ooo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool0
7_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0@Oooool00ol00?oo
ooooooooo`0@ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0@ooooo`03o`00oooooooooooo047ooooo00?o0000ooooooooool03Oooool001Gooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo00;o
003o0_ooool01?oo003oooooooooool00?l2ooooo`05ool00?ooooooooooooooool00?l00_ooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooo`00o`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool0
1?oo003oooooooooooooool2o`00o`03oooooooo003ooooo00Gooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00Coo`00oooooooooooo003o
0_ooool00ooo003oooooooooo`02o`00o`;ooooo00?oo`00ooooooooool01?ooool01?oo003ooooo
ooooool00?l2ooooo`03ool00?oooooooooo00;o003o0_ooool01?oo003oooooooooool00?l2oooo
o`03ool00?oooooooooo00;ooooo00?o0000ooooooooool06?ooool5o`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`11ooooo`03o`00oooooooooooo013ooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool0E?ooool00ol0003oooooooooo`0=ooooo`005Oooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00Gooooo0_l00?l2ooooo`03ool00?oooooooooo00;o003o0_ooool01?oo
003oooooooooool00?l2ooooo`03ool00?oooooooooo00;o003o0_ooool01?oo003oooooooooool0
0?l3ooooo`04ool00?ooooooooooo`00o`;ooooo00?oo`00ooooooooool00_l00?l2ooooo`04ool0
0?ooooooooooo`00o`?ooooo00?oo`00ooooooooool00oooool01?oo003oooooooooool00?l3oooo
o`04ool00?oooooo003oo`00o`;ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02
ooooo`;o003o00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00?ooooo00Coo`00oooooooooooooooo0_l00?l00oooooooo`00ooooo`02ooooo`04o`00oooo
ooooooooool000Gooooo00Goo`00ooooooooooooooooo`00o`02ooooo`04ool00?ooooooooooo`00
o`?ooooo00Coo`00oooooooooooo003o0_ooool00ooo003oooooooooo`02o`00o`;ooooo00Coo`00
oooooooooooo003o0oooool01?oo003oooooooooool00?l2ooooo`03ool00?oooooooooo00;o003o
0_ooool01?oo003oooooooooool00?l2ooooo`03ool00?oooooooooo00;ooooo00?o0000oooooooo
ool08?ooool2o`0000Gooooo0_l00012ooooo`03o`00oooooooooooo01Kooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo
ool0@?ooool2o`0000oooooo000Fooooo`;o00001?ooool2o`0000Kooooo0_l00?l2ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooool00?l00_l00?l00oooooooo`00ooooo`05ooooo`03ool0
0?oooooooooo00;o003o0_ooool01?oo003oooooooooool00?l2ooooo`04ool00?ooooooooooo`00
o`?ooooo00Coo`00oooooooooooo003o0oooool00ooo003oooooooooo`03ooooo`04ool00?oooooo
ooooo`00o`?ooooo00Coo`00oooooooooooo003o0_ooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003o003oo`00o`04ooooo`03ool0
0?oooooooooo00;ooooo0_l00?l00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;o003o
0_ooool00ooo003oooooooooo`03ooooo`05ool00?ooooooooooooooool00?l00_ooool01Ooo003o
oooooooooooooooo003o00;ooooo00Coo`00oooooooooooo003o0_ooool01Ooo003ooooooooooooo
oooo003o00;ooooo00?oo`00ooooooooool00_l00?l2ooooo`04ool00?oooooo003oo`00o`;ooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo047ooooo
00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo047ooooo
00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool01Oooool01Ol00?ooooooo`00
ooooooooo`0000;ooooo0_l00?l2ooooo`03ool00?oooooo003o00?ooooo00Goo`00oooooooooooo
ooooo`00o`02ooooo`03ool00?oooooooooo00;o003o0_ooool01?oo003oooooooooool00?l2oooo
o`05ool00?ooooooooooooooool00?l00_ooool01?oo003oooooooooool00?l3ooooo`03ool00?oo
oooooooo00?ooooo00Coo`00oooooooooooo003o0oooool00ooo003oooooo`00o`03ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooo`00o`03ooooo`03ool0
0?l00?oo003o00Cooooo00?oo`00ooooooooool00_ooool2o`00o`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`04ool00?ooooooooooooooo`;o
003o00Coooooool00?oooooooooo0_l00?l2ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool00_l00?l2ooooo`03ool00?oooooooooo00;o003o0_ooool00ooo003oooooo`00o`03oooo
o`04ool00?ooooooooooo`00o`?ooooo00?oo`00ooooool00?l00_l00?l2ooooo`03ool00?oooooo
003o00?ooooo00?oo`00ooooooooool00_l00?l2ooooo`07ool00?oooooo003oooooool00?oooooo
ool00004ooooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo047ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03
o`00oooooooooooo047ooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool0
2Oooool01Ooo003oooooo`00oooooooo003o00;ooooo00Ooo`00ooooool00?ooooooo`00oooooooo
o`0000;ooooo0_l00?l2ooooo`05ool00?ooooooooooooooool00?l00_ooool00ooo003oooooo`00
o`03ooooo`03ool00?oooooooooo00;o003o0_ooool01?oo003oooooooooool00?l3ooooo`03ool0
0?oooooooooo00?ooooo00Coo`00oooooooooooo003o0oooool01?oo003oooooo`00ool00?l2oooo
o`03ool00?oooooooooo00Cooooo00Coo`00oooooooooooo003o0oooool00ooo003o003oo`00o`03
ooooo`03ool00?l00?oo003o00Cooooo00?oo`00ooooooooool00oooool00ol00?ooo`00ooooo`02
ooooo`03o`00ooooooooo`0000?ooooo00Co003oooooooooooooo`001Oooool01?oo003ooooooooo
ooooool2o`00o`03oooooooo003ooooo00;ooooo00Co003oooooooooooooo`001Oooool01?oo003o
ooooooooool00?l3ooooo`04ool00?ooooooooooo`00o`?ooooo00Coo`00ooooool00?oo003o0_oo
ool00ooo003oooooooooo`02o`00o`;ooooo00Goo`00ooooooooooooooooo`00o`02ooooo`07ool0
0?oooooo003oooooool00?ooooooool00002ooooo`;o003o0_ooool01ooo003oooooo`00oooooooo
003ooooooooo00001?ooool00ol0003oooooooooo`0Oooooo`?o00001Oooool00ol0003ooooooooo
o`11ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?oooooooooo
o`11ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo00Cooooo00So003o
oooooooooooo003ooooooooo003oooooo`00o`;ooooo00?o003ooooooooo00000oooool00ol00?oo
ooooool00002ooooo`07o`00oooooooo003ooooooooo003oooooo`00o`04ooooo`07ool00?oooooo
ooooooooool00?ooooooool00002ooooo`;o003o0_ooool00ooo003oooooooooo`02o`00o`;ooooo
00?oo`00ooooooooool00oooool01Ooo003ooooooooooooooooo003o00;ooooo00Ooo`00o`00oooo
ooooooooo`00ooooooooo`0000Kooooo00Coo`00oooooooooooo003o0oooool00ooo003o003ooooo
o`03ooooo`03ool00?l00?oooooo00Cooooo00?oo`00ooooooooool00_ooool00ol00?ooooooool0
0003ooooo`03o`00ooooooooo`0000?ooooo00Co003oooooooooooooo`001Oooool01?oo003ooooo
ooooool00?l2ooooo`05o`00oooo003oooooooooool00?l00oooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00;o003o0_ooool00ooo003oooooooooo`02o`00o`;ooooo00Coo`00oooo
ool00?oo003o0_ooool00ooo003oooooooooo`02o`00o`;ooooo00?oo`00ooooool00?l01?ooool0
2Ooo003ooooooooooooooooo003ooooooooo003oooooo`00o`02ooooo`09o`00ooooooooo`00oooo
ool00?ooooooo`00ooooooooo`0000Cooooo00?o0000ooooooooool09oooool2o`00047ooooo0_l0
0?lBooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo05?ooooo0_l0000?ooooo`007?ooool2o`0000Gooooo00Ko003o
oooooooooooo003ooooooooo0006ooooo`07ool00?oooooo003oooooool00?ooooooool00002oooo
o`09o`00oooooooooooooooooooo003oooooo`00oooooooo003o00;ooooo00Ooo`00ooooool00?oo
ooooo`00ooooooooo`0000;ooooo00Go003oooooooooooooooooool00002ooooo`05o`00oooooooo
oooooooooooo00001Oooool00ooo003oooooooooo`02o`00o`;ooooo00Ooo`00oooooooooooooooo
o`00ooooooooo`0000Kooooo00Coo`00oooooooooooo003o0oooool00ooo003oooooo`00o`03oooo
o`03ool00?oooooo003o00Cooooo00?oo`00ooooooooool00_ooool2o`00o`04ool00?oooooooooo
ooooo`;o003o00?oo`00ooooooooool00_l00?l2ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`02o`00o`;ooooo00?oo`00ooooooooool00oooool0
1Ooo003ooooooooooooooooo003o00;ooooo00Goo`00ooooooooooooooooo`00o`02ooooo`07ool0
0?ooooooooooooooool00?ooooooool00004ooooo`07o`00ooooooooo`00ooooool00?ooooooo`00
o`02ooooo`07ool00?l00?ooooooooooool00?ooooooool00006ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo043o
oooo0_l00?lBooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0@Oooool00ol0003o
ooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`04ooooo`08o`00ooooooooooooo`00oooo
ooooo`00ooooool00?l2ooooo`04o`00ooooooooo`00o`00o`Cooooo00?oo`00ooooooooool00_oo
ool01Ol00?ooooooool00?oooooo003o00;ooooo00Wo003ooooooooo003oooooo`00oooooooo003o
oooooooo00000oooool01?l00?oooooooooooooo0006ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool00_l00?l2ooooo`03ool00?l00?oooooo00?ooooo00?oo`00ooooooooool01?oo
ool01?oo003oooooooooool00?l3ooooo`03ool00?l00?oo003o00?ooooo00?oo`00o`00ool00?l0
1?ooool00ooo003oooooooooo`02ooooo`;o003o00Coo`00oooooooooooo003o0_ooool01Ooo003o
oooooooooooooooo003o00;ooooo00?oo`00ooooooooool00oooool01?oo003oooooooooool00?l3
ooooo`03ool00?oooooooooo00;o003o0_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00;o003o0_ooool00ooo003oooooooooo`02o`00o`;ooooo00?oo`00ooooool00?l00oooool0
0ooo003oooooo`00o`04ooooo`05ool00?oooooo003oooooool00?l00_ooool00ooo003o003ooooo
o`03ooooo`03ool00?oooooo003o00;ooooo00Co003ooooooooo003o003o0oooool00ol00?ooo`00
ooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0@?ooool00ol00?oooooo
ooooo`0Aooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool00_ooool2o`00o`Gooooo
00?o003oooooooooool04?ooool00ol00?ooooooooooo`11ooooo`03o`000?oooooooooo00gooooo
000Looooo`03o`000?oooooooooo00Wooooo00?oo`00ooooool00?l00_ooool01?l00?ooooooool0
0?l00?l3ooooo`04o`00oooo003oooooo`00o`;ooooo00?o003ooooooooo00001?ooool01Ol00?oo
ooooool00?oooooo003o00?ooooo00?oo`00ooooooooool00_l00?l2ooooo`03ool00?oooooooooo
00;o003o0_ooool00ooo003oooooooooo`03ooooo`04ool00?ooooooooooo`00o`?ooooo00Ooo`00
o`00ooooooooooooo`00ooooooooo`0000Kooooo00Coo`00ooooool00?oo003o0oooool01?oo003o
003oooooool00?l2ooooo`03ool00?l00?oo003o00Cooooo00?oo`00ooooooooool00oooool00ol0
0?ooo`00ooooo`03ooooo`05o`00oooo003oooooooooool00?l00oooool00ooo003oooooooooo`03
ooooo`04ool00?ooooooooooo`00o`;ooooo00?o003oool00?ooool00_ooool01?l00?oooooooooo
oooo0005ooooo`04ool00?ooooooooooo`00o`?ooooo00Coo`00oooooooooooo003o0oooool02Ooo
003oooooo`00oooooooo003ooooooooo003oooooo`00o`02ooooo`03o`00ooooooooo`0000Cooooo
00Co003ooooooooo003o003o0oooool01?l00?ooo`00ooooool00?l2ooooo`04o`00ooooooooo`00
o`00o`?ooooo00?o003oool00?ooool00oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo047ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooo
oooo047ooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool00oooool00ol0
0?ooooooooooo`02ooooo`?oo`000oooool2o`00o`03ool00?oooooooooo00;ooooo00Co003oool0
0?oooooo003o0_ooool01Ol00?ooooooool00?oooooo003o00Cooooo00Ooo`00oooooooooooooooo
o`00ooooooooo`0000;ooooo0_l00?l2ooooo`03ool00?oooooooooo00;o003o0_ooool00ooo003o
ooooooooo`03ooooo`05ool00?ooooooooooooooool00?l00_ooool01ooo003o003ooooooooooooo
003ooooooooo00001_ooool00ooo003oooooo`00o`04ooooo`03ool00?l00?oooooo00?ooooo00?o
o`00o`00ooooool01?ooool00ooo003oooooooooo`02ooooo`03o`00ooooooooo`0000;ooooo00Co
003oooooool00?ooo`000_ooool2o`00o`;ooooo00?oo`00ooooooooool00oooool01?oo003ooooo
o`00ool00?l2ooooo`05o`00oooo003oooooooooool00?l00oooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00;o003o0_ooool01Ooo003oooooo`00oooooooo003o00;ooooo00Woo`00
ooooool00?ooooooo`00ooooooooo`00ooooool00?l00_ooool01?l00?ooooooool00?l00?l5oooo
o`03ool00?l00?oooooo00;ooooo00?o003oool00?l00?l01?ooool3ool000?ooooo0ooo0003oooo
o`03o`000?oooooooooo02Oooooo0_l00011ooooo`;o003o4_ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Coooo
o`;o00003oooool001cooooo0_l00003ooooo`;o003o1?ooool3ool000Cooooo0ooo0003ooooo`04
o`00oooo003oooooo`00o`Cooooo00?oo`00o`00ooooool00_ooool01?l00?ooooooool00?l00?l2
ooooo`03o`00ooooooooo`0000;ooooo00Go003oooooooooooooooooool00002ooooo`;o003o0_oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;o003o0_ooool01ooo003ooooooooo
oooooooo003ooooooooo00001_ooool01Ooo003oooooo`00oooooooo003o00;ooooo00Coo`00oooo
oooooooo003o0_ooool00ooo003oooooo`00o`04ooooo`03ool00?oooooooooo00;ooooo0_l00?l0
1ooo003oooooooooool00?ooooooo`00oooo00000_ooool2o`00o`;ooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`03ooooo`04o`00oooo003oooooooooo`;o003o0_ooool00ooo003o
ooooooooo`03ooooo`05ool00?ooooooooooooooool00?l00_ooool01Ooo003ooooooooooooooooo
003o00;ooooo00Ooo`00ooooooooooooooooo`00ooooooooo`0000Cooooo00Co003ooooooooo003o
003o0oooool00ol00?ooooooool00004ooooo`?oo`001?ooool3ool000?ooooo0ooo0003ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0@?ooool2o`00oa;ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`;o003o1Oooool00ol00?ooooooooooo`0@ooooo`03
o`00oooooooooooo047ooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool0
2?ooool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool00ol00?ooo`00o`00o`03ooooo`04o`00
ooooooooo`00o`00o`;ooooo00?o003ooooooooo00001?ooool00ol00?ooooooool00006ooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_l00?l2ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool01?ooool01Ooo003ooooooooooooooooo003o00;ooooo00Goo`00oooo
oooooooo003oooooo`03ool00003o`00oooooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
1_l00?ooo`00ool00?oo003oooooo`00o`;ooooo00?oo`00ooooooooool00_ooool00ol00?oooooo
ool00005ooooo`03ool00?oooooo003o00Cooooo00?oo`00ooooool00?l00_l00?l2ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool00_l00?l2ooooo`05ool00?oooooo003oooooool0
0?l00_ooool00ooo003o003oooooo`03ooooo`03ool00?oooooo003o00Cooooo00?oo`00o`00oooo
ool00_ooool3ool000Cooooo0ooo0004ooooo`?oo`000oooool3ool000?ooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`10ooooo`03o`00oooooooooooo017ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00Go0000oooooooo
ooooooooo`00o`05ooooo`;o003o1Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
047ooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool03oooool3ool000?o
oooo0ooo0004ooooo`?oo`000oooool01?l00?ooooooool00?l00?l4ooooo`03ool00?oooooooooo
00;ooooo00?o003ooooooooo00000oooool01?l00?oooooooooooooo0005ooooo`03ool00?oooooo
003o00Cooooo00?oo`00ooooooooool00_ooool00ol00?ooo`00ooooo`05ooooo`05ool00?oooooo
003oooooool00?l00_ooool01Ooo003oooooooooool00?oooooo00?oo`0000?o003oooooooooool0
0_ooool00ooo003oooooooooo`03ooooo`?oo`000oooool01Ol00?ooo`00oooooooooooo003o00?o
oooo00?oo`00ooooooooool00oooool00ooo003oooooo`00o`04ooooo`05ool00?oooooooooooooo
ool00?l00_ooool00ooo003oooooooooo`03ooooo`04ool00?ooooooooooo`00o`?ooooo00?oo`00
ooooool00?l01?ooool00ooo003o003oooooo`02ooooo`04o`00oooo003oooooo`00o`?ooooo0ooo
0003ooooo`?oo`001?ooool3ool0013ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`11ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00?ooooo00Co0000oooooooooooooooo0_l00?l4ooooo`;o003o
1Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
=?ooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`0Eooooo`?oo`001?oo
ool3ool000Gooooo00?oo`00ooooooooool00_ooool01?l00?ooo`00ooooool00?l2ooooo`07o`00
ooooooooo`00ooooool00?ooooooo`00o`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool00_ooool01?l00?ooo`00ool00?oo0003ooooo`03o`00oooo003ooooo00Gooooo00?oo`00
ooooool00?l01?ooool01Ooo003oooooooooool00?oooooo00?oo`001Oooool00ooo003ooooooooo
o`02ooooo`09o`00oooo003oo`00ool00?oooooo003oooooool00?ooo`0000;ooooo00Go003ooooo
ool00?ooooooool00005ooooo`03ool00?oooooo003o00?ooooo0ooo00000ol00?ooooooooooo`02
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_l00?l2ooooo`03ool00?oooooo
003o00;ooooo00Co003ooooooooo003o003o0oooool00ol00?ooo`00o`00o`04ooooo`?oo`000ooo
ool3ool001Oooooo00?o0000ooooooooool09oooool2o`00047ooooo0_l00?lBooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`04o`000?oo
ooooooooooooo`;o003o1Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01cooooo
0_l00?leooooo`;o00003oooool001cooooo0_l0000Mooooo`?oo`001?ooool00ol00?ooo`00o`00
o`03ooooo`04o`00oooo003oooooo`00o`Cooooo00Goo`00ooooool00?ooooooo`00o`02ooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooool00?l00_ooool01?l00?ooo`00ool00?oo0003oooo
o`03o`00oooo003ooooo00Gooooo00Goo`00ooooool00?ooooooo`00o`02ooooo`04ool00?oooooo
ooooo`00o`Cooooo00?o003oooooooooool00_ooool00ooo003oooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00Co003oooooooooooooo`000_ooool01Ol00?ooooooo`00ooooooooo`0000Go
oooo00?oo`00ooooool00?l00oooool3ool00003o`00oooooooo003o00;ooooo00?oo`00oooooooo
ool00oooool01Ooo003ooooooooooooooooo003o00;ooooo00?oo`00ooooooooool00_ooool00ol0
0?ooooooool00004ooooo`03o`00oooo003ooooo00Cooooo0ooo000Mooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0@?ooool2o`00oa7ooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool04?ooool00ol0
0?ooooooooooo`09ooooo`;o003o=_ooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003o
ooooooooo`0Sooooo`?oo`000oooool01?l00?ooo`00ooooool00?l4ooooo`03ool00?oooooo003o
00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooo`00o`02ooooo`04o`00oooo003oo`00
ool000Cooooo00?oo`00ooooooooool01?ooool01Ooo003ooooooooooooooooo003o00;ooooo00?o
o`00ooooooooool00oooool00ol00?ooooooo`00o`04ooooo`05ool00?ooooooooooooooool00?l0
0_ooool00ol00?ooooooo`00o`03ooooo`08ool00?ooooooooooo`00oooooooo003ooooooooo0005
ooooo`03ool00?oooooooooo00?ooooo0ooo00000ol00?ooooooo`00o`02ooooo`03ool00?oooooo
oooo00?ooooo00[oo`00oooooooooooo003oooooool00?ooooooool00?oooooo003o0_ooool01?l0
0?ooooooool00?l00?l3ooooo`?oo`009?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo043ooooo00?o003oooooooooool04?ooool2o`00o`Gooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`03ooooo`05o`000?ooooooooooooooool00?l01Oooool2o`00o`Gooooo00?o
003oooooooooool04?ooool00ol00?ooooooooooo`09ooooo`;o003o=_ooool00ol0003ooooooooo
o`0=ooooo`003oooool3o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo02?ooooo0ooo0004
ooooo`03ool00?oooooooooo00;ooooo00?o003ooooooooo00000oooool01?l00?oooooooooooooo
0005ooooo`03ool00?oooooo003o00;ooooo0_l00?l5ooooo`03o`00oooo003ooooo00Gooooo00Ko
o`00ooooool00?ooooooo`00ooooool3ool000;ooooo00Go003oooooool00?ooooooo`00o`04oooo
o`03ool00?oooooooooo00Cooooo00?o003oooooooooool00_ooool3ool000Gooooo00?oo`00oooo
ooooool00oooool00ooo003oooooo`00o`05ooooo`;o003o0_ooool00ol00?ooooooool00005oooo
o`04ool00?ooooooooooo`00o`?ooooo00?oo`00ooooool00?l01?ooool00ooo003o003oooooo`02
ooooo`?oo`009?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo047ooooo00?o003o
ooooooooool03oooool2o`00o`Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03
ooooo`05o`000?ooooooooooooooool00?l01Oooool2o`00o`Gooooo00?o003oooooooooool04?oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo03Cooooo00?o0000ooooooooool03Ooo
ool0013ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo02?ooooo0ooo0003ooooo`04o`00oooo003oooooo`00o`;ooooo00Oo003ooooooooo003o
ooooo`00oooooooo003o00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`09oooo
o`03o`00oooo003ooooo00Gooooo00?oo`00ooooool00?l00oooool3ool000;ooooo0ol00?l6oooo
o`05ool00?ooooooooooooooool00?l00_ooool00ol00?ooooooo`00o`02ooooo`?oo`0000Ko003o
oooooooooooo003ooooooooo0005ooooo`03ool00?l00?oooooo00_ooooo00?oo`00ooooooooool0
0oooool01?oo003oooooooooool00?l3ooooo`03ool00?oooooo003o00;ooooo00?o003ooooooooo
00001?ooool3ool002Cooooo00?o0000ooooooooool09oooool2o`00043ooooo00?o003oooooool0
0?l04_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool00oooool01?l0003oooooooooooooool2o`00o`Gooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0Mooooo`03o`00oooooooooooo03Cooooo0_l0000?ooooo`004?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo0ol0000Zooooo`03ool00?oooooo003o
00;ooooo00Oo003ooooooooo003oooooo`00oooooooo003o00;ooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooo`00o`09ooooo`03o`00oooo003ooooo00Gooooo00?oo`00ooooool00?l00_oo
ool01?l00?ooo`00ool00?oo0002ooooo`03o`00oooooooooooo00Kooooo00Goo`00oooooooooooo
ooooo`00o`03ooooo`;o003o0_ooool3ool00006o`00ooooooooooooo`00ooooooooo`001Oooool0
0ooo003o003oooooo`09ooooo`03o`00ooooooooo`0000Gooooo00?oo`00ooooooooool00_ooool0
0ol00?ooooooool00004ooooo`03o`00ooooooooo`0002[ooooo0_l0000Pooooo`Go00001?ooool0
0ol0003oooooooooo`0oooooo`03o`00oooooooo003o01Sooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`0eooooo`03o`000?oooooooooo00gooooo000@ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Yooooo`?oo`001Oooool0
0ooo003oooooo`00o`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooool00?l02_ooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo0_l00?l9ooooo`05o`00oooooooo
oooooooooooo00000oooool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l2ooooo`03o`00
ooooooooo`0000Gooooo00?oo`00o`00ooooool02Oooool00ol00?ooooooool00005ooooo`09ool0
0?ooooooooooo`00oooooooo003ooooooooo003o003o00Cooooo0ooo000Zooooo`03o`000?oooooo
oooo01oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0oooooo`03o`00oooo
oooooooo017ooooo0_l00?l5ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00ooo
ool01?l0003oooooooooooooool2o`00o`Cooooo0_l00?l4ooooo`;o003o4_ooool00ol00?oooooo
ooooo`09ooooo`;o003o1Oooool00ol00?ooooooooooo`0^ooooo`03o`000?oooooooooo00gooooo
000@ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`0Yooooo`?oo`000oooool00ol00?ooooooool00003ooooo`04o`00ooooooooooooool000Go
oooo00?oo`00ooooool00?l02_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00go
oooo00Go003oooooooooooooooooool0000Cooooo`03ool00?oooooooooo00?ooooo00?oo`00o`00
ooooool02Oooool00ol00?ooooooool00005ooooo`09ool00?ooooooooooo`00oooooooo003ooooo
oooo003o003o00Cooooo0ooo000Zooooo`03o`000?oooooooooo01Sooooo1Ol00003ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0@Oooool00ol00?ooooooooooo`0?ooooo`;o003o
2oooool00ol00?ooooooooooo`03ooooo`05o`000?ooooooooooooooool00?l01Oooool2o`00o`Co
oooo0_l00?lBooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0^ooooo`03o`000?oooooooooo00gooooo000?ooooo`;o00001?ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo02Wooooo0ooo0003ooooo`07o`00ooooooooo`00oooo
ool00?ooooooo`00o`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool02_ooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooo003o00gooooo00Go003oooooooooooooooooool0
0003ooooo`03o`00oooooooooooo00_ooooo00?o003ooooooooo00001Oooool00ooo003ooooooooo
o`0;ooooo`03ool00?oooooooooo00?ooooo00Coo`00oooooooooooo003o0oooool00ooo003o003o
ooooo`03ooooo`?oo`00:_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00?ooooo
0_l00010ooooo`03o`00oooooooo003o017ooooo0_l00?l5ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool00oooool01?l0003oooooooooooooool2o`00o`Gooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooo003o00Gooooo00?o003ooooooooo
ool0;Oooool2o`0000oooooo000@ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o0000
<Oooool01_l00?ooo`00ooooool00?ooooooo`00o`;ooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`0:ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooool00?l04Oooool01Ooo
003ooooooooooooooooo003o00gooooo00?o003ooooooooo00001Oooool00ooo003o003oooooo`09
ooooo`03o`00ooooooooo`0000Gooooo00?oo`00ooooooooool00_ooool00ol00?ooooooool0000b
ooooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo03oooooo00?o003oooooool00?l06?ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooo003o00Cooooo00?o003oooooooooool0;oooool00ol0003oooooooooo`0=ooooo`007?ooool0
0ol0003oooooooooo`0aooooo`03ool00?oooooo003o00Cooooo00?oo`00ooooooooool00oooool0
0ooo003oooooo`00o`0:ooooo`03ool00?oooooooooo00Cooooo00?oo`00o`00ooooool03Oooool0
1Ol00?ooooooooooooooooooo`0000?ooooo00?o003oooooooooool02oooool00ol00?ooooooool0
0005ooooo`03ool00?l00?oooooo00Wooooo00?o003ooooooooo00001Oooool02Ooo003ooooooooo
ool00?ooooooo`00ooooooooo`00o`00o`0aooooo`03o`000?oooooooooo01kooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo03oooooo00?o003oooooooooool04Oooool2
o`00o`Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`04o`000?oooooo
ooooooooo`;o003o1?ooool2o`00o`Cooooo0_l00?lBooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool01?ooool00ol00?ooooooo`00o`0_ooooo`03o`000?oooooooooo00gooooo000L
ooooo`03o`000?oooooooooo033ooooo00?o003oool00?ooool00_ooool01?l00?oooooooooooooo
0005ooooo`03ool00?oooooo003o00[ooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`0=ooooo`05o`00oooooooooooooooooooo00000oooool00ol00?ooooooooooo`0=ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00o`00ooooool02Oooool00ol00?ooooooool00005ooooo`09ool0
0?ooooooooooo`00oooooooo003ooooooooo003o003o037ooooo00?o0000ooooooooool07oooool3
o`0000Gooooo0_l00012ooooo`03o`00oooooooooooo00oooooo0_l00?l;ooooo`03o`00oooooooo
oooo00?ooooo00Go0000ooooooooooooooooo`00o`05ooooo`;o003o1?ooool2o`00oa;ooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02cooooo0_l0
000?ooooo`007?ooool00ol0003oooooooooo`0`ooooo`06o`00oooo003oooooo`00oooooooo003o
0_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo003o00[ooooo00?oo`00ooooooooool0
1?ooool00ooo003o003oooooo`0=ooooo`05o`00oooooooooooooooooooo00004_ooool00ol00?oo
o`00ooooo`04ooooo`03ool00?l00?oooooo00Wooooo00?o003ooooooooo00001Oooool00ooo003o
ooooo`00o`04ooooo`03ool00?l00?oooooo033ooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0oooooo`03o`00oooooooo003o017ooooo0_l00?l5ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool00oooool01_l0003oooooooooool00?ooooooo`00o`Gooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooool00?l01_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo02Oooooo00?o0000
ooooooooool03Oooool001cooooo0_l0000aooooo`06o`00oooo003oooooo`00oooooooo003o0_oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool01?oo
ool00ooo003o003oooooo`0Aooooo`05ool00?ooooooooooooooool00?l03_ooool00ol00?ooo`00
ooooo`04ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`02ooooo`03o`00ooooooooo`0003;ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0nooooo`04o`00ooooooooooooo`00oaSooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo01_ooooo00?o003oooooool00?l01?ooool00ol00?oo
ooooooooo`04ooooo`;o003o:Oooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003ooooo
ooooo`0aooooo`03ool00?l00?oooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003ooooo
o`00o`09ooooo`?oo`001Oooool00ooo003o003oooooo`0=ooooo`05o`00oooooooooooooooooooo
00000oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo003ooooo00?ooooo0ooo000:ooooo`03
o`00ooooooooo`0000Gooooo00?oo`00ooooooooool00_ooool00ol00?ooooooool0000booooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0?_ooool01?l00?ooooooooooool00?l@oooo
o`03o`00oooooooooooo00Cooooo0_l00?l5ooooo`03o`00oooooooooooo00?ooooo00Ko0000oooo
oooooooo003oooooool00?l4ooooo`;o003o1?ooool2o`00oa;ooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooo003o00Cooooo0_l00?lYooooo`03o`000?oo
oooooooo00gooooo000Looooo`03o`000?oooooooooo033ooooo00?o003oool00?ooool00_ooool0
1?l00?oooooooooooooo0005ooooo`03ool00?oooooo003o00Wooooo0ooo0005ooooo`03ool00?oo
oooooooo00gooooo00Go003oooooooooooooooooool00003ooooo`03o`00oooooooooooo00gooooo
00?oo`00ooooooooool00_ooool3ool000[ooooo00?o003ooooooooo00001Oooool00ooo003ooooo
o`00o`03ooooo`03o`00oooo003o003o037ooooo00?o0000ooooooooool09oooool2o`0005?ooooo
00?o003oooooool00?l01Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo
00Co0000oooooooooooo003o1_ooool2o`00o`Cooooo0_l00?lBooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`04ooooo`;o003o:?ooool2o`0000oo
oooo000Looooo`03o`000?oooooooooo033ooooo00?o003oool00?l00?l00_ooool01?l00?oooooo
oooooooo0005ooooo`03ool00?oooooo003o00Wooooo0ooo0005ooooo`03ool00?l00?oooooo00go
oooo00Go003oooooooooooooooooool0000Cooooo`03ool00?oooooooooo00;ooooo0ooo000:oooo
o`03o`00ooooooooo`0000Gooooo00?oo`00ooooool00?l01?ooool00ooo003oooooooooo`0`oooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0@Oooool00ol00?ooooooooooo`0>oooo
o`03o`00oooooooo003o00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03oooo
o`06o`000?ooooooooooo`00oooooooo003o1Oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo017ooooo00?o003oooooooooool01oooool01?l00?ooooooooooool00?l6ooooo`03o`00
oooooooooooo00Wooooo0_l00?lRooooo`03o`000?oooooooooo00gooooo000Looooo`;o0000<Ooo
ool3ool000?ooooo00?o003ooooooooo00001Oooool00ooo003oooooooooo`0;ooooo`03o`00oooo
oooooooo00?ooooo00?oo`00o`00ooooool04Oooool01Ooo003ooooooooooooooooo003o00kooooo
00?o003oool00?ooool04_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo003o00?ooooo
0ooo000aooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0?_ooool01?l00?oooooo
ooooool00?lBooooo`03o`00oooooooooooo00;ooooo0_l00?l5ooooo`03o`00oooooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?o
oooo0_l00?lLooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool01Oooool2o`00
o`Gooooo00?o003oooooooooool08Oooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003o
ooooooooo`0`ooooo`?oo`000oooool00ol00?ooooooool00005ooooo`03ool00?oooooo003o00_o
oooo00?o003oooooooooool00oooool00ooo003o003oooooo`0=ooooo`05o`00oooooooooooooooo
oooo00000oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo003ooooo00Cooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooool00005ooooo`03ool00?oooooooooo00?ooooo0ooo000aoooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0?_ooool01?l00?ooooooooooool00?l@
ooooo`03o`00oooooooooooo00Cooooo0_l00?l5ooooo`03o`00oooooooooooo00?ooooo00Ko0000
oooooooooooo003oooooool00?l4ooooo`;o003o1Oooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo00Kooooo0ooo0005ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooool0
0?l01_ooool00ol00?ooooooooooo`0Pooooo`03o`000?oooooooooo00gooooo000Looooo`03o`00
0?oooooooooo033ooooo0ooo0005ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooool00?l0
4Oooool00ooo003oooooooooo`0=ooooo`05o`00oooooooooooooooooooo00000oooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooo003ooooo00Cooooo00?o003oooooooooool02Oooool00ol00?oo
ooooool00005ooooo`03ool00?oooooo003o00?ooooo0ooo000aooooo`03o`000?oooooooooo02Oo
oooo0_l0000nooooo`?oo`004_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool00oooool01?l0003oooooooooool00?l5ooooo`03o`00oooooooo003o
00Cooooo0_l00?lBooooo`03o`00oooooooooooo00Kooooo0ooo00000ooooooo003oooooo`02oooo
o`04o`00ooooooooooooo`00o`?ooooo00?o003oooooool00?l01?ooool00ol00?ooooooo`00o`0Q
ooooo`;o00003oooool001cooooo00?o0000ooooooooool0=_ooool00ol00?ooooooool00005oooo
o`03ool00?l00?oooooo00_ooooo00?o003oooooooooool00oooool00ooo003o003oooooo`0=oooo
o`05o`00oooooooooooooooooooo00004oooool00ooo003oooooooooo`03ooooo`03o`00oooooooo
oooo00Wooooo00?o003ooooooooo00001Oooool00ooo003oooooo`00o`0gooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0?Oooool3ool00003ooooool00?oooooo00kooooo0ooo0000
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool0
0ol0003oooooo`00o`02ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool3
ool00003ooooool00?oooooo00Gooooo00?o003oooooooooool02?ooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool03Oooool001cooooo0_l0000goooo
o`03o`00ooooooooo`0000Gooooo00?oo`00ooooooooool02oooool00ol00?ooooooooooo`03oooo
o`03ool00?l00?oooooo017ooooo00Coo`00oooooooooooo003o3oooool00ol00?ooo`00ooooo`0B
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooool00?l0=oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo03gooooo0ooo00000ooooooo003oooooo`0>ooooo`?oo`0000?o003o
ooooooooool00_ooool2o`00o`Gooooo00?o003oooooooooool00oooool00ol0003oooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l01_ooool2o`00o`[ooooo0_l00?l@ooooo`04ool00?oo
ooooooooo`00o`?ooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`04ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0=ooooo`007?oo
ool00ol0003oooooooooo`0fooooo`03o`00ooooooooo`0000Gooooo00?oo`00o`00ooooool02ooo
ool00ol00?ooooooooooo`03ooooo`03ool00?l00?oooooo00kooooo00Co003oooooooooooooo`00
0_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooo003ooooo00Cooooo00?o003oooooooooool0
2Oooool00ol00?ooooooool00005ooooo`03ool00?oooooooooo03Oooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0mooooo`05o`00oooo003oooooooooool00?l03oooool3ool000Go
oooo0_l00?l5ooooo`03o`00oooooooooooo00?ooooo00?o0000ooooool00?l00_ooool01Ol00?oo
oooooooooooooooo003o00Oooooo00?o003oooooooooool01oooool00ol00?ooooooo`00o`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oool00?ooool01?ooool3ool000Gooooo00?o003ooooo
ool00?l01_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01_ooooo00?o0000oooo
ooooool03Oooool000kooooo1Ol00003ooooo`;o00001?ooool00ol0003oooooooooo`0hooooo`03
ool00?oooooooooo00?ooooo00?oo`00o`00ooooool04Oooool00ooo003oooooooooo`0>ooooo`04
o`00ooooooooooooool000;ooooo00?o003oooooooooool03Oooool00ol00?ooo`00ooooo`04oooo
o`03o`00oooooooooooo00Wooooo00?o003ooooooooo00001Oooool00ooo003oooooo`00o`0goooo
o`03o`000?oooooooooo02Oooooo0_l0000nooooo`03o`00oooo003ooooo017ooooo00Co003oool0
0?oooooo003o1Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o0000
ooooool00?l01_ooool00ol00?ooooooo`00o`04ooooo`;o003o1oooool3ool000Sooooo00?o003o
ooooooooool01oooool01?oo003oooooooooool00?l2ooooo`?oo`0000?oooooo`00ooooool00_oo
ool00ol00?ooooooo`00o`04ooooo`03o`00oooooooo003o00Cooooo0_l00?l5ooooo`;o003o5?oo
ool2o`0000oooooo000?ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`0fooooo`03o`00ooooooooo`0000Gooooo00?oo`00o`00ooooool0
2oooool00ol00?ooooooooooo`03ooooo`03ool00?oooooooooo00kooooo00Co003ooooooooooooo
o`004oooool00ooo003oooooooooo`03ooooo`03o`00oooooooooooo00[ooooo00?o003oool00?oo
ool01?ooool00ooo003oooooo`00o`0gooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool0?_ooool01?oo003oooooooooool00?l?ooooo`04o`00oooo003oooooo`00o`Cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`000?oooooo003o00;ooooo00Oo003o
ooooooooooooooooo`00oooooooo003o00Cooooo00?o003oooooooooool01_ooool3ool00003oooo
ool00?oooooo00Gooooo00?o003oooooooooool01_ooool01Ol00?ooo`00oooooooooooo003o00;o
oooo0ooo00000ooooooo003oooooo`09ooooo`03o`00oooooooo003o00Cooooo0_l00?l5ooooo`;o
003o5Oooool00ol0003oooooooooo`0=ooooo`004?ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000?ooooo0ol0000fooooo`03o`00ooooooooo`0000Gooooo00?oo`00oooooooo
ool02oooool00ol00?ooooooooooo`03ooooo`03ool00?oooooooooo017ooooo00Coo`00oooooooo
oooo003o3oooool00ol00?ooo`00ooooo`0Booooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ool00?l0=_ooool2o`00027ooooo0ol00005ooooo`03o`000?oooooooooo03gooooo00Go003oool0
0?ooooooooooo`00o`0@ooooo`03ool00?oooooo003o00Cooooo0_l00?l5ooooo`03o`00oooooooo
oooo00?ooooo00?o0000ooooool00?l00_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool01_ooool3ool00003ooooool00?oooooo00kooooo00Go003o
ool00?ooooooooooo`00o`02ooooo`05o`00oooo003oooooooooool00?l00_ooool01?l00?oooooo
ooooool00?l4ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool06_ooool00ol0003o
ooooooooo`0=ooooo`004Oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`00000hooooo`03o`00ooooooooo`0000Gooooo00?oo`00o`00ooooool02oooool00ol0
0?ooooooooooo`03ooooo`03ool00?oooooooooo00kooooo00Co003oooooooooooooo`000_ooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooo003ooooo00?ooooo00?o003oooooooooool02oooool0
0ol00?ooo`00ooooo`04ooooo`03ool00?oooooooooo03Oooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo03gooooo00Go003oool00?ooooooooooo`00
o`0?ooooo`03o`00oooo003ooooo00Gooooo0_l00?l5ooooo`03o`00oooooooooooo00?ooooo00?o
0000ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003oooooooooool0
1_ooool01?oo003oooooooooool00?l6ooooo`03o`00oooooooooooo00Kooooo00?o003oool00?oo
ool01?ooool00ol00?ooo`00ooooo`03ooooo`?oo`0000?oooooo`00ooooool00oooool00ol00?oo
ooooo`00o`04ooooo`03o`00oooooooooooo00Cooooo0_l00?lEooooo`03o`000?oooooooooo00go
oooo000>ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo03Sooooo00?oo`00ooooooooool00oooool00ooo003o003oooooo`0Aoooo
o`03ool00?oooooooooo00kooooo00Co003oooooooooooooo`000_ooool00ol00?ooooooooooo`0>
ooooo`03ool00?oooooooooo00;ooooo00?o003oooooooooool02oooool00ol00?ooo`00ooooo`04
ooooo`03ool00?oooooo003o03Oooooo00?o0000ooooooooool06?ooool5o`0000?ooooo00?o0000
ooooooooool01?ooool2o`0003kooooo00?o003oool00?ooool04Oooool01?l00?ooo`00ooooool0
0?l5ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol0003oooooo`00
o`02ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`04ooooo`;o003o1oooool00ol00?oo
o`00ooooo`08ooooo`03o`00oooooooooooo00Kooooo00Go003oool00?ooooooooooo`00o`02oooo
o`06o`00oooo003oooooooooool00?oooooo0ooo00000ooooooo003oooooo`05ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooool00?l01?ooool2o`00o`Gooooo0_l00?l=ooooo`;o00003ooo
ool000kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool0=_ooool00ol00?ooooooool00005ooooo`03ool00?l00?oooooo00_ooooo
00?o003oooooooooool00oooool00ooo003oooooooooo`0>ooooo`04o`00ooooooooooooool001?o
oooo00?oo`00ooooooooool00_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooo003ooooo00Co
oooo00?oo`00ooooool00?l0=oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0?_ooool01?oo003oooooooooool00?l?ooooo`04o`00oooo003ooooo
o`00o`[ooooo00?o003oooooooooool01?ooool00ol0003oooooo`00o`06ooooo`03o`00oooooooo
003o00Cooooo0_l00?l7ooooo`03o`00oooo003ooooo00Sooooo00?o003oooooooooool01oooool0
1?oo003oooooooooool00?l3ooooo`05ool00?ooooooooooo`00ooooool00ooo0005ooooo`04o`00
ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooo`00o`05oooo
o`;o003o3_ooool00ol0003oooooooooo`0=ooooo`003oooool3o`0000Cooooo0_l00004ooooo`;o
0000=oooool00ol00?ooooooool00005ooooo`03ool00?oooooooooo00cooooo00Co003ooooooooo
oooooooo0ooo000?ooooo`04o`00ooooooooooooool000;ooooo00?o003oooooooooool03Oooool3
ool001;ooooo00?oo`00ooooooooool00oooool00ooo003oooooo`00o`0gooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0mooooo`05o`00oooo003o
ooooooooool00?l01?ooool00ol00?ooooooooooo`09ooooo`03ool00?oooooo003o00;ooooo0ooo
00000ol00?ooooooooooo`02ooooo`;o003o1Oooool00ol0003oooooo`00o`02ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`07ooooo`05ool00?oo
ooooooooooooool00?l01Oooool00ol00?ooooooooooo`06ooooo`05o`00oooo003oooooooooool0
0?l00_ooool01Ol00?ooo`00oooooooooooo003o00;ooooo00Coo`00oooooooooooo003o0oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Wooooo0_l00?l5ooooo`03o`00oooooooo
oooo00Kooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool0=_ooool00ol0
0?ooooooool00005ooooo`03ool00?l00?oooooo00cooooo00Co003ooooooooooooooooo0ooo000B
ooooo`04ool00?ooooooooooo`00o`oooooo0ooo0003ooooo`03o`00oooooooooooo00_ooooo00?o
003oool00?ooool01?ooool00ooo003oooooooooo`0gooooo`03o`000?oooooooooo01oooooo0_l0
0006ooooo`03o`000?oooooooooo03gooooo00Go003oool00?ooooooooooo`00o`03ooooo`;o003o
2oooool00ooo003oooooooooo`02ooooo`?oo`0000?o003oooooooooool00_ooool2o`00o`Gooooo
00?o0000ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003ooooooooo
ool01Oooool00ol00?ooo`00ooooo`02ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool01_ooool00ol00?ooo`00ooooo`04ooooo`03o`00oooo003ooooo00Cooooo00Coo`00oooooooo
oooo003o0_ooool3ool00003ooooool00?oooooo00Wooooo00?o003oooooool00?l01?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool03Oooool001co
oooo00?o0000ooooooooool0>?ooool00ooo003oooooooooo`03ooooo`03ool00?l00?oooooo013o
oooo0ooo000?ooooo`04o`00ooooooooooooool000;ooooo00?o003oooooooooool03Oooool3ool0
00?ooooo00?o003oooooooooool02oooool00ol00?ooo`00ooooo`04ooooo`03ool00?oooooo003o
03Oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`04ooooo`;o0000?Oooool00ol0
0?ooooooool00006ooooo`;o003o2_ooool01?l00?ooo`00ooooool00?l2ooooo`?oo`0000?o003o
ooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`000?l00?oooooo00;ooooo00Oo003o
ooooooooooooooooo`00oooooooo003o00Cooooo0_l00?l7ooooo`03o`00oooo003ooooo00;ooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`06ooooo`03o`00oooo003ooooo00Cooooo
00Go003oool00?ooooooooooo`00o`02ooooo`04ool00?ooooooooooo`00o`;ooooo0ooo00000ooo
oooo003oooooo`02ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooool00?l01_ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Gooooo0_l0000?ooooo`007?ooool00ol0
003oooooooooo`0fooooo`03o`00ooooooooo`0000Gooooo00?oo`00o`00ooooool03?ooool00ol0
0?ooooooooooo`0Cooooo`04o`00ooooooooooooool001Sooooo00?o003oooooooooool02oooool0
0ol00?ooo`00ooooo`04ooooo`03ool00?oooooo003o03Oooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0nooooo`04ool00?ooooooooooo`00o`?ooooo00?o003oooooooooool02?oo
ool01Ol00?ooooooool00?oooooo003o00?ooooo00?oo`00ooooooooool01?ooool00ol00?oooooo
ooooo`04ooooo`03o`000?l00?oooooo00Gooooo00Co003ooooooooooooo003o1?ooool2o`00o`Oo
oooo00?o003oool00?ooool02?ooool00ol00?ooooooooooo`07ooooo`04ool00?ooooooooooo`00
o`?ooooo00Coo`00oooooooooooo003o0_ooool00ooo003oooooooooo`03ooooo`?oo`0000?ooooo
o`00ooooool00_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooo003o00Cooooo00?o
003oooooool00?l01?ooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo00gooooo000L
ooooo`;o0000=oooool00ol00?ooooooool00005ooooo`03ool00?l00?oooooo00cooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0>ooooo`04o`00ooooooooooooool000;ooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`0Aooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooool00?l0=oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Gooooo00?o
003oooooooooool0=?ooool00ol00?ooooooool00002ooooo`03o`00ooooooooo`0000;oo`0000?o
003oooooooooool01oooool01Ol00?ooooooool00?oooooo003o00?ooooo00?oo`00ooooool00?l0
1?ooool2o`00o`Gooooo00?o0000o`00ooooool00_ooool00ol00?ooooooooooo`03ooooo`05o`00
ooooooooooooooooool00?l02_ooool01Ooo003ooooooooooooooooo003o00Gooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooool00002ooooo`05o`00oooooooo003ooooooooo00000_ooool0
1?l00?oooooooooooooo0002ooooo`05o`00oooooooooooooooooooo00001?ooool3ool000;ooooo
00?o003oooooooooool02?ooool00ol00?ooooooo`00o`04ooooo`;o003o2?ooool00ol0003ooooo
ooooo`0=ooooo`007?ooool00ol0003oooooooooo`0fooooo`03o`00ooooooooo`0000Gooooo00?o
o`00ooooooooool03?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00Co
o`00oooooooooooo003o4?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00_ooooo
00?o003oool00?ooool01?ooool00ooo003oooooooooo`0gooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool01?ooool2o`00ocKooooo00?o003ooooooooo00000_ooool00ol00?oooooo
ool00002ool00003ooooool00?oooooo00Wooooo00?oo`00ooooooooool00oooool00ooo003ooooo
o`00o`04ooooo`;o003o1Oooool00ol0003oooooooooo`02ooooo`04o`00ooooooooooooo`00o`So
oooo00?o003oooooooooool01?ooool00ol00?ooooooool00003ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool01Oooool00ol00?ooooooool00002ooooo`05o`00oooooooo003ooooo
oooo00001?ooool01Ol00?ooo`00oooooooooooo003o00;ooooo00Ko003oool00?ooooooooooo`00
ooooool3ool000Kooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`04ooooo`;o003o
2?ooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`0hooooo`03ool00?oo
oooooooo00?ooooo00?oo`00o`00ooooool04Oooool00ol00?ooooooooooo`0>ooooo`04o`00oooo
ooooooooool000;ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00_ooooo00?o003oool00?ooool01?ooool00ooo003oooooo`00o`0gooooo`03o`00
0?oooooooooo02Oooooo0_l00005ooooo`;o003o1Oooool00ol00?ooooooooooo`0^ooooo`03o`00
ooooooooo`0000Cooooo0ooo00000ooooooo003oooooo`07ooooo`05o`00ooooooooo`00ooooool0
0?l00oooool00ooo003oooooo`00o`05ooooo`03o`00oooooooooooo00?ooooo00?o0000o`00oooo
ool00_ooool01?l00?ooooooooooool00?l2ooooo`07o`00ooooooooooooooooool00?ooooooo`00
o`06ooooo`03o`00ooooooooo`0000?ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`05ooooo`03o`00ooooooooo`0000Cooooo00?o003ooooooooo00000_ooool01?l00?ooooooo`00
oooo0003ooooo`04o`00ooooooooooooool000;ooooo00?o003ooooooooo00000_oo0002ooooo`07
o`00ooooooooooooooooool00?ooooooo`00o`06ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool01Oooool2o`0000oooooo000Looooo`03o`000?oooooooooo03Kooooo00?o003ooooo
oooo00001Oooool00ooo003o003oooooo`0<ooooo`03o`00oooooooooooo01?ooooo00Ko003ooooo
ooooooooo`00ooooool00?lFooooo`03o`00oooooooooooo00_ooooo00?o003oool00?ooool01?oo
ool00ooo003oooooo`00o`0gooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo033ooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`09ooooo`05o`00ooooooooo`00ooooool00?l00oooool00ooo003ooooo
ooooo`0;ooooo`03o`000?l00?oooooo00Gooooo00Co003ooooooooooooo003o0oooool00ol00?oo
ooooo`00o`06ooooo`03o`00ooooooooo`0000Wooooo00?o003oooooooooool01oooool01?oo003o
ooooooooool00?l3ooooo`07ool00?ooooooooooo`00oooooooo003oool00005ooooo`05o`00oooo
003oooooooooool00?l00_ooool01Ooo003ooooooooooooooooo003o00;ooooo00Co003ooooooooo
oooo003o0oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00Sooooo00?o0000
ooooooooool03Oooool001cooooo0_l0000gooooo`03o`00ooooooooo`0000Gooooo00?oo`00o`00
ooooool03?ooool01Ol00?oooooooooooooooooo003o017ooooo00Co003oooooooooooooo`004ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00_ooooo00?o003oool00?ooool01?oo
ool00ooo003oooooo`00o`0gooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01Ooo
ool00ol00?ooooooooooo`0dooooo`03o`00ooooooooo`0000;ooooo00Co003oooooooooooooo`00
0_ooool00ol00?ooooooooooo`06ooooo`05o`00ooooooooo`00ooooool00?l00oooool00ooo003o
ooooooooo`03ooooo`?oo`001Oooool00ol0003o003oooooo`02ooooo`03o`00oooooooooooo00?o
oooo00Go003oooooooooooooooooo`00o`0:ooooo`05ool00?ooooooooooooooool00?l01Oooool0
0ol00?ooooooooooo`05ooooo`03o`00ooooooooo`0000;ooooo00Go003oooooool00?ooooooool0
0002ooooo`04o`00ooooooooooooool000?ooooo00Co003oooooool00?ooo`000_ooool01?l00?oo
oooooooooooo0003ooooo`03o`00ooooooooo`0000;oo`001Oooool01?l00?ooooooooooool00?l3
ooooo`03o`00oooooooo003o00Sooooo00?o0000ooooooooool03Oooool001cooooo00?o0000oooo
ooooool0=_ooool00ol00?ooooooool00005ooooo`03ool00?oooooooooo00cooooo00Go003ooooo
ooooooooooooo`00o`0Booooo`05o`00ooooooooo`00ooooool00?l04Oooool00ol00?oooooooooo
o`0Aooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooool00?l0=oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo00?ooooo00?o003oooooool00?l01?ooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooooooo02Oooooo00?o003ooooooooo00000_ooool01?l00?oooooooooo
oooo0002ooooo`03o`00oooooooooooo00Sooooo00?oo`00ooooool00?l00oooool00ooo003ooooo
o`00o`03ooooo`?oo`001Oooool00ol0003oooooooooo`02ooooo`04o`00ooooooooooooo`00o`So
oooo00?o003oooooooooool01?ooool00ol00?ooooooool00003ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool01_ooool00ol00?ooooooool00002ooooo`05o`00oooooooo003ooooo
oooo00001?ooool00ol00?ooo`00ooooo`02ooooo`04o`00oooooooo003oool000Gooooo00Koo`00
ooooooooooooooooo`00ooooool3ool00003ooooool00?oooooo00;ooooo00?o003oooooooooool0
1?ooool01?l00?ooooooooooool00?l7ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`00
0?oooooooooo03Sooooo00?oo`00ooooooooool00oooool00ooo003o003oooooo`0@ooooo`03o`00
oooooooooooo013ooooo00Go003ooooooooo003oooooo`00o`0Booooo`04o`00ooooooooooooo`00
o`kooooo00?o003oool00?ooool01?ooool00ooo003oooooooooo`0gooooo`03o`000?oooooooooo
02Oooooo0_l00004ooooo`03o`00oooooooo003o00Cooooo00?o003oooooool00?l01?ooool2o`00
obSooooo00Co003oooooooooooooo`000_ooool01?l00?oooooooooooooo0002ooooo`03o`00oooo
oooooooo00Kooooo00?o003ooooooooo00001?ooool01?l00?ooo`00ooooool00?l3ooooo`?oo`00
1Oooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`04ooooo`03o`00ooooooooo`0000?ooooo00?o003ooooooooo
ool00_ooool2o`00o`Kooooo00Co003oooooooooooooo`001?ooool00ol00?ooooooool00002oooo
o`04o`00oooooooo003oool000?ooooo00Co003oooooooooooooo`000_ooool01?l00?oooooooooo
oooo0005ooooo`?oo`0000?oooooo`00ooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Cooooo0_l0000?ooooo`007?ooool00ol0003oooooooooo`0hooooo`03ool00?oo
oooooooo00?ooooo00?oo`00o`00ooooool03Oooool00ol00?ooooooooooo`0Cooooo`05o`00oooo
ooooo`00ooooool00?l05Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo003ooooo00Cooooo
00?oo`00o`00ooooool0=oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00?ooooo
00?o003oooooooooool01?ooool00ol00?ooooooo`00o`0aooooo`03ool00?oooooooooo00;ooooo
00?o003oool00?ooool02_ooool01Ol00?ooooooool00?oooooo003o00?ooooo00?oo`00ooooool0
0?l01?ooool00ooo003o003oooooo`04ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooo
oooo003o0oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooool000Wooooo00?o003o
ooooooooool01oooool01?oo003oooooooooool00?l3ooooo`07ool00?ooooooooooo`00oooooooo
003oool00003ooooo`04o`00oooooooo003oool000;ooooo00Co003oooooooooooooo`000oooool0
1?l00?oooooooooooooo0002ooooo`03o`00oooooooooooo00?oo`0000?oooooo`00ooooool00_oo
ool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00gooooo000Looooo`;o0000=oooool0
0ol00?ooooooool00005ooooo`03ool00?l00?oooooo00gooooo00Co003ooooooooooooo003o5?oo
ool00ooo003oooooooooo`0Eooooo`03o`00oooooooooooo00cooooo00?o003oool00?ooool01?oo
ool00ooo003o003oooooo`0gooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01Ooo
ool00ol00?ooooooooooo`09ooooo`;o003o1Oooool2o`00ob7ooooo00Co003oooooooooooooo`00
0_ooool01?l00?oooooooooooooo0002ooooo`03o`00oooooooooooo00Gooooo00Ko003ooooooooo
ooooo`00ooooool00?l2ooooo`03o`00oooo003ooooo00Gooooo00?oo`00ooooooooool01?ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00Go003oooooooooooooooooo`00
o`0:ooooo`05ool00?ooooooooooooooool00?l01?ooool2o`00o`Kooooo00Co003ooooooooooooo
o`000_ooool01Ol00?ooooooooooooooooooo`0000;ooooo00Co003oooooooooooooo`001Oooool0
1Ol00?ooo`00oooooooooooo003o00;ooooo00Goo`00ooooooooooooooooo`00o`02ooooo`03ool0
0?oooooooooo00?ooooo0ooo00000ooooooo003oooooo`02ooooo`04o`00ooooooooooooo`00o`Oo
oooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool0=_ooool00ol00?oooooo
ool00005ooooo`03ool00?oooooooooo00gooooo00Co003ooooooooooooo003o4_ooool01Ol00?oo
ooooool00?oooooo003o01;ooooo00?o003oooooooooool04?ooool00ooo003oooooooooo`03oooo
o`03ool00?l00?oooooo03Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`03oooo
o`03o`00oooooooo003o00Cooooo00?o003oooooooooool01?ooool2o`00o`Gooooo00?o003ooooo
ooooool08?ooool01?l00?oooooooooooooo0002ooooo`04o`00oooooooo003oool000;ooooo00?o
003oooooooooool02?ooool00ooo003oooooo`00o`02ooooo`04o`00oooo003oooooo`00o`Cooooo
00?oo`00o`00ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00oooooooo003o00Oooooo
00?o003oooooool00?l01Oooool01?l00?oooooooooooooo0003ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool01Oooool01?l00?oooooooooooooo0002ooooo`;o003o0_ooool01ooo
003ooooooooooooooooo003ooooooooo00000oooool2o`00o`03oooooooo003ooooo00Cooooo00Go
o`00ooooooooooooooooo`00o`02ooooo`03ool00?oooooooooo00?ooooo0ooo0005ooooo`04o`00
ooooooooooooo`00o`Oooooo00?o0000ooooooooool03Oooool000oooooo0ol00004ooooo`;o0000
1?ooool00ol0003oooooooooo`0fooooo`03o`00ooooooooo`0000Gooooo00?oo`00o`00ooooool0
3Oooool01?l00?ooooooooooool00?lBooooo`05o`00ooooooooo`00ooooool00?l04_ooool01?l0
0?ooooooooooool00?l>ooooo`03o`00oooo003ooooo00Cooooo00?oo`00ooooooooool0=oooool0
0ol0003oooooooooo`0Wooooo`;o00001?ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooo
003o00Cooooo0_l00?l6ooooo`03o`00oooooooooooo01oooooo00Co003oooooooooooooo`000_oo
ool01?l00?ooooooo`00oooo0002ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooooooo
o`001?ooool01?l00?ooo`00ooooool00?l3ooooo`03o`00oooo003o003o00Gooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool00oooool01?l00?oooooooooooooo0003ooooo`03o`00oooooooooooo00;ooooo0_l00?l6
ooooo`04o`00ooooooooooooool000?ooooo00Co003oooooooooooooo`000_ooool2o`00o`03oooo
oooo003ooooo00;ooooo00Co003oooooooooooooo`000_ooool01?l00?ooooooo`00oooo0005oooo
o`05o`00oooo003oooooooooool00?l00oooool01Ooo003oooooooooool00?oooooo00?oo`000_oo
ool00ol00?ooooooooooo`04ooooo`;o00003oooool000kooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0>?ooool00ooo003ooooo
ooooo`03ooooo`03ool00?l00?oooooo02?ooooo00Go003ooooooooo003oooooo`00o`0Booooo`04
o`00ooooooooooooo`00o`kooooo00?o003oool00?ooool01?ooool00ooo003o003oooooo`0goooo
o`03o`000?oooooooooo023ooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00?o003ooooo
ooooool01?ooool01?l00?ooooooooooool00?l;ooooo`;o003o1Oooool00ol00?ooooooooooo`0I
ooooo`04o`00ooooooooooooool000Cooooo00?o003oool00?ooool02Oooool01_l00?oooooooooo
oooo003oooooo`00o`?ooooo00?oo`00ooooool00?l01?ooool00ooo003o003oooooo`04ooooo`03
o`00oooooooooooo00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo003o
00Gooooo00Co003oooooooooooooo`002Oooool00ol00?ooooooooooo`07ooooo`05ool00?oooooo
ooooooooool00?l00_ooool00ooo003oooooooooo`02o`00o`03oooooooo003ooooo00;ooooo0_l0
0?l02?ooooooo`00oooooooooooo003oooooool00?ooo`000oooool01?l00?ooooooo`00oooo0002
ooooo`05o`00ooooooooooooo`00oooo00000_ooool00ol00?ooooooool00002ool000[ooooo00?o
0000ooooooooool03Oooool001;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ooooool3o`0003Oooooo00?o003oool00?ooool01?ooool00ooo003oooooooooo`0=ooooo`04o`00
ooooooooooooo`00oaCooooo00?oo`00ooooooooool05Oooool00ol00?ooooooooooo`0<ooooo`03
o`00oooo003ooooo00Cooooo00?oo`00o`00ooooool0=_ooool2o`00027ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00Oo003ooooo
ooooooooooooo`00oooooooo003o00Gooooo0_l00?l5ooooo`03o`00oooooooooooo01cooooo00Co
o`00oooooooooooo003o0_ooool01?oo003oooooooooool00?l7ooooo`06o`00ooooooooooooool0
0?oooooo003o0_ooool00ol00?ooo`00ooooo`04ooooo`03o`00oooo003ooooo00Gooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`03ooooo`05o`00ooooooooooooooooool00?l02_oo
ool01Ooo003ooooooooooooooooo003o00Gooooo00?o003oooooooooool01?ooool01?l00?oooooo
oooooooo0006ooooo`04ool00?ooooooooooo`00o`;ooooo00?oo`00ooooooooool00_ooool00ol0
0?ooooooool00002ooooo`04o`00oooooooo003oool000?ooooo00Co003oooooool00?ooo`000_oo
ool01Ol00?ooooooooooool00?ooo`0000;ooooo00?o003ooooooooo00000_oo000:ooooo`03o`00
0?oooooooooo00gooooo000@ooooo`;o00000oooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo03Oooooo00?o003oool00?ooool01?ooool00ooo003oooooooooo`0=ooooo`04o`00
ooooooooooooo`00oa;ooooo00Go003ooooooooo003oooooo`00o`0Booooo`03o`00oooooooooooo
013ooooo00?oo`00ooooooooool00oooool00ooo003o003oooooo`0gooooo`03o`000?oooooooooo
01oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`04o`00oooooooo
ooooo`00o`?ooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`04ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Booooo`04o`00oooo
ooooooooool000;ooooo0_l00?l01Oooooooo`00oooooooooooo003o00[ooooo00?oo`00ooooool0
0?l00_ooool01?l00?ooo`00ooooool00?l3ooooo`03o`00oooo003o003o00?ooooo0ooo0004oooo
o`03o`00oooooooo003o00Kooooo00Co003ooooooooooooo003o2?ooool01Ooo003ooooooooooooo
oooo003o00Cooooo00?o003oooooooooool01Oooool01?l00?oooooooooooooo0006ooooo`04ool0
0?ooooooooooo`00o`;ooooo00Coo`00oooooooooooooooo0_l00?l00oooooooo`00ooooo`04oooo
o`05ool00?ooooooooooooooool00?l00_ooool00ooo003oooooooooo`03ooooo`05o`00oooo003o
ooooooooool00?l00_ooool01_oo003ooooooooooooooooo003oooooo`?oo`000oooool00ol0003o
ooooooooo`0=ooooo`004_ooool01?l0003oooooooooool00002ooooo`05o`000?oooooooooooooo
ool00000>Oooool00ol00?ooo`00ooooo`04ooooo`03ool00?oooooooooo00kooooo0_l00?lCoooo
o`05o`00ooooooooo`00ooooool00?l04_ooool00ol00?ooooooo`00o`0?ooooo`03o`00oooo003o
oooo00Cooooo00?oo`00ooooooooool0=oooool00ol0003oooooooooo`0Oooooo`04o`000?oooooo
ooooo`0000Cooooo1Ol000001?l00?oo0000o`000?l00?l3o`000004ool00?l0003o0000o`00o`;o
000000Coo`00o`00ool0003o003o0ol000001?oo003o0000o`000?l00?l3o`000004ool00?l0003o
0000o`00o`;o000000?oo`00o`000?l00?l01?l000000ooo003o0000o`000003o`000003ool00?l0
003o000000Co000000Coo`00o`000?l0003o003o0ol000000ooo003o0000o`000002o`00o`05o`00
0?oo003o0000o`000?l00?l00ol000001?oo003o0000o`000?l00?l3o`000003ool00?l0003o0000
00;o000000Co003oool00?l0003o003o0ol000000ol00?ooo`00o`00o`03o`0000?oo`001?l00000
0ol00?ooo`00o`00o`05o`000007ool00?l0003o0000o`000?l00?oo0000ool00003o`000004o`00
ool0003o0000ool000?o000000Go003oo`000?l0003oo`00o`000002o`00o`;o000000Goo`00o`00
0?l0003o0000o`00o`02o`000003ool00?l0003o000000Co000000?oo`00o`000?l000000ol00000
1Ooo003o0000o`000?l0003o003o00;o000000Ooo`00o`000?l0003o003oo`000?l00?ooo`0000Go
000000?o003oool00?l000000_l000001?l00?oo0000o`000?oo0005o`000006ool00?l0003o0000
o`000?l00?oo00000ooo0004o`0000oooooo000>ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo03Sooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`0>ooooo`03o`00oooooooooooo01;ooooo00Go003ooooooooo003o
ooooo`00o`0Cooooo`;o003o3oooool00ol00?ooo`00ooooo`04ooooo`03ool00?l00?oooooo03Oo
oooo00?o0000ooooooooool07oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
00Wooooo00Coo`00oooooooooooo003o0_ooool00ooo003oooooooooo`04ooooo`04ool00?oooooo
ooooo`00o`?ooooo00Coo`00o`00oooooooo003o0_ooool01?oo003oooooooooool00?l3ooooo`04
ool00?oooooo003oo`00o`;ooooo00?oo`00ooooooooool01?ooool01?oo003oooooooooool00?l7
ooooo`03o`00oooooooooooo00Kooooo00Coo`00oooooooooooo003o1Oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooooooo0ooo0005ooooo`03ool0
0?l00?oooooo00;ooooo00Co003ooooooooo003o003o0_ooool00ol00?ooooooool00002ooooo`03
o`00oooooooooooo00Sooooo00Coo`00o`00oooooooo003o0_ooool00ooo003oooooooooo`0Eoooo
o`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01?ooool00ol00?ooooooo`00o`04oooo
o`03o`00oooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooool00002
ool000?ooooo00?o0000ooooooooool03Oooool000oooooo0ol00004ooooo`;o00001?ooool2o`00
03Sooooo00?o003oool00?ooool01?ooool00ooo003oooooooooo`0>ooooo`;o003o5Oooool00ooo
003oooooooooo`0Dooooo`03o`00oooooooooooo00kooooo00?oo`00ooooooooool00oooool00ooo
003o003oooooo`0gooooo`03o`000?oooooooooo01oooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`05ooooo`03o`00oooooooooooo00?oo`0000Koooooo`00ooooooooooooool0
0?l00?l2ooooo`07o`00ooooooooooooool00?l00?ooooooo`00o`03ooooo`04ool00?l00?oooooo
o`00o`;ooooo00Coo`00ooooool00?oo003o0oooool01?oo003oooooo`00ool00?l2ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool01oooool2o`00o`Cooooo00Go003ooooooooooooo
ooooool00002ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01oooool00ol00?oo
ooooooooo`04ooooo`03o`00ool0003ooooo00Cooooo00?oo`00o`00ooooool00_ooool01?l00?oo
ooooool00?l00?l2ooooo`03o`00ooooooooo`0000;ooooo00?o003oooooooooool01Oooool01?l0
0?oooooooooooooo0002ooooo`04o`00ooooooooooooool000;ooooo00?o003oooooooooool06Ooo
ool00ol00?ooooooooooo`03ooooo`?o003o1?ooool00ol00?ooooooo`00o`03ooooo`04o`00oooo
ooooooooo`00o`?ooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`0=ooooo`007?oo
ool00ol0003oooooooooo`0gooooo`03o`00oooo003ooooo00Cooooo00?oo`00ooooooooool09?oo
ool00ol00?ooo`00o`00o`0Vooooo`03ool00?oooooooooo00?ooooo00?oo`00o`00ooooool0=ooo
ool00ol0003oooooooooo`0Pooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`03o`00oooo
oooooooo00?oo`001?ooool01Ooo003o003ooooooooooooo003o00;ooooo00?oo`00o`00ooooool0
1?ooool00ooo003o003oooooo`03ooooo`04ool00?oooooo003oo`00o`?ooooo00Coo`00ooooool0
0?oo003o0_ooool00ooo003oooooooooo`02o`00o`;ooooo00Coo`00oooooooooooo003o1_ooool0
0ol00?ooooooooooo`03ooooo`05o`00oooooooooooooooooooo00002?ooool00ol00?ooooooo`00
o`03ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`05ooooo`03o`000?oooooooooo00;o
oooo00?o003oool00?ooool00oooool01?l00?ooooooool00?l00?l4ooooo`03ool00?oooooooooo
00Sooooo00Go003oooooooooooooo`00o`00o`04ooooo`04ool00?ooooooooooo`00oa_ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00Co
003oooooool00?oo003o0oooool01?l00?ooooooooooool00?l4ooooo`03o`000?oooooooooo00go
oooo000Looooo`03o`000?oooooooooo03Oooooo00?o003oool00?ooool01?ooool00ooo003ooooo
ooooo`0Tooooo`03o`00oooo003o003o02Kooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`0gooooo`03o`000?oooooooooo02Oooooo0_l00006ooooo`03o`00oooooooooooo00?oo`00
00Koooooo`00ooooooooooooool00?l00?l2ooooo`07o`00ooooooooooooool00?l00?ooooooo`00
o`03ooooo`04ool00?ooooooooooo`00o`;ooooo00?oo`00ooooool00?l01?ooool00ooo003ooooo
ooooo`03ooooo`05ool00?ooooooooooooooool00?l00_ooool01?oo003oooooooooool00?l6oooo
o`;o003o1?ooool01Ol00?ooooooooooooooooooo`0000;ooooo00?o003oooooooooool01Oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooool00?l01Oooool00ol0003ooooooooo
o`02ooooo`03o`00oooo003o003o00Gooooo00Ooo`00ooooooooooooooooo`00ooooooooo`0000;o
oooo00?o003oooooooooool01Oooool01ol00?oooooooooooooo003o003oooooool00?l00_ooool0
1?oo003oooooooooool00?lRooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02_oo
ool01?l00?ooooooooooool00?l3ooooo`;o00003oooool001cooooo00?o0000ooooooooool0>?oo
ool00ooo003oooooooooo`02ooooo`?oo`009Oooool00ol00?ooo`00o`00o`0Uooooo`?oo`001?oo
ool00ooo003o003oooooo`0gooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02?oo
ool01_l00?oooooooooooooooooo003oooooo`?oo`001Oooool01?oo003oooooooooool00?l3oooo
o`04ool00?l00?ooooooo`00o`;ooooo00Coo`00oooooooooooo003o0oooool01?oo003oooooo`00
ool00?l2ooooo`03ool00?oooooooooo00;o003o0_ooool01?oo003oooooooooool00?l7ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooool00002ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00;ooooo00?o003oo`000?ooool00oooool00ol00?ooo`00o`00o`03ooooo`04o`00ooooooooo`00
o`00o`;ooooo00?o003ooooooooo00000_ooool00ol00?ooooooooooo`05ooooo`07o`00oooooooo
ooooool00?l00?ooooooo`00o`02ooooo`03ool00?oooooooooo02;ooooo0_l00?l5ooooo`;o003o
1?ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooo003o00Gooooo00?o0000ooooooooool0
3Oooool001cooooo0_l0000hooooo`03o`00oooo003ooooo00?ooooo0ooo000Uooooo`03o`00oooo
003ooooo02Gooooo0ooo0004ooooo`03ool00?l00?oooooo03Oooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0<ooooo`03o`00ooooooooo`0000;oo`000_ooool01?l00?oooooooooo
oooo0002ooooo`08o`00oooooooooooooooooooo003o003oooooool00?l2ooooo`04ool00?l00?oo
ooooo`00o`?ooooo00Coo`00ooooool00?oo003o0_ooool01?oo003oooooooooool00?l3ooooo`03
ool00?oooooooooo00Oooooo0_l00?l8ooooo`04ool00?ooooooooooo`00o`Gooooo00?o003ooooo
ool00?l01_ooool00ol00?ooooooooooo`05ooooo`03o`00ool0003ooooo00Cooooo00?oo`00oooo
ooooool00_ooool01?l00?ooooooool00?l00?l2ooooo`03o`00ooooooooo`0000;ooooo00?o003o
ooooooooool02?ooool01?oo003oooooooooool00?l2ooooo`03ool00?oooooooooo02;ooooo0_l0
0?l5ooooo`;o003o1?ooool00ol00?ooooooo`00o`0<ooooo`03o`000?oooooooooo00gooooo000L
ooooo`03o`000?oooooooooo03Oooooo00?o003oool00?ooool00oooool3ool002Kooooo00?oo`00
o`00ooooool09?ooool3ool000Cooooo00?oo`00o`00ooooool0=oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo00Gooooo00Co003ooooooooooooo003o1Oooool3ool000;ooooo00Co
003oooooooooooooo`001_ooool00ooo003oooooooooo`03ooooo`04ool00?l00?ooooooo`00o`?o
oooo00Coo`00o`00oooooooo003o0_ooool00ooo003oooooooooo`02o`00o`;ooooo00Coo`00oooo
oooooooo003o1_ooool00ol00?ooooooooooo`03ooooo`05o`00oooooooooooooooooooo00002?oo
ool00ol00?ooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool0
0_ooool00ol00?oo0000ooooo`03ooooo`03o`00oooo003ooooo00?ooooo00Co003ooooooooo003o
003o1?ooool00ooo003oooooooooo`08ooooo`05o`00ooooooooooooool00?l00?l01?ooool01?oo
003oooooooooool00?lYooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01?ooool0
0ol00?ooooooo`00o`05ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo
03Oooooo00?o003oool00?ooool01?ooool00ol00?ooooooooooo`0Tooooo`03o`00oooo003o003o
02Kooooo00?o003oooooooooool00oooool00ooo003oooooooooo`0gooooo`03o`000?oooooooooo
02Oooooo0_l00006ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o0ooo
ool00ol00?ooooooool00002ool00003ooooool00?oooooo00;ooooo00Coo`00oooooooooooo003o
0_ooool00ooo003o003oooooo`04ooooo`03ool00?l00?oooooo00?ooooo00Goo`00oooooooooooo
ooooo`00o`02ooooo`03ool00?oooooo003o00Oooooo0_l00?l4ooooo`07o`00oooooooooooooooo
oooo003oooooo`00o`08ooooo`05o`00ooooooooooooooooool00?l00_ooool01?l00?oooooooooo
ool00?l5ooooo`03o`000?oooooooooo00;ooooo0ooo0005ooooo`09ool00?ooooooooooooooool0
0?ooooooool00?oooooo003o00Sooooo00Oo003oooooooooooooo`00o`00oooooooo003o00;ooooo
00Coo`00oooooooooooo003o:?ooool2o`00o`_ooooo00?o003oooooool00?l01?ooool2o`0000oo
oooo000Looooo`03o`000?oooooooooo03Sooooo00?oo`00ooooooooool00oooool00ol00?oooooo
ooooo`0Tooooo`?oo`009_ooool00ol00?ooooooooooo`03ooooo`03ool00?l00?oooooo03Oooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`05ooooo`04o`00ooooooooooooo`00o`?o
oooo00?o003oooooooooool01_ooool3ool000Gooooo00Coo`00oooooooooooo003o0_ooool01?oo
003oooooooooool00?l3ooooo`04ool00?ooooooooooo`00o`;ooooo00Goo`00ooooool00?oooooo
o`00o`02ooooo`03ool00?oooooo003o00Sooooo00?o003oooooooooool00_ooool01ol00?oooooo
ooooooooooooo`00ooooool00?l01_ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo
00?ooooo00Oo003oooooooooooooooooo`00oooooooo000000Cooooo0ooo0003ooooo`03o`00oooo
ooooo`0000?ooooo00Go003ooooooooo003oooooo`00o`08ooooo`04o`00ooooooooooooool000;o
oooo00Co003oooooooooooooo`000_ooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo
00?ooooo0_l00?l5ooooo`03o`00oooooooo003o00Gooooo00?o0000ooooooooool03Oooool001co
oooo0_l0000hooooo`03o`00oooo003ooooo00Cooooo00?o003oooooooooool09?ooool3ool002Ko
oooo00?o003oooooooooool00oooool00ooo003o003oooooo`0gooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool03?ooool01?l00?ooooooooooool00?l5ooooo`?oo`0000?oooooo`00
ooooool00_ooool01?oo003oooooooooool00?l2ooooo`04ool00?l00?ooooooo`00o`?ooooo00Co
o`00o`00oooooooo003o0_ooool00ooo003oooooo`00o`04ooooo`03ool00?oooooooooo00Oooooo
00?o003oooooooooool01oooool00ooo003oooooo`00o`06ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01?ooool00ol00?ooooooo`000004ooooo`?oo`000oooool00ol00?oooooo
ool00003ooooo`05o`00ooooooooo`00ooooool00?l02oooool01?oo003oooooooooool00?l2oooo
o`03ool00?oooooooooo033ooooo00?o003oooooooooool02oooool00ol0003oooooooooo`0=oooo
o`007?ooool00ol0003oooooooooo`0gooooo`03o`00oooo003ooooo00Cooooo00?o003ooooooooo
ool09?ooool3ool002cooooo00?oo`00o`00ooooool0=oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00Kooooo00?o003oooooooooool01_ooool01Ol00?oooooooooooooooooo003o
00;ooooo00Go003ooooooooooooo003oooooo`03ool000Gooooo00Coo`00o`00oooooooo003o0ooo
ool01?oo003o003oooooool00?l2ooooo`05ool00?oooooo003oooooool00?l00_ooool00ooo003o
ooooo`00o`07ooooo`03o`00oooooooooooo00?ooooo00Go003oooooooooooooooooool00008oooo
o`03o`00oooooooo003o00?ooooo00Co003ooooooooooooo003o0_ooool01ol00?oooooooooooooo
oooo003oooooool000001?ooool00ol00?ooooooooooo`03ooooo`03o`00ooooooooo`0000Gooooo
00?oo`00ooooooooool02?ooool01?l00?oooooooooooooo0005ooooo`03ool00?oooooo003o033o
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo00go
oooo000Looooo`03o`000?oooooooooo03Oooooo00?o003oool00?ooool0;?ooool00ol0003ooooo
ooooo`0[ooooo`03ool00?oooooooooo03Oooooo00?o0000ooooooooool09oooool2o`0000Oooooo
0_l00?l4ooooo`03o`00oooooooo003o00Cooooo00Co003ooooooooooooo003o0_ooool00ol00?oo
ooooool00002ool000;ooooo00Go003oooooooooooooo`00o`00o`05ooooo`03ool00?l00?oooooo
00?ooooo00Goo`00ooooooooooooooooo`00o`02ooooo`03ool00?oooooo003o00Oooooo00?o003o
ooooooooool00oooool01Ol00?ooooooooooooooooooo`0000[ooooo00Go003ooooooooooooooooo
o`00o`02ooooo`04o`00ooooooooooooo`00o`Gooooo00?o0000ooooooooool00_ooool2o`00o`Ko
oooo00Woo`00ooooooooooooooooo`00ooooooooo`00ooooool00?l02?ooool00ol00?ooooooool0
0002ool00007ooooool00?oooooooooooooo003oooooo`00o`0fooooo`;o003o1Oooool2o`0000oo
oooo000Looooo`03o`000?oooooooooo03Sooooo00?oo`00ooooooooool00oooool00ol00?oooooo
ooooo`0Uooooo`03o`000?oooooooooo02Gooooo00?o003oooooooooool00oooool00ooo003ooooo
ooooo`0gooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01_ooool2o`00o`Cooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`?oo`000_ooool01?l00?oooooo
oooooooo0002ooooo`05o`00oooooooooooooooooooo00000_ooool02?l00?oooooooooooooo003o
ooooo`00oooooooo003o0_ooool00ooo003oooooo`00o`07ooooo`03o`00oooooooooooo00?ooooo
00Oo003oooooooooooooooooool00?oooooo003o00Sooooo00Go003oooooooooooooooooo`00o`05
ooooo`07o`00ooooooooooooooooool00?ooooooo`000004ooooo`;o003o1?ooool00ol00?oooooo
ool00003ooooo`05o`00ooooooooo`00ooooool00?l02Oooool01_l00?ooo`00ool00?oo003ooooo
o`00o`;ooooo00?oo`00ooooool00?l0=_ooool2o`00o`Kooooo00?o0000ooooooooool03Oooool0
01cooooo0_l0000hooooo`03o`00oooo003ooooo00Cooooo00?o003oooooooooool09Oooool00ol0
003oooooooooo`0Uooooo`03o`00oooooooooooo00?ooooo00?oo`00o`00ooooool0=oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`06ooooo`05o`00ooooooooooooooooool00?l00_ooool01Ol00?oooooooooooooo
oooo003o00;ooooo00Coo`00oooooooooooo003o0oooool01?oo003o003oooooool00?l2ooooo`03
ool00?oooooo003o00Cooooo00?oo`00ooooooooool01oooool00ol00?ooooooooooo`07ooooo`03
ool00?oooooo003o00Kooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l2oooo
o`07o`00ooooooooooooooooool00?ooooooo`000005ooooo`03o`00oooooooooooo00;ooooo00?o
003ooooooooo00000oooool01Ol00?ooooooool00?oooooo003o00[ooooo0ooo00001Ooooooo003o
ooooooooooooo`0003Wooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`0=ooooo`00
7?ooool00ol0003oooooooooo`0gooooo`03o`00oooo003ooooo00Cooooo00?o003oooooooooool0
9Oooool00ol0003oooooooooo`0Uooooo`03o`00oooooooooooo00?ooooo00?oo`00o`00ooooool0
=oooool00ol0003oooooooooo`0Wooooo`;o00001oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooool00?l00oooool01?l00?ooooooooooool00?l5ooooo`?o
o`000_ooool01ol00?oooooooooooooo003o003oooooool00?l00_ooool01Ooo003o003ooooooooo
oooo003o00;ooooo00?oo`00ooooool00?l01oooool00ol00?ooooooooooo`03ooooo`06o`00oooo
oooooooooooooooo003o003o1oooool2o`00o`Oooooo00?o003oooooooooool01?ooool00ol00?oo
ooooo`000004ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo00001Oooool00ooo003o
ooooooooo`09ooooo`;o003o0oooool01_l00?oooooooooooooo003oooooo`00ocgooooo0_l0000?
ooooo`004?ooool3o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo03Oooooo00?o003oool0
0?ooool0;?ooool00ol0003oooooooooo`0[ooooo`03ool00?l00?oooooo03Oooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`06ooooo`;o003o1?ooool00ol00?ooooooo`00o`04oooo
o`03o`00oooooooo003o00?ooooo00?o003oooooooooool01_ooool3ool000Gooooo00?oo`00oooo
ooooool00oooool01Ooo003o003ooooooooooooo003o00;ooooo00?oo`00ooooool00?l01oooool0
0ol00?ooooooooooo`03ooooo`05o`00oooooooooooooooooooo00002?ooool2o`00o`Cooooo00?o
003oooooool00?l00oooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0_l0
0?l5ooooo`?oo`000_ooool01?l00?ooooooool00?l00?l:ooooo`;o003o1_ooool00ooo003ooooo
o`00o`0nooooo`03o`000?oooooooooo00gooooo000Aooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000003[ooooo00?oo`00ooooooooool00oooool00ol00?oo
ooooooooo`0Uooooo`03o`000?oooooooooo02Gooooo00?o003oooooooooool00oooool00ooo003o
ooooooooo`0gooooo`03o`000?oooooooooo01oooooo0ol00005ooooo`03o`000?oooooooooo00Ko
oooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00Ko
oooo00Ko003oooooooooooooooooo`00ooooool3ool000;ooooo00Co003oooooooooooooo`001Ooo
ool01Ooo003o003ooooooooooooo003o00;ooooo00?oo`00o`00ooooool01oooool00ol00?oooooo
ooooo`03ooooo`06o`00oooooooooooooooooooo003o003o2?ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooo003o00?ooooo00Oo003oooooooooooooooooo`00oooooooo000000Cooooo0_l0
0?l4ooooo`04o`00oooo003oo`00ool000;ooooo00Co003ooooooooo003o003o2_ooool2o`00o`?o
oooo00Ko003oooooooooooooo`00ooooool00?lnooooo`03o`000?oooooooooo00gooooo000>oooo
o`Go00000_ooool01?l0003oooooooooool00003ooooo`?o0000>?ooool00ooo003oooooooooo`03
ooooo`03o`00oooooooooooo02Gooooo00?o0000ooooooooool09Oooool00ol00?ooooooooooo`03
ooooo`03ool00?l00?oooooo03Kooooo0_l0000Rooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool03?ooool00ol00?ooooooooooo`06ooooo`05o`00ooooooooooooooooool00?l00_oo
ool01Ol00?oooooooooooooooooo003o00;ooooo00Ko003oooooooooooooooooo`00ooooool3ool0
0006ooooool00?oooooooooooooo003o003o1Oooool00ooo003oooooooooo`07ooooo`03o`00oooo
oooooooo00Oooooo00?oo`00o`00ooooool01_ooool00ol00?ooooooooooo`03ooooo`04o`00oooo
ooooooooo`00o`;ooooo00Oo003oooooooooooooooooo`00oooooooo000000Gooooo00?o003ooooo
ooooool00_ooool01?l00?ooo`00ool00?oo0002ooooo`04o`00ooooooooo`00o`00o`oooooo00Co
003oooooooooooooo`00@?ooool00ol0003oooooooooo`0=ooooo`003_ooool01?l0003ooooooooo
ool00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0=oooool00ol00?oo
o`00ooooo`04ooooo`03o`00oooooooooooo02Gooooo00?o0000ooooooooool09Oooool00ol00?oo
ooooooooo`03ooooo`03ool00?l00?oooooo03Oooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`04ooooo`;o00003_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00?o
oooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooo
o`0000;oo`0000Goooooo`00ooooooooooooool00003ooooo`05o`00ooooooooooooool00?l00?l0
2?ooool00ol00?ooooooooooo`03ooooo`;o003o0_ooool00ooo003o003oooooo`06ooooo`;o003o
1_ooool00ol00?ooooooooooo`04ooooo`04o`00ooooooooooooo`0000Cooooo00?o003ooooooooo
ool00oooool00ol00?ooooooo`00o`05ooooo`03ool00?oooooooooo00kooooo00Go003ooooooooo
ooooo`00o`00o`0nooooo`;o00003oooool000oooooo00?o0000ooooool000000oooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo03Oooooo00?o003oool00?ooool0;?ooool00ol0
003oooooooooo`0[ooooo`03ool00?oooooooooo03Oooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool00oooool2o`00
o`Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`03ooooo`?oo`0000Koooooo`00
ooooooooooooool00?l00?l2ooooo`05o`00ooooooooooooool00?l00?l02?ooool00ol00?oooooo
ooooo`04ooooo`04o`00ooooooooooooool000Sooooo0_l00?l4ooooo`03o`00oooooooo003o00?o
oooo00?o003oooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00Go
oooo00So003oooooooooooooooooo`00ooooooooo`00o`00oa;ooooo00?oo`00o`00ooooool0?_oo
ool00ol0003oooooooooo`0=ooooo`004?ooool2o`0000?ooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`0fooooo`?oo`001?ooool00ol00?ooooooooooo`0Vooooo`03o`000?oo
oooooooo02Gooooo00?o003oooooooooool00_ooool3ool003Sooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00gooooo00Goo`00o`00oooooooooooo
o`00o`02ooooo`03ool00?l00?oooooo00Oooooo00?o003oooooooooool01?ooool01?l00?oooooo
oooooooo0009ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l00oooool01?l00?oo
ooooooooool00?l2ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`03ooooo`04o`00ooooooooo`00o`00o`oooooo00Go003oooooooooooooo`00o`00
o`0oooooo`03o`000?oooooooooo00gooooo000Aooooo`03o`000?oooooooooo00;ooooo0_l00004
ooooo`;o0000=oooool3ool000Cooooo00?o003oooooooooool09_ooool00ol0003oooooooooo`0U
ooooo`03o`00oooooooooooo00;ooooo0ooo000hooooo`03o`000?oooooooooo01oooooo0_l00006
ooooo`03o`000?oooooooooo01Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooo003o00Cooooo00?o003oooooool00?l00oooool00ol00?ooooooool00002
ool000;ooooo00Co003oooooooooooooo`002Oooool00ol00?ooooooooooo`06ooooo`?oo`001ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o
0_ooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00?ooooo0_l00?l4ooooo`04o`00
ooooooooo`00o`00o`oooooo00Co003oooooooooooooo`00@?ooool00ol0003oooooooooo`0=oooo
o`007?ooool00ol0003oooooooooo`0fooooo`?oo`001?ooool00ol00?ooooooooooo`0Vooooo`03
o`000?oooooooooo02Gooooo00?o003oooooooooool00_ooool3ool003Sooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`04ooooo`;o00005?ooool2o`00o`Gooooo0_l00?l4ooooo`03
o`00oooooooo003o00Cooooo00?o003oooooool00?l00oooool00ol00?ooooooool00002ool000Go
oooo00?oo`00o`00ooooool01oooool00ol00?ooooooooooo`04ooooo`03o`00ooooooooo`0000;o
o`001oooool2o`00o`Kooooo00?o003oooooooooool01?ooool01?l00?ooooooooooool00004oooo
o`03o`00oooooooooooo00?ooooo0_l00?l6ooooo`03ool00?oooooooooo00kooooo00Go003ooooo
ooooooooo`00o`00o`0nooooo`;o00003oooool001cooooo00?o0000ooooooooool0=oooool00ol0
0?ooooooooooo`0/ooooo`03o`000?oooooooooo02_ooooo00?o003oooooooooool0=oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo01?ooooo0_l00?l5ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`03ooooo`03o`00ooooooooo`00
00;oo`000_ooool01Ol00?oooooooooooooo003o003o00Sooooo00?o003oooooooooool01?ooool0
0ol00?ooooooool00002ool000Oooooo0_l00?l4ooooo`03o`00oooooooo003o00?ooooo00?o003o
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00?ooooo0_l00?l5
ooooo`?oo`004_ooool00ooo003o003oooooo`0nooooo`03o`000?oooooooooo00gooooo000Loooo
o`03o`000?oooooooooo03Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Voooo
o`03o`000?oooooooooo02Kooooo00?o003oooooooooool0??ooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo01[ooooo0_l00?l4ooooo`03o`00oooooooo003o00gooooo00Go003ooooo
ooooooooooooo`00o`02ooooo`03ool00?oooooooooo00Oooooo00?o003oooooooooool01?ooool0
0ol00?ooooooo`00o`0:ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l00oooool0
1?l00?ooooooooooool00?l2ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool02Ooo
ool01?l00?ooo`00ool00?oo000?ooooo`05o`00ooooooooooooool00?l00?l0?oooool00ol0003o
ooooooooo`0=ooooo`007?ooool2o`0003kooooo00?o003oooooooooool09_ooool00ol0003ooooo
ooooo`0Vooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0=oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo01[ooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool01?l00?oo
oooooooooooo0009ooooo`03o`00oooooooooooo00Gooooo0_l00?l9ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l2ooooo`03o`000?oooooo
oooo00;ooooo00?o003oooooooooool00oooool2o`00o`Cooooo00Co003oool00?oo003oo`003ooo
ool00ol00?ooooooool00002ool003oooooo00?o0000ooooooooool03Oooool001cooooo00?o0000
ooooooooool0>?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02Kooooo00?o0000
ooooooooool09_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo03Oooooo00?o0000
ooooooooool09oooool2o`0001_ooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`04
ooooo`03o`00oooooooo003o00?ooooo00?o003oooooooooool01_ooool3ool000Sooooo00?o003o
ooooooooool04?ooool2o`00o`Kooooo00?o003oooooooooool00oooool01Ol00?oooooooooooooo
oooo000000Cooooo00?o003oooooooooool00oooool2o`00o`Cooooo00?o003oooooool00?l04?oo
ool00ol00?ooooooool00002ool003kooooo0_l0000?ooooo`007?ooool00ol0003oooooooooo`0h
ooooo`03o`00oooooooooooo02_ooooo00?o0000ooooooooool0:oooool00ol00?ooooooooooo`0g
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool08_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooool0
0002ool000Sooooo00?o003oooooooooool04?ooool2o`00o`Cooooo00?o003oooooool00?l00ooo
ool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool00ooo
ool2o`00oaWooooo0ooo000oooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooo
oooo03Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Vooooo`03o`000?oooooo
oooo02Kooooo00?o003oooooooooool0??ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo023ooooo0_l00?l>ooooo`06o`00ooooooooooooooooool00?oooooo0ooo0008ooooo`03o`00
oooooooooooo017ooooo00?o003oooooooooool00_ooool2o`00o`Cooooo00?o003oooooool00?l0
0oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00Wooooo00?o003oooooool00?l0
4?ooool01?l00?ooooooooooool00?m0ooooo`03o`000?oooooooooo00gooooo000Looooo`;o0000
?_ooool00ol00?ooooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0gooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
8?ooool2o`00o`Gooooo0_l00?l4ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooo
oooo003o2Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool00oooool00ol00?ooooooo`00o`03ooooo`03o`000?oooooooooo00;ooooo00?o003ooooo
ooooool00oooool2o`00o`Cooooo00?o003oooooool00?l04?ooool00ol00?ooooooooooo`11oooo
o`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo03Sooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0gooooo`03o`000?oooooooooo02Oooooo0_l0000Rooooo`03
o`00oooooooooooo00?ooooo0_l00?l4ooooo`03o`00oooooooooooo017ooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00Go003ooooooooo
ooooooooo`000004ooooo`03o`00oooooooooooo00?ooooo0_l00?l4ooooo`03o`00oooooooo003o
013ooooo00Co003ooooooooooooo003o?oooool2o`0000oooooo000Looooo`03o`000?oooooooooo
03Sooooo00?o003oooooooooool0:oooool00ol0003oooooooooo`0[ooooo`03o`00oooooooooooo
03Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Wooooo`;o003o1?ooool00ol0
0?ooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Wooooo00?o003oooooooooool04?ooool2
o`00o`Cooooo0_l00?l4ooooo`03o`00oooooooo003o00?ooooo00?o0000ooooooooool00_ooool0
0ol00?ooooooooooo`03ooooo`;o003o6_ooool00ol00?ooooooooooo`0nooooo`03o`000?oooooo
oooo00gooooo000Looooo`03o`000?oooooooooo03Sooooo00?o003oooooooooool0:oooool00ol0
003oooooooooo`0Vooooo`03o`00oooooooooooo03cooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0_ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l02_ooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo0_l00?l4ooooo`03o`00oooooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo003o
013ooooo00Co003ooooooooooooo003o@?ooool00ol0003oooooooooo`0=ooooo`007?ooool2o`00
03kooooo00?o003oooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool0=oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
02Oooooo0_l00?l4ooooo`03o`00oooooooo003o00Cooooo00?o003oooooool00?l02_ooool00ol0
0?ooooooooooo`0@ooooo`;o003o1?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o
00?ooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooool00?l04?ooool01?l00?ooooooooooool00?m0ooooo`03o`000?oooooo
oooo00gooooo000Looooo`03o`000?oooooooooo03Sooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0gooooo`03o`000?oooooooooo02Oooooo0_l0000Xooooo`;o003o1?ooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`04ooooo`05o`00ooooooooooooooooool000001?ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00?ooooo0_l00?lAooooo`03o`00oooooooooooo043ooooo0_l0000?
ooooo`003oooool3o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo03Sooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0Vooooo`03o`000?oooooooooo02_ooooo00?o003ooooo
ooooool0=oooool00ol0003oooooooooo`0Nooooo`Go00001?ooool00ol0003oooooooooo`0]oooo
o`03o`00oooooooo003o00Cooooo00?o003oooooool00?l02_ooool00ol00?ooooooooooo`0@oooo
o`;o003o1Oooool00ol00?ooooooooooo`04ooooo`05o`00ooooooooooooooooool000001?ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0?oooool0
0ol0003oooooooooo`0=ooooo`003_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`0hooooo`03o`00oooooooooooo02_ooooo00?o
0000ooooooooool0IOooool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0;oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00[ooooo
00?o003oooooooooool04?ooool2o`00o`Cooooo0_l00?l4ooooo`03o`00oooooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol00?ooooooooooo`09ooooo`;o003o4oooool00ol00?oooooo
ooooo`0oooooo`03o`000?oooooooooo00gooooo000Booooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooooooo0ol0000mooooo`03o`00oooooooooooo02Kooooo00?o0000oooooooo
ool09_ooool00ol00?ooooooooooo`0kooooo`;o00008_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo02kooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`0:ooooo`03
o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`03ooooo`;o
003o1?ooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool00oooool2o`00oa7ooooo00?o003oooooool00?l0@Oooool00ol0003oooooooooo`0=ooooo`00
4_ooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000>_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo03Oooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`03ooooo`;o0000;oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`;o003o1?ooool00ol0
003oooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool2o`00
oa7ooooo00?o003oooooooooool0@?ooool2o`0000oooooo000>ooooo`Co00000oooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo03Sooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0gooooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo02kooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`0:
ooooo`03o`00oooooooooooo013ooooo0_l00?l5ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool05_ooool00ol00?ooooooo`00o`11ooooo`03o`000?oooooooooo00gooooo000>oooo
o`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0h
ooooo`03o`00oooooooooooo02_ooooo00?o0000ooooooooool0:_ooool00ol00?ooooooooooo`0h
ooooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo03Cooooo0_l00?l;ooooo`03o`00oooooooooooo013ooooo0_l00?l4ooooo`;o003o1?oo
ool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool02Ooo
ool2o`00oa?ooooo00?o003oooooooooool0?oooool00ol0003oooooooooo`0=ooooo`003_ooool5
o`0000?ooooo0_l00004ooooo`;o0000>Oooool01Ol00?oooooooooooooooooo003o02Wooooo00?o
0000ooooooooool09_ooool00ol00?ooooooooooo`0looooo`03o`000?oooooooooo01oooooo0ol0
0005ooooo`03o`000?oooooooooo03Cooooo0_l00?l;ooooo`03o`00oooooooooooo017ooooo00?o
003oooooooooool00_ooool2o`00o`Cooooo0_l00?l4ooooo`03o`000?oooooooooo00;ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`;o003o4Oooool00ol00?ooooooo`00
o`11ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo03cooooo00?o003o
ooooooooool09oooool00ol0003oooooooooo`0Vooooo`05o`00ooooooooooooooooool00?l0>_oo
ool00ol0003oooooooooo`0Wooooo`;o0000@_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool00oooool2o`00o`Cooooo00?o0000ooooooooool00_oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo0_l00?lAooooo`03o`00oooo
oooooooo043ooooo0_l0000?ooooo`007?ooool00ol0003oooooooooo`0hooooo`05o`00oooooooo
ooooooooool00?l0:Oooool00ol0003oooooooooo`0Vooooo`05o`00ooooooooooooooooool00?l0
>_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Gooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0@ooooo`;o003o1Oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo01Kooooo0_l00?m2ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oo
oooooooo03Sooooo00?o003oooooooooool0:oooool00ol0003oooooooooo`0Zooooo`03o`00oooo
oooooooo03Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0dooooo`;o003o2ooo
ool00ol00?ooooooooooo`0@ooooo`;o003o1?ooool2o`00o`Cooooo00?o003oooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00ooo
ool2o`00oa;ooooo00?o003oooooooooool0@?ooool00ol0003oooooooooo`0=ooooo`007?ooool2
o`0003[ooooo00Co003ooooooooooooo003o:Oooool00ol0003oooooooooo`0Wooooo`03o`00oooo
oooooooo03_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0dooooo`;o003o2ooo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo0_l00?l4ooooo`;o003o1?oo
ool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00Wooooo0_l00?lAooooo`;o003o@_oo
ool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`0looooo`03o`00oooooooo
oooo02Oooooo00?o0000ooooooooool09oooool01?l00?ooooooooooool00?ljooooo`03o`000?oo
oooooooo02Oooooo0_l0000eooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool04?oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo0_l00?l4ooooo`03o`000?oo
oooooooo00;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo013ooooo00?o003oooooooooool0@?ooool2o`0000oooooo000Looooo`03o`000?oooooo
oooo03Wooooo00Co003ooooooooooooo003o:Oooool00ol0003oooooooooo`0Wooooo`04o`00oooo
ooooooooo`00oc[ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`11ooooo`03o`00
oooooooooooo013ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool04?ooool2o`00od;ooooo00?o0000ooooooooool0
3Oooool001cooooo00?o0000ooooooooool0>Oooool00ol00?ooooooooooo`0Zooooo`03o`000?oo
oooooooo02[ooooo00?o003oooooooooool0>?ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo047ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`;o003o1?oo
ool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0@?oo
ool00ol0003oooooooooo`0=ooooo`007?ooool2o`0003[ooooo00Co003ooooooooooooo003o:Ooo
ool00ol0003oooooooooo`0Wooooo`03o`00oooooooooooo03_ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`11ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00ooo
ool2o`00o`Cooooo00?o003oooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool04?ooool2o`00od;ooooo00?o0000ooooooooool03Ooo
ool001cooooo00?o0000ooooooooool0??ooool00ol00?ooooooooooo`0Wooooo`03o`000?oooooo
oooo02Oooooo00Co003ooooooooooooo003o>_ooool00ol0003oooooooooo`0Wooooo`;o0000@_oo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0@?oo
ool2o`0000oooooo000Looooo`03o`000?oooooooooo03Wooooo00Co003ooooooooooooo003o:Ooo
ool00ol0003oooooooooo`0Wooooo`04o`00ooooooooooooo`00oc[ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`11ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
4?ooool2o`00od;ooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool0>Ooo
ool00ol00?ooooooooooo`0Zooooo`03o`000?oooooooooo02[ooooo00?o003oooooooooool0>?oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo047ooooo00?o003oooooooooool04?oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool05ooo
ool00ol00?ooooooooooo`10ooooo`03o`000?oooooooooo00gooooo000Looooo`;o0000>_ooool0
1?l00?ooooooooooool00?lYooooo`03o`000?oooooooooo02Oooooo00?o003oooooooooool0>ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo047ooooo00?o003oooooooooool04?oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool04?oo
ool2o`00od;ooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool0??ooool0
0ol00?ooooooooooo`0Wooooo`03o`000?oooooooooo02Oooooo00?o003oooooool00?l0>oooool0
0ol0003oooooooooo`0Wooooo`;o0000@_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo013ooooo00?o003oooooooooool0@?ooool2o`0000oooooo000?ooooo`?o00001?ooool2o`00
00Cooooo00?o0000ooooooooool0>Oooool00ol00?ooooooo`00o`0Zooooo`03o`000?oooooooooo
02Oooooo00?o003oooooool00?l0>oooool00ol0003oooooooooo`0Oooooo`?o00001Oooool00ol0
003oooooooooo`11ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool2o`00
od;ooooo00?o0000ooooooooool03Oooool000kooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0>Oooool00ol00?ooooooooooo`0Z
ooooo`03o`000?oooooooooo02Wooooo00?o003oooooooooool0>Oooool00ol0003oooooooooo`0N
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`11ooooo`03o`00oooo
oooooooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo01Oooooo00?o003oooooooooool0@?ooool00ol0003oooooooooo`0=ooooo`003_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool3o`0003[ooooo
00?o003oooooooooool0:Oooool00ol0003oooooooooo`0Xooooo`03o`00oooooooooooo03Wooooo
0_l0000Tooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0@Oooool00ol00?oooooo
ooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0@ooooo`03o`00oooooooooooo047ooooo00?o0000ooooooooool03Oooool000kooooo1?l0
0003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0>oooool00ol00?oooooo
ooooo`0Xooooo`03o`000?oooooooooo02Sooooo0_l00?lkooooo`03o`000?oooooooooo023ooooo
0_l00005ooooo`;o0000@_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo
00?o003oooooooooool0@?ooool2o`0000oooooo000>ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`0jooooo`;o003o:_ooool00ol0003ooooo
ooooo`0Xooooo`;o003o>oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0@Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo
00?o003oooooooooool0@Oooool00ol0003oooooooooo`0=ooooo`003oooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0>_ooool2o`00ob[ooooo
00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Nooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`1Dooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool00oooool00ol0003oooooooooo`0Qooooo`03o`00oooooooooooo047ooooo00?o0000oooooooo
ool03Oooool0013ooooo0_l00004ooooo`;o00001?ooool2o`0006Oooooo00?o0000ooooooooool0
IOooool00ol0003oooooooooo`0Oooooo`?o00001Oooool00ol0003oooooooooo`1Vooooo`03o`00
0?oooooooooo06Gooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Wooooo`;o00000oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00Co0000oooooooooooooooo0_l0000?ooooo`007?oooooBo`0002Woooood_l0
000?ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooo
oooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooo
oooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`008?oo
ool2o`00023ooooo0ol0000Looooo`?o00001?ooool2o`0001Wooooo0ol00003ooooo`?o00006Ooo
ool5o`0000?ooooo0_l0000Hooooo`Go00000_ooool3o`0004_ooooo0_l0000Oooooo`?o00007?oo
ool3o`0000Cooooo0_l0000Iooooo`?o00000oooool3o`0001Sooooo1Ol00003ooooo`;o00006?oo
ool5o`0000;ooooo0ol0000]ooooo`007oooool01?l0003oooooooooool0000Nooooo`05o`000?oo
ooooooooooooool000007?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Wo
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01Oooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool0000Hooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`17ooooo`04o`000?ooooooooooo`0001gooooo00Go0000oooo
ooooooooooooo`00000Looooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00006Ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool05_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0001Sooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`03o`000?oooooooooo02[ooooo000Oooooo`04o`000?ooooooooooo`0002;ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Wooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00006Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Oo
oooo00Co0000oooooooooooo00008Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00006Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Iooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0:_ooool001oooooo00Co0000oooooooooooo00008_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
6Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo00Go0000oooooooooooo
ooooo`000002ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`17ooooo`04o`000?ooooooooooo`00027ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:_ooool001oooooo00Co0000
oooooooooooo00007_ooool4o`0001gooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000Iooooo`04o`000?ooooooooooooooo`Co00006Oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00005oooool01_l0003ooooooooooooooooo0000ooooo`Co0000
B_ooool01?l0003oooooooooool0000Mooooo`Co00007Oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0001Wooooo00Co0000oooooooooooooooo1?l0000Hooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool0000Gooooo`06o`000?ooooooooooooooool0
003ooooo1?l0000]ooooo`007oooool01?l0003oooooooooool0000Nooooo`03o`000?oooooooooo
01gooooo0_l00004ooooo`04o`000?ooooooooooo`0001Sooooo0_l00003ooooo`03o`000?oooooo
oooo01[ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001Oooooo
00Oo0000ooooooooooooooooo`000?oooooo000004gooooo00Co0000oooooooooooo00007Oooool0
0ol0003oooooooooo`0Mooooo`;o00001?ooool01?l0003oooooooooool0000Hooooo`;o00000ooo
ool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool0000Gooooo`07o`000?ooooooooooooooool0003oooooo`00000`ooooo`008?ooool2o`00
01oooooo1Ol0000Looooo`03o`000?oooooooooo00?ooooo0_l0000Jooooo`04o`000?oooooooooo
ooooo`Go00006Oooool3o`0000Cooooo0_l0000Iooooo`?o00000_ooool5o`0004[ooooo0_l0000N
ooooo`Go00007?ooool00ol0003oooooooooo`03ooooo`;o00006_ooool01?l0003ooooooooooooo
ool5o`0001Sooooo0ol00004ooooo`;o00006Oooool3o`0000;ooooo1Ol0000/ooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`007?oooooBo`0002?ooooo0ol0
0004ooooom3o00004?ooool001Kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool08?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0>ooooo`005Oooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo0<kooooo00?o0000ooooooooool06_ooool5o`0000Gooooo00Go0000oooooooooooooooo
o`00003>ooooo`03o`000?oooooooooo00kooooo000Eooooo`04o`000?ooooooooooo`0000?ooooo
0ol00002ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool01?oo003ooooo
ooooooooool2o`0002Cooooo0_l00004ooooo`?o0000b_ooool3o`00013ooooo000Eooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`0Tooooo`05
o`000?ooooooooooooooool00000c_ooool00ol0003oooooooooo`0>ooooo`005Oooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool08?ooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>
ooooo`005Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?o0000
ooooooooool08Oooool3o`0000Cooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>
ooooo`005_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`0Xoooo
o`;o0000c?ooool2o`00013ooooo000Looooo`03o`000?oooooooooo00;ooooo00?oo`00oooooooo
ool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo
ool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000Looooo`;o0000
0oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
0_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool0
3_ooool001cooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo0<cooooo00?o0000ooooooooool03_ooool001cooooo00?o0000ooooooooool00_ooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool0
0ol0003oooooooooo`0Xooooo`;o0000c?ooool2o`00013ooooo000Looooo`03o`000?oooooooooo
00;ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo
00kooooo000Looooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000Looooo`03o`000?oooooooooo00;ooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo
000Looooo`;o00000oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool00_ooool00ol0003oooooooooo`0Xooooo`;o0000c?ooool2o`00013ooooo000L
ooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`3<
ooooo`03o`000?oooooooooo00kooooo000Looooo`03o`000?oooooooooo00;ooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000Looooo`03
o`000?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo00;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`3<ooooo`03
o`000?oooooooooo00kooooo000Looooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool0
:?ooool2o`000<cooooo0_l0000@ooooo`007?ooool00ol0003oooooooooo`02ooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool00_ooool3ool000Cooooo0ooo0004ooooo`?oo`001Ooo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0c?oo
ool00ol0003oooooooooo`0>ooooo`007?ooool2o`0000?ooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool3
ool000?ooooo0ooo0004ooooo`?oo`001?ooool3ool000Cooooo0ooo0005ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03o`000?oooooo
oooo023ooooo1Ol00003ooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool0
01cooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`03ooooo`?oo`001Oooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`03ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`001?ooool3ool0
00Cooooo0ooo0004ooooo`?oo`001Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`?oo`000oooool00ol0
003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0c?ooool0
0ol0003oooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo
00?ooooo0ooo0005ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo0ooo0004ooooo`?oo`006?ooool3ool0
00Cooooo0ooo0005ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo0ooo0003ooooo`03o`000?oooooooooo
01[ooooo1Ol00003ooooo`03o`000?oooooooooo00?ooooo0ol0003:ooooo`?o00004?ooool001co
oooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`03ooooo`?oo`001Oooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool3ool000Go
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`?oo`001?ooool3ool002Ko
oooo0ooo0004ooooo`?oo`001Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?o
oooo0ooo0005ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`02ooooo`?oo`000oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`007?ooool00ol0003ooooo
ooooo`02ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00?ooooo0ooo0005ooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool00oooool3ool003Cooooo0ooo0005ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool00oooool3ool000Gooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00Sooooo00?o0000ooooooooool08?ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`00
7?ooool2o`0000?ooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool00oooool3ool000Gooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`03ooooo`?oo`00=?ooool3ool000Gooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`03ooooo`?oo`001Oooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool02?ooool00ol0003oooooooooo`0Pooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00ko
oooo000Looooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool02oooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool02oooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo04;ooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`0;ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`08ooooo`03o`000?oooooooooo027ooooo0ol00004ooooo`;o0000c?ooool2o`00013ooooo
000Looooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool02oooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool02oooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`03ooooo`?oo`00@_ooool3ool000Gooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool02oooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool02?ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool001cooooo00?o0000
ooooooooool00_ooool00ooo003oooooooooo`0:ooooo`?oo`001Oooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool3ool004;ooooo0ooo0005
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03
ooooo`?oo`002Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0<cooooo00?o0000
ooooooooool03_ooool000oooooo0ol00004ooooo`;o00001?ooool00ol0003oooooooooo`02oooo
o`03ool00?oooooooooo00[ooooo0ooo0005ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool02oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`03ooooo`?oo`00@_ooool3ool000Gooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool02oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo0ooo0009oooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>oooo
o`004?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool00_ooool00ooo003oooooooooo`0:ooooo`?oo`001Oooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0D?ooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0;oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool3ool000Wooooo00?o0000oooo
ooooool0:?ooool2o`000<cooooo0_l0000@ooooo`004?ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000?ooooo0ol00002ooooo`03ool00?oooooooooo01;ooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo053ooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool02oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00kooooo0_l0000Zoooo
o`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool0013ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00?oo`00oooo
ooooool04_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00_ooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool0D?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool03oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0<cooooo00?o0000oooo
ooooool03_ooool0013ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00?ooooo0ooo001?ooooo`?oo`001Oooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0aoooo
o`?oo`00L?ooool3ool002Gooooo00?o0000ooooooooool03_ooool000oooooo0_l00004ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0Boooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool3ool004oooooo0ooo0005oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0;oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0Xoooo
o`;o0000<_ooool3ool0073ooooo0ooo000Tooooo`;o00004?ooool0013ooooo00?o0000oooooooo
ool00oooool2o`0000Cooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0Booooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool3ool004oooooo0ooo0005ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0;ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo037ooooo0ooo001`ooooo`?oo`004Oooool3ool0017ooooo00?o0000oooooooo
ool03_ooool001cooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0Booooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool0GOooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0booooo`03ool0
0?oooooooooo073ooooo00?oo`00ooooooooool04?ooool3ool0017ooooo00?o0000ooooooooool0
3_ooool001cooooo0_l00003ooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`1Mooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool03ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03;ooooo00?oo`00ooooooooool0L?oo
ool00ooo003oooooooooo`0@ooooo`?oo`004Oooool00ol0003oooooooooo`0>ooooo`007?ooool0
0ol0003oooooooooo`02ooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`0;ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`1Mooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`0;ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool03oooool0
0ol0003oooooooooo`0Xooooo`;o00007Oooool3ool001?ooooo00?oo`00ooooooooool00_ooool3
ool006_ooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0?ooooo`;o00004?ooool0
01cooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool0GOooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Looooo`?oo`004oooool00ooo
003oooooooooo`02ooooo`?oo`00Joooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo
013ooooo00?o0000ooooooooool03_ooool001cooooo00?o0000ooooooooool00_ooool00ooo003o
ooooooooo`0Booooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool02oooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0GOooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool02oooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00oooooo00?o0000ooooooooool08Oooool3o`0000Co
oooo00?o0000ooooooooool07?ooool3ool001?ooooo00?oo`00ooooooooool00_ooool3ool006_o
oooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0@ooooo`03o`000?oooooooooo00ko
oooo000Looooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool04_ooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo05gooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`0?ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Mooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`1Zooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool04?ooool00ol0003ooooo
ooooo`0>ooooo`007?ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo01;ooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`1Mooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool03oooool00ol0003oooooooooo`0Jooooo`Go00000oooool00ol0003ooooooooo
o`03ooooo`?o00007Oooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool00oooool3ool006Cooooo00?oo`00ooooooooool04Oooool00ooo003ooooooooo
o`0>ooooo`?o00004?ooool001cooooo0_l00003ooooo`03ool00?oooooooooo01;ooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`1Mooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool03oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool07Oooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool00oooool3ool006Cooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0@
ooooo`03o`000?oooooooooo00kooooo000Looooo`03o`000?oooooooooo00;ooooo00?oo`00oooo
ooooool04_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00_ooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo05gooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00_ooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Mooooo`03ool00?oooooooooo01;ooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`03ooooo`?oo`00I?ooool00ooo003oooooooooo`0Aoooo
o`03ool00?oooooooooo00?ooooo0ooo000:ooooo`03o`000?oooooooooo00kooooo000Looooo`03
o`000?oooooooooo00;ooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`03ooooo`?o
o`003?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool0GOooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool02_ooool3ool000Gooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0Qooooo`;o
00001Oooool00ol0003oooooooooo`0Mooooo`03ool00?oooooooooo01;ooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo0ooo001Mooooo`03
ool00?oooooooooo017ooooo00?oo`00ooooooooool00oooool3ool000[ooooo00?o0000oooooooo
ool03_ooool001cooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0Booooo`03ool0
0?oooooooooo00?ooooo0ooo000<ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`1Mooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`0:ooooo`?oo`001Oooool00ooo003oooooooooo`0?ooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool00oooool2o`0001kooooo00?oo`00ooooooooool0
4_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
0oooool3ool005gooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`03ooooo`?oo`00
2Oooool2o`00013ooooo000Looooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool04_oo
ool00ooo003oooooooooo`03ooooo`?oo`003?ooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool0GOooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool02_ooool3ool000Gooooo00?oo`00ooooooooool03ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01gooooo00?oo`00ooooooooool04_oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00ooo
ool3ool005gooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo00Wooooo00?o0000ooooooooool03_ooool001cooooo00?o0000ooooooooool00_ooool0
0ooo003oooooooooo`0Booooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo05gooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool03oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01gooooo00?oo`00ooooooooool04_ooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`1Looooo`03ool00?oooooooooo00?ooooo0ooo000;ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`007?ooool2o`00
00?ooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool00oooool3ool005gooooo0ooo0005ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool07Oooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00?ooooo0ooo001Fooooo`03ool00?oooooooooo00?ooooo0ooo000;ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`007?ooool00ol0003o
ooooooooo`02ooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool04_ooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooooooo00?ooooo0ooo001Mooooo`?oo`001Oooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool03oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo01gooooo00?oo`00ooooooooool04_ooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`03ooooo`?oo`00E_ooool00ooo003oooooooooo`03ooooo`?oo`002oooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool03_ooool001cooooo
00?o0000ooooooooool00_ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo01;ooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`?oo`00GOooool3ool000Gooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00oooooo
00?o0000ooooooooool0:?ooool2o`0001kooooo00?oo`00ooooooooool04_ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`03ooooo`?oo`00E_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00[ooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`08ooooo`;o00004?ooool001cooooo00?o
0000ooooooooool00_ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo01;ooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`1[ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool04_ooool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool07Oooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool00oooool3ool004oooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`0:ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool02Oooool00ol0003ooooooooo
o`0>ooooo`007?ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo01;ooooo00?oo`00
ooooooooool04_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo06_ooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00oooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0Mooooo`03ool00?oooooooooo01;ooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`03ooooo`?oo`00Coooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03
ooooo`?oo`000oooool00ol0003oooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`02oooo
o`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo06_ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Boooo
o`03ool00?oooooooooo00oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Moooo
o`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03oooo
o`?oo`00Coooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00[ooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`03ooooo`?oo`000oooool00ol0003oooooooooo`0>oooo
o`007?ooool2o`0000?ooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0Booooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool0Joooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo01;ooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0Xooooo`;o
00007_ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo
ool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool01?ooool00ooo003oooooooooo`02ooooo`?oo`00BOooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00[ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`?o
o`000_ooool2o`00013ooooo000Looooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool0
4_ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
Joooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool0
3oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01gooooo00?oo`00ooooooooool0
4_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
0_ooool3ool004Wooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0:ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03o`00
0?oooooooooo00kooooo000Looooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool04_oo
ool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0Jooo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool03ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01gooooo00?oo`00ooooooooool04_oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_oo
ool3ool004Wooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0:ooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03o`000?oo
oooooooo00kooooo000>ooooo`Go00000oooool2o`0000Cooooo00?o0000ooooooooool00_ooool0
0ooo003oooooooooo`0Booooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`1[ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool04_ooool0
0ooo003oooooooooo`0?ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool07Oooool0
0ooo003oooooooooo`0Booooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo04Sooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo000?ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`03ool00?oo
oooooooo01;ooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo06_ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Booooo`03ool00?oo
oooooooo00oooooo00?o0000ooooooooool0:?ooool2o`0001kooooo00?oo`00ooooooooool04_oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`03ooooo`?oo`00@_ooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo00[ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`04ool00?oo
ooooooooooooo`;o00004?ooool0013ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool04_ooool00ooo003ooooo
ooooo`0Booooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0Joooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool03oooool00ol0003ooooo
ooooo`0Rooooo`;o00001?ooool00ol0003oooooooooo`0Mooooo`03ool00?oooooooooo01;ooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool00oooool3ool004;ooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`0:ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`02ooooo`03o`000?oooooooooo00kooooo000Aooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooooooool3o`0000;ooooo00?oo`00ooooooooool04_ooool00ooo003o
ooooooooo`0Booooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0Joooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool03_ooool2o`0002?o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Mooooo`03ool00?oooooooooo
01;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool00oooool3ool004;ooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`0:ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo000>ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00?oo`00
ooooooooool04_ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool0Joooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01;ooooo00?oo`00
ooooooooool03oooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000?ooooo00Co
0000oooooooooooooooo0ooo000Iooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`03ooooo`?oo`00>oooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00[ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00;ooooo00?o0000ooooooooool03_ooool000kooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool00ooo003o
ooooooooo`0Booooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool00oooool00ooo003o
ooooooooo`1[ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool04_ooool00ooo003o
ooooooooo`0?ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00000oooool3o`00
0004oooooooo003oo`00ool000Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03
ooooo`?oo`001Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?o00004?ooool0
00oooooo0ol00004ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo
01;ooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
06_ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo
00oooooo00?o0000ooooooooool08Oooool01?l0003oooooooooool00003ooooo`04o`000?oooooo
ooooooooo`?oo`001Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool02_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo03Wooooo0ooo
0005ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool04Oooool00ooo003ooooooooo
o`0Gooooo`03o`000?oooooooooo00kooooo000Looooo`03o`000?oooooooooo00;ooooo00?oo`00
ooooooooool04_ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool0Joooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01;ooooo00?oo`00
ooooooooool03oooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool02Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool02_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo043ooooo0ooo
0004ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool05oooool00ol0003ooooooooo
o`0>ooooo`007?ooool2o`0000?ooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0B
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0Joooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0R
ooooo`;o00001?ooool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool0@?ooool3ool000Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0G
ooooo`03o`000?oooooooooo00kooooo000Looooo`03o`000?oooooooooo00;ooooo00?oo`00oooo
ooooool04Oooool3ool001?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1[oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool04Oooool3ool0013ooooo00?o0000oooo
ooooool0:?ooool2o`0000[ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`10oooo
o`?oo`001?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo01Kooooo0_l0000@oooo
o`007?ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo017ooooo0ooo000Cooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool0Joooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo017ooooo0ooo000@ooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool02Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool02_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo04Kooooo0ooo0005ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Aooooo`03
ool00?oooooooooo01Oooooo00?o0000ooooooooool03_ooool001cooooo00?o0000ooooooooool0
0_ooool00ooo003oooooooooo`0Aooooo`?oo`004oooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo06_ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Aooooo`?oo`00
4?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`16ooooo`?oo`001Oooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0Gooooo`03o`00
0?oooooooooo00kooooo000Looooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool09ooo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo06_ooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`0Tooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02Ooo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool02_oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo04Kooooo0ooo0005ooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Aooooo`03ool00?oo
oooooooo01Oooooo00?o0000ooooooooool03_ooool001cooooo00?o0000ooooooooool00_ooool0
0ooo003oooooooooo`0Wooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0Joooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo02Cooooo00?o0000ooooooooool0:?ooool2
o`0000Wooooo0ooo0005ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool02_ooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo04gooooo0ooo0005ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0Fooooo`;o00004?ooool0
01cooooo0_l00003ooooo`03ool00?oooooooooo02Oooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`1[ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool09?ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo00Sooooo0ooo0005ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
04gooooo0ooo0005ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool04Oooool00ooo
003oooooooooo`0Gooooo`03o`000?oooooooooo00kooooo000Looooo`03o`000?oooooooooo00;o
oooo00?oo`00ooooooooool09oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo06_o
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Tooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool02?ooool3ool000Gooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`0:ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0COooool3ool000Go
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo01Oo
oooo00?o0000ooooooooool03_ooool001cooooo00?o0000ooooooooool00_ooool00ooo003ooooo
ooooo`0Wooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0Joooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo02Cooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0@ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool02_ooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo05Gooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`0Aooooo`03ool00?oooooooooo01Oooooo00?o0000ooooooooool03_ooool001cooooo00?o
0000ooooooooool00_ooool00ooo003oooooooooo`0Wooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool0Joooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo02Cooooo00?o
0000ooooooooool0:?ooool2o`00017ooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`09ooooo`?oo`001Oooool00ooo003oooooooooo`1Dooooo`?oo`001Oooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`0Aooooo`03ool00?oooooooooo01Kooooo0_l0000@ooooo`007?ooool00ol0003oooooooooo`02
ooooo`03ool00?oooooooooo02Oooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1[
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool09?ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`09
ooooo`?oo`001Oooool00ooo003oooooooooo`1Dooooo`?oo`001Oooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0A
ooooo`03ool00?oooooooooo01Oooooo00?o0000ooooooooool03_ooool001cooooo00?o0000oooo
ooooool00_ooool00ooo003oooooooooo`0Wooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool0Joooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo02Cooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool02Oooool3ool000Gooooo00?oo`00ooooooooool0E?ooool3ool000Gooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool04Oooool00ooo003oooooooooo`0Gooooo`03o`000?oooooooooo00kooooo000Looooo`;o
00000oooool00ooo003oooooooooo`0Wooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo
ool0Joooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo02Cooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool04Oooool00ooo003oooooooooo`1Kooooo`?oo`001Oooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0Gooooo`03
o`000?oooooooooo00kooooo000Looooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool0
9oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo06_ooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`0Tooooo`03o`000?oooooooooo02Sooooo0_l0000@ooooo`?oo`00
1Oooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo05_ooooo0ooo0005ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Aooooo`03ool0
0?oooooooooo01Kooooo0_l0000@ooooo`007?ooool00ol0003oooooooooo`02ooooo`03ool00?oo
oooooooo02Oooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1[ooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool09?ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00oooooo0ooo0005ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool0Fooo
ool3ool000Gooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo017ooooo00?oo`00ooooooooool05oooool00ol0003oooooooooo`0>ooooo`007?ooool0
0ol0003oooooooooo`02ooooo`03ool00?oooooooooo02Oooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`1[ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool09?ooool0
0ol0003oooooooooo`0Qooooo`?o00001?ooool00ol0003oooooooooo`0?ooooo`?oo`001Oooool0
0ooo003oooooooooo`0Aooooo`03ool00?oooooooooo06?ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool05oooool0
0ol0003oooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo
02Oooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1[ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool09?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo
06;ooooo0ooo0004ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool04Oooool00ooo
003oooooooooo`0Gooooo`03o`000?oooooooooo00kooooo000Looooo`03o`000?oooooooooo00;o
oooo00?oo`00ooooooooool09oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo06_o
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Tooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool00oooool3o`0001Oooooo00?oo`00ooooooooool04Oooool00ooo003o
ooooooooo`1Rooooo`?oo`001?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo017o
oooo00?oo`00ooooooooool05Oooool3o`00013ooooo000Looooo`;o00000oooool00ooo003ooooo
ooooo`0Wooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0Joooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo02Cooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool04Oooool00ooo003ooooo
ooooo`1Rooooo`?oo`001?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo017ooooo
00?oo`00ooooooooool05oooool00ol0003oooooooooo`0>ooooo`007?ooool00ol0003ooooooooo
o`02ooooo`03ool00?oooooooooo02Oooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`1[ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool09?ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool00ooo003ooooooooo
o`0Aooooo`03ool00?oooooooooo06Wooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`0@ooooo`?oo`006?ooool00ol0003oooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`02
ooooo`03ool00?oooooooooo02Oooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1[
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool09?ooool00ol0003oooooooooo`0Q
ooooo`;o00001Oooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo017ooooo00?oo`00
ooooooooool0J?ooool3ool000Gooooo00?oo`00ooooooooool04?ooool3ool001Sooooo00?o0000
ooooooooool03_ooool000oooooo0ol00004ooooo`;o00001?ooool00ol0003oooooooooo`02oooo
o`03ool00?oooooooooo02Oooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1[oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool09?ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00?ooooo0_l0000Hooooo`03ool00?oooooooooo017ooooo00?oo`00oooo
ooooool0J?ooool3ool000Gooooo00?oo`00ooooooooool04?ooool3ool001Oooooo0_l0000@oooo
o`003_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`02ooooo`03ool00?oooooooooo02Oooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`1[ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool09?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01Kooooo0ooo000Booooo`03ool00?oooooo
oooo06Sooooo0ooo0005ooooo`03ool00?oooooooooo02_ooooo00?o0000ooooooooool03_ooool0
01;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o
o`00ooooooooool09oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo06_ooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`0Tooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool05_ooool3ool001;ooooo00?oo`00ooooooooool0L?ooool00ooo003ooooooooo
o`0[ooooo`03o`000?oooooooooo00kooooo000@ooooo`;o00000oooool01?l0003oooooooooool0
0003ooooo`?o00000_ooool00ooo003oooooooooo`0Wooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool0Joooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo02?ooooo0_l0
000Zooooo`03o`000?oooooooooo01Kooooo0ooo000Aooooo`?oo`00LOooool00ooo003ooooooooo
o`0[ooooo`03o`000?oooooooooo00kooooo000Booooo`04o`000?ooooooooooo`0000;ooooo00Go
0000ooooooooooooooooo`000004ooooo`03ool00?oooooooooo02Oooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`1[ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
9?ooool00ol0003oooooooooo`0Xooooo`;o0000:oooool3ool0073ooooo0ooo000[ooooo`;o0000
4?ooool000kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0Wooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool0Joooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo02Co
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Zooooo`?oo`00L?ooool3ool002co
oooo00?o0000ooooooooool03_ooool000oooooo0ol00004ooooo`;o00001?ooool00ol0003ooooo
ooooo`02ooooo`03ool00?oooooooooo02Oooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`1[ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool09?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo09gooooo0ooo000/ooooo`03o`000?oooooooooo00kooooo
000Looooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool09oooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo06_ooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`0Tooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0c?ooool00ol0003ooooooooo
o`0>ooooo`007?ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo02Oooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`1[ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool09?ooool00ol0003oooooooooo`0Xooooo`;o0000c?ooool2o`00013ooooo000Loooo
o`;o00000oooool00ooo003oooooooooo`0Wooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool0Joooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo02Cooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000Looooo`03
o`000?oooooooooo00;ooooo00?oo`00ooooooooool09oooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo06_ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Tooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`00
7?ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo02Oooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`1[ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
9?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool0
3_ooool001cooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0Wooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool0Joooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo02Cooooo00?o0000ooooooooool0:?ooool2o`000<cooooo0_l0000@ooooo`007?ooool0
0ol0003oooooooooo`02ooooo`03ool00?oooooooooo02Kooooo0ooo0004ooooo`03ool00?oooooo
oooo06_ooooo00?oo`00ooooooooool00oooool3ool002Gooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000Looooo`03o`000?oooooooooo
00;ooooo00?oo`00ooooooooool09_ooool3ool000Cooooo00?oo`00ooooooooool0Joooool00ooo
003oooooooooo`03ooooo`?oo`009Oooool00ol0003oooooooooo`0Pooooo`Go00000oooool00ol0
003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000Looooo`;o00000oooool00ooo003o
ooooooooo`0Vooooo`?oo`001?ooool00ooo003oooooooooo`1[ooooo`03ool00?oooooooooo00?o
oooo0ooo000Uooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000Looooo`03o`000?oooooooooo00;o
oooo00?oo`00ooooooooool0;Oooool00ooo003oooooooooo`1[ooooo`03ool00?oooooooooo02_o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`03ooooo`?o0000b_ooool3o`00013o
oooo000Looooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool0;Oooool00ooo003ooooo
ooooo`1[ooooo`03ool00?oooooooooo02_ooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool001cooooo00?o
0000ooooooooool00_ooool00ooo003oooooooooo`0]ooooo`03ool00?oooooooooo06_ooooo00?o
o`00ooooooooool0:oooool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000Looooo`04o`000?oo
ooooooooooooo`?oo`00;_ooool00ooo003oooooooooo`1[ooooo`03ool00?oooooooooo02_ooooo
00?o0000ooooooooool08?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool0c?ooool00ol0003oooooooooo`0>ooooo`007?ooool2o`0000;ooooo0ooo000^ooooo`03ool0
0?oooooooooo06_ooooo00?oo`00ooooooooool0:oooool00ol0003oooooooooo`0Qooooo`?o0000
1?ooool2o`000<cooooo0_l0000@ooooo`007?ooool01?l0003oooooooooooooool3ool002kooooo
00?oo`00ooooooooool0Joooool00ooo003oooooooooo`0[ooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`007?ooool00ol0003ooooooooo
o`0booooo`03ool00?oooooooooo06_ooooo00?oo`00ooooooooool0:oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool001cooooo00?o0000
ooooooooool0<_ooool00ooo003oooooooooo`1[ooooo`03ool00?oooooooooo02_ooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000Loooo
o`03o`000?oooooooooo03;ooooo00?oo`00ooooooooool0Joooool00ooo003oooooooooo`0[oooo
o`03o`000?oooooooooo02Sooooo0_l0003<ooooo`;o00004?ooool001cooooo00?o0000oooooooo
ool0<_ooool00ooo003oooooooooo`1[ooooo`03ool00?oooooooooo02_ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000Looooo`;o0000
<oooool00ooo003oooooooooo`1[ooooo`03ool00?oooooooooo02_ooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000Looooo`03o`000?oo
oooooooo03;ooooo00?oo`00ooooooooool0Joooool00ooo003oooooooooo`0[ooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`007?ooool0
0ol0003oooooooooo`0booooo`03ool00?oooooooooo06_ooooo00?oo`00ooooooooool0:oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool0
01cooooo00?o0000ooooooooool0<_ooool00ooo003oooooooooo`1[ooooo`03ool00?oooooooooo
02_ooooo00?o0000ooooooooool0:?ooool2o`000<cooooo0_l0000@ooooo`004?ooool3o`0000?o
oooo0_l00004ooooo`03o`000?oooooooooo03;ooooo00?oo`00ooooooooool0Joooool00ooo003o
ooooooooo`0[ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0c?ooool00ol0003o
ooooooooo`0>ooooo`004Oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`00000dooooo`03ool00?oooooooooo06_ooooo00?oo`00ooooooooool0:oooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool03_ooool000ko
oooo1Ol00002ooooo`04o`000?ooooooooooo`0000?ooooo0ol0000booooo`03ool00?oooooooooo
06_ooooo00?oo`00ooooooooool0:_ooool2o`0002[ooooo00?o0000ooooooooool0c?ooool00ol0
003oooooooooo`0>ooooo`003_ooool01?l0003oooooooooool00003ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool0<_ooool00ooo003oooooooooo`1[ooooo`03ool00?oooooo
oooo02_ooooo00?o0000ooooooooool0:?ooool2o`000<cooooo0_l0000@ooooo`003oooool00ol0
003oooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0<_ooool0
0ooo003oooooooooo`1[ooooo`03ool00?oooooooooo02_ooooo00?o0000ooooooooool08Oooool3
o`0000Cooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`004?ooool2o`00
00?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0booooo`03ool00?oooooo
oooo06_ooooo00?oo`00ooooooooool0:oooool00ol0003oooooooooo`0Pooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00kooooo000A
ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`03o`000?oooooooooo03;ooooo00?oo`00
ooooooooool0Joooool00ooo003oooooooooo`0[ooooo`03o`000?oooooooooo02Cooooo00Go0000
ooooooooooooooooo`00003>ooooo`03o`000?oooooooooo00kooooo000Looooo`03o`000?oooooo
oooo037ooooo0ooo001[ooooo`?oo`00;?ooool00ol0003oooooooooo`0Rooooo`;o00001?ooool3
o`000<[ooooo0ol0000@ooooo`007?ooool2o`0003;ooooo0ooo001[ooooo`?oo`00;?ooool00ol0
003oooooooooo`0Tooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0>
ooooo`007?ooool00ol0003oooooooooo`0aooooo`?oo`00Joooool3ool002cooooo00?o0000oooo
ooooool08?ooool01Ol0003ooooooooooooooooo000000?oooood?l0000@ooooo`007?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo027ooooo0ol0003Tooooo`007?oooooBo`000?oo
oooo2oooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oo
oooonOooool00?oooooonOooool00?oooooonOooool00001\
\>"],
  ImageRangeCache->{{{0, 503}, {310.438, 0}} -> {-0.0514703, -0.0309082, \
0.0041808, 0.0041808}, {{12.3125, 240.062}, {303, 162.25}} -> {-6.7051, \
-11.041, 0.0502515, 0.499035}, {{262.875, 490.688}, {303, 162.25}} -> \
{-19.2978, -4.26868, 0.0502515, 0.0509911}, {{12.3125, 240.062}, {148.125, \
7.375}} -> {-4.94479, -60.4796, 0.145729, 0.341693}, {{262.875, 490.688}, \
{148.125, 7.375}} -> {-42.1612, -11.7081, 0.147552, 0.0492634}}]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 800}, {0, 578}},
ScreenStyleEnvironment->"Working",
WindowSize->{759, 694},
WindowMargins->{{Automatic, 230}, {53, Automatic}},
CellLabelAutoDelete->True,
Magnification->1,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 58, 0, 62, "Title"],

Cell[CellGroupData[{
Cell[1788, 54, 99, 4, 59, "Section"],

Cell[CellGroupData[{
Cell[1912, 62, 60, 0, 49, "Subsection"],
Cell[1975, 64, 127, 2, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2139, 71, 37, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2201, 75, 59, 0, 43, "Subsubsection"],
Cell[2263, 77, 118, 2, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2418, 84, 67, 0, 43, "Subsubsection"],
Cell[2488, 86, 820, 15, 143, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3357, 107, 45, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[3427, 111, 62, 0, 43, "Subsubsection"],
Cell[3492, 113, 330, 6, 111, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3859, 124, 67, 0, 35, "Subsubsection"],
Cell[3929, 126, 227, 4, 46, "Text"],
Cell[4159, 132, 551, 10, 159, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4747, 147, 48, 0, 35, "Subsubsection"],
Cell[4798, 149, 367, 8, 64, "Text"],
Cell[5168, 159, 302, 4, 111, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5507, 168, 83, 1, 35, "Subsubsection"],
Cell[5593, 171, 683, 12, 191, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6313, 188, 83, 1, 35, "Subsubsection"],
Cell[6399, 191, 684, 12, 191, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7132, 209, 39, 0, 33, "Subsection"],
Cell[7174, 211, 333, 7, 46, "Text"],
Cell[7510, 220, 541, 10, 143, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[8088, 235, 41, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[8154, 239, 45, 0, 43, "Subsubsection"],
Cell[8202, 241, 67, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[8306, 247, 43, 0, 43, "Subsubsection"],
Cell[8352, 249, 58, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[8447, 255, 104, 4, 43, "Subsubsection"],
Cell[8554, 261, 74, 1, 47, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[8677, 268, 109, 4, 33, "Subsection"],
Cell[8789, 274, 136, 3, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[8962, 282, 50, 0, 33, "Subsection"],
Cell[9015, 284, 181, 3, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[9233, 292, 48, 0, 33, "Subsection"],
Cell[9284, 294, 141, 2, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[9462, 301, 40, 0, 33, "Subsection"],
Cell[9505, 303, 396, 7, 127, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[9938, 315, 39, 0, 33, "Subsection"],
Cell[9980, 317, 326, 6, 95, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[10355, 329, 60, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[10440, 333, 38, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[10503, 337, 402, 7, 111, "Input"],
Cell[10908, 346, 60764, 1202, 176, 6495, 529, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[71721, 1554, 71, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[71817, 1558, 304, 5, 79, "Input"],
Cell[72124, 1565, 63833, 2156, 186, 24579, 1667, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[136006, 3727, 65, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[136096, 3731, 270, 5, 63, "Input"],
Cell[136369, 3738, 84839, 1801, 186, 12558, 904, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[221257, 5545, 70, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[221352, 5549, 255, 5, 79, "Input"],
Cell[221610, 5556, 32318, 908, 186, 7269, 594, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[253977, 6470, 64, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[254066, 6474, 302, 6, 79, "Input"],
Cell[254371, 6482, 24400, 808, 186, 7196, 591, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[278820, 7296, 52, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[278897, 7300, 338, 6, 95, "Input"],
Cell[279238, 7308, 71234, 2351, 186, 26180, 1790, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[350509, 9664, 376, 7, 95, "Input"],
Cell[350888, 9673, 86343, 1923, 186, 14159, 1027, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[437280, 11602, 30, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[437335, 11606, 113, 2, 47, "Input"],
Cell[437451, 11610, 177069, 5512, 320, 54764, 3999, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[614581, 17129, 72, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[614678, 17133, 38, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[614741, 17137, 402, 7, 111, "Input"],
Cell[615146, 17146, 99578, 1789, 176, 8212, 658, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[714773, 18941, 71, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[714869, 18945, 304, 5, 79, "Input"],
Cell[715176, 18952, 76764, 3035, 186, 38499, 2558, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[791989, 21993, 65, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[792079, 21997, 270, 5, 63, "Input"],
Cell[792352, 22004, 117386, 2464, 186, 17621, 1228, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[909787, 24474, 70, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[909882, 24478, 255, 5, 79, "Input"],
Cell[910140, 24485, 36850, 1069, 186, 8914, 720, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[947039, 25560, 64, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[947128, 25564, 302, 6, 79, "Input"],
Cell[947433, 25572, 28835, 971, 186, 8913, 720, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[976317, 26549, 52, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[976394, 26553, 338, 6, 95, "Input"],
Cell[976735, 26561, 83646, 3324, 186, 41675, 2801, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[1060418, 29890, 376, 7, 95, "Input"],
Cell[1060797, 29899, 121039, 2713, 186, 20800, 1471, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1181885, 32618, 30, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[1181940, 32622, 113, 2, 47, "Input"],
Cell[1182056, 32626, 212977, 7351, 320, 80262, 5709, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1395094, 39984, 66, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[1395185, 39988, 38, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1395248, 39992, 418, 7, 111, "Input"],
Cell[1395669, 40001, 60141, 1195, 176, 6495, 529, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1455859, 41202, 71, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[1455955, 41206, 304, 5, 79, "Input"],
Cell[1456262, 41213, 65098, 2174, 186, 24580, 1669, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1521409, 43393, 65, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[1521499, 43397, 270, 5, 63, "Input"],
Cell[1521772, 43404, 86866, 1836, 186, 12770, 917, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1608687, 45246, 70, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[1608782, 45250, 255, 5, 79, "Input"],
Cell[1609040, 45257, 55989, 1143, 186, 6546, 528, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1665078, 46406, 64, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[1665167, 46410, 302, 6, 79, "Input"],
Cell[1665472, 46418, 39557, 995, 186, 7186, 591, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1705078, 47419, 52, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[1705155, 47423, 338, 6, 95, "Input"],
Cell[1705496, 47431, 75963, 2411, 186, 26179, 1792, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[1781496, 49847, 376, 7, 95, "Input"],
Cell[1781875, 49856, 93686, 2024, 186, 14361, 1040, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1875610, 51886, 30, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[1875665, 51890, 113, 2, 47, "Input"],
Cell[1875781, 51894, 213778, 5921, 320, 54232, 3948, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2089620, 57822, 78, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[2089723, 57826, 38, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2089786, 57830, 418, 7, 111, "Input"],
Cell[2090207, 57839, 100143, 1796, 176, 8210, 658, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2190399, 59641, 71, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[2190495, 59645, 304, 5, 79, "Input"],
Cell[2190802, 59652, 77051, 3042, 186, 38486, 2561, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2267902, 62700, 65, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[2267992, 62704, 270, 5, 63, "Input"],
Cell[2268265, 62711, 118005, 2489, 186, 17936, 1249, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2386319, 65206, 70, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[2386414, 65210, 255, 5, 79, "Input"],
Cell[2386672, 65217, 55880, 1248, 186, 8175, 654, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2442601, 66471, 64, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[2442690, 66475, 302, 6, 79, "Input"],
Cell[2442995, 66483, 51296, 1248, 186, 8905, 720, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2494340, 67737, 52, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[2494417, 67741, 338, 6, 95, "Input"],
Cell[2494758, 67749, 86926, 3368, 186, 41626, 2804, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[2581721, 71122, 376, 7, 95, "Input"],
Cell[2582100, 71131, 126648, 2800, 186, 21099, 1492, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2708797, 73937, 30, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[2708852, 73941, 113, 2, 47, "Input"],
Cell[2708968, 73945, 244884, 7709, 320, 79765, 5667, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2953913, 81661, 79, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[2954017, 81665, 38, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2954080, 81669, 433, 7, 111, "Input"],
Cell[2954516, 81678, 55036, 1132, 176, 6489, 529, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3009601, 82816, 71, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[3009697, 82820, 304, 5, 79, "Input"],
Cell[3010004, 82827, 70425, 2147, 186, 22699, 1553, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3080478, 84980, 65, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[3080568, 84984, 270, 5, 63, "Input"],
Cell[3080841, 84991, 84515, 1756, 186, 11779, 853, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3165405, 86753, 70, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[3165500, 86757, 255, 5, 79, "Input"],
Cell[3165758, 86764, 38988, 988, 186, 7200, 591, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3204795, 87758, 64, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[3204884, 87762, 302, 6, 79, "Input"],
Cell[3205189, 87770, 24400, 808, 186, 7196, 591, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3229638, 88584, 52, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[3229715, 88588, 338, 6, 95, "Input"],
Cell[3230056, 88596, 80291, 2372, 186, 24299, 1676, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[3310384, 90973, 376, 7, 95, "Input"],
Cell[3310763, 90982, 85864, 1875, 186, 13380, 976, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3396676, 92863, 30, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[3396731, 92867, 113, 2, 47, "Input"],
Cell[3396847, 92871, 188288, 5516, 320, 52035, 3831, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3585196, 98394, 102, 3, 59, "Section"],

Cell[CellGroupData[{
Cell[3585323, 98401, 38, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[3585386, 98405, 503, 9, 111, "Input"],
Cell[3585892, 98416, 51095, 1101, 176, 6745, 550, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3637036, 99523, 71, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[3637132, 99527, 304, 5, 79, "Input"],
Cell[3637439, 99534, 73743, 2388, 186, 26564, 1801, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3711231, 101928, 65, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[3711321, 101932, 270, 5, 63, "Input"],
Cell[3711594, 101939, 94673, 2593, 186, 25497, 1734, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3806316, 104538, 70, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[3806411, 104542, 255, 5, 79, "Input"],
Cell[3806669, 104549, 66891, 1281, 186, 6522, 531, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3873609, 105836, 64, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[3873698, 105840, 302, 6, 79, "Input"],
Cell[3874003, 105848, 39768, 998, 186, 7190, 591, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3913820, 106852, 52, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[3913897, 106856, 338, 6, 95, "Input"],
Cell[3914238, 106864, 87353, 2659, 186, 28190, 1924, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[4001628, 109528, 376, 7, 95, "Input"],
Cell[4002007, 109537, 100927, 2773, 186, 27086, 1857, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[4102983, 112316, 30, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[4103038, 112320, 113, 2, 47, "Input"],
Cell[4103154, 112324, 242692, 7048, 320, 68948, 4900, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

